/* eslint-disable consistent-return */
/* eslint-disable react-hooks/exhaustive-deps */

"use client";

import dayjs from "dayjs";
import { useMemo } from "react";
import { z } from "zod";

import Container from "@/components/shared/container";
import { FlightList } from "@/features/flight/components/flight-list/flight-list";
import ScrollToTop from "@/features/scroll-to-top/scroll-to-top";
import TravelPlannerFlightForm from "@/features/travel-planner/components/travel-planner/travel-planner-flight-form";
import { usePageInfo } from "@/hooks/use-page-info";
import { useApp } from "@/hooks/useApp";
import { localeStorageHelper } from "@/libs/helpers/locale-storage-helper";
import { Main } from "@/templates/Main";

const localStorageValueSchema = z.object({
  "departure-date": z.object({
    date: z.string(),
  }),
  "return-date": z
    .object({
      date: z.string(),
    })
    .nullable(),
  origin: z.object({
    id: z.string(),
    value: z.string(),
    type: z.string(),
  }),
  departure: z.object({
    id: z.string(),
    value: z.string(),
    type: z.string(),
  }),
  flightTripKind: z.string(),
  passengers: z.object({
    employee: z
      .object({
        count: z.number(),
      })
      .optional(),
    guest: z.object({
      count: z.number(),
    }),
    child: z.object({
      count: z.number(),
    }),
    cabinType: z.object({
      value: z.string(),
      title: z.string(),
    }),
  }),
});

export default function FlightListPage() {
  const { info, isDone } = usePageInfo();
  const { isB2E } = useApp();

  const defaultValues = useMemo(() => {
    if (isDone) {
      const { queryParams } = info!;

      if (queryParams.flightTripKind) {
        const origin = {
          id: queryParams.originId,
          value: queryParams.originName,
          type: queryParams.originType,
        };
        const departure = {
          id: queryParams.departureId,
          value: queryParams.departureName,
          type: queryParams.departureType,
        };
        const departureDate = {
          date: dayjs(queryParams.departureTime).toISOString(),
        };
        const returnDate = {
          date: dayjs(queryParams.returnTime).toISOString(),
        };
        const { flightTripKind, passenger } = queryParams;
        const cabinType = {
          value: queryParams.cabinClass,
          title: queryParams.cabinClassTitle,
        };
        let passengers: any = {};

        if (!isB2E) {
          const [adultStr, childStr] = `${passenger}`.split(",");

          const guest = {
            count: adultStr ? +adultStr : 0,
          };
          const child = {
            count: childStr ? +childStr : 0,
          };

          passengers = {
            guest,
            child,
            cabinType,
          };
        } else {
          const [employeeStr, adultStr, childStr] = `${passenger}`.split(",");

          const employee = {
            count: employeeStr ? +employeeStr : 0,
          };

          const guest = {
            count: adultStr ? +adultStr : 0,
          };
          const child = {
            count: childStr ? +childStr : 0,
          };

          passengers = {
            employee,
            guest,
            child,
            cabinType,
          };
        }

        const safedTravelPlannerFromUrl = localStorageValueSchema.safeParse({
          origin,
          departure,
          "departure-date": departureDate,
          "return-date": returnDate,
          flightTripKind,
          passengers,
        });

        if (safedTravelPlannerFromUrl.success) {
          const localStorageValue =
            localeStorageHelper.get("travel-planner") ?? {};

          const data = {
            ...localStorageValue,
            ...safedTravelPlannerFromUrl.data,
          };
          localeStorageHelper.set("travel-planner", data);
          return {
            ...data,
            "departure-date": {
              date: dayjs(
                safedTravelPlannerFromUrl.data["departure-date"].date,
              ).toDate(),
            },
            "return-date": {
              date: safedTravelPlannerFromUrl.data["return-date"]
                ? dayjs(
                    safedTravelPlannerFromUrl.data["return-date"].date,
                  ).toDate()
                : undefined,
            },
          };
        }
      }

      const localStorageValue = localeStorageHelper.get("travel-planner");
      const safedLocalStorageValue =
        localStorageValueSchema.safeParse(localStorageValue);
      if (!safedLocalStorageValue.success) {
        return {};
      }

      return {
        ...localStorageValue,
        "departure-date": {
          date: dayjs(localStorageValue?.["departure-date"].date).toDate(),
        },
        "return-date": {
          date: dayjs(localStorageValue?.["return-date"]?.date).toDate(),
        },
      };
    }
  }, [isDone]);

  return (
    <Main>
      <Container>
        <div className="flex flex-col gap-8  py-8">
          {isDone && (
            <TravelPlannerFlightForm hideShadow defaultValues={defaultValues} />
          )}
          <FlightList />
        </div>
      </Container>
      <ScrollToTop />
    </Main>
  );
}
