/* eslint-disable jsx-a11y/alt-text */
/* eslint-disable @next/next/no-img-element */

"use client";

import type { IconType } from "@/components/ui/lucid-icon/lucid-icon";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";

interface ErrorProps {
  message?: string;
  clientConfig?: any;
  noHtml?: boolean;
}

interface ContactLabelProps {
  type: "mailto" | "tel";
  icon?: IconType;
  label: string;
}

const ContactLabel = ({ type, icon, label }: ContactLabelProps) => {
  return (
    <a
      href={`${type}:${label}`}
      className="flex items-center gap-2 overflow-hidden"
    >
      {icon && (
        <LIcon
          className="inline-block align-middle"
          aria-label="phone number"
          name={icon as IconType}
          size={16}
        />
      )}

      <span className="block truncate align-middle">{label}</span>
    </a>
  );
};

const ErrorBody = ({ props }: any) => {
  const ramdomImage = Math.floor(Math.random() * (6 - 1 + 1) + 1);
  return (
    <div className="flex h-screen flex-col bg-white md:flex-row">
      <div className="relative flex h-1/2 w-full flex-col items-center justify-center p-[5vw] md:h-auto">
        <div className="flex flex-col">
          <img
            className="max-w-[50%]"
            src={
              props?.clientConfig?.logoUrl ||
              "/assets/images/errorBoundry/eva.png"
            }
            alt="Eva"
          />
          <h1 className="mt-10 text-4xl font-semibold text-gray-800 lg:!mt-16 lg:!text-6xl landscape:mt-8 landscape:text-4xl lg:landscape:mt-10">
            Hemen dönüyoruz!
          </h1>
          <p className="mt-5 text-2xl text-gray-600 sm:mt-8">
            şu anda sitemiz bakım aşamasında
          </p>
          <p className="mt-10 text-lg text-gray-600 sm:mt-[88px] landscape:hidden lg:landscape:block">
            Anlayışınız için teşekkür ederiz.
          </p>
        </div>
        {props?.clientConfig?.domainProducts && (
          <div className="absolute bottom-0 flex w-full items-center gap-x-6 p-[5vw] text-sm text-gray-700 md:text-base landscape:py-[2vw] lg:landscape:py-[5vw]">
            {props?.clientConfig?.domainProducts![0]?.phone && (
              <ContactLabel
                type="tel"
                icon="Headphones"
                label={props?.clientConfig?.domainProducts![0]?.phone}
              />
            )}
            {props?.clientConfig?.domainProducts![0]?.email && (
              <ContactLabel
                type="mailto"
                icon="Mail"
                label={props?.clientConfig?.domainProducts![0]?.email}
              />
            )}
          </div>
        )}
      </div>
      <div className="image-area h-1/2 w-full md:h-auto">
        <img
          className="size-full object-cover object-center"
          src={`/assets/images/errorBoundry/${ramdomImage}.jpg`}
        />
      </div>
    </div>
  );
};

export const Error = (props: ErrorProps) => {
  const IsHtmlOrDivTag = !props?.noHtml ? "html" : "div";
  return (
    <IsHtmlOrDivTag lang="tr">
      <>
        {!props?.noHtml ? (
          <>
            <head>
              <title>Hata</title>
              <link
                rel="icon"
                href={props?.clientConfig?.faviconUrl}
                type="image/x-icon"
              />
            </head>
            <body className="overflow-hidden">
              <ErrorBody props={props} />
            </body>
          </>
        ) : (
          <div className="overflow-hidden">
            <ErrorBody props={props} />
          </div>
        )}
        <span className="hidden">{props.message}</span>
      </>
    </IsHtmlOrDivTag>
  );
};

export default { Error };
