import type { ValidateResult } from "react-hook-form";

import type { InputProps } from "@/components/ui/input/input";
import type { MaskedInputProps } from "@/components/ui/masked-input/masked-input";
import MaskedInput from "@/components/ui/masked-input/masked-input";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormMaskInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {
  mask: MaskedInputProps["mask"];
  validate?: (value: string) => ValidateResult | Promise<ValidateResult>;
}

const FormMaskInput = ({ name, mask, ...props }: FormMaskInputProps) => {
  return (
    <FormItem name={name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          fullWidth
          defaultValue={field.value}
          onChange={(value) => setValue(value)}
          onChangeUnMasked={(value) => setValue(value)}
          onBlur={field.onBlur}
          mask={mask}
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormMaskInput;
