import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import { Input, type InputProps } from "@/components/ui/input/input";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormTextInputProps extends FormItemProps, Omit<InputProps, "name"> {}

const FormTextInput = ({ name, rules, ...props }: FormTextInputProps) => {
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={rules}>
      {({ field, fieldState }) => (
        <Input
          {...props}
          {...field}
          errorMessage={fieldState.error?.message}
          isInvalid={Boolean(fieldState.error)}
        />
      )}
    </FormItem>
  );
};

export default FormTextInput;
