import type { TextareaHTMLAttributes } from "react";

import { cn } from "@/libs/utils";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormTextAreaInputProps
  extends Omit<TextareaHTMLAttributes<HTMLTextAreaElement>, "name">,
    FormItemProps {}

const FormTextAreaInput = ({
  name,
  rules,
  ...props
}: FormTextAreaInputProps) => {
  return (
    <FormItem name={name} rules={rules}>
      {({ field, fieldState }) => {
        return (
          <div>
            <textarea
              className={cn(
                "w-full resize-none rounded-primary border p-3 text-sm shadow-sm outline-none placeholder:text-gray-500 focus:border-primary-200 focus:ring-1 focus:ring-primary-50",
                {
                  "!border-red-500": !!fieldState.error?.message,
                },
              )}
              {...props}
              {...field}
            />
            {fieldState.error?.message && (
              <div className="w-full text-sm text-red-500">
                {fieldState.error?.message}
              </div>
            )}
          </div>
        );
      }}
    </FormItem>
  );
};

export default FormTextAreaInput;
