import { useBoolean } from "usehooks-ts";

import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import TimePicker from "@/components/widget/time-picker/time-picker";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormTimePickerProps extends Omit<FormItemProps, "children"> {
  label?: string;
}

const FormTimePicker = ({ label, ...props }: FormTimePickerProps) => {
  const popoverBoolean = useBoolean();
  return (
    <FormItem {...props}>
      {({ field, fieldState }) => (
        <Popover
          open={popoverBoolean.value}
          onOpenChange={popoverBoolean.setValue}
        >
          <PopoverTrigger>
            <div className="w-full">
              <TriggerButton
                size="lg"
                fullWidth
                label={label ?? "Saat Seçin"}
                value={field.value}
                isFocus={popoverBoolean.value}
                isInvalid={!!fieldState.error}
              />
              {fieldState.error && (
                <div className="mt-1 w-full text-left text-sm text-red-500">
                  {fieldState.error?.message}
                </div>
              )}
            </div>
          </PopoverTrigger>
          <PopoverContent className="scroll-bar -ml-6 max-h-[300px] py-0">
            <TimePicker
              endTime="23:59"
              startTime="00:00"
              onChange={(value) => {
                field.onChange(value);
                popoverBoolean.setFalse();
              }}
              placeholder="Time Picker"
              rangeMinute={30}
              value={field.value}
            />
          </PopoverContent>
        </Popover>
      )}
    </FormItem>
  );
};

export default FormTimePicker;
