import { useEffect } from "react";
import { useFormContext } from "react-hook-form";
import { useDebounceCallback } from "usehooks-ts";

import type { InputProps } from "@/components/ui/input/input";
import MaskedInput from "@/components/ui/masked-input/masked-input";
import { checkDateOfBirth } from "@/validations/form-rules/rules/date-of-birth-rule";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormBirthDateInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {}

const FormBirthDateInput = ({
  name,
  rules,
  ...props
}: FormBirthDateInputProps) => {
  const methods = useFormContext();

  const handleValue = useDebounceCallback((value: string) => {
    methods.setValue(name, value);
  }, 500);

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      handleValue("");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={{ ...rules, validate: checkDateOfBirth }}>
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          defaultValue={field.value}
          onChange={(value) => setValue(value)}
          mask="date"
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          onBlur={field.onBlur}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormBirthDateInput;
