import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { cn } from "@/libs/utils";
import { useCountriesQuery } from "@/services/white-label/location/countries.services";
import type { CountriesListType } from "@/services/white-label/location/location.services.types";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormCountrySelectProps extends Omit<FormItemProps, "children"> {
  placeholder?: string;
  onChange?: (countryId: number) => void;
}

const FormCountrySelect = ({ name, ...props }: FormCountrySelectProps) => {
  const countriesQuery = useCountriesQuery();
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <div>
          <Select
            value={
              countriesQuery.data?.result.find(
                (x) => x.name === field.value?.name,
              )?.name
            }
            onValueChange={(itemName) => {
              const item = countriesQuery.data?.result.find(
                (x) => x.name === itemName,
              );

              if (item) {
                setValue(item);
                if (props?.onChange) props?.onChange(item.id);
              }
            }}
            defaultValue={field.value}
          >
            <SelectTrigger
              className={cn(
                "h-[52px] rounded-primary border border-gray-200 bg-white py-6 shadow-xs",
                {
                  "border-error-500": fieldState.error,
                },
              )}
            >
              <SelectValue
                defaultValue={field.value}
                placeholder={props.placeholder}
              />
            </SelectTrigger>
            <SelectContent className="scroll-bar max-h-[200px] text-sm text-gray-500">
              {countriesQuery.data?.result
                .filter((item, index) => {
                  const isExist = countriesQuery.data?.result.findIndex(
                    (x) => x.name === item.name,
                  );
                  return isExist === index;
                })
                .reduce((acc: CountriesListType[], item) => {
                  if (item.id === 277) {
                    acc.unshift(item);
                  } else {
                    acc.push(item);
                  }
                  return acc;
                }, [])
                .map((item) => (
                  <SelectItem
                    key={`${item.name}-${item.id}`}
                    className="cursor-pointer px-3.5"
                    value={item.name.toString()}
                  >
                    {item.name}
                  </SelectItem>
                ))}
            </SelectContent>
          </Select>
          {fieldState.error && (
            <div className="mt-1">
              <span className="text-sm text-error-500">
                {fieldState.error?.message}
              </span>
            </div>
          )}
        </div>
      )}
    </FormItem>
  );
};

export default FormCountrySelect;
