import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import type { InputProps } from "@/components/ui/input/input";
import { Input } from "@/components/ui/input/input";
import { checkEmail } from "@/validations/form-rules/rules/mail-rules";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormEmailInputProps extends FormItemProps, Omit<InputProps, "name"> {}

const FormEmailInput = ({ name, rules, ...props }: FormEmailInputProps) => {
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={{ ...rules, validate: checkEmail }}>
      {({ field, fieldState }) => (
        <Input
          {...props}
          {...field}
          errorMessage={fieldState.error?.message}
          isInvalid={Boolean(fieldState.error)}
        />
      )}
    </FormItem>
  );
};

export default FormEmailInput;
