import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import {
  RadioGroup,
  RadioGroupItem,
} from "@/components/ui/radio-button/radio-group";
import { useLocale } from "@/hooks/useLocale";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormGenderRadioProps extends FormItemProps {}

const FormGenderRadio = ({ name, rules }: FormGenderRadioProps) => {
  const { t } = useLocale();
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={rules}>
      {({ field, fieldState, setValue }) => (
        <div>
          <RadioGroup
            defaultValue={field.value}
            value={field.value}
            onValueChange={(value) => setValue(value)}
            className="flex gap-2"
            id={name}
          >
            <RadioGroupItem value="1" id={name + 1} label={t("Female")} />
            <RadioGroupItem value="0" id={name + 0} label={t("Male")} />
          </RadioGroup>
          <span className="text-sm text-red-500">
            {fieldState.error && fieldState.error.message}
          </span>
        </div>
      )}
    </FormItem>
  );
};

export default FormGenderRadio;
