import { useEffect } from "react";
import { useFormContext, type ValidateResult } from "react-hook-form";

import type { InputProps } from "@/components/ui/input/input";
import MaskedInput from "@/components/ui/masked-input/masked-input";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormIdentityInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {
  validate?: (value: string) => ValidateResult | Promise<ValidateResult>;
}

const FormIdentityInput = ({ name, ...props }: FormIdentityInputProps) => {
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          defaultValue={field.value}
          onChange={(value) => setValue(value)}
          onBlur={field.onBlur}
          mask="identity"
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormIdentityInput;
