/* eslint-disable react-hooks/rules-of-hooks */

import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { cn } from "@/libs/utils";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

type LocalizationFormItemData = {
  name: string;
  value: string;
};
interface FormCitiesSelectProps extends Omit<FormItemProps, "children"> {
  placeholder?: string;
  data: LocalizationFormItemData[];
  defaultValue?: string;
}

const FormLocatizationSelect = (props: FormCitiesSelectProps) => {
  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <div className="w-full">
          <Select
            value={field.value}
            onValueChange={(item) => {
              if (item) setValue(item);
            }}
            defaultValue={props.defaultValue}
          >
            <SelectTrigger
              className={cn(
                "h-[44px]  rounded-primary border border-gray-200 bg-white py-2 shadow-xs",
                {
                  "border-error-500": fieldState.error,
                },
              )}
            >
              <SelectValue
                defaultValue={props.defaultValue}
                placeholder={props.placeholder}
              />
            </SelectTrigger>
            <SelectContent className="scroll-bar max-h-[200px] text-sm text-gray-500">
              {props.data?.map((item) => (
                <SelectItem
                  key={item.name}
                  className="cursor-pointer px-3.5"
                  value={item.value}
                >
                  {item.name}
                </SelectItem>
              ))}
            </SelectContent>
          </Select>
          {fieldState.error && (
            <div className="mt-1">
              <span className="text-sm text-error-500">
                {fieldState.error?.message}
              </span>
            </div>
          )}
        </div>
      )}
    </FormItem>
  );
};

export default FormLocatizationSelect;
