import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import type { InputProps } from "@/components/ui/input/input";
import MaskedInput from "@/components/ui/masked-input/masked-input";
import { checkPassportDate } from "@/validations/form-rules/rules/passport-date-rule";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormPassportDateInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {}

const FormPassportDateInput = ({
  name,
  rules,
  ...props
}: FormPassportDateInputProps) => {
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem name={name} rules={{ ...rules, validate: checkPassportDate }}>
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          defaultValue={field.value}
          onChange={(value) => setValue(value)}
          mask="date"
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          onBlur={field.onBlur}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormPassportDateInput;
