import { useEffect } from "react";
import { useFormContext } from "react-hook-form";

import { type InputProps } from "@/components/ui/input/input";
import MaskedInput from "@/components/ui/masked-input/masked-input";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

import type { FormItemProps } from "../../form-item";
import FormItem from "../../form-item";

interface FormPassportInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {}

const FormPassportNoInput = ({
  name,
  rules,
  ...props
}: FormPassportInputProps) => {
  const methods = useFormContext();

  useEffect(() => {
    if (!methods.getValues(`${name}`)) {
      methods.setValue(`${name}`, "");
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <FormItem
      name={name}
      rules={{
        ...rules,
        required: requiredRule,
        validate: (value) => {
          const pasaportRegex = /.*[\W_]+/;
          if (value > 50)
            return "Pasaport numarası 50 karakterden fazla olamaz";

          if (pasaportRegex.test(value)) {
            return "Sadece harf ve sayı girebilirsiniz";
          }
          return true;
        },
      }}
    >
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          mask="passport"
          defaultValue={field.value}
          onChange={(value) => {
            setValue(value);
          }}
          onBlur={field.onBlur}
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormPassportNoInput;
