import type {
  FieldValues,
  Path,
  RegisterOptions,
  UseControllerReturn,
} from "react-hook-form";
import { useController, useFormContext } from "react-hook-form";

interface Props<T extends FieldValues = FieldValues> {
  name: Path<T>;
  rules?: Omit<
    RegisterOptions<FieldValues, Path<T>>,
    "valueAsNumber" | "valueAsDate" | "setValueAs" | "disabled"
  >;
  children: (
    controller: UseControllerReturn<FieldValues, Path<T>> & {
      setValue: (value: any) => void;
    },
  ) => any;
}

function FormItem<T extends FieldValues = FieldValues>(props: Props<T>) {
  const formMethods = useFormContext();
  const controller = useController({
    name: props.name,
    control: formMethods.control,
    rules: props.rules,
  });
  return props.children({
    ...controller,
    setValue(value) {
      controller.field.onChange(value);
    },
  });
}

export type FormItemProps = Omit<Props, "children">;
export default FormItem;
