"use client";

import { AddonProductTypeEnum } from "@/@types/enums/addon-product-type.enum";
import type { IClientDomainAddonResponse } from "@/server/services/addon.services";

import FlightPageContent from "./flight-page-content";
import HotelPageContent from "./hotel-page-content";
import RentCarPageContent from "./rentcar-page-content";
import TourPageContent from "./tour-page-content";
import TransferPageContent from "./transfer-page-content";

interface DefaultPageByAddondsProps {
  appAddons: IClientDomainAddonResponse[];
}

function DefaultPageByAddonds(props: DefaultPageByAddondsProps) {
  function hasAddonInApp(addonProductTypeCode: AddonProductTypeEnum) {
    if (props.appAddons) {
      return !!props.appAddons.some((x) =>
        x?.Addon?.ProductTypes?.some((y) => y.Code === addonProductTypeCode),
      );
    }

    return false;
  }

  const renderDefaultPageAtHomePage = (): JSX.Element => {
    if (hasAddonInApp(AddonProductTypeEnum.Flight)) {
      return <FlightPageContent />;
    }
    if (hasAddonInApp(AddonProductTypeEnum.Hotel)) {
      return <HotelPageContent />;
    }
    if (hasAddonInApp(AddonProductTypeEnum.Tour)) {
      return <TourPageContent />;
    }
    if (hasAddonInApp(AddonProductTypeEnum.CarRental)) {
      return <RentCarPageContent />;
    }
    if (hasAddonInApp(AddonProductTypeEnum.Transfer)) {
      return <TransferPageContent />;
    }
    return <HotelPageContent />;
  };

  return renderDefaultPageAtHomePage();
}

export default DefaultPageByAddonds;
