"use client";

import type { PropsWithChildren } from "react";

import MainContent from "@/layouts/main-layout/main-content";
import type { IClientConfiguration } from "@/models/client-configs.model";
import CoreProvider from "@/providers/core-provider/core-provider";
import { ErrorBoundary } from "@/providers/error-boundary/error-boundary";
import { InitializeProvider } from "@/providers/initialize-provider/initialize-provider";
import { LocalizationProvider } from "@/providers/localization-provider/localization-provider";
import QueryProvider from "@/providers/query-provider/QueryProvider";
import { ServerDataProvider } from "@/providers/server-data-provider/server-data-provider";
import StoreProvider from "@/providers/store-provider/StoreProvider";
import ThemeProvider from "@/providers/theme-provider/ThemeProvider";
import type { IPathResponse } from "@/server/services/path.services";
import type { StrategyKeysTypes } from "@/services/app-api/apis/strategy.services";
import { Main } from "@/templates/Main";

import Footer from "../footer/Footer";
import FooterB2C from "../footer/Footer-b2c";
import FooterOtel from "../footer/Footer-otel";
import Header from "../header/Header";
import Loader from "../loader/Loader";
import NotifyDialogControl from "../notify-dialog/notify-dialog-control";
import Overlay from "../overlay/overlay";

interface PageWrapperProps extends PropsWithChildren {
  clientToken: string;
  strategyKeys: Record<string, string>;
  clientConfig: IClientConfiguration;
  appAddons: any;
  authTokenInfo: any;
  languages: any;
  currency: any;
  appData: any;
  pathValue?: IPathResponse;
}

function PageWrapper(props: PageWrapperProps) {
  return (
    <ErrorBoundary>
      <ServerDataProvider
        clientToken={props.clientToken}
        strategyKeys={props.strategyKeys as unknown as StrategyKeysTypes}
        clientConfig={{
          ...props.clientConfig,
          properties: {
            ...props.clientConfig.properties,
            borderRadius:
              props.pathValue?.result?.visual?.style.borderRadius ??
              props.clientConfig?.properties.borderRadius,
            fontFamily:
              props.pathValue?.result?.visual?.style.fontFamily ??
              props.clientConfig?.properties.fontFamily,
            fontSize:
              props.pathValue?.result?.visual?.style.fontSize ??
              props.clientConfig?.properties.fontSize,
            color:
              props.pathValue?.result?.visual?.style.color ??
              props.clientConfig?.properties.color,
          },
        }}
        addonList={props.appAddons}
        pathValue={props.pathValue}
      >
        <StoreProvider
          authTokenInfo={props.authTokenInfo}
          localizationData={{
            language: props.languages?.value ?? "tr",
            currency: props.currency?.value ?? "TRY",
          }}
          appData={props.appData}
        >
          <QueryProvider>
            <LocalizationProvider lang={props.languages?.value ?? "tr"}>
              <ThemeProvider>
                <InitializeProvider>
                  <CoreProvider>
                    <Main>
                      <div>
                        <Overlay />
                        <Loader />
                      </div>
                      <Header />
                      <MainContent>{props.children}</MainContent>
                      <NotifyDialogControl />
                      {props.appData.strategy === "B2C" && <FooterB2C />}
                      {props.appData.strategy === "Corporate" && <Footer />}
                      {props.appData.strategy === "Otel" && <FooterOtel />}
                    </Main>
                  </CoreProvider>
                </InitializeProvider>
              </ThemeProvider>
            </LocalizationProvider>
          </QueryProvider>
        </StoreProvider>
      </ServerDataProvider>
    </ErrorBoundary>
  );
}

export default PageWrapper;
