import type { VariantProps } from "class-variance-authority";
import { cva } from "class-variance-authority";
import React from "react";

import { cn } from "@/libs/utils";

import type { IconType } from "./icon.types";

const iconVariants = cva(undefined, {
  variants: {
    size: {
      sm: "text-sm",
      md: "text-base",
      lg: "text-lg",
      xl: "text-xl",
      "2xl": "text-2xl",
    },
  },
  defaultVariants: {
    size: "md",
  },
});

export interface IconProps extends VariantProps<typeof iconVariants> {
  name: IconType;
}

const Icon = ({ name, size }: IconProps) => {
  return <i className={cn(`icon-${name}`, iconVariants({ size }))} />;
};

export default Icon;
