/* eslint-disable no-nested-ternary */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Image from "next/image";
import Link from "next/link";
import React from "react";
import { useMediaQuery } from "usehooks-ts";

import NoImage from "@/assets/svg/images/no-image.svg";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import type { STextProps } from "@/components/ui/status-text/status-text";
import { StatusText } from "@/components/ui/status-text/status-text";
import BookingRequest from "@/components/widget/request-card/booking-request-card/booking-request-card";
import BookingRequestCardDetailConfirmRejectDeniedButtonList from "@/features/booking-request/components/booking-request-card-detail/booking-request-card-detail-button-list";
import PermGuard from "@/features/permission/components/perm-guard";
import { JsonParserHelper } from "@/libs/helpers/string-to-json-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type { CorpRequestHistories } from "@/models/booking-request.model";
import type { CancelReasonItem } from "@/services/eva-display/book-cancel-reason/booking-cancel-reason-service.types";
import type { IBookingRequestItem } from "@/services/eva-display/demand/demand-service.types";
import type {
  IDisplayInformations,
  ISearchRequest,
} from "@/services/eva-display/demand/display-information/display-information";
import type { IPassengerInformation } from "@/services/eva-display/demand/passenger-information/passenger-information";
import type {
  IReservationData,
  IRoom,
} from "@/services/eva-display/demand/reservation-data/reservation-data";
import { requestApprovalAllowPerm } from "@/validations/permissions/request-approval";

import styles from "./booking-request-card-detail.module.css";

export interface ReactQueryReturnProps {
  error: null;
  failureCount: number;
  isPaused: boolean;
  status: string;
  isLoading: boolean;
  isSuccess: boolean;
  isError: boolean;
  isIdle: boolean;
}

interface BookingRequestCardDetailProps {
  id: number;
  className?: string;
  status: STextProps["status"];
  data: IBookingRequestItem;
  displayInformations: IDisplayInformations;
  reservationData: IReservationData;
  passengerInformations: IPassengerInformation[];
  searchRequest: ISearchRequest;
  onAccept: () => void;
  onReject: () => void;
  onDenied: () => void;
  bookingRequestStatusMutation: ReactQueryReturnProps;
  cancelReasonData: CancelReasonItem[];
  setRejectSelectValue: (e: { value: string; name: string }) => void;
  rejectSelectValue: {
    value: string;
    name: string;
  };
  corpRequestHistories: CorpRequestHistories[];
}

export function Undefined() {
  return <small className="text-error-400">bulunamadı</small>;
}

export function JoinItems({ ...items }: any) {
  return Object.values(items).join(" ");
}

function BookingRequestCardDetail({
  id,
  className,
  status,
  data,
  displayInformations,
  reservationData,
  passengerInformations,
  onAccept,
  onReject,
  onDenied,
  bookingRequestStatusMutation,
  searchRequest,
  cancelReasonData,
  setRejectSelectValue,
  rejectSelectValue,
  corpRequestHistories,
}: BookingRequestCardDetailProps) {
  const isDesktop = useMediaQuery("(min-width: 768px)");

  const location = reservationData?.SearchResponse?.Items
    ? reservationData?.SearchResponse?.Items[0]?.Location
    : null;

  const searchData = JsonParserHelper.jsonParseOrUndefined(
    searchRequest as unknown as string,
  );

  const format = "DD MMM";
  const RoomCollectionResult =
    reservationData.DetailResponse?.RoomCollectionResult;

  const hotelImage =
    reservationData.SearchResponse!.Items &&
    reservationData.SearchResponse!.Items[0]?.Images?.[0]?.Url;

  const itemTotalPrice = data?.totalPrice!.toFixed(2);

  const errorStatusText = corpRequestHistories?.find(
    (item: CorpRequestHistories) => item.newStatus === data.requestStatus,
  );

  return (
    <div className={cn(styles.container, className, "group")}>
      <div className={styles.wrapper}>
        <Link
          href="/booking-request"
          className="mr-auto flex items-center gap-1.5 text-primary-500"
        >
          <LIcon name="ArrowLeft" size={18} />
          <span className="font-base font-medium">Geri Dön</span>
        </Link>
        <h1 className="text-xl font-semibold md:text-3xl">
          {`${location && location.split(",")[0]}${
            data?.travelReasonName ? ` ${data?.travelReasonName}` : ""
          } Seyahati`}
          <p className="mt-1 text-sm font-normal text-gray-500 md:mt-2.5 md:text-base">
            {dayjs.utc(data?.createDate).format("DD MMMM YYYY (HH:mm)")}{" "}
            tarihinde oluşturuldu.
          </p>
        </h1>

        <Card className="p-4 shadow-lg md:p-8">
          <div className="flex flex-col md:justify-between lg:flex-row lg:items-center">
            <div className="flex flex-col gap-5">
              <div>
                <p className="mb-2.5 font-medium text-gray-500">Onay Durumu</p>
                <StatusText
                  status={status}
                  text={`${dayjs
                    .utc(data.updateDate)
                    .format("DD MMMM YYYY (hh:mm A)")} tarihinde ${
                    data.updatedByUserName
                      ? `${
                          errorStatusText?.createdByFullName
                            ? errorStatusText?.createdByFullName
                            : data.updatedByUserName
                        } tarafindan`
                      : ``
                  } ${
                    status === "denied"
                      ? "Reddedildi"
                      : status === "error"
                        ? "iptal edildi"
                        : "onaylandı"
                  }.`}
                />
              </div>
              {status === "denied" && errorStatusText?.description && (
                <div>
                  <p className="mb-2.5 font-medium text-gray-500">
                    Reddedilme Nedeni
                  </p>
                  <p className="text-base text-gray-800">
                    {errorStatusText?.description}
                  </p>
                </div>
              )}
            </div>
            <BookingRequestCardDetailConfirmRejectDeniedButtonList
              status={status}
              createdByUserId={data.createdByUserId}
              bookingRequestStatusMutation={bookingRequestStatusMutation}
              onAccept={onAccept}
              onReject={onReject}
              onDenied={onDenied}
              cancelReasonData={cancelReasonData}
              setRejectSelectValue={(value) => setRejectSelectValue(value)}
              rejectSelectValue={rejectSelectValue}
            />
          </div>
        </Card>
        <Card className="p-4 md:p-8">
          <h2 className={cn(styles.title, "mb-4 text-lg")}>
            Rezervasyon Bilgileri
          </h2>
          <div className="grid grid-cols-2 gap-x-2 gap-y-3 md:grid-cols-3 lg:grid-cols-5">
            <div className={styles.rowCell}>
              <p className="font-medium text-gray-500">Seyahat Yeri</p>
              <p className="mt-1">
                {location || searchData?.DestinationName || Undefined()}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className="font-medium text-gray-500">Giriş-Çıkış Tarihleri</p>
              <p className="mt-1">
                {dayjs(
                  displayInformations?.CheckInDate || searchData.CheckInDate,
                ).format(format)}{" "}
                -{" "}
                {dayjs(
                  displayInformations?.CheckOutDate || searchData.CheckOutDate,
                ).format(format)}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className="font-medium text-gray-500">Seyahat Nedeni</p>
              <p className="mt-1">
                {data?.travelReasonName ? data?.travelReasonName : "-"}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className="font-medium text-gray-500">Toplam Tutar</p>
              <p className="mt-1">
                {PriceManager({
                  currency:
                    reservationData.SearchResponse.Items[0]?.TotalPrice.slice(
                      0,
                      3,
                    ) as string,
                  value: +itemTotalPrice,
                })}
              </p>
            </div>
          </div>
        </Card>
        <Card className="p-4 md:p-8">
          <div className="mb-4 flex items-center justify-between">
            <h2 className={cn(styles.title, "text-lg")}>Otel Bilgileri</h2>
            <PermGuard permission={requestApprovalAllowPerm}>
              {status === "warning" && isDesktop && (
                <Link href={`/booking-request-hotel-change?id=${id}`}>
                  <Button variant="outline-primary">Otel Değiştir</Button>
                </Link>
              )}
            </PermGuard>
          </div>
          <div className="flex flex-row gap-4">
            <div className={styles.imageBox}>
              {hotelImage ? (
                <img
                  src={hotelImage}
                  className={styles.image}
                  alt="cardAltText"
                />
              ) : (
                <Image src={NoImage} alt="No picture image" />
              )}
            </div>
            <div className="flex flex-col items-start gap-2">
              <h2 className={cn(styles.title, "text-lg")}>
                {displayInformations?.HotelName || Undefined()}
              </h2>
              <p className="text-sm text-gray-500">
                {location || searchData?.DestinationName || Undefined()}
              </p>

              <Button
                variant="primary-text"
                className="!hidden !h-auto !p-0 text-primary-500"
                rightIcon={{ name: "ChevronRight", size: 20 }}
              >
                Detaylı Bilgi
              </Button>
            </div>
          </div>
          <PermGuard permission={requestApprovalAllowPerm}>
            {status === "warning" && !isDesktop && (
              <div className="mt-6">
                <Link href={`/booking-request-hotel-change?id=${id}`}>
                  <Button variant="outline-primary" className="w-full">
                    Otel Değiştir
                  </Button>
                </Link>
              </div>
            )}
          </PermGuard>
        </Card>
        <Card className="p-4 md:p-8">
          <div className="flex items-center justify-between">
            <h2 className={cn(styles.title, "text-lg")}>Oda ve Kişi Bilgisi</h2>
            <Button className="!hidden" variant="outline-primary">
              Oda Değiştir
            </Button>
          </div>
          <p className={cn(styles.subTitle, "-mt-1")}>
            {`${searchData?.Rooms?.length || Undefined()} oda, ${
              Object.values(passengerInformations)?.length || Undefined()
            } kişi`}
          </p>
          {RoomCollectionResult?.map((_roomGroup) => (
            <div key={_roomGroup.RoomId}>
              {_roomGroup.Rooms.map((_room: IRoom) => (
                <div key={_room.Key}>
                  <div
                    className="mt-5 flex items-center gap-3"
                    key={_roomGroup.RoomId}
                  >
                    <div className={styles.thumbImgWrapper}>
                      {_roomGroup.Images?.[0]?.Url ? (
                        <img
                          src={_roomGroup.Images?.[0]?.Url}
                          className={styles.image}
                          alt="cardAltText"
                        />
                      ) : (
                        <Image src={NoImage} alt="No picture image" />
                      )}
                    </div>
                    <div className="flex flex-col">
                      <p className="text-sm font-semibold">
                        {_roomGroup.Title || Undefined()} (
                        {`${_room?.PassengerKeys.length} Kişi`})
                      </p>
                      {!!_room.MealType && !!_room.MealType.Description && (
                        <div className="mt-1 flex items-center gap-4">
                          <div
                            key={_room.Key}
                            className="flex items-center gap-1 text-gray-500"
                          >
                            <LIcon name="UtensilsCrossed" size="14" />
                            <p className="text-sm">
                              {_room.MealType.Description}
                            </p>
                          </div>
                        </div>
                      )}
                    </div>
                  </div>
                  {passengerInformations
                    ? Object.values(passengerInformations)
                        .filter((p) => _room?.PassengerKeys.includes(p.Key))
                        .map((passanger) => {
                          let phoneNumber;
                          if (passanger?.PhoneNumbers) {
                            phoneNumber = JoinItems([
                              passanger?.PhoneNumbers[0]?.CountryCode,
                              passanger?.PhoneNumbers[0]?.AreaCode,
                              passanger?.PhoneNumbers[0]?.Number,
                            ]);
                          }

                          return (
                            <div
                              key={passanger.Key}
                              className={cn(
                                styles.tableBox,
                                "mt-4 pb-4 border-b last:border-b-0",
                              )}
                            >
                              <div className={styles.rowCell}>
                                <p className={styles.heading}>Ad Soyad</p>
                                <p
                                  className="mt-1 truncate"
                                  title={`${passanger?.Name} ${passanger?.Surname}`}
                                >
                                  {passanger?.Name || Undefined()}{" "}
                                  {passanger?.Surname}
                                </p>
                              </div>
                              <div className={styles.rowCell}>
                                <p className={styles.heading}>Doğum Tarihi</p>
                                <p className="mt-1">
                                  {dayjs(passanger?.Birthday).format(
                                    "DD.MM.YYYY",
                                  )}
                                </p>
                              </div>
                              <div className={styles.rowCell}>
                                <p className={styles.heading}>
                                  Telefon Numarası
                                </p>
                                <p className="mt-1">
                                  {`+${phoneNumber}` || <Undefined />}
                                </p>
                              </div>
                              <div className={styles.rowCell}>
                                <p className={styles.heading}>E-posta</p>
                                <p
                                  className="mt-1 truncate"
                                  title={passanger?.Email}
                                >
                                  {passanger?.Email || <Undefined />}
                                </p>
                              </div>
                            </div>
                          );
                        })
                    : Undefined()}
                </div>
              ))}
            </div>
          ))}
        </Card>

        {reservationData.ReservationNote && (
          <Card className="p-4 md:p-8">
            <div className="flex items-center justify-between">
              <h2 className={cn(styles.title, "text-lg")}>Not</h2>
            </div>
            <div className="mt-3 text-gray-500">
              {reservationData.ReservationNote}
            </div>
          </Card>
        )}
        {reservationData.ProjectCode && (
          <Card className="p-4 md:p-8">
            <div className="flex items-center justify-between">
              <h2 className={cn(styles.title, "text-lg")}>Fatura Notu</h2>
            </div>
            <div className="mt-3 text-gray-500">
              {reservationData.ProjectCode}
            </div>
          </Card>
        )}

        {displayInformations?.Approvers &&
          displayInformations?.Approvers.length > 0 && (
            <Card className="p-8">
              <div className="flex items-center justify-between">
                <h2 className={cn(styles.title, "text-lg")}>
                  Onaylayacak Kişiler
                </h2>
              </div>
              <div className="mt-3 text-gray-500">
                {displayInformations.Approvers.map(
                  (item) => item.FullName,
                ).join(", ")}
              </div>
            </Card>
          )}
        <Card className="hidden p-4 md:p-8">
          <BookingRequest.Note
            className="bg-white"
            description="Lorem ipsum dolor sit amet lorem ipsum amet"
          />
        </Card>
      </div>
    </div>
  );
}

export default BookingRequestCardDetail;
