/* eslint-disable @next/next/no-img-element */
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  EarlyBookingDiscount,
  HotelDiscountPrice,
  HotelPrice,
  HotelRezervationSummaryRoomInfo,
  RezervationSummaryDivider,
  RezervationSummaryProvider,
  RezervationSummaryTitle,
  RezervationSummaryTotalPrice,
} from "@/components/widget/rezervation-summary/rezervation-summary";
import { rooomData } from "@/data/dummy/room-card";
import { cn } from "@/libs/utils";

import styles from "./booking-request-flight-change-confirmation-step.module.css";

const cardImg =
  "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100";

const BookingRequestFlightChangeConfirmationStep = () => {
  return (
    <div className="flex flex-col gap-6">
      <Card className="p-8">
        <div className="mb-4 flex items-center justify-between">
          <h2 className={cn(styles.title, "text-lg")}>Otel Bilgileri</h2>
          <Button variant="outline-primary">Otel Değiştir</Button>
        </div>
        <div className="flex flex-row gap-4">
          <div className={styles.imageBox}>
            <img className="size-full object-cover" src={cardImg} alt="pic" />
          </div>
          <div className="flex flex-col items-start gap-2">
            <h2 className={cn(styles.title, "text-lg")}>Trilye Resort</h2>
            <p className="text-sm text-gray-500">Antalya / Lara / Kundu</p>

            <Button
              variant="primary-text"
              className="!h-auto !p-0 text-primary-500"
              rightIcon={{ name: "ChevronRight", size: 20 }}
            >
              Detaylı Bilgi
            </Button>
          </div>
        </div>
      </Card>

      <Card className="p-8">
        <div className="flex items-center justify-between">
          <h2 className={cn(styles.title, "text-lg")}>Oda ve Kişi Bilgisi</h2>
          <Button className="!hidden" variant="outline-primary">
            Oda Değiştir
          </Button>
        </div>
        <p className={cn(styles.subTitle, "-mt-1")}>1 oda, 2 kişi</p>

        <div className="mt-5 flex items-center gap-3">
          <div className={styles.thumbImgWrapper}>
            <img
              className={styles.image}
              src={rooomData[0] && rooomData[0].images[0]?.url}
              alt="pic"
            />
          </div>
          <div className="flex flex-col">
            <p className="text-sm font-semibold">
              Standart Room, 1 Double Bed, Sea view, Balcony
            </p>
            <div className="mt-1 flex items-center gap-4">
              <div className="flex items-center gap-1 text-gray-500">
                <LIcon name="UtensilsCrossed" size="14" />
                <p className="text-sm">Oda Kahvaltı</p>
              </div>
              <div className="flex items-center gap-1 text-gray-500">
                <LIcon name="UtensilsCrossed" size="14" />
                <p className="text-sm">Geri Ödemesiz</p>
              </div>
            </div>
          </div>
        </div>
      </Card>

      <RezervationSummaryProvider>
        <RezervationSummaryTitle title="Fiyat Özeti" />
        <RezervationSummaryDivider />
        <HotelRezervationSummaryRoomInfo
          title="1. Deluxe King Room, 1 King Bed, Sea view, Balcony"
          passengerDescription="2 yetişkin"
          mealDescription="Ultra herşey dahil"
        >
          <HotelPrice
            nightlyRateDescription="9 Gece"
            discount
            discountDescription="%30 İndirim"
            price="7500TL"
          />
          <HotelDiscountPrice price="6200TL" />
        </HotelRezervationSummaryRoomInfo>
        <RezervationSummaryDivider />
        <EarlyBookingDiscount price="600TL" title="Erken Rezervasyon" />
        <RezervationSummaryDivider />
        <RezervationSummaryTotalPrice price="7800TL" />
      </RezervationSummaryProvider>

      <Card className="flex flex-col gap-4 p-8">
        <h3 className="text-xl font-semibold">Notunuz var mı?</h3>
        <textarea rows={7} placeholder="Talep değiştirme nedeninizi yazın." />
      </Card>

      <Card className="mb-5 flex items-center justify-between gap-2 px-8 py-6 shadow-lg">
        <div>
          <p className="font-medium text-gray-500">Toplam Tutar</p>
          <p className="text-lg font-semibold">7800 TL</p>
        </div>
        <div className="flex gap-2">
          <Button variant="outline">Vazgeç</Button>
          <Button variant="primary">Değiştir ve Onayla</Button>
        </div>
      </Card>
    </div>
  );
};

export default BookingRequestFlightChangeConfirmationStep;
