import React, { useState } from "react";

import { Button } from "@/components/ui/button/button";
import {
  FlightBrand,
  FlightCard,
  FlightDetail,
  FlightDetailAction,
  FlightDetailCard,
  FlightInformation,
  FlightPrice,
  FlightTime,
} from "@/components/widget/flight-card/flight-card";
import FlightListOrderDropdown from "@/features/flight/components/flight-list/components/flight-list-order-dropdown";

interface BookingRequestHotelChangeHotelStepProps {
  swiper?: any;
}

const BookingRequestFlightChangeFlightStep = (
  props: BookingRequestHotelChangeHotelStepProps,
) => {
  const [showDetailItemIndex, SetShowDetailItemIndex] = useState<number>(-1);

  return (
    <div>
      <div className="flex flex-col overflow-hidden rounded-lg">
        <p className="bg-primary-50 px-4 py-1 font-semibold">Seçili Bilet</p>
        <div className="w-full">
          <FlightCard>
            <div className="flex justify-between">
              <FlightBrand
                logoSrc="https://seeklogo.com/images/T/turkish-airlines-logo-25BACC2D0C-seeklogo.com.png"
                brandName="Turkish Airlines"
                flightCode="TK283623"
              />
              <FlightTime
                totalFlightHours="2sa 15dk"
                flightStartTime="22:05"
                endStartTime="00:05"
                transferInformation="2 Aktarma"
                startIATACode="SAW"
                endIATACode="BUD"
                transferIATACodes="ABD,DER"
              />
              <FlightInformation
                seatInformation="Son iki Koltuk!"
                baggageInformation="15 Kg"
                flightClass="Ekonomi"
              />
              <FlightPrice price="2.781,68 TL" isOptimal />
            </div>
            <div className="flex flex-col gap-6">
              <FlightDetailAction
                infoText="Uçuş hizmetinizin bir bölümü Anadolu Jet tarafından yürütülecektir."
                onClick={() => props?.swiper.slideTo(1, 700)}
                buttonVariant="outline-primary"
                buttonText="Değiştirmeden İlerle"
                isOpen
              />
            </div>
          </FlightCard>
        </div>
      </div>

      <div className="mb-4 mt-8 flex items-center justify-between">
        <div className="text-gray-800">
          <h2 className="text-xl font-semibold">Alternatif Uçuşlar</h2>
          <p className="font-medium">İstanbul - Antalya</p>
        </div>

        <FlightListOrderDropdown />
      </div>

      <div className="flex flex-col gap-4">
        {[1, 2, 3, 4, 5].map((item) => {
          return (
            <FlightCard key={item}>
              <div className="flex justify-between">
                <FlightBrand
                  logoSrc="https://seeklogo.com/images/T/turkish-airlines-logo-25BACC2D0C-seeklogo.com.png"
                  brandName="Turkish Airlines"
                  flightCode="TK283623"
                />
                <FlightTime
                  totalFlightHours="2sa 15dk"
                  flightStartTime="22:05"
                  endStartTime="00:05"
                  transferInformation="2 Aktarma"
                  startIATACode="SAW"
                  endIATACode="BUD"
                  transferIATACodes="ABD,DER"
                />
                <FlightInformation
                  seatInformation="Son iki Koltuk!"
                  baggageInformation="15 Kg"
                  flightClass="Ekonomi"
                />
                <FlightPrice price="2.781,68 TL" isOptimal />
              </div>
              <div className="flex flex-col gap-6">
                <FlightDetailAction
                  infoText="Uçuş hizmetinizin bir bölümü Anadolu Jet tarafından yürütülecektir."
                  onClick={() =>
                    showDetailItemIndex === item
                      ? SetShowDetailItemIndex(-1)
                      : SetShowDetailItemIndex(item)
                  }
                  isOpen={showDetailItemIndex === item}
                />

                <FlightDetail active={showDetailItemIndex === item}>
                  {Array.from({ length: 5 }).map((_, i) => (
                    <FlightDetailCard
                      key={+i}
                      flightClass="Economy (B)"
                      price="1500TL"
                      buttonOnClick={() => props?.swiper.slideTo(1, 700)}
                      properties={[
                        {
                          text: "1 Parça Kabin Bagajı",
                        },
                        {
                          text: "1 Parça Kabin Bagajı",
                        },
                        {
                          text: "1 Parça Kabin Bagajı",
                        },
                      ]}
                    />
                  ))}
                </FlightDetail>
              </div>
            </FlightCard>
          );
        })}
      </div>

      <div className="mt-4 flex flex-col items-center gap-4 text-center">
        <span>4899 sonuçtan 10 tanesini görüntülediniz</span>

        <div className="flex w-5/12 justify-center">
          <Button variant="outline-primary" className="w-auto md:w-full">
            Daha fazla göster
          </Button>
        </div>
      </div>
    </div>
  );
};

export default BookingRequestFlightChangeFlightStep;
