/* eslint-disable @typescript-eslint/naming-convention */
/* eslint-disable unused-imports/no-unused-vars */
/* eslint-disable @next/next/no-img-element */
/* eslint-disable react-hooks/exhaustive-deps */

import dayjs from "dayjs";
import Link from "next/link";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { useBookingRequestHotelChange } from "@/features/booking-request-change/booking-request-hotel-change/hooks/use-booking-request-hotel-change";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type { IBookingRequest } from "@/models/booking-request.model";
import { useHotelAddToCartQuery } from "@/services/eva-display/hotel/hotel-add-to-cart/hotel-add-to-cart.services";
import type {
  HotelListPassengerList,
  IHotelListItem,
} from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import {
  EarlyBookingDiscount,
  HotelDiscountPrice,
  HotelPrice,
  HotelRezervationSummary,
  HotelRezervationSummaryDateInfo,
  HotelRezervationSummaryRoomInfo,
  RezervationSummaryDivider,
  RezervationSummaryProvider,
  RezervationSummaryTitle,
  RezervationSummaryTotalPrice,
} from "../../rezervation-summary/rezervation-summary";
import styles from "./booking-request-hotel-change-confirmation-step.module.css";

interface BookingRequestHotelChangeConfirmationStepProps {
  searchId?: string;
  selectedHotel?: IHotelListItem;
  SelectedRoom?: any;
  bookingRequest: IBookingRequest;
  passengers?: HotelListPassengerList[];
}

interface HotelCartComponentProps {
  hotelInfo: any;
  roomInfo: any;
  bookingRequest: IBookingRequest;
  passengers?: HotelListPassengerList[];
}

const HotelCartComponent = ({
  hotelInfo,
  roomInfo,
  ...props
}: HotelCartComponentProps) => {
  const { data, isLoading, isSuccess } = useHotelAddToCartQuery({
    HotelCartProductRequest: {
      ProductKey: roomInfo.ProductKey,
      SearchId: roomInfo?.SearchId,
    },
  });

  const { changeBookingRequest, isLoading: changeBookingIsLoading } =
    useBookingRequestHotelChange({
      searchId: roomInfo?.SearchId,
      searchProductKey: hotelInfo?.key,
      detailProductKey: roomInfo?.ProductKey,
      detailData: hotelInfo,
      bookingRequest: props.bookingRequest,
      passengers: props.passengers,
    });

  return (
    // eslint-disable-next-line react/jsx-no-useless-fragment
    <>
      {isSuccess && !isLoading && data && (
        <>
          <Card className="p-8">
            <div className="mb-4 flex items-center justify-between">
              <h2 className={cn(styles.title, "text-lg")}>Otel Bilgileri</h2>
            </div>
            <div className="flex flex-row gap-4">
              <div className={styles.imageBox}>
                {hotelInfo.images[0] ? (
                  <img
                    className="size-full object-cover"
                    src={hotelInfo.images[0].url}
                    alt="pic"
                  />
                ) : (
                  <Skeleton className="size-[70px] " />
                )}
              </div>
              <div className="flex flex-col items-start gap-2">
                <h2 className={cn(styles.title, "text-lg")}>
                  {hotelInfo?.name}
                </h2>
                <p className="text-sm text-gray-500">{hotelInfo?.location}</p>

                <Button
                  variant="primary-text"
                  className="!h-auto !p-0 text-primary-500"
                  rightIcon={{ name: "ChevronRight", size: 20 }}
                >
                  Detaylı Bilgi
                </Button>
              </div>
            </div>
          </Card>

          <Card className="p-8">
            <div className="flex items-center justify-between">
              <h2 className={cn(styles.title, "text-lg")}>
                Oda ve Kişi Bilgisi
              </h2>
            </div>
            <p className={cn(styles.subTitle, "-mt-1")}>
              {data.roomItemList.length} oda
            </p>

            {data.roomItemList.map((room, index) => {
              return (
                <div
                  key={`${`${index}`}`}
                  className="mt-5 flex items-center gap-3"
                >
                  <div className={styles.thumbImgWrapper}>
                    {data.image ? (
                      <img
                        className={styles.image}
                        src={data.image?.thumbnailUrl}
                        alt="pic"
                      />
                    ) : (
                      <Skeleton className="h-[60px] w-[120px] " />
                    )}
                  </div>
                  <div className="flex flex-col">
                    <p className="text-sm font-semibold">{room.roomTitle}</p>
                    <div className="mt-1 flex items-center gap-4">
                      <div className="flex items-center gap-1 text-gray-500">
                        <LIcon name="UtensilsCrossed" size="14" />
                        <p className="text-sm">Oda Kahvaltı</p>
                      </div>
                      <div className="flex items-center gap-1 text-gray-500">
                        <LIcon name="UtensilsCrossed" size="14" />
                        <p className="text-sm">Geri Ödemesiz</p>
                      </div>
                    </div>
                  </div>
                </div>
              );
            })}
          </Card>

          <RezervationSummaryProvider className="border-solid p-4">
            <RezervationSummaryTitle title="Rezervasyon Özeti" />
            <HotelRezervationSummary
              hotelName={data?.hotelName}
              image={data?.image?.url}
            >
              <RezervationSummaryDivider />
              <HotelRezervationSummaryDateInfo
                startDate={dayjs(data.checkInDate).format("DD MMMM YYYY")}
                endDate={dayjs(data.checkOutDate).format("DD MMMM YYYY")}
                startTime={dayjs(data.checkInDate).format("HH:mm")}
                endTime={dayjs(data.checkOutDate).format("HH:mm")}
                nightlyRateDescription={data.accommodationCount}
              />
              <RezervationSummaryDivider />
              {data.roomItemList &&
                data.roomItemList.map((roomItem) => (
                  <>
                    <HotelRezervationSummaryRoomInfo
                      key={roomItem.roomTitle}
                      title={`${roomItem.roomTitle}`}
                      passengerDescription={
                        roomItem.passengerInformation.description
                      }
                      mealDescription={roomItem.mealType}
                    >
                      <HotelPrice
                        nightlyRateDescription={
                          roomItem.roomPriceDiscountString
                        }
                        discount
                        discountDescription={
                          roomItem.roomPriceDiscountDescription
                        }
                        price={PriceManager({
                          currency: roomItem.totalPriceWithDiscount.slice(0, 3),
                          value: +roomItem.totalPriceWithDiscount.slice(3),
                        })}
                      />
                      {roomItem.roomPriceDiscountDescription && (
                        <HotelDiscountPrice
                          price={PriceManager({
                            currency: roomItem.basePrice.slice(0, 3),
                            value: +roomItem.basePrice.slice(3),
                          })}
                        />
                      )}
                    </HotelRezervationSummaryRoomInfo>
                    <RezervationSummaryDivider />
                  </>
                ))}
            </HotelRezervationSummary>
            {data.extendedDiscountInformationList &&
              data.extendedDiscountInformationList.map((discount) => (
                <EarlyBookingDiscount
                  key={discount.description}
                  price={PriceManager({
                    currency: discount.price.slice(0, 3),
                    value: +discount.price.slice(3),
                  })}
                  title={discount.description}
                />
              ))}
            <RezervationSummaryTotalPrice
              price={PriceManager({
                currency: data.totalPrice.slice(0, 3),
                value: +data.totalPrice.slice(3),
              })}
            />
          </RezervationSummaryProvider>

          <Card className="mt-6">
            <div className="flex items-center justify-between">
              <div className="flex shrink-0 flex-col items-start gap-1">
                <span className="text-base font-medium text-gray-500">
                  Toplam Tutar
                </span>
                <span className="text-lg font-semibold">
                  {PriceManager({
                    currency: data.totalPrice.slice(0, 3),
                    value: +data.totalPrice.slice(3),
                  })}
                </span>
              </div>
              <div className="flex flex-col-reverse  gap-3 md:flex-row">
                <Link
                  href={`/booking-request-detail?id=${props.bookingRequest.id}`}
                >
                  <Button variant="outline" className="w-full md:w-auto">
                    Vazgeç
                  </Button>
                </Link>
                <Button
                  variant="primary"
                  onClick={() => {
                    if (data) {
                      changeBookingRequest({
                        cartId: data.cartId,
                      });
                    }
                  }}
                  loading={changeBookingIsLoading}
                >
                  Değiştir ve Onayla
                </Button>
              </div>
            </div>
          </Card>
        </>
      )}
    </>
  );
};

const BookingRequestHotelChangeConfirmationStep = (
  props: BookingRequestHotelChangeConfirmationStepProps,
) => {
  return (
    <div className="space-y-4">
      <HotelCartComponent
        bookingRequest={props.bookingRequest}
        hotelInfo={props.selectedHotel}
        passengers={props.passengers}
        roomInfo={{
          ProductKey: props.SelectedRoom?.productKey || "",
          SearchId: props?.searchId || "",
        }}
      />
    </div>
  );
};

export default BookingRequestHotelChangeConfirmationStep;
