import React from "react";

import { Button } from "@/components/ui/button/button";
import HotelCard from "@/components/widget/hotel-card/hotel-card";
import ListSkeleton from "@/components/widget/list-skeleton/list-skeleton";
import HotelListGetMoreButton from "@/features/hotel/components/hotel-list/components/hotel-list-get-more-button";
import HotelListItem from "@/features/hotel/components/hotel-list/components/hotel-list-item";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { IHotelListItem } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

interface BookingRequestHotelChangeHotelStepProps {
  hotelName?: string;
  location?: string;
  totalPrice?: number | string;
  images?: string[];
  recommended?: boolean;
  alternateHotels?: IHotelListItem[];
  loading?: boolean;
  setSelectedHotel?(e: IHotelListItem): void;
  nightInfo: string;
}

const BookingRequestHotelChangeHotelStep = (
  props: BookingRequestHotelChangeHotelStepProps,
) => {
  return (
    <div>
      <div className="flex flex-col overflow-hidden rounded-lg">
        <p className="bg-primary-50 px-4 py-1 font-semibold">Seçili Otel</p>

        <HotelCard
          className="choosed swiper-container !max-w-full !rounded-none !rounded-b-lg !ring-0"
          id="HotelCardId"
          durationNight={props.nightInfo}
          swiperContainerModifierClass="choosedswiper"
          hotelLocation={
            props.location && props.location.replaceAll(", ", " / ")
          }
          isRecommended={props?.recommended}
          hotelName={props.hotelName}
          images={props.images}
          renderPrimaryButton={() => <div />}
          onClickLike={() => {}}
          onClickPrimaryButton={() => {
            // props?.swiper.slideTo(1, 700);
          }}
          price={
            PriceManager({
              currency: `${props.totalPrice}`.slice(0, 3) as string,
              value:
                (+`${props.totalPrice}`.slice(3) as unknown as number) || 0,
            }) as unknown as number
          }
          hasHygienicalMeasure={false}
        />
      </div>

      <h2 className="my-4 text-xl font-semibold">Alternatif Oteller</h2>

      <div className="flex flex-col gap-4">
        {props?.loading && <ListSkeleton size={5} />}
        {props.alternateHotels &&
          props.alternateHotels.map((item: IHotelListItem, key) => {
            // This item keys manipulated for this loop by service merge function
            return (
              <HotelListItem
                className="!max-w-full hover:!ring-0"
                item={item}
                key={item.key}
                swiperContainerModifierClass={`swiper-${`${item.hotelId}${key}`}`}
                renderPrimaryButton={() => (
                  <Button
                    variant="primary"
                    className="mt-4 !w-[105px]"
                    onClick={() => {
                      if (props.setSelectedHotel) props.setSelectedHotel(item);
                    }}
                  >
                    Seç
                  </Button>
                )}
              />
            );
          })}

        <HotelListGetMoreButton />
      </div>
    </div>
  );
};

export default BookingRequestHotelChangeHotelStep;
