import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";

import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { ThemeProviderDecorators } from "@/storybook/Decorator";

import {
  BookingRequestRezervationInformation,
  RezervationFlightCard,
  RezervationFlightInfo,
  RezervationSuccessFlightPrice,
  RezervationSuccessTotalPrice,
} from "./booking-request-rezervation-information";

const meta = {
  title: "Widgets/BookingRequestRezervationInformation",
  component: BookingRequestRezervationInformation,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof BookingRequestRezervationInformation>;

export default meta;

type Story = StoryObj<typeof BookingRequestRezervationInformation>;

const RezervationInfo = [
  {
    label: "Uçuş Tipi",
    value: "Gidiş Dönüş",
    icon: <LIcon name="Plane" size="18" />,
  },
  {
    label: "Kişi Sayısı",
    value: "2 Yetişkin",
    icon: <LIcon name="User" size="18" />,
  },
  {
    label: "Kişi Bilgisi",
    value: "İbrahim Kara",
  },
];

const priceDescription = [
  {
    description: "Uçuş Bedeli",
    price: "19.500TL",
  },
  {
    description: "Servis Bedeli",
    price: "5,00TL",
  },
  {
    description: "Vergi",
    price: "300,00TL",
  },
];

export const DefaultBookingRequestRezervationInformation: Story = {
  render: () => {
    return (
      <div className="mt-10 flex justify-center">
        <div className="min-w-[688px]">
          <BookingRequestRezervationInformation>
            <RezervationFlightInfo data={RezervationInfo} />
            <div>
              <RezervationFlightCard
                destination="İstanbul"
                origin="Ankara"
                date="5 Aralık 2023 Sal"
                logoSrc="https://concorecdn.jollytur.com/concore/media/site/assets/img/theme/TK-42x42.gif?v1040"
                brandName="Turkish Airlines"
                flightCode="TK283623"
                totalFlightHours="2sa 15dk"
                flightStartTime="22:05"
                endStartTime="00:05"
                transferInformation="2 Aktarma"
                startIATACode="SAW"
                endIATACode="BUD"
                transferIATACodes="ABD,DER"
                totalPrice="7800TL"
              />
            </div>
            <RezervationSuccessFlightPrice
              priceDescription={priceDescription}
            />
            <RezervationSuccessTotalPrice price="7800TL" />
          </BookingRequestRezervationInformation>
        </div>
      </div>
    );
  },
};
