import { useFormContext } from "react-hook-form";

import FormItem from "@/components/form/form-item";
import Card from "@/components/ui/card/card";
import PriceRange from "@/components/widget/price-range/price-range";

export interface CoreListFilterPriceProps {
  name: string;
  properties: {
    start: number;
    end: number;
    currencySymbol?: string;
    label: string;
  };
}

// Option
export const CoreListFilterPrice = (props: CoreListFilterPriceProps) => {
  const methods = useFormContext();
  const roundNumber = (num: number) => {
    return Math.round(num * 100) / 100;
  };

  return (
    <FormItem name={props.name}>
      {({ field }) => (
        <Card className="border-none md:border-solid">
          <h1>{props.properties.label}</h1>
          <PriceRange
            initalRangeValues={{
              end: roundNumber(field.value?.end ?? props.properties.end),
              start: roundNumber(field.value?.start ?? props.properties.start),
            }}
            onChange={(value) => {
              methods.setValue(props.name, value, {
                shouldTouch: true,
              });
            }}
            rangeValues={{
              end: roundNumber(props.properties.end),
              start: roundNumber(props.properties.start),
            }}
            currencySymbol={props.properties.currencySymbol}
          />
        </Card>
      )}
    </FormItem>
  );
};
