import { type PropsWithChildren } from "react";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { useLocale } from "@/hooks/useLocale";

interface CoreListFilterResponsiveProps extends PropsWithChildren {
  filterModalOpen?: boolean;
  onMobileModalClose?: () => void;
  onMobileModalOpen?: () => void;
  onApply?: () => void;
}

export const CoreListFilterResponsive = (
  props: CoreListFilterResponsiveProps,
) => {
  const { t } = useLocale();
  return (
    <>
      <div className="block text-gray-500 md:hidden">
        <Button
          variant="outline"
          className="w-full"
          onClick={() => {
            if (props.onMobileModalOpen) {
              props.onMobileModalOpen();
            }
          }}
        >
          <LIcon name="Filter" size={20} />
          &nbsp;&nbsp;{t("filter")}
        </Button>
      </div>

      <Modal
        open={props.filterModalOpen || false}
        footer={false}
        size="full"
        title={t("filter")}
        onClose={props.onMobileModalClose || (() => {})}
        onOkText={t("Apply")}
        onOk={() => {
          props?.onApply?.();
          props?.onMobileModalClose?.();
        }}
      >
        <div className="scroll-bar mb-5 flex max-h-[calc(100%-100px)] flex-col gap-2 overflow-y-scroll ">
          {props.children}
        </div>
        {/* </div> */}
      </Modal>
    </>
  );
};
