import { type PropsWithChildren, type ReactElement } from "react";

import Card from "@/components/ui/card/card";

import CoreListCardContainer from "./core-list-card-container";
import { CoreListFilterPrice } from "./core-list-filter-price";
import CoreSingleCheckBoxList from "./core-list-single-checkbox-list";

export enum FilterItemTypeEnum {
  PRICE_RANGE = "price-range",
  DROPDOWN_INPUT = "dropdown-input",
  CARD_CONTAINER = "card-container",
  CHECKBOX_LIST = "checkbox-list",
  SINGLE_CHECKBOX_LIST = "single-checkbox-list",
  DIVIDER = "divider",
}
export type FilterItemType =
  | FilterItemTypeEnum.PRICE_RANGE
  | FilterItemTypeEnum.CARD_CONTAINER
  | FilterItemTypeEnum.SINGLE_CHECKBOX_LIST
  | FilterItemTypeEnum.CHECKBOX_LIST
  | FilterItemTypeEnum.DIVIDER;

export type FilterItem = {
  value?: any;
  type: FilterItemType;
  properties: any;
  name: string;
  filterOptions?: FilterItem[];
};

export const CoreListFilterObject = (
  item: FilterItem,
): Record<FilterItemType, ReactElement<PropsWithChildren>> => {
  return {
    [FilterItemTypeEnum.PRICE_RANGE]: <CoreListFilterPrice {...item} />,
    [FilterItemTypeEnum.CARD_CONTAINER]: (
      <CoreListCardContainer>
        {item.filterOptions
          ? // eslint-disable-next-line @typescript-eslint/no-use-before-define
            item.filterOptions.map((subItem) => FilterCompResolver(subItem))
          : null}
      </CoreListCardContainer>
    ),
    [FilterItemTypeEnum.CHECKBOX_LIST]: <CoreSingleCheckBoxList {...item} />,
    [FilterItemTypeEnum.SINGLE_CHECKBOX_LIST]: (
      <Card className="border-none md:border-solid">
        <CoreSingleCheckBoxList {...item} />
      </Card>
    ),
    [FilterItemTypeEnum.DIVIDER]: (
      <div {...item} className="h-px w-full border-t border-gray-100" />
    ),
  };
};

function FilterCompResolver(item: FilterItem) {
  const Component = CoreListFilterObject(item)[item.type];
  if (Component) {
    return Component;
  }
  return null;
}

export interface CoreListFilterProps {
  filterOptions: FilterItem[];
}

export const CoreListFilter = (props: CoreListFilterProps) => {
  return props.filterOptions.map((item) => FilterCompResolver(item));
};
