import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import SortButtonGroup from "@/components/widget/sort-button-group/sort-button-group";
import { useLocale } from "@/hooks/useLocale";

export type CoreListSortValueType =
  | "Average"
  | "PriceAscending"
  | "PriceDescending";

export interface CoreListSortBaseProps {
  onChange: (value: string) => void;
  value: CoreListSortValueType;
}

export interface CoreListSortResponsiveProps {
  mobileModalOpen?: boolean;
  onMobileModalClose?: () => void;
  onMobileModalOpen?: () => void;
}

export interface CoreListSortRootProps
  extends CoreListSortBaseProps,
    CoreListSortResponsiveProps {}

const CoreListSortMobile = ({
  value,
  onChange,
  mobileModalOpen,
  onMobileModalClose,
  onMobileModalOpen,
}: CoreListSortRootProps) => {
  const { t } = useLocale();
  return (
    <>
      <div className="block md:hidden">
        <Button
          className="w-full text-gray-500"
          variant="outline"
          onClick={() => {
            if (onMobileModalOpen) {
              onMobileModalOpen();
            }
          }}
        >
          <LIcon name="ArrowDownWideNarrow" size={20} />
          &nbsp;&nbsp;{t("Sort by")}
        </Button>
      </div>
      <Modal
        onClose={onMobileModalClose || (() => {})}
        className="!m-0 !p-0"
        open={mobileModalOpen || false}
        footer=" "
      >
        <div className="p-4">
          <div className="text-xl font-semibold text-gray-800 ">Sırala</div>
          <div className="flex flex-col gap-2 py-8">
            <Button
              variant={value === "Average" ? "outline-primary" : "outline"}
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => onChange("Average")}
            >
              <LIcon
                name={value === "Average" ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Recommended Ranking")}
            </Button>
            <Button
              variant={
                value === "PriceAscending" ? "outline-primary" : "outline"
              }
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => onChange("PriceAscending")}
            >
              <LIcon
                name={value === "PriceAscending" ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Price (lowest first)")}
            </Button>
            <Button
              variant={
                value === "PriceDescending" ? "outline-primary" : "outline"
              }
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => onChange("PriceDescending")}
            >
              <LIcon
                name={value === "PriceDescending" ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Price (highest first)")}
            </Button>
          </div>
        </div>
      </Modal>
    </>
  );
};

const CoreListSortDesktop = ({ value, onChange }: CoreListSortBaseProps) => {
  const { t } = useLocale();
  return (
    <div className="hidden md:block">
      <SortButtonGroup
        onChange={onChange}
        defaultActive={value}
        items={[
          {
            // @todo - add translation for 'Önerilen sıralama'
            label: t("Recommended Ranking"),
            key: "Average",
          },
          {
            // @todo - add translation for 'Artan fiyat'
            label: t("Price (lowest first)"),
            key: "PriceAscending",
          },
          {
            // @todo - add translation for 'Azalan fiyat'
            label: t("Price (highest first)"),
            key: "PriceDescending",
          },
        ]}
      />
    </div>
  );
};

const CoreListSort = (props: CoreListSortRootProps) => {
  return (
    <>
      <CoreListSortDesktop {...props} />
      <CoreListSortMobile {...props} />
    </>
  );
};

export default CoreListSort;
