import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";

import { ThemeProviderDecorators } from "@/storybook/Decorator";

import FilterCheckbox from "./filter-checkbox";

const meta = {
  title: "Widgets/FilterCheckbox",
  component: FilterCheckbox,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  args: {
    items: [
      { key: "1", label: "Kaş (400)" },
      { key: "2", label: "Kemer (162)" },
      { key: "3", label: "Muratpaşa (86)" },
      { key: "4", label: "Alanya (79)" },
      { key: "5", label: "Kumluca (66)" },
    ],
    collapseTitle: "Bölge",
    collapseDefaultOpen: true,
  },
  argTypes: {
    collapseTitle: {
      control: {
        type: "text",
      },
    },
  },
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof FilterCheckbox>;

export default meta;

type Story = StoryObj<typeof FilterCheckbox>;

export const DefaultFilterCheckbox: Story = {
  args: {},
};

export const WithMoreItems: Story = {
  args: {
    items: [
      { key: "1", label: "Kaş (400)" },
      { key: "2", label: "Kemer (162)" },
      { key: "3", label: "Muratpaşa (86)" },
      { key: "4", label: "Alanya (79)" },
      { key: "5", label: "Kumluca (66)" },
      { key: "11", label: "Kaş (400)" },
      { key: "22", label: "Kemer (162)" },
      { key: "31", label: "Muratpaşa (86)" },
      { key: "41", label: "Alanya (79)" },
      { key: "51", label: "Kumluca (66)" },
    ],
  },
};

export const Searchable: Story = {
  args: {
    searchable: true,
    searchPlaceholder: "Bölge ara",
    items: [
      { key: "1", label: "Kaş (400)" },
      { key: "2", label: "Kemer (162)" },
      { key: "3", label: "Muratpaşa (86)" },
      { key: "4", label: "Alanya (79)" },
      { key: "5", label: "Kumluca (66)" },
      { key: "11", label: "Kaş (400)" },
      { key: "22", label: "Kemer (162)" },
      { key: "31", label: "Muratpaşa (86)" },
      { key: "41", label: "Alanya (79)" },
      { key: "51", label: "Kumluca (66)" },
    ],
  },
};

export const WithLongLabels: Story = {
  args: {
    searchable: true,
    searchPlaceholder: "Bölge ara",
    items: [
      {
        key: "1",
        label:
          "Afyonkarahisar Merkez Kocatepe Afyonkarahisar Merkez Kocatepe (400)",
      },
      { key: "2", label: "Kemer, Alanya, Manavgat (162)" },
    ],
  },
};

export const SearchableWithInitialValue: Story = {
  args: {
    searchable: true,
    searchPlaceholder: "Bölge ara",
    items: [
      { key: "1", label: "Kaş (400)" },
      { key: "2", label: "Kemer (162)" },
      { key: "3", label: "Muratpaşa (86)" },
      { key: "4", label: "Alanya (79)" },
      { key: "5", label: "Kumluca (66)" },
    ],
    searchValue: "Kaş",
  },
};

export const InitialSelectedValues: Story = {
  args: {
    searchable: true,
    searchPlaceholder: "Bölge ara",
    initialSelectedItems: ["1", "2"],
  },
};
