import Link from "next/link";

import Form from "@/components/form/form";
import FormItem from "@/components/form/form-item";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import { Input } from "@/components/ui/input/input";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";

interface FormType {
  Email: string;
}

export interface ForgotPasswordFormProps {
  onSubmit: (variables: FormType) => void;
  validations: {
    email: any;
  };
}

const ForgotPasswordForm = (props: ForgotPasswordFormProps) => {
  async function handleSubmit(params: FormType) {
    props.onSubmit(params);
  }
  return (
    <div>
      <Card className="flex max-w-[392px] flex-col gap-8 bg-white p-8 shadow-2xl">
        <Link
          className="flex flex-row items-center gap-1 text-base font-medium text-gray-500"
          href="/auth/login"
        >
          <LIcon className="w-5" name="ArrowLeft" />
          <span>Giriş yap</span>
        </Link>
        <div className="flex flex-col gap-2">
          <span className="text-2xl font-semibold text-gray-800">
            Şifremi Unuttum
          </span>
          <span className="text-base text-gray-500">
            Doğrulama kodu göndereceğimiz e-posta adresini yazın.
          </span>
        </div>

        <Form
          // eslint-disable-next-line react/jsx-no-bind
          onSubmit={handleSubmit}
        >
          <div className="flex flex-col gap-8">
            <FormItem name="Email" rules={props.validations.email}>
              {({ field, fieldState }) => (
                <Input
                  {...field}
                  fullWidth
                  label="E-Posta"
                  size="md"
                  isInvalid={!!fieldState.error}
                  errorMessage={fieldState.error?.message}
                />
              )}
            </FormItem>
            <Button
              type="submit"
              className="!h-[44px] w-full"
              variant="primary"
            >
              Gönder
            </Button>
          </div>
        </Form>
      </Card>
    </div>
  );
};

export { ForgotPasswordForm };
