import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";

import { ThemeProviderDecorators } from "@/storybook/Decorator";

import HotelCard from "./hotel-card";

const meta = {
  title: "Widgets/HotelCard",
  component: HotelCard,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  args: {
    hotelName: "Caresse Luxury Collection Resort & Spa",
    hotelLocation: "Antalya / Lara / Kundu",
    discount: {
      rate: 20,
      price: 27500,
    },
    price: 25223,
    isRecommended: true,
    likeButtonVisible: false,
    includedSpecifications: [
      {
        icon: "Activity",
        text: "Ücretsiz İptal",
      },
      {
        icon: "Activity",
        text: "Şimdi Al Sonra Öde",
      },
      {
        icon: "Activity",
        text: "Havaalanı Servisi",
      },
      {
        icon: "Activity",
        text: "Ücretsiz İptal",
      },
      {
        icon: "Activity",
        text: "Şimdi Al Sonra Öde",
      },
      {
        icon: "Activity",
        text: "Havaalanı Servisi",
      },
      {
        icon: "Activity",
        text: "Şimdi Al Sonra Öde",
      },
      {
        icon: "Activity",
        text: "Havaalanı Servisi",
      },
    ],
    durationNight: "7 gece toplam",
    mainSpesisification: "Ultra her şey dahil",
    images: [
      "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100",
      "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100",
      "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100",
      "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100",
      "https://images.unsplash.com/photo-1566073771259-6a8506099945?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=500&q=100",
    ],
  },
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof HotelCard>;

export default meta;

type Story = StoryObj<typeof HotelCard>;

export const DefaultHotelCard: Story = {
  args: {},
};

export const HotelCardNoImage: Story = {
  args: {
    images: undefined,
  },
};

export const HotelCardNoRecommended: Story = {
  args: {
    isRecommended: false,
  },
};

export const HotelCardNoPrice: Story = {
  args: {
    price: undefined,
  },
};

export const HotelCardWithLike: Story = {
  args: {
    likeButtonVisible: true,
  },
};

export const HotelCardMobile: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    likeButtonVisible: true,
  },
};

export const HotelCardSpecificationError: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    SpecificationError: "Seçtiğiniz tarihlerde boş oda kalmadı.",
  },
};

export const HotelCardSelectDate: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    selectDateForPrice: true,
  },
};

export const HotelCardAvailableButton: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    availableDateButton: true,
  },
};
