/* eslint-disable no-nested-ternary */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable @next/next/no-img-element */
/* eslint-disable react/no-danger */
import Image from "next/image";
import React, { useCallback } from "react";
import { useMediaQuery } from "usehooks-ts";

import NoImage from "@/assets/svg/images/no-image.svg";
import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import { Carousel } from "@/components/ui/carousel/carousel";
import {
  HoverCard,
  HoverCardContent,
  HoverCardTrigger,
} from "@/components/ui/hover-card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useLocale } from "@/hooks/useLocale";
import hasClassParents from "@/libs/helpers/hasClass";
import { cn } from "@/libs/utils";
import type { HotelListItemDiscountInformation } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import styles from "./hotel-card.module.css";

interface DiscountBadgeProps {
  price: number;
  rate: number;
}
interface IncludedSpecification {
  icon?: any;
  tooltip?: string;
  text: string;
}
export interface HotelCardProps {
  id: string;
  className?: string;
  hotelName?: string;
  hotelLocation?: string;
  discount?: DiscountBadgeProps;
  isRecommended?: boolean;
  isLike?: boolean;
  likeButtonVisible?: boolean;
  images?: string[];
  durationNight?: string;
  renderPrimaryButton?: () => React.ReactNode;
  renderHotelSelectButton?: () => React.ReactNode;
  mainSpesisification?: string;
  includedSpecifications?: IncludedSpecification[];
  SpecificationError?: string;
  selectDateForPrice?: boolean;
  swiperContainerModifierClass?: string;
  price?: number;
  availableDateButton?: boolean;
  hasHygienicalMeasure: boolean;
  onClickPrimaryButton?: (id: string) => void;
  onClickLike?: (id: string) => void;
  loyaltyValue?: number;
  discountInformations?: HotelListItemDiscountInformation[];
}

type AvailableButtonProps = {
  // eslint-disable-next-line react/no-unused-prop-types
  type: "desktop" | "mobile";
};

function HotelCard({
  id,
  hotelName,
  hotelLocation,
  discount,
  isRecommended,
  isLike,
  likeButtonVisible = false,
  images,
  durationNight,
  includedSpecifications,
  price,
  selectDateForPrice,
  mainSpesisification,
  SpecificationError,
  availableDateButton,
  hasHygienicalMeasure,
  renderPrimaryButton,
  renderHotelSelectButton,
  onClickLike,
  onClickPrimaryButton,
  className,
  swiperContainerModifierClass,
  loyaltyValue,
  discountInformations,
}: HotelCardProps) {
  const handleOnPrimaryClick = useCallback(
    () => onClickPrimaryButton?.(id),
    [id, onClickPrimaryButton],
  );
  const isDesktop = useMediaQuery("(min-width: 768px)");
  const { t } = useLocale();
  const AvailableButton = useCallback(
    ({ type }: AvailableButtonProps) => (
      /* @todo add translation for 'İncele' & 'Müsait Tarihler' */
      <Button
        variant="outline"
        // className="mt-2 w-full text-sm text-gray-500 sm:!block"
        className={cn(
          "mt-2 w-full text-sm text-gray-500",
          // @todo - This field is not used currently. When service is ready, it will be used.
          type === "desktop" ? "!hidden sm:!hidden" : "!hidden sm:!hidden",
        )}
        onClick={handleOnPrimaryClick}
      >
        Müsait Tarihler
      </Button>
    ),
    [handleOnPrimaryClick],
  );

  const extendincludedSpecifications = includedSpecifications
    ?.slice(3)
    .map(({ text }, key) => <li key={+key}>{text}</li>);

  return (
    <div
      className={cn(styles.container, className, "group")}
      onClick={(e) =>
        !isDesktop &&
        !hasClassParents(e.target as HTMLElement, [
          "swiper-navigation",
          "popover-trigger",
        ]) &&
        handleOnPrimaryClick()
      }
    >
      <div className={styles.left}>
        {/* @todo - add translation for 'Öneriliyor' */}
        {isRecommended && (
          <Badge
            leftIcon={{
              name: "ThumbsUp",
              size: 12,
              strokeWidth: 2,
              className: "ml-1",
            }}
            className={styles.recommended}
          >
            {t("Recommended")}
          </Badge>
        )}
        {likeButtonVisible && (
          <Badge
            leftIcon={{
              name: "Heart",
              size: 12,
              strokeWidth: 3,
              className: "ml-1 text-primary-500",
            }}
            className={cn(styles.like, isLike && "bg-primary-500")}
            onClick={() => onClickLike?.(id)}
          />
        )}

        {images && images?.length > 0 && (
          <Carousel
            wrapperClassName={styles["left-carousel"]}
            className="size-full"
            loop
            navigation={images.length > 1}
            containerModifierClass={swiperContainerModifierClass}
          >
            {images?.map((image) => (
              <img
                src={image}
                alt="Hotel card images"
                key={image}
                className="h-[214px] w-full object-cover md:h-full"
              />
            ))}
          </Carousel>
        )}
        {!images && (
          <Image
            src={NoImage}
            className="h-[214px] w-full object-cover md:h-full"
            alt="No picture image"
          />
        )}
      </div>
      <div className={styles.contentWrapper}>
        <div className={styles["left-content-wrapper"]}>
          {/* Hotel Name and Location */}
          <div className="flex flex-col gap-1">
            {hasHygienicalMeasure && (
              <div className="inline-flex">
                <Badge>
                  <div className="flex gap-1">
                    <LIcon name="ShieldCheck" size="14" />
                    <span>{t("Safe Tourism Certified Hotel")}</span>
                  </div>
                </Badge>
              </div>
            )}

            <h2 className={cn(styles.title, "group-hover:underline")}>
              {hotelName}
            </h2>
            <p className={styles.location}>{hotelLocation}</p>
          </div>
          {/* Hotel Specifications  - @todo it'll be complete */}
          <div>
            {SpecificationError ? (
              <Badge
                variant="error"
                leftIcon={{
                  name: "Clock",
                }}
              >
                {SpecificationError}
              </Badge>
            ) : (
              <>
                {mainSpesisification && (
                  <div className="flex items-center gap-1">
                    <LIcon name="UtensilsCrossed" size="14" />
                    <p className="text-sm">{mainSpesisification}</p>
                  </div>
                )}
                {(includedSpecifications?.length || 0) > 0 && (
                  <div className={styles.badgeGroup}>
                    {includedSpecifications
                      ?.slice(0, 3)
                      .map(({ text, icon, tooltip }) => {
                        if (icon === "masterpass") {
                          return (
                            <HoverCard key={text} openDelay={100}>
                              <HoverCardTrigger>
                                <Badge childrenClassName="flex gap-1.5">
                                  <Image
                                    src="/assets/images/mastercard.png"
                                    width={16}
                                    height={16}
                                    alt="mastercard"
                                  />
                                  {text}
                                </Badge>
                              </HoverCardTrigger>
                              <HoverCardContent className="border-none bg-gray-900  text-white">
                                {tooltip && (
                                  <p
                                    className="text-sm"
                                    dangerouslySetInnerHTML={{
                                      __html: tooltip as TrustedHTML,
                                    }}
                                  />
                                )}
                              </HoverCardContent>
                            </HoverCard>
                          );
                        }
                        if (text === "Ücretsiz iptal") {
                          return (
                            <Badge key={text} variant="grayGreen">
                              {text}
                            </Badge>
                          );
                        }
                        return <Badge key={text}>{text}</Badge>;
                      })}
                    {discountInformations &&
                      discountInformations?.length > 0 &&
                      discountInformations?.map(({ tooltip, description }) =>
                        tooltip.trim() !== "" ? (
                          <HoverCard key={description} openDelay={100}>
                            <HoverCardTrigger>
                              <Badge childrenClassName="flex gap-1.5">
                                {description}
                              </Badge>
                            </HoverCardTrigger>
                            <HoverCardContent className="border-none bg-gray-900  text-white">
                              {tooltip && (
                                <p
                                  className="text-sm"
                                  dangerouslySetInnerHTML={{
                                    __html: tooltip as TrustedHTML,
                                  }}
                                />
                              )}
                            </HoverCardContent>
                          </HoverCard>
                        ) : (
                          <Badge key={description}>{description}</Badge>
                        ),
                      )}
                    {(includedSpecifications?.length || 0) > 3 && (
                      <HoverCard openDelay={100}>
                        <HoverCardTrigger>
                          <div className="popover-trigger cursor-pointer items-center rounded-full border border-gray-100 bg-gray-100 px-2 py-0.5 text-xs font-medium text-slate-800">
                            +{(includedSpecifications?.length || 0) - 3}
                          </div>
                        </HoverCardTrigger>
                        <HoverCardContent className="border-none bg-gray-900  text-white">
                          <div className="flex flex-col gap-2">
                            <span className="font-semibold">
                              Kampanya ve indirimler
                            </span>
                            <ul className="!list-disc p-5">
                              {extendincludedSpecifications}
                            </ul>
                          </div>
                        </HoverCardContent>
                      </HoverCard>
                    )}
                  </div>
                )}
              </>
            )}
          </div>
        </div>
        <div className={styles.divider} />
        <div className={cn(styles["right-content-wrapper"])}>
          {selectDateForPrice && !availableDateButton ? (
            <div className={styles["select-date-wrapper"]}>
              {/* @todo - add translation for 'Fiyat görebilmek için tarih seçin' */}
              <p
                className={styles["select-date-text"]}
                onClick={handleOnPrimaryClick}
                aria-hidden="true"
              >
                Fiyatları görebilmek için tarih seçin
              </p>
              {/* @todo add translation for 'Tarih Seç' */}
              <Button
                variant="primary"
                className="!hidden w-[105px] sm:!block"
                onClick={handleOnPrimaryClick}
              >
                {t("Select Date")}
              </Button>
            </div>
          ) : (
            <>
              {/* Price & Discount Info */}
              <div className="relative z-50 flex w-full flex-col items-start justify-start text-left md:items-end">
                {!!loyaltyValue && loyaltyValue > 0 && (
                  <div>
                    <HoverCard openDelay={100}>
                      <HoverCardTrigger>
                        <div role="button" className="ring-0 hover:ring-0">
                          <Badge
                            variant="blueLight"
                            className="mb-2 cursor-pointer rounded-full"
                          >
                            <div className="flex items-center gap-2">
                              <span>
                                {t("{{point}} Miles", { point: loyaltyValue })}
                              </span>
                              <LIcon name="Info" className="size-3" />
                            </div>
                          </Badge>
                        </div>
                      </HoverCardTrigger>
                      <HoverCardContent>
                        <p className="mb-2 text-sm">{t("Miles")}</p>
                        <p className="text-xs">
                          {t(
                            "The number of miles to be earned on the total cost of your stay. It will be uploaded to the guest specified as the contact person.",
                          )}
                        </p>
                      </HoverCardContent>
                    </HoverCard>
                  </div>
                )}
                {price && (
                  <>
                    {discount && !availableDateButton && (
                      <>
                        {/* @todo - add translation for 'İndirim' */}
                        <Badge variant="grayGreen">
                          %
                          {t("{{discount}} discount", {
                            discount: discount.rate,
                          })}
                        </Badge>
                      </>
                    )}
                    <div className={cn(styles.price)}>
                      {!isDesktop && durationNight && (
                        <p className={styles["night-info"]}>{durationNight}</p>
                      )}

                      <div className="flex flex-row items-center justify-start gap-2 md:flex-col md:items-end md:gap-0">
                        {discount && !availableDateButton && (
                          <>
                            {/* @todo - add dynamic currency */}
                            <p className={styles["discount-price"]}>
                              {/* @todo - add dynamic currency and format */}
                              {discount.price}
                            </p>
                          </>
                        )}
                        {/* @todo - add dynamic currency and format */}

                        <div>{price || 0.0}</div>
                      </div>
                    </div>
                  </>
                )}
              </div>
              {/* Card Button and night info */}
              <div className={styles["card-button-wrapper"]}>
                {price && (
                  <>
                    {/* @todo - add translation for 'gece toplam' */}
                    {isDesktop && (
                      <p className={styles["night-info"]}>{durationNight}</p>
                    )}
                    {/* eslint-disable-next-line no-nested-ternary */}
                    {renderPrimaryButton ? (
                      renderPrimaryButton()
                    ) : !availableDateButton ? (
                      renderHotelSelectButton ? (
                        renderHotelSelectButton()
                      ) : (
                        <Button
                          variant="primary"
                          className="!hidden w-[105px] sm:!block"
                          onClick={handleOnPrimaryClick}
                        >
                          {t("View")}
                        </Button>
                      )
                    ) : (
                      availableDateButton && <AvailableButton type="desktop" />
                    )}
                  </>
                )}
              </div>
            </>
          )}
        </div>
        {availableDateButton && (
          <div className={styles["available-button-wrapper"]}>
            <AvailableButton type="mobile" />
          </div>
        )}
      </div>
    </div>
  );
}

export default HotelCard;
