/* eslint-disable tailwindcss/no-custom-classname */

"use client";

import React from "react";
import { useMediaQuery } from "usehooks-ts";

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion/accordion";
import { Badge } from "@/components/ui/badge/badge";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { SeeAllText } from "@/components/ui/see-all-text/see-all-text";
import { useLocale } from "@/hooks/useLocale";

export interface HotelProperty {
  label: string;
  value: string;
}
export interface HotelProductDetailAboutProps {
  hotelName: string;
  informationText?: string;
  hotelProperty?: HotelProperty[];
  hotelPolicies?: Pick<HotelProperty, "label">[];
  hotelTheme?: string[];
  documentNumber?: string;
}

const HotelProductDetailAbout = ({
  hotelName,
  informationText,
  hotelProperty,
  hotelPolicies,
  hotelTheme,
  documentNumber,
}: HotelProductDetailAboutProps) => {
  const { t } = useLocale();
  const isDesktop = useMediaQuery("(min-width: 768px)");
  return (
    <Accordion type="single" defaultValue="item-1" collapsible>
      <AccordionItem value="item-1" className="border-b-0">
        <AccordionTrigger className="p-0 text-xl font-semibold">
          {t("About")}
        </AccordionTrigger>
        <AccordionContent>
          <div>
            <div className="mt-6">
              <h5 className="text-base font-semibold">
                {hotelName} {t("About")}
              </h5>
              <div className="mt-2">
                {informationText && (
                  <SeeAllText
                    innerHtml
                    text={informationText}
                    classname="text-sm text-gray-500"
                    lineClampSize="3"
                  />
                )}
              </div>
              {!isDesktop && documentNumber && (
                <div className="mt-4 flex flex-col rounded-primary bg-gray-50 p-4">
                  <span className="text-base text-gray-800">
                    {t("Ministry of Culture and Tourism/Tourism")}
                  </span>
                  <span className="text-sm text-[#475467]">
                    {t("Operation Certificate")}:{documentNumber}
                  </span>
                </div>
              )}
              {hotelProperty && hotelProperty.length > 0 && (
                <div>
                  <h5 className="mt-6 text-base font-semibold">
                    {t("Features")}
                  </h5>
                  <ul className="mt-4 grid w-full grid-cols-1 gap-x-4 gap-y-3 text-sm sm:grid-cols-2 md:grid-cols-3">
                    {hotelProperty?.map((data) => (
                      <li key={data.label}>
                        <Card className="flex items-center gap-1 ">
                          <LIcon name="Check" size={12} />
                          <span>{data.label}:</span>
                          <span className="ml-auto">{data.value}</span>
                        </Card>
                      </li>
                    ))}
                  </ul>
                </div>
              )}
              {hotelPolicies && hotelPolicies.length > 0 && (
                <div>
                  <h5 className="mt-6 text-base font-semibold">
                    {t("Policies")}
                  </h5>
                  <ul className="mt-4 grid w-full grid-cols-1 gap-x-4 gap-y-3 text-sm sm:grid-cols-2 md:grid-cols-3">
                    {hotelPolicies?.map((data) => (
                      <li key={data.label}>
                        <Card className="flex items-center gap-1 ">
                          <LIcon name="Check" size={12} />
                          <span>{data.label}</span>
                        </Card>
                      </li>
                    ))}
                  </ul>
                </div>
              )}
              {hotelTheme && hotelTheme?.length > 0 && (
                <div>
                  <h5 className="mt-6 text-base font-semibold">
                    {t("Hotel Theme")}
                  </h5>
                  <ul className="mt-4 flex w-full flex-wrap gap-x-4 gap-y-3 text-sm">
                    {hotelTheme?.map((data) => (
                      <li key={data}>
                        <Badge className="!px-3 !py-1">{data}</Badge>
                      </li>
                    ))}
                  </ul>
                </div>
              )}
            </div>
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
};

export default HotelProductDetailAbout;
