/* eslint-disable react/no-danger */
/* eslint-disable react/jsx-no-useless-fragment */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import React from "react";

import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";
import type { HotelListItemCampaignInformation } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

export interface HotelProductDetailCampaignProps {
  items: HotelListItemCampaignInformation[];
}

const HotelProductDetailCampaignItem = ({
  description,
  tooltip,
}: Pick<HotelListItemCampaignInformation, "description" | "tooltip">) => {
  const { closeModal, openModal, modalOpen } = useModal({ open: false });
  return (
    <>
      <div
        onClick={() => !!tooltip && openModal()}
        className={cn(
          "flex h-12 items-center justify-start rounded-primary border border-gray-200 bg-gray-50 px-3 text-gray-800",
          !!tooltip && "cursor-pointer",
        )}
      >
        <span className="line-clamp-1">{description}</span>
      </div>

      <Modal
        size="full"
        open={modalOpen}
        onClose={closeModal}
        className="z-[101]"
        header={
          <div className="m-auto w-full max-w-[800px] text-lg font-semibold">
            {description}
          </div>
        }
        title={description}
        footer
      >
        <div className="m-auto my-4 max-h-[100vh-100px] w-full max-w-[800px] overflow-auto">
          <div dangerouslySetInnerHTML={{ __html: tooltip }} />
        </div>
      </Modal>
    </>
  );
};

const HotelProductDetailCampaign = ({
  items = [],
}: HotelProductDetailCampaignProps) => {
  const { t } = useLocale();
  const extendincludedSpecifications = items.map(
    ({ description, tooltip }, key) => (
      <li key={+key}>
        <HotelProductDetailCampaignItem
          description={description}
          tooltip={tooltip}
        />
      </li>
    ),
  );

  return (
    extendincludedSpecifications.length > 0 && (
      <>
        <h6 className="mb-4 font-semibold md:mb-0">
          {t("Campaigns and Advantages")}
        </h6>
        <ul className="grid grid-cols-1 gap-2 text-sm lg:grid-cols-3">
          {extendincludedSpecifications}
        </ul>
      </>
    )
  );
};

export default HotelProductDetailCampaign;
