/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */

"use client";

// Import Swiper styles
import "swiper/css";

import React from "react";
import { Navigation } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";

import NoImage from "@/assets/svg/images/no-image.svg";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";

interface HotelProductDetailEventItemProps {
  imageUrl?: string;
  title: string;
  description: string;
}

const HotelProductDetailEventItem = ({
  imageUrl,
  title,
  description,
}: HotelProductDetailEventItemProps) => {
  return (
    <div className="group/item rounded border border-gray-200">
      <div className="h-[190px] w-full overflow-hidden">
        {!imageUrl ? (
          <img
            className="size-full object-cover"
            src={NoImage.src}
            alt="No Image"
          />
        ) : (
          <img
            className="size-full object-cover transition-all duration-300 ease-in-out group-hover/item:scale-105"
            src={imageUrl}
            alt={`${title} Etkinlik Resmi`}
          />
        )}
      </div>
      <div className="bg-gray-50 p-4">
        <h5 className="font-semibold text-gray-800">{title}</h5>
        <p className="text-sm text-gray-400">{description}</p>
      </div>
    </div>
  );
};

export interface HotelProductDetailEventsProps {
  items: HotelProductDetailEventItemProps[];
}

const HotelProductDetailEvents = ({ items }: HotelProductDetailEventsProps) => {
  return (
    <div className="border-b-0">
      <div className="flex justify-between">
        <span className="p-0 text-xl font-semibold">Etkinlikler</span>
        {items.length > 3 && (
          <div className="hidden gap-2 md:flex">
            <div
              id="prev-button"
              className="flex size-10 cursor-pointer items-center justify-center rounded-3xl border border-gray-300 bg-white"
            >
              <LIcon name="ChevronLeft" color="#667085" size="20" />
            </div>
            <div
              id="next-button"
              className="flex size-10 cursor-pointer items-center justify-center rounded-3xl border border-gray-300 bg-white"
            >
              <LIcon color="#667085" size="20" name="ChevronRight" />
            </div>
          </div>
        )}
      </div>
      <div>
        <div className="mt-6">
          <Swiper
            spaceBetween={25}
            slidesPerView={3}
            breakpoints={{
              0: {
                slidesPerView: 1,
              },
              640: {
                slidesPerView: 2,
              },
              768: {
                slidesPerView: 3,
              },
            }}
            modules={[Navigation]}
            navigation={{
              prevEl: "#prev-button",
              nextEl: "#next-button",
            }}
          >
            {items.map(({ imageUrl, description, title }) => (
              <SwiperSlide key={title}>
                <HotelProductDetailEventItem
                  imageUrl={imageUrl}
                  title={title}
                  description={description}
                />
              </SwiperSlide>
            ))}
          </Swiper>
        </div>
      </div>
    </div>
  );
};

export default HotelProductDetailEvents;
