import React from "react";

import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useLocale } from "@/hooks/useLocale";

export interface NearDistanceType {
  distanceUnit: string;
  distance: string;
  name: string;
}

export interface HotelProductDetailLocationProps {
  address: string;
  nearDistances: NearDistanceType[];
}

const HotelProductDetailLocation = ({
  address,
  nearDistances,
}: HotelProductDetailLocationProps) => {
  const { t } = useLocale();
  return (
    <div>
      <div>
        <h6 className="font-semibold">{t("Discover Location")}</h6>
        <p
          className="mt-2 text-sm font-medium text-gray-800"
          dangerouslySetInnerHTML={{
            __html: address,
          }}
        />
      </div>
      <ul className="mt-4 w-full text-sm">
        {nearDistances.map((data, index) => (
          <li key={+index} className="my-3 grid grid-cols-4 gap-1 text-sm">
            <span className="col-span-3 line-clamp-2 text-gray-800">
              <LIcon
                name="MapPin"
                size={14}
                className="inline !text-gray-500"
              />
              &nbsp;{data.name} {data.distanceUnit}
            </span>
            <span className="col-span-1 text-right text-gray-800">
              {data.distance}
            </span>
          </li>
        ))}
      </ul>
    </div>
  );
};

export default HotelProductDetailLocation;
