/* eslint-disable react/no-danger */
/* eslint-disable tailwindcss/no-custom-classname */

"use client";

import type { icons } from "lucide-react";
import React from "react";

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion/accordion";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useLocale } from "@/hooks/useLocale";

export enum HotelOtherInfoType {
  "EatingDrinking" = 8,
}
export interface HotelOtherInfo {
  label: string;
  value: string;
  id: number;
}
export interface HotelProductDetailOtherInfoProps {
  hotelOtherInfo: HotelOtherInfo[];
}

export interface IconWithTextTypes {
  className?: string;
  text: string;
  icon: keyof typeof icons;
  size?: number;
}

const IconWithText = ({
  className = "text-base font-normal",
  icon,
  text,
  size = 20,
}: IconWithTextTypes) => {
  return (
    <div className="flex items-center gap-2">
      <LIcon name={icon} size={size} />
      <p className={className}>{text}</p>
    </div>
  );
};

const HotelProductDetailOtherInfo = ({
  hotelOtherInfo,
}: HotelProductDetailOtherInfoProps) => {
  const { t } = useLocale();
  return (
    <Accordion type="single" defaultValue="item-3" collapsible>
      <AccordionItem value="item-3" className="border-b-0">
        <AccordionTrigger className="p-0 text-xl font-semibold">
          {t("Other informations")}
        </AccordionTrigger>
        <AccordionContent>
          <div className="mt-6 flex flex-col gap-3">
            {hotelOtherInfo.map((data, index) => {
              return (
                <Card key={data.label}>
                  <Accordion type="single" collapsible>
                    <AccordionItem
                      value={`item-3-${index}`}
                      className="scroll-mt-20 border-b-0 md:scroll-mt-48"
                      id={`${data.id}-accordion`}
                    >
                      <AccordionTrigger className="p-0">
                        <IconWithText text={data.label} icon="Info" />
                      </AccordionTrigger>
                      <AccordionContent>
                        <div dangerouslySetInnerHTML={{ __html: data.value }} />
                      </AccordionContent>
                    </AccordionItem>
                  </Accordion>
                </Card>
              );
            })}
          </div>
        </AccordionContent>
      </AccordionItem>
    </Accordion>
  );
};

export default HotelProductDetailOtherInfo;
