/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
/* eslint-disable react/no-danger */
/* eslint-disable @next/next/no-img-element */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */

"use client";

import React, { useState } from "react";

import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import { SeeAllText } from "@/components/ui/see-all-text/see-all-text";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";

export interface HighlightedFeaturesType {
  text?: string;
  icon?: string;
}
export interface HotelProductDetailOverviewProps {
  informationText?: string;
  highlightedFeatures?: HighlightedFeaturesType[];
  documentNumber?: string;
}

const HotelProductDetailOverview = ({
  informationText,
  highlightedFeatures,
  documentNumber,
}: HotelProductDetailOverviewProps) => {
  const [showAllHighlightedFeatures, setShowAllHighlightedFeatures] =
    useState(false);
  const fullImage =
    informationText || (highlightedFeatures && highlightedFeatures.length > 0);
  const { isDesktop } = useBreakpoints();
  const { t } = useLocale();
  const highlightedCount = isDesktop ? 8 : 6;
  return (
    <div className="grid gap-y-6">
      {isDesktop && <h2 className="text-xl font-semibold">{t("Overview")}</h2>}
      <div className="flex w-full flex-col gap-4 overflow-hidden md:gap-10 lg:flex-row">
        <div
          data-full={!fullImage}
          className="content-area mb-4 data-[full='true']:lg:w-5/12"
        >
          {informationText && (
            <div className="flex flex-col items-start gap-4">
              <div className="flex w-full items-center justify-between">
                <h5 className="font-semibold">{t("About the hotel")}</h5>
              </div>
              {informationText.length > 200 ? (
                <div className="overflow-auto">
                  <SeeAllText
                    innerHtml
                    text={informationText}
                    classname="text-sm text-gray-500"
                    lineClampSize="2"
                  />
                </div>
              ) : (
                <div dangerouslySetInnerHTML={{ __html: informationText }} />
              )}
            </div>
          )}
          {isDesktop && documentNumber && (
            <div>
              <span className="text-sm text-gray-500">
                {t("Ministry of Culture and Tourism/Tourism") +
                  t("Operation Certificate")}
                :&nbsp;{documentNumber}
              </span>
            </div>
          )}

          {highlightedFeatures && highlightedFeatures.length > 0 && (
            <div className="mt-4 flex flex-col items-start gap-4">
              <h5 className="font-semibold">{t("Highlights")}</h5>
              <ul className="grid w-full grid-cols-2 gap-2 text-sm md:grid-cols-4 md:gap-4">
                {highlightedFeatures
                  .slice(
                    0,
                    showAllHighlightedFeatures
                      ? highlightedFeatures.length
                      : highlightedCount,
                  )
                  .map((item) => (
                    <li key={item.text}>
                      <Badge
                        className="-ml-1 w-full !gap-1 !border-0 !bg-transparent !p-0 !text-sm !font-normal"
                        leftIcon={{
                          name: "MapPin",
                          size: 12,
                          className: "shrink-0",
                        }}
                      >
                        <span className="truncate">{item.text}</span>
                      </Badge>
                    </li>
                  ))}
              </ul>
              {highlightedFeatures.length > 8 && (
                <Button
                  variant="primary-text"
                  className="!h-auto !p-0 text-primary-500"
                  rightIcon={{ name: "ChevronRight", size: 20 }}
                  onClick={() => {
                    const element = document.getElementById("facilities");
                    if (element) {
                      element.scrollIntoView({ behavior: "smooth" });
                    }
                    // If there is no element with the id "facilities", then show all highlighted features
                    else {
                      setShowAllHighlightedFeatures(
                        !showAllHighlightedFeatures,
                      );
                    }
                  }}
                >
                  {showAllHighlightedFeatures ? (
                    t("See ess")
                  ) : (
                    <>
                      {t("See all")} (
                      {highlightedFeatures.length - highlightedCount})
                    </>
                  )}
                </Button>
              )}
            </div>
          )}
        </div>
      </div>
    </div>
  );
};

export default HotelProductDetailOverview;
