"use client";

import dayjs from "dayjs";
import React, { useMemo, useState } from "react";

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion/accordion";
import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import { RadioGroup } from "@/components/ui/radio-button/radio-group";
import { useLocale } from "@/hooks/useLocale";

export interface SeasonFacilitiesType {
  icon?: string;
  type?: string;
  name?: string;
}
export interface SeasonFacilitiesViewType {
  icon?: string;
  type?: string;
  name: string[];
}
export interface SeasonType {
  id: number;
  endDate: string;
  isCurrent: boolean;
  startDate: string;
  name: string;
  facilities: SeasonFacilitiesType[];
}
export interface HotelProductDetailServicesAndFacilitiesType {
  season: SeasonType[];
}

const HotelProductDetailServicesAndFacilities = ({
  season,
}: HotelProductDetailServicesAndFacilitiesType) => {
  const [isShowMore, setIsShowMore] = useState<boolean | null>(null);
  const { t } = useLocale();

  const seasonFacilities = useMemo(
    () =>
      season
        ?.find((item) => item.isCurrent)
        ?.facilities.reduce((prev, curr) => {
          if (
            !prev.find((item) => item.type === curr.type) &&
            typeof curr.name === "string"
          ) {
            prev.push({ type: curr.type, name: [curr.name] });
          } else {
            const index = prev.findIndex((item) => item.type === curr.type);
            if (!!index && typeof curr.name === "string") {
              prev[index]?.name.push(curr.name);
            }
          }
          return prev;

          // return prev
        }, [] as SeasonFacilitiesViewType[]),
    [season],
  );

  if ((seasonFacilities?.length || 0) > 4) {
    setIsShowMore(false);
  }

  return (
    <div>
      <Accordion type="single" defaultValue="item-1" collapsible>
        <AccordionItem value="item-1" className="border-b-0">
          <AccordionTrigger className="p-0 text-xl font-semibold">
            {t("Hotel services and facilities")}
          </AccordionTrigger>
          <AccordionContent>
            <div className="pt-6">
              <RadioGroup defaultValue="one" className="flex gap-4">
                {season.map((data) => {
                  if (data.id === 0) {
                    return null;
                  }
                  return (
                    <Card className="p-1 sm:p-2 md:p-4" key={data.id}>
                      <div className="ml-1">
                        <p className="text-sm font-medium">{data.name}</p>
                        {data.id !== 0 && (
                          <p className="text-sm leading-tight text-gray-500">
                            {`${dayjs(data.startDate).format(
                              "MMM YYYY",
                            )} - ${dayjs(data.endDate).format("MMM YYYY")}`}
                          </p>
                        )}
                      </div>
                    </Card>
                  );
                })}
              </RadioGroup>
              <div className="mt-6">
                {seasonFacilities
                  ?.slice(0, isShowMore ? seasonFacilities.length : 4)
                  .map((data) => (
                    <div key={data.type}>
                      <h5 className="text-base font-semibold">{data.type}</h5>
                      <ul className="mt-4 grid w-full grid-cols-2 gap-x-4 gap-y-3 sm:grid-cols-3 md:grid-cols-4">
                        {
                          // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                          data.name!.map((item) => {
                            return (
                              <li key={item}>
                                <Badge
                                  className="-ml-1 !border-0 !bg-transparent !p-0 !text-sm !font-normal"
                                  leftIcon={{ name: "MapPin", size: 12 }}
                                >
                                  {item}
                                </Badge>
                              </li>
                            );
                          })
                        }
                      </ul>
                      <hr className="my-4" />
                    </div>
                  ))}

                {/*
                //the designs here can be added according to the status of the incoming data
                 <div>
                  <div className="flex flex-row items-center gap-4">
                    <h5 className="text-base font-semibold">Plaj & havuz</h5>

                    <Button
                      variant="primary-text"
                      className="!h-auto !p-0 text-primary-500"
                      rightIcon={{ name: "ChevronRight", size: 20 }}
                    >
                      Detaylı bilgi
                    </Button>
                  </div>

                  <ul className="mt-4 grid w-full grid-cols-2 gap-x-4 gap-y-3 text-sm sm:grid-cols-3 md:grid-cols-4">
                    {[1, 2, 3, 4, 5, 6, 7, 8].map((item) => {
                      return (
                        <li key={item}>
                          <Badge
                            className="-ml-1 !border-0 !bg-transparent !p-0 !text-sm !font-normal"
                            leftIcon={{ name: "Check", size: 12 }}
                          >
                            Denize sıfır
                          </Badge>
                        </li>
                      );
                    })}
                  </ul>
                </div> */}

                {Boolean(isShowMore) && (
                  <Button
                    variant="primary-text"
                    className="mx-auto mt-6 !h-auto !p-0 text-primary-500"
                    rightIcon={{
                      name: isShowMore ? "ChevronUp" : "ChevronDown",
                      size: 20,
                    }}
                    onClick={() => setIsShowMore(!isShowMore)}
                  >
                    {isShowMore ? t("show less") : t("Show more")}
                  </Button>
                )}
              </div>
            </div>
          </AccordionContent>
        </AccordionItem>
      </Accordion>
    </div>
  );
};

export default HotelProductDetailServicesAndFacilities;
