/* eslint-disable react-hooks/rules-of-hooks */
import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";
import { useState } from "react";

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion/accordion";
import { ThemeProviderDecorators } from "@/storybook/Decorator";

import { AccordionPaymentOption } from "./accordion-payment-option";

const meta = {
  title: "Widgets/Payment/AccordionPaymentOption",
  component: AccordionPaymentOption,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof AccordionPaymentOption>;

export default meta;

type Story = StoryObj<typeof AccordionPaymentOption>;

export const DefaultAccordionPaymentOption: Story = {
  render: () => {
    const [selectedPaymentMethod, setSelectedPaymentMethod] =
      useState("masterpass");
    return (
      <div className="">
        <Accordion className="flex flex-col gap-4" type="single" collapsible>
          <AccordionItem
            className="w-[744px] rounded-primary border bg-gray-100 px-4 py-2"
            value="masterpass"
          >
            <AccordionTrigger
              className="flex justify-between p-0 hover:no-underline"
              onClick={() => setSelectedPaymentMethod("masterpass")}
              showButton={false}
            >
              <AccordionPaymentOption
                title="Kredi/banka kartı ile öde"
                description="Kredi veya banka kartlarınızla güvenli ödeme yapabilirsiniz."
                open={selectedPaymentMethod === "creditCard"}
                id="creditCard"
              />
            </AccordionTrigger>
            <AccordionContent>
              <span>denme denememe</span>
            </AccordionContent>
          </AccordionItem>
          <AccordionItem
            className="w-[744px] rounded-primary border bg-gray-100 px-4 py-2"
            value="creditCard"
          >
            <AccordionTrigger
              className="flex justify-between p-0 hover:no-underline"
              onClick={() => setSelectedPaymentMethod("creditCard")}
              showButton={false}
            >
              <AccordionPaymentOption
                title="Masterpass ile şimdi al, sonra öde"
                description="Ödemenizi Masterpass güvencesi ile yapın."
                open={selectedPaymentMethod === "masterpass"}
                id="masterpass"
              />
            </AccordionTrigger>
            <AccordionContent>
              <span>denme denememe</span>
            </AccordionContent>
          </AccordionItem>
        </Accordion>
      </div>
    );
  },
};
