import Image from "next/image";
import type { PropsWithChildren } from "react";
import React from "react";

import LIcon from "@/components/ui/lucid-icon/lucid-icon";

export interface AccordionPaymentOptionProps extends PropsWithChildren {
  title: string;
  description: string;
  open: boolean;
  id: string;
  icon?: React.ReactNode | string;
}

const AccordionPaymentOption = (props: AccordionPaymentOptionProps) => {
  const { icon = <LIcon name="CreditCard" color="#1D2939" /> } = props; // default icon

  return (
    <div className="flex w-full justify-between">
      <div className="flex gap-4">
        <div className="flex items-center justify-center">
          <input
            className="size-[16px] rounded-md border border-primary-500 accent-primary-500"
            type="radio"
            name={props.id}
            id={props.id}
            checked={props.open}
          />
        </div>

        <div className="flex flex-col items-start text-left font-normal">
          <span className="text-base">{props.title}</span>
          <span className="text-xs text-gray-500">{props.description}</span>
        </div>
      </div>
      <div className="max-h-[24px]">
        {typeof icon === "string" ? (
          <Image src={icon as string} alt="chip" width={24} height={16} />
        ) : (
          icon
        )}
      </div>
    </div>
  );
};

export { AccordionPaymentOption };
