import Image from "next/image";

import { cn } from "@/libs/utils";

import styles from "./credit-card-infos.module.css";

export interface CreditCardInfosProps {
  showBack?: boolean;
  cardNumber: string;
  cardHolderName: string;
  cardExpireDate: string;
  cardCvv: string;
}

const CreditCardInfos = (props: CreditCardInfosProps) => {
  const cardContainerClass = `h-[202px] w-full rounded-lg border bg-gray-50 ${
    props.showBack ? styles.showBack : ""
  }`;

  return (
    <div className={cardContainerClass}>
      <div className="flex size-full flex-col justify-between font-medium text-gray-400">
        {props.showBack ? (
          <div className="flex flex-1 flex-col justify-center gap-4">
            <div className="h-[42px] w-full  bg-gray-200" />
            <div className="mx-5 flex justify-end rounded-primary border bg-white p-2">
              <span className={cn({ "text-black": "text-black" })}>
                {props.cardCvv}
              </span>
            </div>
          </div>
        ) : (
          <div className="px-6 py-4">
            <div className="flex justify-end">
              <Image
                src="/assets/images/chip.png"
                alt="chip"
                width={31}
                height={22}
              />
            </div>
            <div>
              <div className={cn({ "text-gray-500": "" })}>
                {props.cardNumber}
              </div>
              <div
                className={cn("mt-2 text-sm", {
                  "text-gray-500": "",
                })}
              >
                {props.cardHolderName}
              </div>
              <div className="mt-6 flex gap-2 text-sm">
                <span className={cn({ "text-gray-500": "" })}>
                  {props.cardExpireDate}
                </span>
              </div>
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export { CreditCardInfos };
