/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import Image from "next/image";
import { useBoolean } from "usehooks-ts";

import {
  Dialog,
  DialogContent,
  DialogHeader,
  DialogTitle,
} from "@/components/ui/dialog";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";

const WhatIsAMasterpassDialog = () => {
  const boolean = useBoolean();
  const { isDesktop } = useBreakpoints();
  const { t } = useLocale();
  return (
    <div>
      <span
        className="cursor-pointer text-sm font-medium text-primary-500"
        onClick={boolean.toggle}
      >
        {isDesktop ? t("What is Masterpass?") : <LIcon name="Info" />}
      </span>
      <Dialog modal open={boolean.value} onOpenChange={boolean.setValue}>
        <DialogContent className={`${isDesktop ? "min-w-[625px]" : ""}`}>
          <DialogHeader>
            <DialogTitle>{t("What is Masterpass?")}</DialogTitle>
          </DialogHeader>
          <div className="flex max-h-[626px] flex-col gap-6 overflow-y-scroll">
            <Image
              src="/assets/images/what-is-masterpass.png"
              alt="chip"
              width={575}
              height={225}
            />
            <div className="flex flex-col gap-4">
              <span className="text-sm font-normal text-gray-500">
                {t(
                  "Masterpass is Mastercard's digital payment solution. It stores your card information in a single secure infrastructure and allows you to make your payments quickly.",
                )}
              </span>
              <span className="text-sm font-normal text-gray-500">
                {t(
                  "You can save not only your cards with the Mastercard® logo, but all your debit and credit cards to the Masterpass infrastructure.",
                )}
              </span>
              <span className="text-sm font-normal text-gray-500">
                {t(
                  "Since your card information is already registered, Masterpass offers faster, safer and easier shopping on thousands of valid websites or mobile applications. It allows you to pay securely without re-entering your card information.",
                )}
              </span>
            </div>
            <div className="flex items-center justify-center">
              <Image
                src="/assets/images/masterpass-logo.png"
                alt="chip"
                width={154}
                height={10}
              />
            </div>
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
};

export { WhatIsAMasterpassDialog };
