/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/jsx-key */
/* eslint-disable @next/next/no-img-element */
import React, { useState } from "react";

import { Button } from "@/components/ui/button/button";
import { Carousel } from "@/components/ui/carousel/carousel";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";

export interface ImageProps {
  thumbnail: string;
  src: string;
  alt: string;
}

export interface PhotoGalleryProps {
  images: ImageProps[];
  title?: string;
  splitCount?: number;
  className?: string;
  preview?: boolean;
}

interface PhotoGalleryTitleProps {
  title: string;
}
const PhotoGalleryTitle = ({ title }: PhotoGalleryTitleProps) => {
  return <h3 className="mb-2 text-2xl font-semibold text-gray-800">{title}</h3>;
};

const PhotoGallery = ({
  title,
  images,
  splitCount = 4,
  className,
  preview = true,
}: PhotoGalleryProps) => {
  const [collapsed, setCollapsed] = useState<boolean | null>(
    images.length < (splitCount || 0) ? null : true,
  );
  const [clickedIndex, setClickedIndex] = useState<number | null>(null);
  const { modalOpen, openModal, closeModal } = useModal({ open: false });
  return (
    <>
      <div
        className={className}
        id={`${title?.replaceAll(" ", "-")}_gallery_section`}
      >
        {title && <PhotoGalleryTitle title={title} />}
        <div className="grid grid-cols-4 gap-4">
          {collapsed && splitCount
            ? images.slice(0, splitCount).map((image, index) => (
                <img
                  key={+index}
                  src={image.thumbnail}
                  alt="gallery"
                  className="h-[150px] w-full select-none rounded object-cover"
                  loading="lazy"
                  onClick={() => {
                    setClickedIndex(index);
                    if (preview) openModal();
                  }}
                />
              ))
            : images.map((image, index) => (
                <img
                  key={+index}
                  src={image.thumbnail}
                  alt="gallery"
                  className="h-[150px] w-full select-none rounded-sm object-cover	"
                  loading="lazy"
                  onClick={() => {
                    setClickedIndex(index);
                    if (preview) openModal();
                  }}
                />
              ))}
        </div>
        {collapsed !== null && !!splitCount && (
          <div>
            <Button
              variant="primary-text"
              className="!h-auto !p-0"
              onClick={() => setCollapsed(!collapsed)}
            >
              {collapsed ? (
                <div className="flex items-center justify-start">
                  <span>
                    Daha Fazla Göster ({images.length - (splitCount || 0)})
                  </span>
                  <LIcon name="ChevronRight" size={14} />
                </div>
              ) : (
                "Daha Az"
              )}
            </Button>
          </div>
        )}
      </div>
      {preview && (
        <Modal
          size="full"
          open={modalOpen}
          closable={false}
          footer
          className="z-[103] flex flex-col justify-start bg-sky-950"
          urlHash={`${title?.replaceAll(" ", "-")}_gallery`}
          onClose={closeModal}
        >
          <div className="mx-auto flex w-full max-w-[800px] items-center justify-start gap-2">
            <Button variant="primary-text" onClick={closeModal}>
              <LIcon name="X" size={18} className="text-white" />
            </Button>
            <h2 className="select-none text-2xl font-semibold text-white">
              {title}
            </h2>
          </div>
          <div className="flex size-full grow flex-col justify-center">
            <Carousel
              sliderPerView={1}
              pagination={false}
              initialSlide={clickedIndex || 0}
            >
              {images.map((image, index) => (
                <div className="flex h-[70vh] w-full items-center justify-center ">
                  <img
                    key={+index}
                    src={image.src}
                    alt={`${title}, ${index}`}
                    className="size-full max-w-[1040px] select-none rounded-lg object-contain"
                    loading="lazy"
                  />
                </div>
              ))}
            </Carousel>
          </div>
        </Modal>
      )}
    </>
  );
};

export default PhotoGallery;
