/* eslint-disable @next/next/no-img-element */
import Image from "next/image";
import type { PropsWithChildren } from "react";

import { Badge } from "@/components/ui/badge/badge";
import type { ButtonProps } from "@/components/ui/button/button";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import DefautlImage from "@/public/assets/images/defaultImage.jpg";

interface TextProps {
  text: string;
}

interface CardActionProps {
  onClick: () => void;
  buttonVariant?: ButtonProps["variant"];
  buttonText?: string;
}

const ProductCardWrap = ({ children }: PropsWithChildren) => {
  return (
    <Card className="flex gap-2">
      <div className="flex items-center justify-between gap-2">{children}</div>
    </Card>
  );
};

const ProductCardBrand = (props: { imageUrl?: string }) => {
  return (
    <div className="flex size-full gap-2">
      {props.imageUrl ? (
        <img
          className="h-[214px] w-full object-cover md:h-full"
          src={props.imageUrl}
          alt={props.imageUrl}
        />
      ) : (
        <Image
          className="h-[214px] w-full object-cover md:h-full"
          src={props.imageUrl ?? DefautlImage}
          alt=""
        />
      )}
    </div>
  );
};

const ProductCardTitle = ({ text }: TextProps) => {
  return <h2 className="group-hover:underline">{text}</h2>;
};

const ProductCardInformtation = ({ text }: TextProps) => {
  return (
    <div className="flex gap-2">
      <div className="flex items-center gap-1">
        <LIcon name="UtensilsCrossed" size="14" />
        <p className="text-sm">{text}</p>
      </div>
    </div>
  );
};

const ProductCardInformationBadge = ({ text }: TextProps) => {
  return (
    <Badge key={text} variant="grayGreen">
      {text}
    </Badge>
  );
};

const ProductCardAction = ({
  onClick,
  buttonVariant,
  buttonText,
}: CardActionProps) => {
  return (
    <div className="flex justify-between">
      <Button
        onClick={onClick}
        variant={buttonVariant || "primary"}
        className="min-w-[105px]"
      >
        {buttonText || "İncele"}
      </Button>
    </div>
  );
};

const ProductCardPrice = (props: { price: string }) => {
  return <p>{props.price}</p>;
};

export {
  ProductCardAction,
  ProductCardBrand,
  ProductCardInformationBadge,
  ProductCardInformtation,
  ProductCardPrice,
  ProductCardTitle,
  ProductCardWrap,
};
