import React, { useRef } from "react";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useLocale } from "@/hooks/useLocale";
import type { Image } from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";

import NavigationTab from "../navigation-tab/navigation-tab";
import PhotoGallery from "../photo-gallery/photo-gallery";

type Props = {
  onClose?: () => void;
  images?: Image[];
};

const ProductDetailPhotoGallery = ({ onClose, images }: Props) => {
  const { t } = useLocale();
  const galleryRef = useRef<HTMLDivElement>(null);
  const groupedImages = images?.reduce(
    (acc, image, index) => {
      if (index === 0) return acc;
      const key = image.categoryType;
      return {
        ...acc,
        [key]: [...(acc[key] || []), image],
      };
    },
    {} as Record<string, Image[]>,
  );
  return (
    <div ref={galleryRef}>
      <div className="sticky -top-px flex h-fit flex-col items-start justify-between bg-white">
        <div className="mx-auto flex w-full items-center justify-between px-2 pt-4 md:max-w-[800px] md:px-0 ">
          <h2 className="text-2xl font-semibold text-gray-800">
            {t("Photos")}
          </h2>
          <div>
            <Button
              variant="primary-text"
              className="!h-auto !p-0"
              onClick={() => onClose?.()}
            >
              <LIcon name="X" size={14} />
            </Button>
          </div>
        </div>
        <div className="relative mx-auto size-full md:max-w-[800px] ">
          {/* Header */}
          <NavigationTab
            className="mb-0 mt-4"
            items={Object.keys(groupedImages || {}).map((key) => ({
              value: key,
              label: key,
            }))}
            onChange={(value) => {
              const element = document.getElementById(
                `${value?.replaceAll(" ", "-")}_gallery_section`,
              );
              const containerElement = galleryRef.current?.parentElement;
              const headerOffset = 120;
              const elementPosition = element?.getBoundingClientRect().top || 0;
              const elementDocumentPosition = elementPosition - headerOffset;
              const offsetPosition =
                elementDocumentPosition + (containerElement?.scrollTop || 0);

              if (
                containerElement?.scrollTop !== 0 &&
                offsetPosition === elementDocumentPosition
              )
                return;

              containerElement?.scrollTo({
                top: offsetPosition,
                behavior: "smooth",
              });
            }}
          />
        </div>
      </div>
      <div className="mx-auto md:max-w-[800px]">
        <div className="px-2 py-4 pb-10 md:px-0">
          {Object.keys(groupedImages || {}).map((key) => (
            <PhotoGallery
              key={key}
              title={key}
              images={
                groupedImages?.[key]?.map((image) => ({
                  thumbnail: image.url,
                  src: image.url,
                  alt: "gallery",
                })) || []
              }
              className="mb-4"
            />
          ))}
        </div>
      </div>
    </div>
  );
};

export default ProductDetailPhotoGallery;
