/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */

"use client";

import Image from "next/image";

import Empty from "@/assets/svg/images/empty.svg";
import NoImage from "@/assets/svg/images/no-image.svg";
import Container from "@/components/shared/container";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import type { Image as ImageTYPE } from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";

import ProductDetailPhotoGallery from "../../product-detail-photo-gallery/product-detail-photo-gallery";

interface ProductDetailCoverGalleryProps {
  images: ImageTYPE[];
  noImageText?: string;
}

function ProductDetailCoverGallery({
  images = [],
  noImageText,
}: ProductDetailCoverGalleryProps) {
  const {
    closeModal: galleryCloseModal,
    openModal: galleryOpenModal,
    modalOpen: galleryModalOpen,
  } = useModal({ open: false });

  return (
    <>
      <Container>
        {images.length === 0 && (
          <div className="h-[370px] w-full rounded-primary bg-gray-200">
            <div className="flex flex-col items-center justify-center pt-10">
              <div className="flex justify-center">
                <Image src={NoImage} alt="No Image" />
              </div>
              <div className="mt-[-85px] text-center text-lg text-gray-500">
                {noImageText || "Bu ürünün görselleri hazırlık aşamasındadır."}
              </div>
            </div>
          </div>
        )}
        {images.length > 0 && (
          <div className="grid grid-cols-[1fr_498px] gap-2">
            {!!images[0] && (
              <div
                className="col-span-1 h-[370px] cursor-pointer overflow-hidden rounded-primary bg-red-200"
                onClick={galleryOpenModal}
              >
                <img
                  src={images[0]?.url}
                  alt={`${images[0]?.categoryType} - cover image`}
                  className="size-full object-cover"
                />
              </div>
            )}
            <div className="col-span-1 grid h-[370px] grid-cols-2 grid-rows-2 gap-2">
              {[...images].splice(1, 4).map((image, index) => (
                <div
                  key={+index}
                  className="relative col-span-1 cursor-pointer overflow-hidden rounded-primary"
                  onClick={galleryOpenModal}
                >
                  <img
                    src={image.url}
                    alt={`${image.categoryType} - cover image`}
                    className="size-full object-cover"
                  />
                  {index === 3 && images?.length && images?.length > 5 && (
                    <div className="absolute bottom-3 right-3 flex items-center justify-center rounded-primary bg-black px-2 py-1">
                      <span className="flex items-center text-sm font-semibold text-white">
                        {" "}
                        <LIcon name="Image" size={12} />
                        &nbsp;+&nbsp;{images.length - 5}
                      </span>
                    </div>
                  )}
                </div>
              ))}
              {images.length < 5 &&
                new Array(5 - images.length).fill(0).map((_, index) => (
                  <div
                    key={+index}
                    className="relative col-span-1 overflow-hidden rounded-primary"
                  >
                    <Image src={Empty} alt="No Image" />
                  </div>
                ))}
            </div>
          </div>
        )}
      </Container>
      <Modal
        size="full"
        className="z-[102] !p-0"
        open={galleryModalOpen}
        footer
        closable={false}
        urlHash="product-detail-gallery"
        onClose={galleryCloseModal}
      >
        <ProductDetailPhotoGallery
          onClose={galleryCloseModal}
          images={images}
        />
      </Modal>
    </>
  );
}

export default ProductDetailCoverGallery;
