/* eslint-disable @next/next/no-img-element */
import Image from "next/image";
import React from "react";

import NoImage from "@/assets/svg/images/no-image.svg";
import { Carousel } from "@/components/ui/carousel/carousel";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";

import ProductDetailPhotoGallery from "../../product-detail-photo-gallery/product-detail-photo-gallery";

interface ImageProps {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl?: any;
}

interface ProductDetailOverviewProps {
  images: ImageProps[];
}
export default function ProductDetailGallery({
  images,
}: ProductDetailOverviewProps) {
  const {
    closeModal: galleryCloseModal,
    openModal: galleryOpenModal,
    modalOpen: galleryModalOpen,
  } = useModal({ open: false });
  return (
    <>
      <div className="relative min-h-[50vw] rounded-primary md:min-h-0 md:w-full data-[full='false']:md:w-7/12">
        {(images && images.length === 0) ||
          (!images && (
            <div className="h-[262px] w-full rounded-primary bg-gray-200">
              <div className="flex flex-col items-center justify-center">
                <div className="flex justify-center">
                  <Image src={NoImage} alt="No Image" />
                </div>
                <div className="mt-[-85px] text-center text-lg text-gray-500">
                  Bu ürünün görselleri hazırlık aşamasındadır.
                </div>
              </div>
            </div>
          ))}
        {images &&
          (images.length > 1 ? (
            <div className="relative">
              <Carousel className="h-[262px] w-full md:h-[358px]">
                {images?.map((image) => (
                  <Image
                    className="rounded-primary object-cover"
                    layout="fill"
                    src={image.highResolutionUrl ?? image.url}
                    alt="Hotel card images"
                    key={image.highResolutionUrl ?? image.url}
                    onClick={galleryOpenModal}
                  />
                ))}
              </Carousel>
              <div className="absolute bottom-3 right-3 z-10 bg-[#10182880] p-1 text-xs text-white">
                + {images.length}
              </div>
            </div>
          ) : (
            images?.map((image) => (
              <Image
                className="rounded-primary object-cover "
                layout="fill"
                src={image.highResolutionUrl}
                alt="Hotel card images"
                key={image.highResolutionUrl}
                onClick={galleryOpenModal}
              />
            ))
          ))}
      </div>

      <Modal
        size="full"
        className="z-[102] !p-0"
        urlHash="product-detail-gallery"
        open={galleryModalOpen}
        onClose={galleryCloseModal}
        header={false}
        footer
        closable={false}
      >
        <ProductDetailPhotoGallery
          onClose={galleryCloseModal}
          images={images}
        />
      </Modal>
    </>
  );
}
