import React from "react";

import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import type { LIconProps } from "@/components/ui/lucid-icon/lucid-icon";

import ShareButton from "../../share-button/share-button";

export interface RoomFacilities {
  text: string;
  icon: LIconProps;
}

export interface ProductDetailTitleProps {
  title?: string;
  roomFacilities?: RoomFacilities[];
  boardType?: string;
}

const ProductDetailTitle = ({
  title,
  roomFacilities,
  boardType,
}: ProductDetailTitleProps) => {
  return (
    <div className="flex w-full flex-col justify-between gap-4 bg-white py-4 md:flex-row">
      <div className="flex flex-col gap-2">
        <div className="flex items-center justify-between gap-2">
          <span className="text-xl font-bold leading-[30px] text-gray-800 md:text-3xl">
            {title}
          </span>
          <div className="md:hidden">
            <ShareButton />
          </div>
        </div>
        <div className="flex flex-wrap gap-2">
          {roomFacilities &&
            roomFacilities.length > 0 &&
            roomFacilities.map((item, index) => (
              <Badge key={+index} leftIcon={item.icon}>
                {item.text}
              </Badge>
            ))}
        </div>
        {boardType && <Badge className="w-fit">{boardType}</Badge>}
      </div>
      <div className="hidden flex-col gap-4 md:flex">
        <div className="flex flex-col gap-4 md:flex-col-reverse">
          <div className="flex w-full gap-2">
            <div className="hidden md:block">
              <ShareButton />
            </div>
            <a className="w-full" href="#rooms">
              <Button className="w-full md:w-[248px]" variant="primary">
                Rezervasyon Yap
              </Button>
            </a>
          </div>
        </div>
      </div>
    </div>
  );
};
export { ProductDetailTitle };
