import type { Meta, StoryObj } from "@storybook/react";

import { ThemeProviderDecorators } from "@/storybook/Decorator";
import { passwordValidation } from "@/validations/form-rules/password-rules";
import { checkDateOfBirth } from "@/validations/form-rules/rules/date-of-birth-rule";
import { checkEmail } from "@/validations/form-rules/rules/mail-rules";
import { nameValidation } from "@/validations/form-rules/rules/name-rule";
import { checkPhoneNumber } from "@/validations/form-rules/rules/phone-number-rule";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

import ProfileMemberShipInformations from "./profile-membership-form";

const meta = {
  title: "Widgets/Profile/ProfileMemberShipInformations",
  component: ProfileMemberShipInformations,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
} satisfies Meta<typeof ProfileMemberShipInformations>;

export default meta;

type Story = StoryObj<typeof ProfileMemberShipInformations>;

export const DefaultProfileMemberShipInformations: Story = {
  render: () => {
    return (
      <div className="flex items-center justify-center">
        <ProfileMemberShipInformations
          validations={{
            email: checkEmail,
            surname: nameValidation,
            gender: {
              required: requiredRule,
            },
            dateOfBirth: checkDateOfBirth,
            phoneNumber: checkPhoneNumber,
            name: nameValidation,
            password: passwordValidation,
          }}
          onSubmit={(values) => {
            // eslint-disable-next-line no-console
            console.log({ values });
          }}
        />
      </div>
    );
  },
};
