/* eslint-disable no-nested-ternary */
/* eslint-disable tailwindcss/migration-from-tailwind-2 */
import { t } from "i18next";
import React from "react";
import { useBoolean, useToggle } from "usehooks-ts";

import FormMaskInput from "@/components/form/components/basic/form-mask-input";
import FormTextInput from "@/components/form/components/basic/form-text-input";
import FormBirthDateInput from "@/components/form/components/related/form-birthdate-input";
import FormEmailInput from "@/components/form/components/related/form-email-input";
import FormGenderRadio from "@/components/form/components/related/form-gender-radio";
import FormPhoneInput from "@/components/form/components/related/form-phone-input";
import Form from "@/components/form/form";
import FormItem from "@/components/form/form-item";
import { Button } from "@/components/ui/button/button";
import { PasswordInput } from "@/components/ui/password-input/password-input";
import { NewPasswordForm } from "@/components/widget/new-password-form/new-password-form";
import { useAuth } from "@/features/auth/hooks/use-auth";
import { PhoneNumberHelper } from "@/libs/helpers/phone-number-helper";
import { useResetPassword } from "@/services/white-label/auth/reset-password.services";
import { passwordValidation } from "@/validations/form-rules/password-rules";

import styles from "../profile.module.css";
import ProfileInfo from "../profile-info";

interface FormType {
  name: string;
  surname: string;
  gender: string;
  dateOfBirth: string;
  // phoneNumber: string;
  phoneNumber: {
    dialCode: string;
    phoneNumber: string;
  };
  password: string;
  email: string;
  milesCode?: string;
}

export interface ProfileMemberShipFormProps {
  defaultValues?: Partial<FormType>;
  onSubmit: (variables: FormType) => void;
  isLoading?: boolean;
  validations: {
    name: any;
    surname: any;
    gender: any;
    dateOfBirth: any;
    phoneNumber: any;
    password: any;
    email: any;
  };
}

const ProfileMemberShipInformations = (props: ProfileMemberShipFormProps) => {
  const { token } = useAuth();
  const queryMode = window.location.search.includes("mode=edit");
  const [value, toggle] = useToggle(queryMode);
  const { value: profileNewPassword, toggle: toggleProfileNewPassword } =
    useBoolean(false);

  const resetPasswordMutation = useResetPassword({
    onSuccess() {
      toggleProfileNewPassword();
    },
  });

  async function handleSubmit(params: FormType) {
    toggle();
    props.onSubmit(params);
    window.history.pushState({}, "", window.location.pathname);
  }

  return (
    <div className={styles.contentWrap}>
      <div className={styles.headingWrap}>
        <h1 className={styles.heading}>Üyelik Bilgileri</h1>
        {!value && (
          <Button onClick={toggle} variant="link">
            Düzenle
          </Button>
        )}
      </div>

      {!value && (
        <div className="">
          <div className="my-2 grid grid-cols-1 gap-x-3 gap-y-4 lg:grid-cols-2">
            <ProfileInfo label="Ad" value={props.defaultValues?.name} />
            <ProfileInfo label="Soyad" value={props.defaultValues?.surname} />
            <ProfileInfo
              label="Cinsiyet"
              value={
                props.defaultValues?.gender
                  ? props.defaultValues?.gender === "0"
                    ? "Erkek"
                    : "Kadın"
                  : null
              }
            />
            <ProfileInfo
              label="Doğum Tarihi"
              value={props.defaultValues?.dateOfBirth}
            />
            <ProfileInfo
              label="Mail Adresi"
              value={props.defaultValues?.email}
            />
            <ProfileInfo
              label="Telefon Numarası"
              value={
                props.defaultValues?.phoneNumber?.phoneNumber &&
                PhoneNumberHelper.phoneNumberStringToFormattedString(
                  PhoneNumberHelper.phoneNumberToString(
                    props.defaultValues?.phoneNumber,
                  ),
                )
              }
              // value={`${props.defaultValues?.phoneNumber?.dialCode}${props.defaultValues?.phoneNumber?.phoneNumber}`}
            />
            <ProfileInfo label="Şifre" value="*******" />
            <ProfileInfo
              label="Miles & Smiles Kart Numarası"
              value={props.defaultValues?.milesCode ?? ""}
            />
          </div>
        </div>
      )}

      {value && (
        <Form
          // eslint-disable-next-line react/jsx-no-bind
          onSubmit={handleSubmit}
          defaultValues={{
            name: "",
            surname: "",
            gender: "",
            dateOfBirth: "",
            email: "",
            phoneNumber: {
              dialCode: "+90",
              phoneNumber: "",
            },
            milesCode: "",
            // phoneNumber: { dialCode: "+90", phoneNumber: "" },
            password: "",
            ...props.defaultValues,
          }}
        >
          <div>
            <FormGenderRadio name="gender" />
            <div className="my-2 grid grid-cols-1 gap-3 lg:grid-cols-2">
              <FormTextInput
                rules={props.validations.name}
                fullWidth
                name="name"
                label="Ad"
                size="lg"
              />
              <FormTextInput
                rules={props.validations.surname}
                fullWidth
                name="surname"
                label="Soyad"
                size="lg"
              />

              <FormBirthDateInput
                fullWidth
                name="dateOfBirth"
                size="lg"
                label={`${t("Date of Birth")}* ${t("(dd.mm.yyyy)")}`}
              />
              <FormEmailInput fullWidth name="email" size="lg" label="Email" />
              <FormPhoneInput
                fullWidth
                name="phoneNumber"
                size="lg"
                label="Telefon Numarası"
              />
              <FormMaskInput
                size="lg"
                placeholder="Miles & Smiles Kart Numarası"
                name="milesCode"
                mask="miles"
              />
              <FormItem name="password" rules={props.validations.password}>
                {({ field, fieldState }) => (
                  <div className="flex flex-col gap-6">
                    <PasswordInput
                      {...field}
                      innerRef={
                        field.ref as unknown as React.RefObject<HTMLInputElement>
                      }
                      fullWidth
                      label="Şifre*"
                      size="lg"
                      isInvalid={!!fieldState.error}
                      errorMessage={fieldState.error?.message}
                    />
                    {value && (
                      // eslint-disable-next-line jsx-a11y/click-events-have-key-events, jsx-a11y/no-static-element-interactions
                      <span
                        onClick={toggleProfileNewPassword}
                        className="cursor-pointer text-sm font-medium text-blue-500"
                      >
                        Şifre Değiştir
                      </span>
                    )}
                  </div>
                )}
              </FormItem>
            </div>
          </div>

          {value && (
            <div className={styles.buttonGroup}>
              <Button onClick={toggle} variant="outline-primary">
                Vazgeç
              </Button>
              <Button type="submit" variant="primary" loading={props.isLoading}>
                Kaydet
              </Button>
            </div>
          )}
        </Form>
      )}

      {profileNewPassword && (
        // eslint-disable-next-line tailwindcss/migration-from-tailwind-2
        <div className="fixed left-0 top-0 z-50 flex size-full items-center justify-center bg-black bg-opacity-50 shadow-2xl">
          <NewPasswordForm
            onClose={() => toggleProfileNewPassword()}
            onSubmit={(values) => {
              resetPasswordMutation.mutate({
                Token: token?.accessToken || "",
                Email: props.defaultValues!.email!.toString(),
                NewPassword: values.newPassword,
                NewPasswordAgain: values.newPassword,
              });
            }}
            validations={{
              password: passwordValidation,
            }}
            className="fixed left-1/2 top-1/2 z-50 min-w-[350px] -translate-x-1/2 -translate-y-1/2 gap-4 border border-gray-200 bg-white shadow-lg duration-200"
            profileNewPassword
          />
        </div>
      )}
    </div>
  );
};

export default ProfileMemberShipInformations;
