/* eslint-disable @typescript-eslint/no-shadow */
/* eslint-disable react/no-array-index-key */
import React from "react";
import { useToggle } from "usehooks-ts";

import FormCountrySelect from "@/components/form/components/related/form-country-select";
import FormIdentityInput from "@/components/form/components/related/form-identity-input";
import FormPassportDateInput from "@/components/form/components/related/form-passport-date-input";
import Form from "@/components/form/form";
import FormItem from "@/components/form/form-item";
import { Button } from "@/components/ui/button/button";
import { Input } from "@/components/ui/input/input";

import styles from "../profile.module.css";
import ProfileInfo from "../profile-info";

interface FormType {
  country: Country;
  tcNo: string;
  passportNo: string;
  pasaportDate: string;
  passportCountry: Country;
}

interface Country {
  id: number | null;
  name: string;
}

export interface ProfilePassportFormProps {
  defaultValues?: Partial<FormType>;
  countries: Country[];
  onSubmit: (variables: FormType) => void;
  isLoading?: boolean;
  validations: {
    country: any;
    tcNo: any;
    passportNo: any;
    pasaportDate: any;
    passportCountry: any;
  };
}

const ProfilePassportInformations = (props: ProfilePassportFormProps) => {
  const queryMode = window.location.search.includes("mode=edit");
  const [value, toggle] = useToggle(queryMode);

  async function handleSubmit(params: FormType) {
    toggle();
    props.onSubmit(params);
    window.history.pushState({}, "", window.location.pathname);
  }

  return (
    <div className={styles.contentWrap}>
      <div className={styles.headingWrap}>
        <h1 className={styles.heading}>Pasaport ve Kimlik Bilgileri</h1>
        {!value && (
          <Button onClick={toggle} variant="link">
            Düzenle
          </Button>
        )}
      </div>

      {!value && (
        <div>
          <div className="my-2 grid grid-cols-1 gap-x-3 gap-y-4 lg:grid-cols-2">
            <ProfileInfo
              label="Ülke/ Uyruk"
              value={props.defaultValues?.country?.name}
            />
            <ProfileInfo label="Kimlik No" value={props.defaultValues?.tcNo} />
            <ProfileInfo
              label="Pasaport No"
              value={props.defaultValues?.passportNo}
            />
            <ProfileInfo
              label="Pasaport Geçerlilik Tarihi"
              value={props.defaultValues?.pasaportDate}
            />
            <ProfileInfo
              label="Pasaport Verilen Ülke"
              value={props.defaultValues?.passportCountry?.name}
            />
          </div>
        </div>
      )}

      {value && (
        <Form
          // eslint-disable-next-line react/jsx-no-bind
          onSubmit={handleSubmit}
          defaultValues={{
            country: props.defaultValues?.country?.id
              ? props.defaultValues.country
              : undefined,
            tcNo: props.defaultValues?.tcNo ?? "",
            passportNo: props.defaultValues?.passportNo ?? "",
            pasaportDate: props.defaultValues?.pasaportDate ?? "",
            passportCountry: props.defaultValues?.passportCountry?.id
              ? props.defaultValues.passportCountry
              : undefined,
          }}
        >
          <div className="my-2 grid  grid-cols-1 gap-3 lg:grid-cols-2">
            <FormCountrySelect
              onChange={() => {}}
              name="country"
              rules={props.validations.country}
              placeholder="Ülke/ Uyruk*"
            />

            <FormIdentityInput
              fullWidth
              name="tcNo"
              size="lg"
              label="TC Kimlik No*"
              rules={{
                required: props.validations.tcNo.required,
                validate: (value: string) =>
                  props.validations.tcNo.validete(value),
              }}
            />
            <FormItem name="passportNo" rules={props.validations.passportNo}>
              {({ field, fieldState }) => (
                <Input
                  {...field}
                  innerRef={
                    field.ref as unknown as React.RefObject<HTMLInputElement>
                  }
                  fullWidth
                  label="Pasaport No"
                  size="lg"
                  isInvalid={!!fieldState.error}
                  errorMessage={fieldState.error?.message}
                />
              )}
            </FormItem>
            <FormPassportDateInput
              fullWidth
              name="pasaportDate"
              size="lg"
              label="Pasaport Geçerlilik Tarihi"
            />
            <FormCountrySelect
              onChange={() => {}}
              name="passportCountry"
              placeholder="Pasaport Verilen Ülke"
            />
          </div>
          {value && (
            <div className={styles.buttonGroup}>
              <Button onClick={toggle} variant="outline-primary">
                Vazgeç
              </Button>
              <Button type="submit" variant="primary" loading={props.isLoading}>
                Kaydet
              </Button>
            </div>
          )}
        </Form>
      )}
    </div>
  );
};

export default ProfilePassportInformations;
