/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Image from "next/image";
import type { PropsWithChildren } from "react";
import React, { useCallback, useEffect, useRef, useState } from "react";
import { useWindowSize } from "usehooks-ts";

import Gear from "@/assets/svg/icons/gear";
import NoImage from "@/assets/svg/images/no-image.svg";
import { Button } from "@/components/ui/button/button";
import { Collapsible } from "@/components/ui/collapsible/collapsible";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import {
  CarType,
  FuelType,
} from "@/services/eva-display/rent-a-car/rent-a-car.enums";
import type { Car } from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";
import type { RentACarItem } from "@/services/eva-display/rent-a-car/rent-a-car-search/rent-a-car-search.types";

import styles from "./rent-a-car-card.module.css";

export interface RentACarCardProps {
  id: string;
  item: Car;
  hideDetail?: boolean;
  hidePrimaryButton?: boolean;
  className?: string;
  loading?: boolean;
  primaryButtonText?: string;
  primaryButtonVariant?: "primary" | "outline-primary";
  onClickPrimaryButton?: (id: string) => void;
}

export const carRentalProviderImageUrl = {
  "": "",
  EC: "https://ams3.digitaloceanspaces.com/concore-stg/concore/media/site/assets/img/logos/EC.svg",
  SXT: "https://ams3.digitaloceanspaces.com/concore-stg/concore/media/site/assets/img/logos/SXT.svg",
};

function RentACarCardDescription({ children }: PropsWithChildren) {
  return (
    children && (
      <div>
        <div className="inline-block whitespace-nowrap text-sm font-normal leading-[20px] tracking-normal text-[#667084]">
          {children}
        </div>
      </div>
    )
  );
}

export function RentACarCardSpesification({
  item,
  colorVariant = "black",
}: {
  item: {
    carDetail: {
      automaticTransmission: boolean;
      fuelType: FuelType;
      passengerCount: number;
    };
  };
  colorVariant?: "black" | "gray";
}) {
  return (
    <div
      className={cn(
        "mt-2 grid grid-cols-[1fr] gap-2 text-sm  md:grid-cols-[auto_auto_1fr]",
        colorVariant === "black" ? "text-gray-800" : "text-gray-500",
      )}
    >
      <div className="flex items-center justify-start gap-1">
        <Gear color={colorVariant} />
        {item.carDetail.automaticTransmission ? "Otomatik" : "Manuel"}
      </div>
      {item.carDetail.fuelType !== FuelType.Unspecified && (
        <div className="flex items-center justify-start gap-1">
          <LIcon name="Fuel" size={14} />
          {FuelType[item.carDetail.fuelType]}
        </div>
      )}
      {!!item.carDetail.passengerCount && (
        <div className="flex items-center justify-start gap-1">
          <LIcon name="Users" size={14} />
          {item.carDetail.passengerCount} Kişilik
        </div>
      )}
    </div>
  );
}

function RentACarCardItemDetail({
  isOpen = false,
  onClose,
  item,
}: {
  isOpen?: boolean;
  onClose?: (open?: boolean) => void;
  item: RentACarItem;
}) {
  const windowSize = useWindowSize();
  const isDesktop = windowSize.width > 640;
  const WrapperContent = isDesktop ? Collapsible : Modal;

  return (
    isOpen && (
      <WrapperContent
        open={isOpen}
        onClose={onClose}
        closable={false}
        className="p-4"
        footer=" "
      >
        {isDesktop ? (
          <div className="mb-4 h-1 w-full border-t border-gray-200" />
        ) : (
          <div>
            <div className="mb-2 font-semibold">Detaylı Bilgi</div>
            <div className="mb-4 h-1 w-full border-t border-gray-200" />
          </div>
        )}
        <div className="grid grid-cols-1 gap-4 md:grid-cols-2">
          {/* Detail Item - Deposit */}
          <div>
            <div className="mb-1 text-sm font-medium">Depozito</div>
            <div className="text-sm text-gray-500">
              {PriceManager({
                currency: item.carDetail.deposit.slice(0, 3) || "TRY",
                value: +item.carDetail.deposit.slice(3),
              })}
              : Yolculuğunuzda HGS-KGS gibi ödemeleri güvence altına almak
              amacıyla kredi kartınızda bu tutar bloke edilir. Aracı teslim
              etmenizin ardından bloke işlemi kaldırılır.
            </div>
          </div>
          {/* Detail Item - Return */}
          <div>
            <div className="mb-1 text-sm font-medium">Teslimat</div>
            <div className="text-sm text-gray-500">
              Ofis Teslim: Aracınızı, rezervasyonunuzu yaptığınız firmanın
              ofisinden teslim alırsınız.
            </div>
          </div>
          {/* Detail Item - Driver Age */}
          <div>
            <div className="mb-1 text-sm font-medium">Sürücü Yaşı</div>
            <div className="text-sm text-gray-500">
              Sürücü {item.carDetail.ageLimit} yaşından büyük olmalıdır.
            </div>
          </div>
          {/* Detail Item - Driver License */}
          <div>
            <div className="mb-1 text-sm font-medium">Sürücü Ehliyeti</div>
            <div className="text-sm text-gray-500">
              Sürücü, en az {item.carDetail.driverLicanseLimit} yıllık ehliyete
              sahip olmalıdır.
            </div>
          </div>
          {/* Detail Item - Cancellation Policy */}
          <div>
            <div className="mb-1 text-sm font-medium">İptal Politikası</div>
            <div className="text-sm text-gray-500">
              Rezervasyon 24 saat öncesine kadar ücretsiz iptal edilebilir.
            </div>
          </div>
          {/* Detail Item - Kilometer Limit */}
          <div>
            <div className="mb-1 text-sm font-medium">Kilometre Sınırı</div>
            <div className="text-sm text-gray-500">
              {item.carIncluded[0]?.name} Km Rezervasyon tutarınızın toplam
              kapsadığı km sınırıdır. Km Sınırını aşmanız halinde ekstra tutar
              ödemeniz gerekecektir.
            </div>
          </div>
        </div>
        {!isDesktop && (
          <div>
            <div className="my-4 h-1 w-full border-t border-gray-200" />
            <Button
              variant="outline"
              className="w-full text-gray-500"
              onClick={() => !!onClose && onClose()}
            >
              Kapat
            </Button>
          </div>
        )}
      </WrapperContent>
    )
  );
}

function RentACarCard({
  id,
  item,
  onClickPrimaryButton,
  className,
  loading,
  hideDetail,
  hidePrimaryButton,
  primaryButtonText,
  primaryButtonVariant,
}: RentACarCardProps) {
  const handleOnPrimaryClick = useCallback(
    () => onClickPrimaryButton?.(id),
    [id, onClickPrimaryButton],
  );
  const specWrapperRef = useRef<HTMLDivElement>(null);
  const [contentSlice, setContentSlice] = useState(3);
  const [isOpen, setIsOpen] = useState(false);

  const windowSize = useWindowSize();
  const isDesktop = windowSize.width > 640;

  const showDetail = (showIcon = true) => (
    <div ref={specWrapperRef}>
      <div
        className="relative flex cursor-pointer items-center gap-1 text-sm text-blue-400"
        onClick={() => setIsOpen(!isOpen)}
      >
        Detayları Göster
        {showIcon && (
          <LIcon name={isOpen ? "ChevronUp" : "ChevronDown"} size={20} />
        )}
      </div>
    </div>
  );

  const providerImage = (
    <div className="absolute left-4 top-4 h-[23px] max-w-[100px]">
      {!!carRentalProviderImageUrl[item?.carRentalCompany?.code] && (
        <img
          src={carRentalProviderImageUrl[item?.carRentalCompany?.code || ""]}
          alt="tour card images"
          key={item.carDetail.imageUrl}
          className="w-full object-contain"
        />
      )}
    </div>
  );

  const getTotalDay = () => {
    const totalHours = dayjs(item.carDetail.returnDate).diff(
      dayjs(item.carDetail.pickupDate),
      "minute",
    );

    return Math.ceil(totalHours / 24 / 60);
  };

  const totalDay = getTotalDay();

  useEffect(() => {
    if ((specWrapperRef?.current?.offsetHeight || 0) > 60) {
      setContentSlice((prev) => prev - 1);
    }
  }, [specWrapperRef, contentSlice]);

  return (
    <div className={cn(styles.container, className, "group")}>
      <div className="flex flex-col sm:min-h-[170px] sm:flex-row">
        <div
          className={styles.left}
          onClick={!isDesktop ? handleOnPrimaryClick : undefined}
        >
          {item.carDetail.imageUrl && (
            <div className={styles["left-carousel"]}>
              <img
                src={item.carDetail.imageUrl}
                alt="tour card images"
                key={item.carDetail.imageUrl}
                className="h-[214px] w-full object-contain md:h-full"
              />
              {providerImage}
            </div>
          )}
          {!item.carDetail.imageUrl && (
            <>
              <Image
                src={NoImage}
                className="h-[214px] w-full object-cover md:h-full"
                alt="No picture image"
              />
              {providerImage}
            </>
          )}
        </div>
        <div className={styles.contentWrapper}>
          <div className={styles["left-content-wrapper"]}>
            {/* tour Name and Location */}
            <div
              className="flex flex-col gap-1"
              onClick={!isDesktop ? handleOnPrimaryClick : undefined}
            >
              <h2 className={cn(styles.title, "group-hover:underline")}>
                {CarType[item.carDetail.type]}
              </h2>
              <div className="flex flex-col gap-1">
                <RentACarCardDescription>
                  {item.carDetail.name}
                </RentACarCardDescription>
              </div>
              {isDesktop && <RentACarCardSpesification item={item} />}
            </div>
            {windowSize.width > 640 && !hideDetail && showDetail()}
          </div>
          <div className={styles.divider} />
          <div className={styles["right-content-wrapper"]}>
            {!isDesktop && (
              <div className="flex flex-col gap-2">
                <RentACarCardSpesification item={item} />
                {windowSize.width < 640 && !hideDetail && showDetail(false)}
              </div>
            )}
            {/* Price & Discount Info */}
            {item.totalPrice && (
              <div className={styles.price}>
                <p className={styles["discount-price"]}>
                  {totalDay || 1}
                  &nbsp;Gün Toplam
                </p>
                <div>
                  {PriceManager({
                    currency: item.totalPrice.slice(0, 3) || "TRY",
                    value: +item.totalPrice.slice(3),
                  })}
                </div>
                <div className={styles["price-info"]}>
                  {PriceManager({
                    currency: item.basePrice.slice(0, 3) || "TRY",
                    value: +item.basePrice.slice(3),
                  })}
                  &nbsp;/&nbsp;Günlük
                </div>
              </div>
            )}
            {/* Card Button and night info */}
            {windowSize.width > 640 && (
              <div className={styles["card-button-wrapper"]}>
                {!hidePrimaryButton && (
                  <Button
                    variant={primaryButtonVariant || "primary"}
                    className="!hidden sm:!flex"
                    onClick={handleOnPrimaryClick}
                    loading={loading}
                  >
                    {primaryButtonText || "Kirala"}
                  </Button>
                )}
              </div>
            )}
          </div>
        </div>
      </div>
      <RentACarCardItemDetail
        isOpen={isOpen}
        onClose={() => {
          setIsOpen(false);
        }}
        item={item}
      />
    </div>
  );
}

export default RentACarCard;
