/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Image from "next/image";
import Link from "next/link";
import { useRouter } from "next/navigation";
import type { PropsWithChildren } from "react";
import React, { useEffect, useRef, useState } from "react";

import Gear from "@/assets/svg/icons/gear";
import NoImage from "@/assets/svg/images/no-image.svg";
import Card from "@/components/ui/card/card";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu/dropdown-menu";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { StatusText } from "@/components/ui/status-text/status-text";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import { statusEnumTypes } from "@/services/eva-display/demand/demand-service.types";
import {
  CarType,
  FuelType,
} from "@/services/eva-display/rent-a-car/rent-a-car.enums";

import styles from "./rent-a-car-request-card.module.css";

export interface RentACarRequestCardItemProps {
  id: number;
  cardTitle: string;
  pickupCode: string;
  pickupDate: string;
  returnCode: string;
  returnDate: string;
  requestStatus: number;
  carRentalCompanyCode: keyof typeof carRentalProviderImageUrl;
  driverFullName: string;
  totalPrice: string;
  carType: number;
  carName: string;
  carImageUrl: string;
  automaticTransmission: boolean;
  fuelType: number;
  passengerCount: number;
}
export interface RentACarRequestCardProps {
  item: RentACarRequestCardItemProps;
  className?: string;
}

export const carRentalProviderImageUrl = {
  "": "",
  EC: "https://ams3.digitaloceanspaces.com/concore-stg/concore/media/site/assets/img/logos/EC.svg",
  SXT: "https://ams3.digitaloceanspaces.com/concore-stg/concore/media/site/assets/img/logos/SXT.svg",
};

function RentACarRequestCardDescription({ children }: PropsWithChildren) {
  return (
    children && (
      <div>
        <div className="inline-block text-sm font-normal leading-[20px] tracking-normal text-[#667084] lg:whitespace-nowrap">
          {children}
        </div>
      </div>
    )
  );
}

function RentACarRequestCardSpesification({
  item,
}: {
  item: RentACarRequestCardItemProps;
}) {
  return (
    <div className="mt-2 grid grid-cols-[1fr] gap-2 text-sm text-gray-500 md:grid-cols-[auto_auto_1fr]">
      <div className="flex items-center justify-start gap-1">
        <Gear color="gray" />
        {item.automaticTransmission ? "Otomatik" : "Manuel"}
      </div>
      {item.fuelType !== FuelType.Unspecified && (
        <div className="flex items-center justify-start gap-1">
          <LIcon name="Fuel" size={14} />
          {FuelType[item.fuelType]}
        </div>
      )}
      {!!item.passengerCount && (
        <div className="flex items-center justify-start gap-1">
          <LIcon name="Users" size={14} />
          {item.passengerCount} Kişilik
        </div>
      )}
    </div>
  );
}

// @todo - this prop type used as mock data on ui deveoplent.
function RentACarRequestCard({ item, className }: RentACarRequestCardProps) {
  const specWrapperRef = useRef<HTMLDivElement>(null);
  const [contentSlice, setContentSlice] = useState(3);
  const { isDesktop } = useBreakpoints();
  const router = useRouter();
  const providerImage = (
    <div className="h-[23px] max-w-[47px]">
      {!!carRentalProviderImageUrl[item.carRentalCompanyCode] && (
        <img
          src={carRentalProviderImageUrl[item.carRentalCompanyCode || ""]}
          alt="tour card images"
          key={item.carImageUrl}
          className="w-full object-contain"
        />
      )}
    </div>
  );

  const requestDetailPath = `/rentcar-request-detail?id=${item?.id}`;
  const handleClickCard = () => {
    if (!isDesktop) {
      window.scrollTo(0, 0);
      router.push(requestDetailPath);
    }
  };

  useEffect(() => {
    if ((specWrapperRef?.current?.offsetHeight || 0) > 60) {
      setContentSlice((prev) => prev - 1);
    }
  }, [specWrapperRef, contentSlice]);

  return (
    <div
      className={cn(styles.container, className, "group")}
      onClick={handleClickCard}
    >
      <div className="flex flex-col gap-4 sm:min-h-[170px] sm:flex-row">
        <div className={styles.contentWrapper}>
          <div className={styles["main-content-wrapper"]}>
            <div className="flex justify-between gap-1">
              <h2 className={cn(styles.title, "group-hover:underline")}>
                {item.cardTitle}
              </h2>
              <div>
                <DropdownMenu>
                  <DropdownMenuTrigger>
                    <LIcon name="MoreVertical" size={20} />
                  </DropdownMenuTrigger>
                  <DropdownMenuContent>
                    {/* <Link
                      href={`booking-request-car-rental-change?id=${item?.id}`}
                    >
                      <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                        <LIcon name="FileEdit" className="mr-2 size-4" />
                        <span>Değiştir</span>
                      </DropdownMenuItem>
                    </Link> */}
                    <Link href={requestDetailPath}>
                      <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                        <LIcon name="Eye" className="mr-2 size-4" />
                        <span>İncele</span>
                      </DropdownMenuItem>
                    </Link>
                  </DropdownMenuContent>
                </DropdownMenu>
              </div>
            </div>

            <div>
              <div className="text-sm text-gray-500">Onay Durumu</div>
              <StatusText
                className={cn(styles.detail, "mt-1")}
                status={statusEnumTypes[item.requestStatus] || "warning"}
              />
            </div>
            <div className="grid grid-cols-6 gap-4 lg:grid-cols-12 lg:gap-0">
              <div className="col-span-6 grid grid-cols-12 text-sm lg:text-base">
                <div className="col-span-6 flex flex-col gap-4">
                  <div>
                    <div className="text-sm text-gray-500">
                      Alış Yeri ve Tarihi
                    </div>
                    <div className="text-gray-800">
                      <div className="line-clamp-1">{item.pickupCode}</div>
                      <div>
                        {dayjs(item.pickupDate).format("DD MMM / HH:mm")}
                      </div>
                    </div>
                  </div>
                  <div>
                    <div className="text-sm text-gray-500">Sürücü</div>
                    <div className="text-gray-800">{item.driverFullName}</div>
                  </div>
                </div>
                <div className="col-span-6 flex flex-col gap-4">
                  <div>
                    <div className="text-sm text-gray-500">
                      Teslim Yeri ve Tarihi
                    </div>
                    <div className="text-gray-800">
                      <div className="line-clamp-1">{item.returnCode}</div>
                      <div>
                        {dayjs(item.returnDate).format("DD MMM / HH:mm")}
                      </div>
                    </div>
                  </div>
                  <div>
                    <div className="text-sm text-gray-500">Toplam Tutar</div>
                    <div className="text-gray-800">
                      {PriceManager({
                        currency: item.totalPrice.slice(0, 3) as string,
                        value: +item.totalPrice.slice(3) as unknown as number,
                      })}
                    </div>
                  </div>
                </div>
              </div>
              <div className="col-span-6">
                <Card className="h-full bg-gray-100 shadow-none">
                  <div className="grid grid-cols-12 gap-4">
                    <div className="col-span-3">
                      {item.carImageUrl && (
                        <div className={styles["left-carousel"]}>
                          {providerImage}
                          <img
                            src={item.carImageUrl}
                            alt="tour card images"
                            key={item.carImageUrl}
                            className="h-[60px] w-full object-contain "
                          />
                        </div>
                      )}
                      {!item.carImageUrl && (
                        <>
                          {providerImage}
                          <Image src={NoImage} alt="No picture image" />
                        </>
                      )}
                    </div>
                    <div className="col-span-9">
                      <div className="flex flex-col items-start justify-between">
                        <div className="text-sm font-semibold">
                          {CarType[item.carType]}
                        </div>
                        <div className="flex flex-col gap-1">
                          <RentACarRequestCardDescription>
                            {item.carName}
                          </RentACarRequestCardDescription>
                        </div>
                        <RentACarRequestCardSpesification item={item} />
                      </div>
                    </div>
                  </div>
                </Card>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}

export default RentACarRequestCard;
