/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Link from "next/link";
import React from "react";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import type { StatusVariants } from "@/components/ui/status-text/status-text.variants";
import PermGuard from "@/features/permission/components/perm-guard";
import { cn } from "@/libs/utils";
import { CarType } from "@/services/eva-display/rent-a-car/rent-a-car.enums";
import type {
  Car,
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";
import { requestApprovalAllowPerm } from "@/validations/permissions/request-approval";

import styles from "../../flight-request-card-detail/flight-request-card-detail.module.css";
import { RentACarCardSpesification } from "../../rent-a-car-card/rent-a-car-card";
import { carRentalProviderImageUrl } from "../../rent-a-car-request-card/rent-a-car-request-card";

type Props = {
  car: Car;
  selectedOptions: Array<CarExtraOption | CarInsurance>;
  status?: StatusVariants;
  requestId?: number;
};

const RentACarRequestDetailCarInformation = ({
  car,
  selectedOptions,
  status,
  requestId,
}: Props) => {
  return (
    <Card className="p-8">
      <div className="mb-4 flex items-center justify-between">
        <h2 className={cn(styles.title, "text-lg")}>Araç Kiralama Bilgileri</h2>
        {!!status && status === "warning" && (
          <PermGuard permission={requestApprovalAllowPerm}>
            <Link href={`/booking-request-car-rental-change?id=${requestId}`}>
              <Button variant="outline-primary">Değiştir</Button>
            </Link>
          </PermGuard>
        )}
      </div>
      <div className="flex items-start justify-start gap-4">
        <div className="relative max-w-[141px]">
          <img
            src={carRentalProviderImageUrl[car?.carRentalCompany?.code]}
            alt="provider image"
            className="absolute left-0 top-0 h-[21px]"
          />
          <img
            src={car?.carDetail?.imageUrl}
            alt="car image"
            className="w-full max-w-[141px]"
          />
        </div>
        <div>
          <div className="text-lg font-semibold text-gray-800">
            {CarType[car?.carDetail.type]}
          </div>
          <div className="text-md text-gray-500">{car?.carDetail.name}</div>
          <RentACarCardSpesification
            item={{
              carDetail: {
                automaticTransmission: car?.carDetail.automaticTransmission,
                passengerCount: car?.carDetail.passengerCount,
                fuelType: car?.carDetail.fuelType,
              },
            }}
            colorVariant="gray"
          />
        </div>
      </div>
      <div className="my-6 flex items-start justify-between border-y border-gray-200 py-3">
        <div className="w-1/2 border-r border-gray-200 pr-2">
          <div className="flex items-center justify-between">
            <div className="text-sm font-semibold text-gray-500">
              Alış Noktası
            </div>
            <div className="text-sm">
              {dayjs(car?.carDetail.pickupDate).format("DD MMM ddd, HH:mm")}
            </div>
          </div>
          <div className="mt-2 flex items-center gap-3 text-sm text-gray-800">
            <LIcon name="MapPin" size={14} /> {car?.carDetail.pickupCode}
          </div>
        </div>
        <div className="w-1/2 pl-2">
          <div className="flex items-center justify-between">
            <div className="text-sm font-semibold text-gray-500">
              Teslim Noktası
            </div>
            <div className="text-sm">
              {dayjs(car?.carDetail.returnDate).format("DD MMM ddd, HH:mm")}
            </div>
          </div>
          <div className="mt-2 flex items-center gap-3 text-sm text-gray-800">
            <LIcon name="MapPin" size={14} />
            {car?.carDetail.returnCode}
          </div>
        </div>
      </div>
      {selectedOptions.length > 0 && (
        <div>
          <div className="font-semibold text-gray-500">
            Ek Hizmetler ve Güvence Paketi
          </div>
          <div>
            {selectedOptions.map((item: any, index: number) => (
              <div
                key={+index}
                className="my-1 flex w-full justify-between text-sm text-gray-800"
              >
                <span>{item.name || item.description}</span>
                {/* @todo - This field is static because BE Team said this field is have to be like this. */}
                <span className="text-gray-800">1 Adet</span>
              </div>
            ))}
          </div>
        </div>
      )}
    </Card>
  );
};

export default RentACarRequestDetailCarInformation;
