import dayjs from "dayjs";
import React from "react";

import Card from "@/components/ui/card/card";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type {
  Car,
  CarDetail,
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

type Props = {
  carDetail: CarDetail;
  car: Car;
  selectedOptions: Array<CarExtraOption | CarInsurance>;
};

const RentACarRequestDetailPriceSummary = ({
  carDetail,
  car,
  selectedOptions,
}: Props) => {
  const getTotalDay = () => {
    const totalHours = dayjs(carDetail?.returnDate).diff(
      dayjs(carDetail?.pickupDate),
      "minute",
    );

    return Math.ceil(totalHours / 24 / 60);
  };
  const totalDay = getTotalDay();

  const oneWayPrice = PriceManager({
    currency: car?.oneWay.slice(0, 3) || "TRY",
    value: +`${car?.oneWay}0`.slice(3),
  });
  const locationFee = PriceManager({
    currency: car?.locationFee.slice(0, 3) || "TRY",
    value: +`${car?.locationFee}0`.slice(3),
  });
  const subTotal =
    selectedOptions.reduce((acc: any, item: any) => {
      return acc + +`${item.totalPrice}0`.slice(3);
    }, 0) +
    +`${car?.oneWay}0`.slice(3) +
    +`${car?.locationFee}0`.slice(3);

  const intlSubTotal = PriceManager({
    currency: car.oneWay.slice(0, 3) || "TRY",
    value: subTotal,
  });

  const allTotal = PriceManager({
    currency: car?.totalPrice.slice(0, 3) || "TRY",
    value: +`${car?.totalPrice}0`.slice(3) + subTotal,
  });

  return (
    <Card className="p-8">
      <div className="text-xl font-semibold text-gray-800">Fiyat Özeti</div>
      {(subTotal > 0 || oneWayPrice || locationFee) && (
        <div className="my-4 rounded bg-blue-50 p-4">
          <p className="text-xs">
            Ek hizmet ücretini ve hizmet bedelini, aracınızı teslim alırken
            hizmeti sağlayan firmaya ofiste ödeyeceksiniz.
          </p>
        </div>
      )}
      <div>
        {(subTotal > 0 || oneWayPrice || locationFee) && (
          <div className="text-sm font-semibold text-gray-800">
            Ofiste Ödenecek Tutar
          </div>
        )}
        <div>
          {(subTotal > 0 || oneWayPrice || locationFee) && (
            <>
              {/* Selected Options */}
              {selectedOptions.length > 0 &&
                selectedOptions.map((item: any) => (
                  <div
                    key={item.Code}
                    className="my-2 flex w-full justify-between text-gray-800"
                  >
                    <span>
                      {(item as CarInsurance).description ||
                        (item as CarExtraOption).name}
                      &nbsp;
                      <span className="text-sm text-gray-500">
                        ({totalDay} gün&nbsp;x&nbsp;
                        {PriceManager({
                          currency: item.unitPrice.slice(0, 3) || "TRY",
                          value: +`${item.unitPrice}0`.slice(3),
                        })}
                        )
                      </span>
                    </span>
                    <span className="text-gray-800">
                      {PriceManager({
                        currency: item.totalPrice.slice(0, 3) || "TRY",
                        value: +`${item.totalPrice}0`.slice(3),
                      })}
                    </span>
                  </div>
                ))}
              {/* One Way Price */}
              {oneWayPrice && (
                <div className="my-1 flex w-full justify-between text-gray-800">
                  <span>Tek Yön Ücreti</span>
                  <span className="text-gray-800">{oneWayPrice}</span>
                </div>
              )}
              {/* Location Fee */}
              {locationFee && (
                <div className="my-1 flex w-full justify-between text-gray-800">
                  <span>Ofis Hizmet Ücreti</span>
                  <span className="text-gray-800">{locationFee}</span>
                </div>
              )}
              <div className="mb-2 mt-3 flex w-full justify-between font-semibold text-gray-800">
                <span>Ara Toplam</span>
                <span className="text-lg font-semibold text-gray-800">
                  {intlSubTotal} TL
                </span>
              </div>
            </>
          )}

          {/* Ödenmiş Tutar */}
          <div className="my-4 flex w-full justify-between font-semibold text-gray-800">
            <span>Ödenmiş Tutar</span>
          </div>
          <div className="items-cener my-1 flex w-full justify-between text-gray-800">
            <span>
              Araç Kiralama&nbsp;
              <span className="text-sm text-gray-500">
                ({totalDay} Gün x{" "}
                {PriceManager({
                  currency: car.basePrice.slice(0, 3) || "TRY",
                  value: +`${car.basePrice}0`.slice(3),
                })}
                )
              </span>
            </span>
            <span className="text-lg font-semibold text-gray-800">
              {PriceManager({
                currency: car?.totalPrice.slice(0, 3) || "TRY",
                value: +`${car?.totalPrice}0`.slice(3),
              })}
            </span>
          </div>
          <div className="mt-3 border-t border-gray-200 pt-4">
            <div className="flex items-center justify-between">
              <span className="text-xl font-medium text-gray-800">
                Toplam Tutar
              </span>
              <span className="text-xl font-semibold">{allTotal} TL</span>
            </div>
          </div>
        </div>
      </div>
    </Card>
  );
};

export default RentACarRequestDetailPriceSummary;
