/* eslint-disable no-nested-ternary */
/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */
/* eslint-disable no-console */
import dayjs from "dayjs";
import Link from "next/link";
import React from "react";

import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { StatusText } from "@/components/ui/status-text/status-text";
import BookingRequest from "@/components/widget/request-card/booking-request-card/booking-request-card";
import BookingRequestCardDetailConfirmRejectDeniedButtonList from "@/features/booking-request/components/booking-request-card-detail/booking-request-card-detail-button-list";
import type { RejectSelectValue } from "@/features/demand/components/demand-detail/rent-a-car-request-detail";
import lcfc from "@/libs/helpers/lower-cased-first-character";
import { cn } from "@/libs/utils";
import type {
  CorpRequestHistories,
  IBookingRequest,
} from "@/models/booking-request.model";
import type { CancelReasonItem } from "@/services/eva-display/book-cancel-reason/booking-cancel-reason-service.types";
import { statusEnumTypes } from "@/services/eva-display/demand/demand-service.types";
import type {
  Car,
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

import type { ReactQueryReturnProps } from "../booking-request-card-detail/booking-request-card-detail";
import styles from "../flight-request-card-detail/flight-request-card-detail.module.css";
import RentACarRequestDetailCarInformation from "./components/rent-a-car-request-detail-car-information";
import RentACarRequestDetailPassengerSummary from "./components/rent-a-car-request-detail-passenger-note";
import RentACarRequestDetailPriceSummary from "./components/rent-a-car-request-detail-price-summary";
import RentACarRequestDetailReservationInfo from "./components/rent-a-car-request-detail-reservation-info";

const RentACarRequestDetailWidget = ({
  data,
  rejectSelectValue,
  onAccept,
  onReject,
  onDenied,
  onRejectSelectValue,
  bookingRequestStatusMutation,
  bookingCancelReason,
}: {
  data: IBookingRequest | null;
  rejectSelectValue: RejectSelectValue;
  onAccept: () => void;
  onReject: () => void;
  onDenied: () => void;
  onRejectSelectValue: (e: RejectSelectValue) => void;
  bookingRequestStatusMutation: any;
  bookingCancelReason: any;
}) => {
  const status = statusEnumTypes[data?.requestStatus || 0] || "warning";
  const reservationData = data?.reservationData as unknown as any;
  const car = lcfc(reservationData?.DetailResponse?.Car) as Car;
  const carDetail = car?.carDetail;
  const carExtraOption =
    car?.carExtraOption?.filter((item: any) => item?.selected) || [];
  const carInsurances =
    car?.carInsurances?.filter((item: any) => item?.selected) || [];
  const selectedOptions = [...carExtraOption, ...carInsurances] as (
    | CarExtraOption
    | CarInsurance
  )[];
  const passengerInformation = data?.passengerInformations?.[0];

  const errorStatusText = data?.corpRequestHistories?.find(
    (item: CorpRequestHistories) => item.newStatus === data.requestStatus,
  );

  return (
    <div className={cn(styles.container, "group", "py-10")}>
      <div className={styles.wrapper}>
        <Link
          href="/booking-request"
          className="mr-auto flex items-center gap-1.5 text-primary-500"
        >
          <LIcon name="ArrowLeft" size={18} />
          <span className="font-base font-medium">Geri Dön</span>
        </Link>
        <h1 className="text-3xl font-semibold">
          {carDetail.returnCode.split(" ")[0]} {data?.travelReasonName} Seyahati
          <p className="mt-2.5 text-base font-normal text-gray-500">
            {dayjs(data?.createDate).format("DD MMMM YYYY (HH:mm:ss)")}
            &nbsp;tarihinde oluşturuldu
          </p>
        </h1>
        {/* Request Status Summary */}
        <Card className="p-8 shadow-lg">
          <div className="flex flex-col md:justify-between lg:flex-row lg:items-center">
            <div className="flex flex-col gap-4 md:flex-row md:gap-10">
              <div className="flex flex-col gap-5">
                <div>
                  <p className="mb-2.5 font-medium text-gray-500">
                    Onay Durumu
                  </p>
                  <StatusText
                    status={status}
                    text={`${dayjs
                      .utc(data?.updateDate)
                      .format("DD MMMM YYYY (hh:mm)")} tarihinde ${
                      data?.updatedByUserName
                        ? `${
                            errorStatusText?.createdByFullName
                              ? errorStatusText?.createdByFullName
                              : data.updatedByUserName
                          } tarafindan`
                        : ``
                    } ${
                      status === "denied"
                        ? "Reddedildi"
                        : status === "error"
                          ? "İptal Edildi"
                          : "Onaylandı"
                    }.`}
                  />
                </div>
                {status === "denied" && errorStatusText?.description && (
                  <div>
                    <p className="mb-2.5 font-medium text-gray-500">
                      Reddedilme Nedeni
                    </p>
                    <p className="text-base text-gray-800">
                      {errorStatusText?.description}
                    </p>
                  </div>
                )}
              </div>
              {status === "denied" ||
                (status !== "error" &&
                  data?.bookedProduct &&
                  data?.bookedProduct.OptionDate &&
                  dayjs((data.bookedProduct as any)?.OptionDate).isValid() && (
                    <div className="flex flex-col">
                      <p className="mb-2.5 font-medium text-gray-500">
                        Opsiyon Süresi
                      </p>
                      <div className="mt-0.5 text-sm font-medium text-warning-500">
                        {`${dayjs
                          .utc((data.bookedProduct as any)?.OptionDate)
                          .format("DD.MM.YYYY HH:mm")}'e kadar`}
                      </div>
                    </div>
                  ))}
            </div>
            <BookingRequestCardDetailConfirmRejectDeniedButtonList
              status={status}
              createdByUserId={data?.createdByUserId || "0"}
              bookingRequestStatusMutation={
                bookingRequestStatusMutation as ReactQueryReturnProps
              }
              onAccept={onAccept}
              onReject={onReject}
              onDenied={onDenied}
              cancelReasonData={
                (bookingCancelReason.data?.items as CancelReasonItem[]) || []
              }
              setRejectSelectValue={(value) =>
                onRejectSelectValue(value as RejectSelectValue)
              }
              rejectSelectValue={rejectSelectValue}
            />
          </div>
        </Card>
        {/* Reservation Information */}
        <RentACarRequestDetailReservationInfo
          car={car}
          travelReasonName={data?.travelReasonName}
          totalPrice={data?.totalPrice || 0}
        />
        {/* Car Rental Information */}
        <RentACarRequestDetailCarInformation
          requestId={data?.id || 0}
          status={status}
          car={car}
          selectedOptions={selectedOptions}
        />
        {/* Passenger Summary */}
        <RentACarRequestDetailPassengerSummary
          passengerInformation={passengerInformation}
        />

        {/* Price Summary */}
        <RentACarRequestDetailPriceSummary
          carDetail={carDetail}
          car={car}
          selectedOptions={selectedOptions}
        />
        {/* Reservation Note */}
        <Card className="p-8">
          <BookingRequest.Note
            className="bg-white"
            description={reservationData?.ReservationNote || "-"}
          />
        </Card>
        {/* Invoice Note */}
        <Card className="p-8">
          <BookingRequest.Note
            title="Fatura Notu"
            className="bg-white"
            description={reservationData?.ProjectCode || "-"}
          />
        </Card>
        {/* Approvers */}
        <Card className="p-8">
          <BookingRequest.Note
            title="Onaylayacak Kişiler"
            className="bg-white"
            description={
              data?.displayInformations?.Approvers?.map(
                (item) => item.FullName,
              ).join(", ") || "-"
            }
          />
        </Card>
      </div>
    </div>
  );
};

export default RentACarRequestDetailWidget;
