/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Link from "next/link";
import { useRouter } from "next/navigation";
import React from "react";

import NoImage from "@/assets/svg/images/no-image.svg";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu/dropdown-menu";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { StatusText } from "@/components/ui/status-text/status-text";
import styles from "@/components/widget/request-card/booking-request-card/booking-request-card.module.css";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type { IBookingRequestItem } from "@/services/eva-display/demand/demand-service.types";
import { statusEnumTypes } from "@/services/eva-display/demand/demand-service.types";
import type { IDisplayInformations } from "@/services/eva-display/demand/display-information/display-information";
import type { IPassengerInformation } from "@/services/eva-display/demand/passenger-information/passenger-information";
import type { IReservationData } from "@/services/eva-display/demand/reservation-data/reservation-data";

export interface IDemandHotelCardProps {
  displayInformations: IDisplayInformations;
  reservationData: IReservationData;
  passengerInformations: IPassengerInformation;
  item: IBookingRequestItem;
}

function Undefined() {
  return <small className="text-error-400">bulunamadı</small>;
}

const BookingRequestCardHotel = ({
  item,
  displayInformations,
  passengerInformations,
  reservationData,
}: IDemandHotelCardProps) => {
  const rooms = displayInformations.SearchRequest?.Rooms?.length;
  const userAmount =
    passengerInformations && Object.values(passengerInformations).length;
  const dateFormat = "DD MMM";
  const { isDesktop } = useBreakpoints();
  const router = useRouter();
  const status = item?.requestStatus as number;
  const location = reservationData?.SearchResponse?.Items[0]?.Location;
  const checkInDate = displayInformations?.SearchRequest?.CheckInDate;
  const checkOutDate = displayInformations?.SearchRequest?.CheckOutDate;
  const { DetailResponse } = reservationData;
  const roomCollectionResult = DetailResponse?.RoomCollectionResult;
  /* const hotelImage = todo otel resimleri yok yerine oda resimleri bastirildi
    DetailResponse.Images &&
    DetailResponse.Images[0] &&
    DetailResponse.Images[0].url; */
  const roomImage =
    roomCollectionResult[0] &&
    roomCollectionResult[0].Images &&
    roomCollectionResult[0].Images[0] &&
    roomCollectionResult[0].Images[0].Url;

  const itemTotalPrice =
    reservationData.DetailResponse.RoomGroupResult[0]!.TotalPrice.slice(3);

  const requestDetailPath = `/booking-request-detail?id=${item?.id}`;
  const handleClickCard = () => {
    if (!isDesktop) {
      window.scrollTo(0, 0);
      router.push(requestDetailPath);
    }
  };

  return (
    <>
      <div className={styles.more}>
        <DropdownMenu>
          <DropdownMenuTrigger>
            <LIcon name="MoreVertical" size={20} />
          </DropdownMenuTrigger>
          <DropdownMenuContent>
            {/* {statusEnumTypes[status] === "warning" && (
              <>
                <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                  <LIcon name="CheckSquare" className="mr-2 h-4 w-4" />
                  <span>Onayla</span>
                </DropdownMenuItem>
                <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                  <LIcon name="Ban" className="mr-2 h-4 w-4" />
                  <span>Reddet</span>
                </DropdownMenuItem>
                <Link href={`booking-request-hotel-change?id=${item?.id}`}>
                  <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                    <LIcon name="FileEdit" className="mr-2 h-4 w-4" />
                    <span>Değiştir</span>
                  </DropdownMenuItem>
                </Link>
              </>
            )} */}
            {/* {statusEnumTypes[status] === "warning" && (
              <Link href={`booking-request-hotel-change?id=${item?.id}`}>
                <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                  <LIcon name="FileEdit" className="mr-2 size-4" />
                  <span>Değiştir</span>
                </DropdownMenuItem>
              </Link>
            )} */}
            <Link href={requestDetailPath}>
              <DropdownMenuItem className="cursor-pointer px-4 py-2.5">
                <LIcon name="Eye" className="mr-2 size-4" />
                <span>İncele</span>
              </DropdownMenuItem>
            </Link>
          </DropdownMenuContent>
        </DropdownMenu>
      </div>
      <div
        className="grid-col-12 flex grid-flow-col grid-rows-3 flex-col gap-4 md:grid md:gap-6"
        onClick={handleClickCard}
      >
        <div
          className={cn(
            styles.imageBox,
            "row-span-3 col-span-3",
            !roomImage &&
              "h-[136px] md:w-[246px] w-full overflow-hidden md:h-auto",
          )}
        >
          {roomImage ? (
            <img src={roomImage} className={styles.image} alt="cardAltText" />
          ) : (
            <img
              src={NoImage.src}
              alt="img not found"
              width="100%"
              className="relative top-2/4 h-[136px] -translate-y-2/4 object-cover md:h-auto md:w-[246px]"
            />
          )}
        </div>
        <div className="-order-1 col-span-10 md:order-none">
          <h2 className={styles.title}>
            {`${location && location.split(",")[0]}${
              item?.travelReasonName ? ` ${item?.travelReasonName}` : ""
            } Seyahati`}
          </h2>
          <p className={styles.subTitle}>{location}</p>
        </div>
        <div className={cn(styles.contentWrapper, "row-span-2 col-span-10")}>
          <div className="grid w-full grid-cols-2 gap-x-3 gap-y-4 md:grid-cols-3">
            <div className={styles.rowCell}>
              <p className={styles.heading}>Konfirme Durumu</p>
              <StatusText
                className={cn(styles.detail, "mt-1")}
                status={statusEnumTypes[status] || "warning"}
              />
            </div>
            <div className={styles.rowCell}>
              <p className={styles.heading}>Otel Adı</p>
              <p className={cn(styles.detail, "mt-1 md:max-w-36")}>
                {displayInformations?.HotelName
                  ? displayInformations?.HotelName
                  : Undefined()}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className={styles.heading}>Giriş-Çıkış Tarihleri</p>
              <p className={cn(styles.detail, "mt-1")}>
                {dayjs(checkInDate).format(dateFormat)} -{" "}
                {dayjs(checkOutDate).format(dateFormat)}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className={styles.heading}>Kişi ve Oda Bilgisi</p>
              <p className={cn(styles.detail, "mt-1")}>
                {`${userAmount || Undefined()} kişi, ${
                  rooms || Undefined()
                } oda`}
              </p>
            </div>
            <div className={cn(styles.rowCell, "order-last md:order-none")}>
              <p className={styles.heading}>Kişiler</p>
              <p className={cn(styles.detail, "mt-1 md:max-w-32 max-w-full")}>
                {passengerInformations
                  ? Object.values(passengerInformations)
                      .map((passanger) => {
                        return `${passanger?.Name} ${passanger?.Surname}`;
                      })
                      .join(", ")
                  : Undefined()}
              </p>
            </div>
            <div className={styles.rowCell}>
              <p className={styles.heading}>Toplam Tutar</p>
              <p className={cn(styles.detail, "mt-1")}>
                {PriceManager({
                  currency:
                    reservationData.SearchResponse.Items[0]?.TotalPrice.slice(
                      0,
                      3,
                    ) as string,
                  value: +itemTotalPrice,
                })}
              </p>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};

export default BookingRequestCardHotel;
