/* eslint-disable react/no-danger */
import Image from "next/image";

import { Badge } from "@/components/ui/badge/badge";
import { Carousel } from "@/components/ui/carousel/carousel";
import { useLocale } from "@/hooks/useLocale";
import type {
  Attributes,
  Facility,
} from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";

export interface RoomAllOptionModalProps {
  images?: string[] | null;
  roomTitle: string;
  informationText?: string;
  roomAttributes?: Attributes[];
  roomFacilities?: Facility[];
}

const RoomAllOptionModal = ({
  images,
  informationText,
  roomAttributes,
  roomFacilities,
  roomTitle,
}: RoomAllOptionModalProps) => {
  const { t } = useLocale();
  return (
    <div className="flex w-full max-w-[800px] flex-col gap-8">
      <div className="max-h-[350px]">
        {images &&
          (images.length > 1 ? (
            <div className="relative">
              <Carousel className="h-[375px] w-full">
                {images?.map((image) => (
                  <Image
                    className="max-h-[375px] w-full object-cover"
                    layout="fill"
                    src={image}
                    alt="Hotel card images"
                    key={image}
                  />
                ))}
              </Carousel>
              <div className="absolute bottom-3 right-3 z-10 bg-[#10182880] p-1 text-xs text-white">
                + {images.length}
              </div>
            </div>
          ) : (
            <div className="max-h-[375px]  w-full">
              {images?.map((image) => (
                <Image
                  className="max-h-[375px] object-cover"
                  layout="fixed"
                  height={375}
                  width={800}
                  src={image}
                  alt="Hotel card images"
                  key={image}
                />
              ))}
            </div>
          ))}
      </div>
      <div className="content-area mb-4 p-4 md:p-0">
        <h2 className="text-xl font-semibold text-gray-800">{roomTitle}</h2>
        <div className="flex flex-col gap-4">
          {informationText && (
            <div className="flex flex-col items-start gap-4">
              <div
                className="text-gray-500"
                dangerouslySetInnerHTML={{ __html: informationText }}
              />
            </div>
          )}

          {roomAttributes && (
            <>
              <hr className="my-4" />
              <div className="flex flex-col items-start gap-4">
                <h5 className="font-semibold text-gray-800">
                  {t("Room features")}
                </h5>
                <ul className="grid w-full grid-cols-2 gap-4 text-sm">
                  {roomAttributes.map((item) => (
                    <li key={item.key} className="whitespace-normal">
                      <Badge
                        className="-ml-1 w-full !gap-1 !border-0 !bg-transparent !p-0 !text-sm !font-normal"
                        leftIcon={{
                          name: "MapPin",
                          size: 12,
                          className: "shrink-0",
                        }}
                      >
                        <span className="line-clamp-3">{item.description}</span>
                      </Badge>
                    </li>
                  ))}
                </ul>
              </div>
            </>
          )}
          {roomFacilities && (
            <>
              <hr className="my-4" />
              <div className="flex flex-col items-start gap-4">
                <h5 className="font-semibold text-gray-800">
                  {t("Room amenities")}
                </h5>
                <ul className="grid w-full grid-cols-2 gap-4 text-sm">
                  {roomFacilities.map((item) => (
                    <li key={item.key}>
                      <Badge
                        className="-ml-1 w-full !gap-1 !border-0 !bg-transparent !p-0 !text-sm !font-normal"
                        leftIcon={{
                          name: "MapPin",
                          size: 12,
                          className: "shrink-0",
                        }}
                      >
                        <span className="line-clamp-3">{item.description}</span>
                      </Badge>
                    </li>
                  ))}
                </ul>
              </div>
            </>
          )}
        </div>
      </div>
    </div>
  );
};

export default RoomAllOptionModal;
