import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import type { RoomFacilities } from "@/components/widget/room/room-card/room-card";
import { rooomData } from "@/data/dummy/room-card";
import { ThemeProviderDecorators } from "@/storybook/Decorator";

import {
  RoomCardAttributes,
  RoomCardImage,
  RoomCardProvider,
  RoomCardTitle,
  RoomsHeading,
  RoomsProperty,
  RoomsPropertyFacilities,
  RoomsPropertyTotalPrice,
} from "./room-card";

const meta = {
  title: "Widgets/RoomCard",
  component: RoomCardProvider,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof RoomCardProvider>;

export default meta;

type Story = StoryObj<typeof RoomCardProvider>;

export const DefaultRoomCard: Story = {
  render: () => {
    return (
      <div className="flex  flex-col items-center justify-center gap-4">
        {rooomData.map((roomInfo) => (
          <div key={roomInfo.roomId} className="">
            <RoomCardProvider>
              <div className="flex gap-4">
                {roomInfo?.images?.length > 0 && (
                  <RoomCardImage imgUrl={roomInfo.images[0]?.url}>
                    {roomInfo.images.length > 1 && (
                      <span>+{roomInfo.images.length - 1}</span>
                    )}
                  </RoomCardImage>
                )}
                <div className="flex flex-col gap-2">
                  <RoomCardTitle>{roomInfo.title}</RoomCardTitle>
                  <RoomCardAttributes
                    viewType={roomInfo.viewType}
                    // attributes={roomInfo.attributes}
                  >
                    {roomInfo.facilities.length > 0 && (
                      <Button
                        className="!m-0 !justify-start !p-0"
                        variant="primary-text"
                      >
                        Tümünü Gör ({roomInfo.facilities.length})
                        <LIcon name="ChevronRight" size="20" />
                      </Button>
                    )}
                  </RoomCardAttributes>
                </div>
              </div>
              <div className="flex flex-col gap-2">
                <RoomsHeading />
                {roomInfo.rooms.map((roomProperty) => (
                  <RoomsProperty active={false} key={roomProperty.roomIndex}>
                    <div className="flex flex-1 basis-10/12 justify-between pr-4">
                      <RoomsPropertyFacilities
                        lowestPriceDescription={
                          roomProperty.lowestPriceDescription as string
                        }
                        mealType={
                          roomProperty?.mealType as unknown as RoomFacilities
                        }
                        freeChildStatus={
                          roomProperty.freeChildStatus as unknown as RoomFacilities
                        }
                      />
                      <RoomsPropertyTotalPrice
                        discountRateDescription={
                          roomProperty.discountRateDescription
                        }
                        nightlyRateDescription={
                          roomProperty.nightlyRateDescription
                        }
                        basePrice="TRY160000.00"
                        totalPrice="TRY160000.00"
                      >
                        <Button
                          className="!m-0 !justify-start !p-0"
                          variant="primary-text"
                        >
                          Fiyat Bilgileri{" "}
                          <LIcon name="ChevronRight" size="20" />
                        </Button>
                      </RoomsPropertyTotalPrice>
                    </div>

                    <Button className="basis-2/12" variant="outline-primary">
                      Oda Seç
                    </Button>
                  </RoomsProperty>
                ))}
              </div>
            </RoomCardProvider>
          </div>
        ))}
      </div>
    );
  },
};
