/* eslint-disable react/no-danger */
/* eslint-disable jsx-a11y/no-static-element-interactions */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */
import { createElement, type PropsWithChildren, type ReactNode } from "react";

import MasterCardSVG from "@/assets/svg/icons/mastercard";
import { Badge } from "@/components/ui/badge/badge";
import Card from "@/components/ui/card/card";
import type { LIconProps } from "@/components/ui/lucid-icon/lucid-icon";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Tooltip } from "@/components/ui/tooltip/tooltip";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type {
  Addons,
  CampaignInformation,
  DiscountInformation,
  Facility,
} from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";

interface RoomImage extends PropsWithChildren {
  imgUrl: string | undefined;
  onClick?: () => void;
}

export interface RoomFacilities {
  key: string;
  icon: string;
  description: string;
  tooltip: any;
  __typename: string;
}
interface RoomCardAttributesProps extends PropsWithChildren {
  viewType?: string;
  attributes?: Facility[];
}

interface RoomsPropertyFacilitiesProps {
  lowestPriceDescription?: string;
  mealType?: RoomFacilities | null | undefined;
  freeChildStatus?: RoomFacilities | null | undefined;
  discountInformations?: DiscountInformation[];
  cancellationPolicyText?: RoomFacilities | null | undefined;
  campaignInformations?: CampaignInformation | null | undefined;
  addons?: Addons[];
}

interface RoomsPropertyTotalPriceProps extends PropsWithChildren {
  discountRateDescription?: string;
  nightlyRateDescription?: string;
  basePrice: string;
  totalPrice?: string;
}

interface RoomsPropertyFacilitiesBadgeProps {
  text: string;
  icon?: ReactNode;
  description?: string;
  tooltip?: string;
}

interface RoomPropertyProps extends PropsWithChildren {
  active: boolean;
}

interface RoomsHeadingProps {
  headingItem?: string[];
}

interface RoomsCancellationPolicyProps {
  cancellationPolicyText?: string;
}

const RoomsPropertyFacilitiesBadge = ({
  text,
  icon,
  tooltip,
}: RoomsPropertyFacilitiesBadgeProps) => {
  const content = (
    <div className="flex items-center justify-start gap-2 text-xs text-gray-800 md:text-sm">
      {icon && <div className="block md:size-3">{icon}</div>}
      <div className={cn("line-clamp-2")}>
        {text?.trim()}
        {tooltip && (
          <div className="h-1 border-b-2 border-dashed border-gray-300" />
        )}
      </div>
    </div>
  );
  const element = tooltip
    ? createElement(
        Tooltip,
        {
          position: "top",
          label: (
            <div
              className="flex max-w-[250px] flex-col whitespace-normal"
              dangerouslySetInnerHTML={{
                __html: tooltip,
              }}
            />
          ),
        },
        content,
      )
    : createElement("div", {}, content);

  return element;
};

const RoomCardProvider = ({ children }: PropsWithChildren) => {
  return (
    <Card className="flex w-full flex-col gap-6 rounded-primary bg-white p-5">
      {children}
    </Card>
  );
};

const RoomCardImage = ({ imgUrl, onClick, children }: RoomImage) => {
  const image: string = !imgUrl ? "/assets/images/defaultImage.jpg" : imgUrl;

  return (
    <div className="roomCardImageGrid" onClick={onClick}>
      <figure className="relative size-full cursor-pointer">
        <img
          className="size-full max-h-[100px] rounded-primary object-cover lg:h-[111px] lg:max-h-[115px]  lg:w-[160px] "
          src={image}
          alt="Room Image"
        />
        {imgUrl && children && (
          <div className="absolute bottom-1 left-1 bg-[#10182880] p-1 text-xs text-white">
            {children}
          </div>
        )}
      </figure>
    </div>
  );
};

const RoomCardTitle = ({ children }: PropsWithChildren) => {
  return (
    <h2 className="roomCardTitleGrid text-xl font-semibold">{children}</h2>
  );
};

const decidedIcons: Record<string, LIconProps["name"]> = {
  "bed-type": "Bed",
  smoking: "CigaretteOff",
  size: "Ruler",
};
const roomCardIconNameChecker = (key: string): LIconProps["name"] => {
  if (decidedIcons[key]) {
    return decidedIcons[key] as any;
  }
  return "Check";
};

const RoomCardAttributes = ({
  viewType,
  attributes,
  children,
}: RoomCardAttributesProps) => {
  return (
    <div className="roomCardAttributesGrid">
      <div className="flex flex-col">
        <div className="flex flex-wrap gap-2 text-sm !text-gray-800">
          {viewType && (
            <span className="flex items-center justify-start gap-1">
              <LIcon name="Image" size="16" />
              {viewType}
            </span>
          )}
          {attributes &&
            attributes?.length > 0 &&
            attributes.map((data, index) => {
              if (index >= 4) {
                return false;
              }
              return (
                <span
                  key={data.key}
                  className="flex items-center justify-start gap-1"
                >
                  <LIcon name={roomCardIconNameChecker(data.key)} size="16" />
                  {data.description}
                </span>
              );
            })}
        </div>
        {children}
      </div>
    </div>
  );
};

const RoomsHeading = ({ headingItem }: RoomsHeadingProps) => {
  return (
    <div className="flex px-5">
      <div className="flex flex-1 basis-10/12 justify-between pr-4 text-sm text-gray-500">
        {headingItem?.map((item, index) => (
          <span
            key={+index}
            data-key={+index}
            className="data-[key='0']:mr-4 data-[key='0']:basis-5/12 data-[key='1']:basis-5/12 data-[key='2']:basis-2/12"
          >
            {item}
          </span>
        ))}
      </div>
      <div className="basis-2/12 " />
    </div>
  );
};

const RoomsProperty = ({ children, active }: RoomPropertyProps) => {
  return (
    <div
      data-active={active}
      className="flex flex-col items-center rounded-primary border p-5 data-[active='true']:border-primary-500 lg:flex-row"
    >
      {children}
    </div>
  );
};

const RoomsPropertyFacilities = ({
  lowestPriceDescription,
  mealType,
  freeChildStatus,
  discountInformations,
  cancellationPolicyText,
  campaignInformations,
  addons,
}: RoomsPropertyFacilitiesProps) => {
  return (
    <div className="flex w-auto flex-col gap-2 md:w-full">
      {lowestPriceDescription && (
        <div className="inline-flex">
          <Badge variant="grayGreen" leftIcon={{ name: "ThumbsUp" }}>
            {lowestPriceDescription.trim()}
          </Badge>
        </div>
      )}
      {addons &&
        addons.map((addon) => (
          <RoomsPropertyFacilitiesBadge
            key={addon.key}
            icon={<LIcon className="" size={12} name="Check" />}
            text={addon.description}
          />
        ))}
      {mealType && mealType.description && (
        <RoomsPropertyFacilitiesBadge
          icon={<LIcon className="" size={12} name="UtensilsCrossed" />}
          text={mealType.description}
          tooltip={mealType.tooltip}
        />
      )}
      {freeChildStatus && (
        <RoomsPropertyFacilitiesBadge
          text={freeChildStatus.description}
          icon={<LIcon className="" size={12} name="Baby" />}
          tooltip={freeChildStatus.tooltip}
        />
      )}
      {discountInformations &&
        discountInformations.map((discount) => (
          <RoomsPropertyFacilitiesBadge
            key={discount.key}
            icon={<LIcon className="" size={12} name="Percent" />}
            text={discount.description}
            tooltip={discount.tooltip}
          />
        ))}
      {cancellationPolicyText && cancellationPolicyText.description && (
        <RoomsPropertyFacilitiesBadge
          text={cancellationPolicyText.description}
          icon={<LIcon className="" size={12} name="Check" />}
          tooltip={cancellationPolicyText.tooltip}
        />
      )}
      {campaignInformations && campaignInformations.description && (
        <RoomsPropertyFacilitiesBadge
          text={campaignInformations.description}
          icon={
            <div className="max-w-[12px]">
              <MasterCardSVG />
            </div>
          }
          tooltip={campaignInformations.tooltip}
        />
      )}
    </div>
  );
};

const RoomsCancellationPolicy = ({
  cancellationPolicyText,
}: RoomsCancellationPolicyProps) => {
  return (
    <div className="flex flex-col gap-2">
      <div className="flex items-center gap-1 text-sm font-medium text-gray-800">
        <LIcon name="Check" size="20" />
        <div>
          {cancellationPolicyText}
          <div className="h-1 border-b-2 border-dashed border-gray-300" />
        </div>
      </div>
    </div>
  );
};
const RoomsCampaignInformation = ({ description }: { description: string }) => {
  return (
    <div className="flex flex-col gap-2">
      <div className="flex items-center gap-1 text-sm text-gray-800">
        <div>
          <MasterCardSVG />
        </div>
        <div>
          {description}
          <div className="h-1 border-b-2 border-dashed border-gray-300" />
        </div>
      </div>
    </div>
  );
};

const RoomsPropertyTotalPrice = ({
  discountRateDescription,
  nightlyRateDescription,
  basePrice,
  totalPrice,
  children,
}: RoomsPropertyTotalPriceProps) => {
  return (
    <div className="flex flex-col items-end ">
      {discountRateDescription && totalPrice && (
        <div className="flex flex-col items-end justify-start gap-2">
          <Badge variant="grayGreen"> {discountRateDescription}</Badge>
          {+totalPrice.slice(3) > 0 && (
            <span className="text-sm text-gray-500 line-through">
              {PriceManager({
                currency: basePrice.slice(0, 3),
                value: +basePrice.slice(3),
              })}
            </span>
          )}
        </div>
      )}

      {totalPrice && +totalPrice.slice(3) > 0 && (
        <span className="text-xl font-semibold">
          {PriceManager({
            currency: totalPrice.slice(0, 3),
            value: +totalPrice.slice(3),
          })}
        </span>
      )}

      {nightlyRateDescription && (
        <span className="text-sm text-gray-500">{nightlyRateDescription}</span>
      )}
      {children}
    </div>
  );
};

export {
  RoomCardAttributes,
  RoomCardImage,
  RoomCardProvider,
  RoomCardTitle,
  RoomsCampaignInformation,
  RoomsCancellationPolicy,
  RoomsHeading,
  RoomsProperty,
  RoomsPropertyFacilities,
  RoomsPropertyTotalPrice,
};
