import dayjs from "dayjs";

import { useLocale } from "@/hooks/useLocale";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { NightlyRateResult } from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";

export interface RoomPriceInformationModalProps {
  nightlyRateDescription?: string;
  totalPrice: string;
  nightlyRateResults: NightlyRateResult[];
}

const RoomPriceInformationModal = ({
  nightlyRateDescription,
  totalPrice,
  nightlyRateResults,
}: RoomPriceInformationModalProps) => {
  const { t } = useLocale();
  return (
    <div className="flex flex-col gap-4">
      <hr className="my-1" />
      <span className="font-semibold text-gray-800">{t("Nightly rates")}</span>
      <div className="flex flex-col gap-1">
        {nightlyRateResults.map((item, i) => (
          <div key={+i} className="flex justify-between">
            <span className="text-sm text-gray-500">
              {dayjs(item.date).format("DD MMM YYYY - ddd")}
            </span>
            <span className="text-sm font-semibold text-gray-800">
              {PriceManager({
                currency: item.totalPrice.slice(0, 3),
                value: +item.totalPrice.slice(3),
              })}
            </span>
          </div>
        ))}
      </div>
      <div className="flex items-center justify-between rounded-primary border bg-gray-50 p-3">
        <div className="flex flex-col gap-1">
          <span className="text-xs text-gray-500">{t("Total")}</span>
          <span className="text-xs text-gray-800">
            {nightlyRateDescription}
          </span>
        </div>
        <span className="font-semibold text-gray-800">
          {PriceManager({
            currency: totalPrice.slice(0, 3),
            value: +totalPrice.slice(3),
          })}
        </span>
      </div>
    </div>
  );
};

export default RoomPriceInformationModal;
