import { INITIAL_VIEWPORTS } from "@storybook/addon-viewport";
import type { Meta, StoryObj } from "@storybook/react";

import { ThemeProviderDecorators } from "@/storybook/Decorator";

import TourCard from "./tour-card";

const meta = {
  title: "Widgets/TourCard",
  component: TourCard,
  tags: ["autodocs"],
  decorators: ThemeProviderDecorators,
  args: {
    tourName: "Kapadokya Turu - 12 gece 13 gün",
    discount: {
      rate: 20,
      price: "27.500 TL",
    },
    price: "25.223 TL",
    detailItems: [
      {
        label: "Hareket Tarihi",
        value: "12 Haz 2024",
        tooltip: {
          children: "+5",
          label: (
            <div className="text-xs">
              <div className="font-medium">Diğer hareket tarihleri</div>
              <div className="p-2">
                <li>18 Ağu 2023</li>
                <li>18 Ağu 2023</li>
              </div>
            </div>
          ),
        },
      },
      {
        label: "Hareket Noktaları",
        value: "Kayseri",
        tooltip: {
          children: "+2",
          label: (
            <div className="text-xs">
              <div className="font-medium">Diğer hareket noktaları</div>
              <div className="p-2">
                <li>İstanbul</li>
                <li>Malatya</li>
              </div>
            </div>
          ),
        },
      },
      {
        label: "Gidiş",
        value: "Uçak(THY)",
      },
      {
        label: "Dönüş",
        value: "Uçak(Pegasus)",
      },
    ],
    isRecommended: true,
    likeButtonVisible: false,
    includedSpecifications: [
      {
        icon: "Activity",
        text: "Ücretsiz İptal",
      },
      {
        icon: "Activity",
        text: "Şimdi Al Sonra Öde",
      },
      {
        icon: "Activity",
        text: "12 Taksit Seçeneği",
      },
      {
        icon: "Activity",
        text: "Ek seçenek 1",
      },
      {
        icon: "Activity",
        text: "Ek seçenek 12",
      },
      {
        icon: "Activity",
        text: "Ek seçenek 3",
      },
    ],
    priceInformation: "`den başlayan",
    images: [
      "https://source.unsplash.com/a-group-of-hot-air-balloons-in-the-sky-3iWk9XvPMqo",
      "https://source.unsplash.com/white-hot-air-balloon-lot-near-mountain-0p_ihwr4j-E",
    ],
  },
  parameters: {
    // 👇 The viewports object from the Essentials addon
    viewport: {
      // 👇 The viewports you want to use
      viewports: INITIAL_VIEWPORTS,
      // 👇 Your own default viewport
    },
  },
} satisfies Meta<typeof TourCard>;

export default meta;

type Story = StoryObj<typeof TourCard>;

export const DefaultTourCard: Story = {
  args: {
    swiperContainerModifierClass: "DefaultTourCard",
  },
};

export const TourCardNoImage: Story = {
  args: {
    images: undefined,
    swiperContainerModifierClass: "TourCardNoImage",
  },
};

export const TourCardNoRecommended: Story = {
  args: {
    isRecommended: false,
    swiperContainerModifierClass: "TourCardNoRecommended",
  },
};

export const TourCardNoPrice: Story = {
  args: {
    price: undefined,
    swiperContainerModifierClass: "TourCardNoPrice",
  },
};

export const TourCardWithLike: Story = {
  args: {
    likeButtonVisible: true,
    swiperContainerModifierClass: "TourCardWithLike",
  },
};

export const TourCardMobile: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    likeButtonVisible: true,
    swiperContainerModifierClass: "TourCardMobile",
  },
};

export const TourCardSpecificationError: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    SpecificationError: "Seçtiğiniz tarihlerde boş oda kalmadı.",
    swiperContainerModifierClass: "TourCardSpecificationError",
  },
};

export const TourCardSelectDate: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    selectDateForPrice: true,
    swiperContainerModifierClass: "TourCardSelectDate",
  },
};

export const TourCardAvailableButton: Story = {
  parameters: {
    viewport: {
      defaultViewport: "iphonex",
    },
  },
  args: {
    availableDateButton: true,
    swiperContainerModifierClass: "TourCardAvailableButton",
  },
};
