/* eslint-disable react/no-danger */
import React from "react";

import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Tooltip } from "@/components/ui/tooltip/tooltip";
import type { DepaturePoint } from "@/services/eva-display/tour/tour-detail/tour-detail-service";

interface TourProductDetailAboutProps {
  departurePoints: DepaturePoint[];
  minNight: number;
  minDay: number;
  transportTypeName: string;
  transportReturnTypeName: string;
  departurePointsText: string | undefined;
  priceIncluded: any;
  priceExternal: any;
  extendIncludedDepaturePoints: any;
}

export default function TourProductDetailAbout({
  departurePoints,
  minNight,
  minDay,
  transportTypeName,
  transportReturnTypeName,
  priceIncluded,
  priceExternal,
  departurePointsText,
  extendIncludedDepaturePoints,
}: TourProductDetailAboutProps) {
  return (
    <Card id="overview" className="scroll-mt-16 md:scroll-mt-44">
      <div className="flex flex-col gap-3">
        <h5 className="text-xl font-semibold text-gray-800">Tur Hakkında</h5>
        <div className="flex flex-col gap-4 sm:grid sm:grid-cols-4">
          {departurePoints && (
            <div>
              <p className="mb-1 text-sm font-normal text-gray-500">
                Hareket Noktaları
              </p>
              <div className="flex items-center justify-between rounded-lg border border-gray-200 bg-gray-100 p-3">
                <div className="flex items-center gap-1">
                  <LIcon name="MapPin" className="text-gray-800" size={16} />
                  {departurePointsText}
                </div>
                <div>
                  {(departurePoints?.length || 0) > 1 && (
                    <Tooltip
                      position="bottom"
                      label={
                        <div className="flex flex-col gap-2">
                          <span className="font-semibold">
                            Diğer Hareket Noktaları
                          </span>
                          <ul className="!list-disc p-5">
                            {extendIncludedDepaturePoints}
                          </ul>
                        </div>
                      }
                    >
                      <div className="cursor-pointer items-center rounded-full border border-gray-100 bg-gray-100 px-2 py-0.5 text-xs font-medium text-slate-800">
                        {extendIncludedDepaturePoints?.length > 0 &&
                          `+${extendIncludedDepaturePoints?.length}`}
                      </div>
                    </Tooltip>
                  )}
                </div>
              </div>
            </div>
          )}
          <div>
            <p className="mb-1 text-sm font-normal text-gray-500">Tur Süresi</p>

            <div className="flex items-center gap-1 rounded-lg border border-gray-200 bg-gray-100 p-3">
              <LIcon name="Timer" color="#1D2939" size={16} />
              <span>{` ${minNight} gece ${minDay} gün`}</span>
            </div>
          </div>
          <div>
            <p className="mb-1 text-sm font-normal text-gray-500">
              Ulaşım (Gidiş-Dönüş)
            </p>
            <div className="flex items-center gap-1 rounded-lg border border-gray-200 bg-gray-100 p-3">
              <LIcon name="BusFront" color="#1D2939" size={16} />
              <span>{`${transportTypeName}${
                transportTypeName === transportReturnTypeName
                  ? ""
                  : ` ${transportReturnTypeName}`
              }`}</span>
            </div>
          </div>
        </div>

        <h4 className="font-semibold text-[#1d2939]">Fiyata Dahil Olanlar</h4>

        <div dangerouslySetInnerHTML={{ __html: priceIncluded?.text }} />
        <h4 className="font-semibold text-[#1d2939]">
          Fiyata Dahil Olmayanlar
        </h4>

        <div dangerouslySetInnerHTML={{ __html: priceExternal?.text }} />
      </div>
    </Card>
  );
}
