/* eslint-disable @next/next/no-img-element */
import Image from "next/image";
import React from "react";

import { Carousel } from "@/components/ui/carousel/carousel";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import type { TourImage } from "@/services/eva-display/tour/tour-detail/tour-detail-service";

import ProductDetailPhotoGallery from "../../product-detail-photo-gallery/product-detail-photo-gallery";

interface TourProductDetailOverviewProps {
  images: TourImage[];
}
export default function TourProductDetailOverview({
  images,
}: TourProductDetailOverviewProps) {
  const {
    closeModal: galleryCloseModal,
    openModal: galleryOpenModal,
    modalOpen: galleryModalOpen,
  } = useModal({ open: false });
  return (
    <>
      <div className="relative min-h-[50vw] rounded-primary md:min-h-0 md:w-full data-[full='false']:md:w-7/12">
        {images &&
          (images.length > 1 ? (
            <div className="relative">
              <Carousel className="h-[262px] w-full md:h-[358px]">
                {images?.map((image) => (
                  <Image
                    className="rounded-primary object-cover"
                    layout="fill"
                    src={image.thumbnailUrl}
                    alt="Hotel card images"
                    key={image.thumbnailUrl}
                    onClick={galleryOpenModal}
                  />
                ))}
              </Carousel>
              <div className="absolute bottom-3 right-3 z-10 bg-[#10182880] p-1 text-xs text-white">
                + {images.length}
              </div>
            </div>
          ) : (
            images?.map((image) => (
              <Image
                className="rounded-primary object-cover "
                layout="fill"
                src={image.thumbnailUrl}
                alt="Hotel card images"
                key={image.thumbnailUrl}
                onClick={galleryOpenModal}
              />
            ))
          ))}
      </div>

      <Modal
        size="full"
        className="z-[102] !p-0"
        open={galleryModalOpen}
        footer
        closable={false}
      >
        <ProductDetailPhotoGallery
          onClose={galleryCloseModal}
          images={images}
        />
      </Modal>
    </>
  );
}
