import dayjs from "dayjs";
import React from "react";

import Card from "@/components/ui/card/card";
import { JoinItems } from "@/components/widget/booking-request-card-detail/booking-request-card-detail";
import { cn } from "@/libs/utils";
import type { IPassengerInformation } from "@/services/eva-display/demand/passenger-information/passenger-information";

import styles from "../flight-request-card-detail/flight-request-card-detail.module.css";

interface TransferRequestCardDetailPersonalInformationProps {
  passengerInformations: IPassengerInformation;
}
export function Undefined() {
  return <small className="text-error-400">bulunamadı</small>;
}
const TransferRequestCardDetailPersonalInformation = ({
  passengerInformations,
}: TransferRequestCardDetailPersonalInformationProps) => {
  return (
    <Card className="p-8">
      <div className="flex items-center justify-between">
        <h2 className={cn(styles.title, "text-lg")}>Kişi Bilgileri</h2>
      </div>

      {passengerInformations
        ? Object.values(passengerInformations).map((passenger) => {
            let phoneNumber;
            if (passenger?.PhoneNumbers) {
              phoneNumber = JoinItems([
                passenger?.PhoneNumbers[0]?.CountryCode,
                passenger?.PhoneNumbers[0]?.AreaCode,
                passenger?.PhoneNumbers[0]?.Number,
              ]);
            }

            return (
              <div
                key={passenger.Key}
                className={cn(
                  "grid mt-4 pb-4 border-b last:border-b-0 grid-cols-2 gap-4 lg:grid-cols-4 lg:gap-0",
                  {
                    "lg:grid-cols-5": !!passenger.MilesCode,
                  },
                )}
              >
                <div className={styles.rowCell}>
                  <p className={styles.heading}>Ad Soyad</p>
                  <p
                    className="mt-1 truncate"
                    title={`${passenger?.Name} ${passenger?.Surname}`}
                  >
                    {passenger?.Name || Undefined()} {passenger?.Surname}
                  </p>
                </div>
                <div className={styles.rowCell}>
                  <p className={styles.heading}>Doğum Tarihi</p>
                  <p className="mt-1">
                    {dayjs(passenger?.Birthday).format("DD.MM.YYYY")}
                  </p>
                </div>
                <div className={styles.rowCell}>
                  <p className={styles.heading}>Telefon Numarası</p>
                  <p className="mt-1">{`+${phoneNumber}` || <Undefined />}</p>
                </div>
                <div className={styles.rowCell}>
                  <p className={styles.heading}>E-posta</p>
                  <p className="mt-1 truncate" title={passenger?.Email}>
                    {passenger?.Email || <Undefined />}
                  </p>
                </div>
                {passenger?.MilesCode && (
                  <div className={styles.rowCell}>
                    <p className={styles.heading}>Miles & Smiles No</p>
                    <p className="mt-1 truncate" title={passenger?.MilesCode}>
                      {passenger?.MilesCode || <Undefined />}
                    </p>
                  </div>
                )}
              </div>
            );
          })
        : Undefined()}
    </Card>
  );
};

export default TransferRequestCardDetailPersonalInformation;
