import dayjs from "dayjs";
import React from "react";

import Card from "@/components/ui/card/card";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type { IBookingRequest } from "@/models/booking-request.model";
import type { ITransferReservationData } from "@/services/eva-display/demand/transfer-reservation-data/transfer-reservation-data";

import styles from "../flight-request-card-detail/flight-request-card-detail.module.css";

interface TransferRequestCardDetailReservationInformationProps {
  data: IBookingRequest;
  reservationData: ITransferReservationData;
}

const TransferRequestCardDetailReservationInformation = ({
  data,
  reservationData,
}: TransferRequestCardDetailReservationInformationProps) => {
  let transferSegmentGroupItems =
    reservationData.DetailResponse.TransferSegmentGroupItem.filter((x) =>
      reservationData.ProductKeys.includes(x.Key),
    );

  transferSegmentGroupItems = transferSegmentGroupItems.sort(
    (a, b) =>
      dayjs(a.Items[0]?.DepartureTime).valueOf() -
      dayjs(b.Items[0]?.DepartureTime).valueOf(),
  );

  const originSegmentGroup = transferSegmentGroupItems[0]?.Items[0];
  // const destinationSegmentGroup =
  //   transferSegmentGroupItems.length === 1
  //     ? null
  //     : transferSegmentGroupItems[1]?.Items[0];

  return (
    <Card className="p-8">
      <h2 className={cn(styles.title, "mb-4 text-lg")}>
        Rezervasyon Bilgileri
      </h2>
      <div className="grid grid-cols-1 gap-x-2 gap-y-3 md:grid-cols-2 lg:grid-cols-4">
        <div className={styles.rowCell}>
          <p className="font-medium text-gray-500">Seyahat Yeri</p>
          <p className="mt-1">{originSegmentGroup?.Name?.split(" - ")[1]}</p>
        </div>
        <div className={styles.rowCell}>
          <p className="font-medium text-gray-500">Gidiş Tarihi ve Saati</p>
          <p className="mt-1">
            {dayjs(originSegmentGroup?.ArrivalTime).format("DD MMM YYYY HH:mm")}
          </p>
        </div>
        <div className={styles.rowCell}>
          <p className="font-medium text-gray-500">Seyahat Nedeni</p>
          <p className="mt-1">
            {data?.travelReasonName ? data?.travelReasonName : "-"}
          </p>
        </div>
        <div className={styles.rowCell}>
          <p className="font-medium text-gray-500">Toplam Tutar</p>
          <p className="mt-1">
            {PriceManager({
              currency: "TRY",
              value: (`${data?.totalPrice}` as unknown as number) || 0,
            })}
          </p>
        </div>
      </div>
    </Card>
  );
};

export default TransferRequestCardDetailReservationInformation;
