/* eslint-disable react/no-array-index-key */
import type { CounterProps } from "@/components/ui/counter/counter";
import Counter from "@/components/ui/counter/counter";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { useLocale } from "@/hooks/useLocale";
import { DateHelper } from "@/libs/helpers/date-time-helper";

interface CustomerCounterProps extends CounterProps {
  label?: string;
}

const CustomerCounter = ({ label, ...counterProps }: CustomerCounterProps) => {
  return (
    <div className="flex items-center justify-between">
      <div className="text-sm">{label}</div>
      <Counter {...counterProps} />
    </div>
  );
};

interface CustomerAgeCounterProps {
  value: number;
  onChange: (value: number) => void;
  label?: string;
  checkInDate?: Date;
}

export function CustomerAgeCounter(props: CustomerAgeCounterProps) {
  const { t } = useLocale();
  return (
    <div className="max-w-80">
      <div className="flex items-center justify-between">
        <div className="text-sm">{props?.label}</div>
        <Select
          value={props.value?.toString()}
          onValueChange={(value) => props.onChange(+value)}
          defaultValue="1"
        >
          <SelectTrigger className="max-h-[30px] max-w-[100px]">
            <SelectValue placeholder="Theme" />
          </SelectTrigger>
          <SelectContent
            style={{ zIndex: 1000 }}
            className="scroll-bar max-h-[200px]"
          >
            {[...Array(18).keys()]
              .filter((x) => x !== 0)
              .map((x, index) => (
                <SelectItem key={index} value={x.toString()}>
                  {x === 1 ? "0-2" : x}
                </SelectItem>
              ))}
          </SelectContent>
        </Select>
      </div>
      {props.checkInDate && (
        <div className="mt-2 line-clamp-2 text-xs text-gray-500">
          {t(
            "The child's date of birth must be between {{date1}} and {{date2}}.",
            {
              // this is january first day
              date1: DateHelper.dayjs(props.checkInDate)
                .subtract(props.value, "years")
                .format("DD.MM.YYYY"),
              date2: DateHelper.dayjs(props.checkInDate)
                .subtract(props.value === 1 ? 0 : props.value - 1, "years")
                .subtract(1, "days")
                .format("DD.MM.YYYY"),
            },
          )}
        </div>
      )}
    </div>
  );
}

export default CustomerCounter;
