/* eslint-disable no-nested-ternary */
import { useLocale } from "@/hooks/useLocale";

import CustomerCounter, { CustomerAgeCounter } from "./customer-counter";

export type RoomAndCustomerCounterValue = Record<
  string,
  { count: number; ages?: number[] }
>;

export interface GroupCustomerCounterProps {
  value: RoomAndCustomerCounterValue;
  onChange: (value: RoomAndCustomerCounterValue) => void;
  items: {
    label: string;
    name: string;
    hasAge?: boolean;
    agesLabel?: (index: number) => string;
    min?: number;
    max?: number;
  }[];
  checkInDate?: Date;
}
const GroupCustomerCounter = (props: GroupCustomerCounterProps) => {
  const { t } = useLocale();
  return (
    <div className="flex flex-col gap-3">
      {props.items.map(
        ({ name, label, hasAge, agesLabel, min, max }, index) => (
          <div key={+index}>
            <CustomerCounter
              label={label}
              min={min ?? 0}
              max={max}
              value={props.value[name]?.count ?? 0}
              onChange={(value) => {
                props.onChange({
                  ...props.value,
                  [name]: {
                    ...props.value[name],
                    count: value,
                    ages:
                      value > 0
                        ? hasAge
                          ? value > props.value[name]!.ages!.length
                            ? [...props.value[name]!.ages!, 1]
                            : props.value[name]!.ages!.slice(0, value)
                          : undefined
                        : [],
                  },
                });
              }}
            />

            {hasAge &&
              !!props.value[name]?.count &&
              props.value[name]!.count > 0 && (
                <>
                  <p className="my-5 text-xs text-primary-500">
                    {t(
                      "Enter the age of the child on the check-in date at the hotel.",
                    )}
                  </p>
                  <div className="flex flex-col justify-stretch gap-3">
                    {Array.from({ length: props.value[name]!.count }).map(
                      (_, indexAge) => (
                        <CustomerAgeCounter
                          key={agesLabel?.(indexAge) ?? "yas"}
                          value={props.value[name]?.ages?.[indexAge] ?? 0}
                          label={
                            agesLabel?.(indexAge) ??
                            `${indexAge + 1}. çocuk yaşı`
                          }
                          checkInDate={props.checkInDate}
                          onChange={(value) => {
                            props.onChange({
                              ...props.value,
                              [name]: {
                                ...props.value[name]!,
                                ages: [
                                  ...props.value[name]!.ages!.slice(
                                    0,
                                    indexAge,
                                  ),
                                  value,
                                  ...props.value[name]!.ages!.slice(
                                    indexAge + 1,
                                    props.value[name]!.ages!.length,
                                  ),
                                ],
                              },
                            });
                          }}
                        />
                      ),
                    )}
                  </div>
                </>
              )}
          </div>
        ),
      )}
    </div>
  );
};

export default GroupCustomerCounter;
