import { Button } from "@/components/ui/button/button";
import { useLocale } from "@/hooks/useLocale";

import type {
  GroupCustomerCounterProps,
  RoomAndCustomerCounterValue,
} from "./room-and-customer-counter";
import GroupCustomerCounter from "./room-and-customer-counter";

export interface GroupsCustomersCounterProps {
  value: RoomAndCustomerCounterValue[];
  onChange: (value: RoomAndCustomerCounterValue[]) => void;
  items:
    | GroupCustomerCounterProps["items"]
    | ((index: number) => GroupCustomerCounterProps["items"]);
  onNewGroup?: () => void;
  onRemoveGroup?: (index: number) => void;
  checkInDate?: Date;
  maxGroupCount?: number;
  warning?: boolean;
  warningMessage?: string;
  warningType?: string;
}

const GroupsCustomersCounter = (props: GroupsCustomersCounterProps) => {
  const { t } = useLocale();
  const addMoreGroups =
    props.maxGroupCount === undefined ||
    props.value.length < props.maxGroupCount;

  return (
    <div>
      <div className="scroll-bar overflow-y-scroll p-4 md:max-h-[300px]">
        {props.value?.map((value, index) => {
          const items =
            typeof props.items === "function"
              ? props.items(index)
              : props.items;
          return (
            <div
              key={items[index]?.name}
              className="mt-5 min-w-[325px] first:mt-0"
            >
              <div className="mb-3 flex items-center justify-between">
                <h3 className="font-bold">
                  {index + 1}
                  {t(". Room")}
                </h3>
                {index !== 0 && (
                  <Button
                    onClick={() => props.onRemoveGroup?.(index)}
                    variant="link"
                    className="!text-error-500"
                    size="sm"
                  >
                    {t("Remove")}
                  </Button>
                )}
              </div>
              <GroupCustomerCounter
                value={value}
                items={items}
                checkInDate={props.checkInDate}
                onChange={(changedValue) => {
                  const newValue = [...props.value];
                  newValue[index] = changedValue;
                  props.onChange(newValue);
                }}
              />
            </div>
          );
        })}
      </div>

      {addMoreGroups && !props.warning && (
        <div className="-mr-3 flex justify-end px-4">
          <Button variant="primary-text" onClick={props.onNewGroup}>
            {t("Add Room")}
          </Button>
        </div>
      )}
      {props.warning && (
        <div className="flex flex-col items-center justify-center p-4">
          <span
            className={`${props.warningType === "error" ? "text-error-500" : "text-warning-500"} max-w-[325px] border-t pt-4 text-sm`}
          >
            {props.warningMessage}
          </span>
          {props.warningType === "warning" && (
            <Button variant="primary-text" onClick={props.onNewGroup}>
              {t("Add Room")}
            </Button>
          )}
        </div>
      )}
    </div>
  );
};

export default GroupsCustomersCounter;
