import { useBoolean } from "usehooks-ts";

import { Dialog, DialogContent } from "@/components/ui/dialog";
import { useLocale } from "@/hooks/useLocale";

import TpBottomBox from "../tp-bottom-box/tp-bottom-box";
import GroupsCustomersCounter from "./components/rooms-and-customers-counter";
import type { CustomerGroupSelectProps } from "./customer-group-select.types";
import { CustomerGroupSelectTriggerButton } from "./customer-group-select-trigger-button";

const CustomerGroupSelectMobile = ({
  ...groupsCustomerCounterProps
}: CustomerGroupSelectProps) => {
  const boolean = useBoolean();
  const { t } = useLocale();
  function getCustomersCount() {
    let count = 0;
    groupsCustomerCounterProps.value?.forEach((itemValue, index) => {
      const items =
        typeof groupsCustomerCounterProps.items === "function"
          ? groupsCustomerCounterProps.items(index)
          : groupsCustomerCounterProps.items;
      items?.forEach((item) => {
        const customer = itemValue[item.name];
        if (customer) {
          count += customer.count;
        }
      });
    });

    return count;
  }

  return (
    <div>
      <CustomerGroupSelectTriggerButton
        {...groupsCustomerCounterProps}
        bool={boolean}
        customerCount={getCustomersCount()}
        onClick={boolean.setTrue}
      />
      <Dialog modal open={boolean.value} onOpenChange={boolean.setValue}>
        <DialogContent className="z-[101] size-full p-0">
          <div className="flex flex-col justify-between pt-4">
            <div className="scroll max-h-[calc(100vh-100px)] grow overflow-x-hidden overflow-y-scroll">
              <GroupsCustomersCounter {...groupsCustomerCounterProps} />
            </div>
            <TpBottomBox
              onApplyClick={boolean.setFalse}
              label={t("{{roomCount}} room, {{travelCount}} travellers", {
                roomCount: groupsCustomerCounterProps.value?.length,
                travelCount: getCustomersCount(),
              })}
              buttonText={t("Apply")}
            />
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
};

export default CustomerGroupSelectMobile;
