import type { UseBooleanOutput } from "@/@types/types/boolean.types";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import { useApp } from "@/hooks/useApp";
import { useLocale } from "@/hooks/useLocale";

import type { CustomerGroupSelectProps } from "./customer-group-select.types";

export const CustomerGroupSelectTriggerButton = ({
  bool,
  onClick,
  customerCount,
  ...groupsCustomerCounterProps
}: CustomerGroupSelectProps & {
  bool: UseBooleanOutput;
  onClick?: VoidFunction;
  customerCount: number;
}) => {
  const { t } = useLocale();
  const { isB2E, isB2C } = useApp();
  return (
    <TriggerButton
      isFocus={bool.value}
      size="lg"
      fullWidth
      className="w-full bg-white group-data-[state=open]:border-primary-200 group-data-[state=open]:ring-2 group-data-[state=open]:ring-primary-50"
      label={isB2E ? t("Person and Room information") : undefined}
      placeholder={isB2C ? t("Person and Room information") : undefined}
      leftIcon={<LIcon name="User" />}
      iconHiddenOnMobile={false}
      onClick={onClick}
      value={t("{{roomCount}} room, {{travelCount}} travellers", {
        roomCount: groupsCustomerCounterProps.value?.length,
        travelCount: customerCount,
      })}
    />
  );
};
