import { useBoolean } from "usehooks-ts";

import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import { useLocale } from "@/hooks/useLocale";

import TpBottomBox from "../tp-bottom-box/tp-bottom-box";
import GroupsCustomersCounter from "./components/rooms-and-customers-counter";
import type { CustomerGroupSelectProps } from "./customer-group-select.types";
import { CustomerGroupSelectTriggerButton } from "./customer-group-select-trigger-button";

const CustomerGroupSelect = ({
  ...groupsCustomerCounterProps
}: CustomerGroupSelectProps) => {
  const boolean = useBoolean();
  const { t } = useLocale();
  function getCustomersCount() {
    let count = 0;
    groupsCustomerCounterProps.value?.forEach((itemValue, index) => {
      const items =
        typeof groupsCustomerCounterProps.items === "function"
          ? groupsCustomerCounterProps.items(index)
          : groupsCustomerCounterProps.items;
      items?.forEach((item) => {
        const customer = itemValue[item.name];
        if (customer) {
          count += customer.count;
        }
      });
    });

    return count;
  }

  return (
    <Popover open={boolean.value} onOpenChange={boolean.setValue}>
      <PopoverTrigger className="group w-full">
        <CustomerGroupSelectTriggerButton
          customerCount={getCustomersCount()}
          bool={boolean}
          {...groupsCustomerCounterProps}
        />
      </PopoverTrigger>
      <PopoverContent className="w-full p-0">
        <GroupsCustomersCounter {...groupsCustomerCounterProps} />
        <TpBottomBox
          onApplyClick={boolean.setFalse}
          label={t("{{roomCount}} room, {{travelCount}} travellers", {
            roomCount: groupsCustomerCounterProps.value?.length,
            travelCount: getCustomersCount(),
          })}
          buttonText={t("Apply")}
        />
      </PopoverContent>
    </Popover>
  );
};

export default CustomerGroupSelect;
