/* eslint-disable no-nested-ternary */
import { useBoolean } from "usehooks-ts";

import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu/dropdown-menu";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import { useLocale } from "@/hooks/useLocale";

import CustomerCounter from "../customer-group-select/components/customer-counter";
import type {
  GroupCustomerCounterProps,
  RoomAndCustomerCounterValue,
} from "../customer-group-select/components/room-and-customer-counter";
import TpBottomBox from "../tp-bottom-box/tp-bottom-box";

export type FlightCustomerCabinTypeValue = Record<
  string,
  { title: string; value: string }
>;

export interface FlightCustomerGroupSelectProps {
  value: RoomAndCustomerCounterValue;
  cabinValue: FlightCustomerCabinTypeValue;
  cabinOnchangeValue: (value: FlightCustomerCabinTypeValue) => void;
  onChange: (value: RoomAndCustomerCounterValue) => void;
  items: GroupCustomerCounterProps["items"];
}

export const DEFAULT_VALUE = {
  employee: { count: 1 },
  guest: { count: 0 },
  child: { count: 0, ages: [] },
  cabinType: "1",
};

export const cabinTypeValues = [
  {
    title: "All",
    value: "4",
  },
  {
    title: "Economy",
    value: "0",
  },
  {
    title: "Business",
    value: "2",
  },
  {
    title: "Confort",
    value: "1",
  },
  {
    title: "First Class",
    value: "3",
  },
];

const FlightCustomerGroupSelect = ({
  ...props
}: FlightCustomerGroupSelectProps) => {
  const boolean = useBoolean();
  const { t } = useLocale();
  function getCustomersCount() {
    if (props.value) {
      return Object.values(props.value).reduce(
        (toplam, category) => toplam + (category?.count || 0),
        0,
      );
    }
    return 0;
  }
  const customerLenght = getCustomersCount();
  return (
    <Popover open={boolean.value} onOpenChange={boolean.setValue}>
      <PopoverTrigger className="group w-full">
        <TriggerButton
          isFocus={boolean.value}
          size="lg"
          fullWidth
          className="w-full group-data-[state=open]:border-primary-200 group-data-[state=open]:ring-2 group-data-[state=open]:ring-primary-50"
          label={t("Passengers & Class")}
          leftIcon={<LIcon name="User" />}
          value={`${customerLenght} ${customerLenght > 1 ? t("Passengers") : t("Passenger")}`}
        />
      </PopoverTrigger>
      <PopoverContent className="flex min-w-[300px] flex-col gap-4 p-5">
        <h2 className="text-base font-semibold text-gray-800">
          {t("Passengers & Class")}
        </h2>
        {props.items.map(({ name, label, hasAge, min }) => {
          if (name === "cabinType") {
            return (
              <div className="flex items-center justify-between" key={name}>
                <span className="text-sm">{t("Class")}</span>
                <DropdownMenu>
                  <DropdownMenuTrigger className=" min-w-[150px]">
                    <TriggerButton
                      size="md"
                      value={
                        props.cabinValue
                          ? t(props.cabinValue[name]?.title as string)
                          : t("Economy")
                      }
                    />
                  </DropdownMenuTrigger>
                  <DropdownMenuContent className="min-w-[190px]">
                    {cabinTypeValues.map((item) => (
                      <DropdownMenuItem
                        key={item.value}
                        onClick={() => {
                          props.cabinOnchangeValue({
                            ...props.cabinValue,
                            cabinType: {
                              title: item.title,
                              value: item.value,
                            },
                          });
                        }}
                      >
                        {t(item.title)}
                      </DropdownMenuItem>
                    ))}
                  </DropdownMenuContent>
                </DropdownMenu>
              </div>
            );
          }
          return (
            <div key={name}>
              <CustomerCounter
                label={label}
                min={min}
                value={props.value ? (props.value[name]?.count ?? 0) : 0}
                onChange={(value) => {
                  props.onChange({
                    ...props.value,
                    [name]: {
                      ...props.value[name],
                      count: value,
                      ages: hasAge
                        ? props.value[name]!.count >
                          props.value[name]!.ages!.length
                          ? [...props.value[name]!.ages!, 0]
                          : props.value[name]!.ages!.slice(
                              0,
                              props.value[name]!.count,
                            )
                        : undefined,
                    },
                  });
                }}
              />
            </div>
          );
        })}
        <TpBottomBox
          buttonText={t("Apply")}
          className="!px-0"
          onApplyClick={boolean.setFalse}
          label={`${customerLenght} ${customerLenght > 1 ? t("Passengers") : t("Passenger")} - ${
            props.cabinValue
              ? t(props.cabinValue.cabinType?.title as string)
              : t("Economy")
          }`}
        />
      </PopoverContent>
    </Popover>
  );
};

export default FlightCustomerGroupSelect;
