import type { ReactNode } from "react";

import { Button } from "@/components/ui/button/button";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";

interface TpBottomBoxProps {
  className?: string;
  label?: ReactNode;
  onApplyClick?: () => void;
  buttonText?: string;
  buttonDisabled?: boolean;
}

const TpBottomBox = ({
  className,
  label,
  onApplyClick,
  buttonText = "Apply",
  buttonDisabled,
}: TpBottomBoxProps) => {
  const { t } = useLocale();
  return (
    <div
      className={cn(
        className,
        "p-4 border-t flex justify-between items-center",
      )}
    >
      <div className="text-xs font-medium text-gray-800">{label}</div>
      <Button
        size="sm"
        disabled={!!buttonDisabled}
        className="min-w-[105px]"
        variant="primary"
        onClick={onApplyClick}
      >
        {t(buttonText)}
      </Button>
    </div>
  );
};

export default TpBottomBox;
