import dayjs from "dayjs";
import { useBoolean } from "usehooks-ts";

import { Button } from "@/components/ui/button/button";
import { Calendar } from "@/components/ui/calendar/calendar";
import { Dialog, DialogContent } from "@/components/ui/dialog";
import { useLocale } from "@/hooks/useLocale";
import { DateHelper } from "@/libs/helpers/date-time-helper";
import { cn } from "@/libs/utils";

import TpDateRangePickerCloseButton from "../tp-date-range-picker/components/tp-date-range-picker-close-button";
import TpDateRangePickerMessageBox from "../tp-date-range-picker/components/tp-date-range-picker-message-box";
import type {
  ITpDatePickerValue,
  TpDatePickerProps,
} from "./tp-date-picker.types";
import { TpDatePickerTriggerButton } from "./tp-date-picker-trigger-button";

const TpDatePickerMobile = ({ className, ...props }: TpDatePickerProps) => {
  const boolean = useBoolean();
  const { t } = useLocale();
  function getMessageByDates(data: ITpDatePickerValue) {
    if (!data?.date) {
      return props.placeHolder;
    }

    return `${DateHelper.formatDateToString(data?.date)}`;
  }
  return (
    <div className={cn("grid gap-2 relative", className)}>
      <TpDatePickerTriggerButton
        {...props}
        bool={boolean}
        onClick={() => {
          boolean.setTrue();
        }}
      />

      <Dialog modal open={boolean.value} onOpenChange={boolean.setValue}>
        <DialogContent noShowClose className="z-[101] size-full p-0">
          <div className="flex flex-col justify-between">
            <div className="shrink-0 px-4 pt-1">
              <TpDateRangePickerCloseButton
                className="mb-2"
                onClick={() => {
                  boolean.setFalse();
                }}
              />
              <TpDateRangePickerMessageBox>
                {getMessageByDates(props.value)}
              </TpDateRangePickerMessageBox>
              <hr className="mt-4" />
            </div>
            <div className="flex max-h-[calc(100dvh-175px)] grow flex-col items-center overflow-y-auto px-4">
              <Calendar
                initialFocus
                mode="single"
                fromDate={dayjs().toDate()}
                toYear={dayjs().year() + 1}
                defaultMonth={
                  props.value?.date ? new Date(props.value?.date) : new Date()
                }
                selected={new Date(props.value?.date ?? "")}
                onSelect={(value) => {
                  if (value) {
                    props.onChange({ date: value });
                  }
                }}
                numberOfMonths={2}
              />
            </div>
            {/* <div>
              <TpBottomBox
                label={
                  <div className="flex gap-2 font-medium">
                    {getMessageByDates(props.value)}
                  </div>
                }
                onApplyClick={boolean.setFalse}
              />
            </div> */}
            <div className="shrink-0 p-4">
              <Button
                variant="primary"
                className="w-full"
                onClick={() => {
                  boolean.setFalse();
                }}
              >
                {t("Apply")}
              </Button>
            </div>
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
};

export default TpDatePickerMobile;
