/* eslint-disable no-nested-ternary */
import dayjs from "dayjs";
import type { PropsWithChildren } from "react";
import { useBoolean } from "usehooks-ts";

import { Calendar } from "@/components/ui/calendar/calendar";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { DateHelper } from "@/libs/helpers/date-time-helper";
import { cn } from "@/libs/utils";

import TpBottomBox from "../tp-bottom-box/tp-bottom-box";
import styles from "../tp-date-range-picker/tp-date-range-picker.module.css";
import TpValidationMessage from "../tp-validation-message/tp-validation-message";
import type {
  ITpDatePickerValue,
  TpDatePickerProps,
} from "./tp-date-picker.types";
import { TpDatePickerTriggerButton } from "./tp-date-picker-trigger-button";

const TpDatePicker = ({ className, ...props }: TpDatePickerProps) => {
  const { t } = useLocale();
  const boolean = useBoolean();
  const { isDesktop } = useBreakpoints();

  function getMessageByDates(data: ITpDatePickerValue) {
    if (!data?.date) {
      return props.placeHolder;
    }

    return `${DateHelper.formatDateToString(data?.date)}`;
  }

  return (
    <div className={cn("grid gap-2 relative", className)}>
      <Popover open={boolean.value} onOpenChange={boolean.setValue}>
        <PopoverTrigger className="w-full">
          <TpDatePickerTriggerButton {...props} bool={boolean} />
        </PopoverTrigger>
        <PopoverContent
          className={styles.popoverContent}
          align="end"
          side="bottom"
          avoidCollisions={false}
        >
          <div>
            <Calendar
              initialFocus
              mode="single"
              fromDate={dayjs().toDate()}
              toYear={dayjs().year() + 1}
              defaultMonth={
                props.value?.date ? new Date(props.value?.date) : new Date()
              }
              selected={new Date(props.value?.date ?? "")}
              onSelect={(value) => {
                if (value) {
                  props.onChange({ date: value });
                }
              }}
              numberOfMonths={isDesktop ? 2 : 1}
            />
          </div>
          <TpBottomBox
            onApplyClick={boolean.setFalse}
            label={
              <div className={styles.popoverFooterContent}>
                {getMessageByDates({ date: props.value?.date })}
              </div>
            }
          />
        </PopoverContent>
      </Popover>
      {props.errorMessage && (
        <TpValidationMessage message={t("This field is required")} />
      )}
    </div>
  );
};

export const TpDateRangeMessageBox = (props: PropsWithChildren) => {
  return (
    <div className={styles.popoverHeaderWrapper}>
      <div className={styles.popoverHeaderContent}>
        <div className={styles.popoverHeaderIconWrapper}>
          <LIcon name="AlertCircle" className={styles.popoverHeaderIcon} />
        </div>
        <div className={styles.popoverHeaderContentText}>{props.children}</div>
      </div>
    </div>
  );
};

TpDatePicker.MessageBox = TpDateRangeMessageBox;

export default TpDatePicker;
