import dayjs from "dayjs";
import { useState } from "react";
import { useBoolean } from "usehooks-ts";

import { Button } from "@/components/ui/button/button";
import { Calendar } from "@/components/ui/calendar/calendar";
import { Dialog, DialogContent } from "@/components/ui/dialog";
import { useLocale } from "@/hooks/useLocale";
import { useMessageByDates } from "@/libs/get-message-by-dates/get-message-by-dates";
import { DateHelper } from "@/libs/helpers/date-time-helper";
import { cn } from "@/libs/utils";

import TpDateRangePickerCloseButton from "./components/tp-date-range-picker-close-button";
import TpDateRangePickerMessageBox from "./components/tp-date-range-picker-message-box";
import type { TpDateRangePickerProps } from "./tp-date-range-picker.types";
import { TpDateRangePickerTriggerButton } from "./tp-date-range-picker-trigger-button";

let memClassName = "";
const selectedStartDayButtonSelector = ".day-range-end.day-range-start";
const hoverDayButtonClass = "border border-gray-200 rounded-primary";

const TpDateRangePickerMobile = ({
  className,
  ...props
}: TpDateRangePickerProps) => {
  const { t } = useLocale();
  const boolean = useBoolean();
  const resetBoolean = useBoolean();
  const [message, setMessage] = useState("");
  const dateMessage = useMessageByDates(props.value, props.showNightInfo);
  const isBeforeCheck = (e: Date) =>
    props.value?.from &&
    !props.value?.to &&
    DateHelper.dayjs(e).isBefore(props.value?.from);
  const isAfterCheck = (e: Date) =>
    props.value?.from &&
    !props.value?.to &&
    DateHelper.dayjs(props.value?.from).isBefore(e);
  const addBorderToElement = (element: MouseEvent) => {
    const target = element?.target as HTMLDivElement;
    target.className = cn(target.className, hoverDayButtonClass);
  };
  const removeBorderFromElement = (element: MouseEvent) => {
    const target = element?.target as HTMLDivElement;
    target.className = target.className.replace(hoverDayButtonClass, "");
  };
  return (
    <div className={cn("grid, gap-2 relative", className)}>
      <TpDateRangePickerTriggerButton
        onClick={boolean.setTrue}
        bool={boolean}
        {...props}
      />

      <Dialog modal open={boolean.value} onOpenChange={boolean.setValue}>
        <DialogContent noShowClose className="z-[101] size-full max-w-2xl p-0">
          <div className="flex flex-col justify-between">
            <div className="shrink-0 px-4 pt-1">
              <TpDateRangePickerCloseButton
                className="mb-2"
                onClick={() => {
                  boolean.setFalse();
                }}
              />
              <TpDateRangePickerMessageBox>
                {message || dateMessage}
              </TpDateRangePickerMessageBox>
              <hr className="mt-4" />
            </div>
            <div className="flex max-h-[calc(100dvh-175px)] grow flex-col items-center overflow-y-auto px-4">
              <Calendar
                initialFocus
                mode="range"
                min={props.minDate}
                fromDate={dayjs().toDate()}
                toDate={
                  props.untilDay
                    ? dayjs().add(props.untilDay, "day").toDate()
                    : undefined
                }
                toYear={!props.untilDay ? dayjs().year() + 1 : undefined}
                defaultMonth={props.value?.from}
                selected={props.value}
                onSelect={(value) => {
                  if (!resetBoolean.value) {
                    if (value?.from && value?.to) {
                      resetBoolean.setTrue();
                    }
                    props.onChange({
                      from: value?.from,
                      to: value?.to,
                    });
                  } else {
                    let changeValue = null;
                    if (props.value.from !== value?.from) {
                      changeValue = value?.from;
                    } else if (props.value.to !== value?.to) {
                      changeValue = value?.to;
                    } else {
                      changeValue = value?.to;
                    }

                    resetBoolean.setFalse();
                    props.onChange({
                      from: changeValue,
                      to: undefined,
                    });
                  }
                }}
                numberOfMonths={2}
                onDayMouseEnter={(e, _, z) => {
                  if (isBeforeCheck(e)) {
                    const selectedButton = document.querySelector(
                      selectedStartDayButtonSelector,
                    );
                    if (selectedButton) {
                      memClassName = selectedButton.className;
                      selectedButton.className = cn(
                        memClassName,
                        "!bg-transparent !text-primary-500 rounded-primary",
                      );
                    }
                    if (z) {
                      addBorderToElement(z as unknown as MouseEvent);
                    }
                    setMessage(t("You are about to change the login date"));
                  }

                  if (props.value?.from && isAfterCheck(e)) {
                    if (z) {
                      addBorderToElement(z as unknown as MouseEvent);
                    }
                    setMessage(
                      `${t("Total")} ${DateHelper.getNightCount(props.value.from, e)} ${t("night")}`,
                    );
                  }
                }}
                onDayMouseLeave={(e, _, z) => {
                  if (isBeforeCheck(e)) {
                    const selectedButton = document.querySelector(
                      selectedStartDayButtonSelector,
                    );
                    if (selectedButton) {
                      selectedButton.className = memClassName;
                    }
                  }

                  if (z) {
                    removeBorderFromElement(z as unknown as MouseEvent);
                  }
                  setMessage("");
                }}
              />
            </div>
            {/* <div className="shrink-0">
              <TpBottomBox
                label={
                  <div className={styles.popoverFooterContent}>
                    {message || dateMessage}
                  </div>
                }
                onApplyClick={boolean.setFalse}
              />
            </div> */}
            <div className="shrink-0 p-4">
              <Button
                variant="primary"
                className="w-full"
                onClick={() => {
                  boolean.setFalse();
                }}
              >
                {t("Apply")}
              </Button>
            </div>
          </div>
        </DialogContent>
      </Dialog>
    </div>
  );
};

export default TpDateRangePickerMobile;
