import type { VariantProps } from "class-variance-authority";
import { cva } from "class-variance-authority";

import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";

const tpValidationMessageVariant = cva(
  "absolute  flex items-center rounded-primary bg-[#01133D] p-2 before:absolute  before:size-0 before:border-[6px] before:border-transparent before:content-['']",
  {
    variants: {
      position: {
        bottom:
          "bottom-[-80%] before:bottom-full before:left-1/2 before:border-b-[#101828]",
        top: "top-[-80%] before:left-1/2 before:top-full before:border-t-[#101828]",
        left: "before:left-full before:top-1/3",
        right: "before:right-full before:top-1/3",
      },
    },
    defaultVariants: {
      position: "top",
    },
  },
);

export interface TpValidationMessageProps
  extends VariantProps<typeof tpValidationMessageVariant> {
  message: string;
  className?: string;
}

const TpValidationMessage = ({
  message,
  position = "top",
  className,
}: TpValidationMessageProps) => {
  const { t } = useLocale();

  function messageGlobalizitonCheck() {
    if (message === "Bu alanın doldurulması zorunludur") {
      return t("This field is required");
    }
    return message;
  }

  return (
    <div
      className={cn(
        tpValidationMessageVariant({
          position,
          className,
        }),
      )}
    >
      <span className="whitespace-nowrap text-xs font-medium text-white">
        {messageGlobalizitonCheck()}
      </span>
    </div>
  );
};
export default TpValidationMessage;
