import { useState } from "react";

import { Checkbox } from "@/components/ui/checkbox/checkbox";
import { Input } from "@/components/ui/input/input";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";

export interface IUserItem {
  name: string;
  value: string | number;
}

interface UserSelectProps {
  users: IUserItem[];
  value?: IUserItem[];
  leftIcon?: React.ReactNode | false;
  placeholder?: string;
  onChange?: (value: IUserItem[]) => void;
}

const UserSelect = (props: UserSelectProps) => {
  const [query, setQuery] = useState("");

  const isSelected = (userItem: IUserItem) => {
    return props.value?.some((valueItem) => valueItem.value === userItem.value);
  };

  return (
    <div>
      <Input
        value={query}
        onChange={(e) => setQuery(e.target.value)}
        placeholder={props.placeholder ?? "Kişi Ara"}
        leftIcon={
          props.leftIcon === false ? undefined : <LIcon name="Search" />
        }
      />
      <span className="m-1 text-xs text-gray-500">{`${props.value?.length} Kişi Seçildi`}</span>
      <div className="mt-5 flex flex-col gap-3">
        {props.users
          .filter((userItem) =>
            userItem.name.toLowerCase().includes(query.toLowerCase()),
          )
          .map((userItem) => (
            <div key={userItem.value}>
              <Checkbox
                id={userItem.value.toString()}
                rounded="md"
                variant="primary"
                label={userItem.name}
                checked={isSelected(userItem)}
                onCheckedChange={(checked) => {
                  if (checked) {
                    props.onChange?.([...(props.value ?? []), userItem]);
                  } else {
                    props.onChange?.(
                      (props.value ?? []).filter(
                        (valueItem) => valueItem.value !== userItem.value,
                      ),
                    );
                  }
                }}
              />
            </div>
          ))}
      </div>
    </div>
  );
};

export default UserSelect;
