import { useForm } from "react-hook-form";

import Form from "@/components/form/form";
import { Button } from "@/components/ui/button/button";

import type { AdvancedListSelectFilterProps } from "./components/advanced-list-select-filter";
import AdvancedListSelectFilter, {
  AdvancedListSelectFilterItemType,
} from "./components/advanced-list-select-filter";

type SelectFilterItem = {
  itemType: typeof AdvancedListSelectFilterItemType;
} & AdvancedListSelectFilterProps;

export type FilterItem = SelectFilterItem;

export interface AdvancedListFiltersProps<T extends FilterItem> {
  filterItems: T[];
  onChangeFilter: (filter: Record<T["name"], any>) => void;
}

const AdvancedListFilters = <T extends FilterItem>(
  props: AdvancedListFiltersProps<T>,
) => {
  const formMethods = useForm({
    mode: "all",
  });

  function getFilterItem(item: FilterItem) {
    switch (item.itemType) {
      case AdvancedListSelectFilterItemType:
        return (
          <AdvancedListSelectFilter key={item.name} {...item} title="test" />
        );
      default:
        return <div>No declare filter item type</div>;
    }
  }

  function getFilterItems(items: FilterItem[]) {
    return items.map((item) => getFilterItem(item));
  }

  const filterItems = getFilterItems(props.filterItems);

  return (
    <div>
      <Form methods={formMethods} onSubmit={() => {}}>
        {filterItems}

        <Button type="submit" variant="primary">
          Filter Uygula
        </Button>
      </Form>
    </div>
  );
};

export default AdvancedListFilters;
