"use client";

import Image from "next/image";
import Link from "next/link";
import { useState } from "react";
import { useBoolean } from "usehooks-ts";

import successIcon from "@/assets/svg/icons/success.svg";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import { ForgotPasswordForm } from "@/components/widget/forgot-password-form/forgot-password-form";
import { useForgotPassword } from "@/services/white-label/auth/forgot-password.services";
import { checkEmail } from "@/validations/form-rules/rules/mail-rules";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

const ForgotPassword = () => {
  const { value, toggle } = useBoolean(false);
  const [mail, setMail] = useState("");
  const forgotPasswordMutation = useForgotPassword({
    onSuccess() {
      toggle();
    },
  });

  if (value) {
    return (
      <div className="flex min-h-[80vh] items-center justify-center">
        <Card className="flex max-w-[392px] flex-col gap-6 bg-white p-6 shadow-2xl">
          <div className="flex flex-col gap-2">
            <Image
              className="mb-5"
              src={successIcon}
              width={48}
              height={48}
              alt="success"
            />
            <span className="text-lg font-medium text-[#1D2939]">
              Sıfırlama maili gönderildi.
            </span>
            <span className="text-base text-gray-500">
              {mail} adresine gönderilen bağlantıya tıklayarak, sıfırlama
              işlemine başlayabilirsin.
            </span>
          </div>

          <Link
            className="flex flex-row gap-1 text-base font-semibold text-gray-500"
            href="/auth"
          >
            <Button variant="primary" className="w-full">
              Giriş Yap
            </Button>
          </Link>
        </Card>
      </div>
    );
  }

  return (
    <div className="flex min-h-[80vh] items-center justify-center">
      <ForgotPasswordForm
        onSubmit={(values) => {
          setMail(values.Email);
          forgotPasswordMutation.mutate(values);
        }}
        validations={{
          email: {
            required: requiredRule,
            validate: checkEmail,
          },
        }}
      />
    </div>
  );
};

export default ForgotPassword;
