/* eslint-disable no-unsafe-optional-chaining */
/* eslint-disable no-alert */

import dayjs from "dayjs";

import Container from "@/components/shared/container";
import TinyHeader from "@/components/shared/tiny-header/tiny-header";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import lcfc from "@/libs/helpers/lower-cased-first-character";
import type { IRentACarBookingRequest } from "@/models/booking-request.model";
import type { Car } from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

import BookingRequestCarRentalSteps from "./components/booking-request-car-rental-steps";
import BookingRequestCarRentalViews from "./components/booking-request-car-rental-views";
import { BookingRequestRentACarChangeProvider } from "./context/booking-request-car-rental-context";

interface BookingRequestCarRentalChangeProps {
  carRentalBookingRequest: IRentACarBookingRequest;
}

const BookingRequestCarRentalChange = (
  props: BookingRequestCarRentalChangeProps,
) => {
  const { reservationData } = props.carRentalBookingRequest;
  const detailResponse = reservationData?.DetailResponse as any;
  const car = lcfc<Car>(detailResponse.Car as Car);
  const { carDetail } = car;

  const selectedOptions = [
    ...(car?.carExtraOption.filter((item) => item?.selected) || []),
    ...(car?.carInsurances.filter((item) => item?.selected) || []),
  ];

  return (
    <BookingRequestRentACarChangeProvider
      selectedOptions={selectedOptions}
      requestId={props.carRentalBookingRequest.id}
      requestData={props.carRentalBookingRequest}
    >
      <div className="border-b border-gray-200 bg-white">
        <Container>
          <TinyHeader href="booking-request" title="Talep Değiştir" />
        </Container>
      </div>
      <Container className="mt-4 pb-5">
        <div className="flex flex-col gap-4">
          {/* Head Info */}
          <Card>
            <div className="flex items-center justify-start gap-10">
              <div>
                <div className="font-medium text-gray-800">
                  {carDetail?.pickupCode}
                </div>
                <div className="text-sm text-gray-500">
                  {dayjs(carDetail?.pickupDate).format("DD MMM ddd, HH:mm")}
                </div>
              </div>
              <div>
                <LIcon name="ArrowRight" size={16} />
              </div>
              <div>
                <div className="font-medium text-gray-800">
                  {carDetail?.returnCode}
                </div>
                <div className="text-sm text-gray-500">
                  {dayjs(carDetail?.returnDate).format("DD MMM ddd, HH:mm")}
                </div>
              </div>
            </div>
          </Card>
          {/* Steps */}
          <BookingRequestCarRentalSteps />
          {/* Render Component */}
          <BookingRequestCarRentalViews
            car={car}
            searchRequest={props.carRentalBookingRequest.searchRequest}
          />
        </div>
      </Container>
    </BookingRequestRentACarChangeProvider>
  );
};

export default BookingRequestCarRentalChange;
