/* eslint-disable no-unsafe-optional-chaining */
import React, { useState } from "react";
import { useForm } from "react-hook-form";
import { useEffectOnce } from "usehooks-ts";

import Form from "@/components/form/form";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import {
  Dialog,
  DialogClose,
  DialogContent,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog";
import RentACarRequestDetailCarInformation from "@/components/widget/rent-a-car-request-detail/components/rent-a-car-request-detail-car-information";
import RentACarRequestDetailPriceSummary from "@/components/widget/rent-a-car-request-detail/components/rent-a-car-request-detail-price-summary";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { useRentACarAddToCart } from "@/services/eva-display/rent-a-car/rent-a-car-add-to-cart/rent-a-car-add-to-cart-service";
import type { PassengerInformation } from "@/services/eva-display/rent-a-car/rent-a-car-request-create/rent-a-car-request-create.types";
import { useRentACarRequestCreate } from "@/services/eva-display/rent-a-car/rent-a-car-request-create/rent-a-car-request-create-service";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

import { useBookingRequestRentACarChangeContext } from "../context/booking-request-car-rental-context";

const BookingRequestCarRentalSummary = () => {
  const {
    selectedCar,
    searchId,
    selectedOptions,
    requestId,
    cartId,
    setCartId,
    requestData,
  } = useBookingRequestRentACarChangeContext();
  const addToCart = useRentACarAddToCart();
  const methods = useForm({
    defaultValues: {
      specialNote: "",
    },
  });
  const [dialogOpen, setDialogOpen] = useState(false);
  const notify = useNotifyStore();
  const { mutateAsync, isLoading } = useRentACarRequestCreate();

  const handleClickSave = () => {
    mutateAsync({
      RequestId: requestId,
      CartId: cartId || "",
      SearchId: searchId,
      ReservationNote: methods.getValues("specialNote") as string,
      TravelReasonId: requestData?.travelReasonId || 0,
      LinkId: "",
      SearchProductKey: selectedCar?.key || "",
      DetailProductKey: selectedCar?.key || "",
      KvkkStatus: true,
      RequesterUserIds: [requestData?.userId || ""],
      RequestDepartmentIds:
        requestData?.displayInformations?.UserDepartments.map(
          (item) => item.Id,
        ) || [],
      PassengerInformations:
        (requestData?.passengerInformations as unknown as PassengerInformation[]) ||
        ([] as PassengerInformation[]),
      ProjectCode: "",
    }).then((e) => {
      if (e.result.requestId === 0) {
        notify.setNotify({
          message: "Bir hata oluştu. Lütfen tekrar deneyin.",
          variant: "error",
          title: "Hata",
        });
        return;
      }
      notify.setNotify({
        message: "Talebiniz başarıyla güncellendi.",
        variant: "success",
        title: "Başarılı",
      });
      window.location.href = `/rentcar-request-detail?id=${e.result.requestId}`;
    });
  };

  useEffectOnce(() => {
    addToCart
      .mutateAsync({
        productKey: selectedCar?.key || "",
        searchId: searchId || "",
        cardId: null,
      })
      .then((response) => {
        if (response.cartId === null) {
          notify.setNotify({
            message: "Bir hata oluştu. Lütfen tekrar deneyin.",
            variant: "error",
            title: "Hata",
          });
          return;
        }
        setCartId(response.cartId);
      })
      .catch(() => {
        notify.setNotify({
          message: "Bir hata oluştu. Lütfen tekrar deneyin.",
          variant: "error",
          title: "Hata",
        });
      });
  });

  if (!selectedCar || !searchId) {
    return null;
  }

  return (
    <Form
      methods={methods}
      onSubmit={(): unknown => {
        return null;
      }}
    >
      <div className="flex flex-col gap-4">
        <RentACarRequestDetailCarInformation
          car={selectedCar}
          selectedOptions={selectedOptions}
        />
        <RentACarRequestDetailPriceSummary
          carDetail={selectedCar?.carDetail}
          car={selectedCar}
          selectedOptions={selectedOptions}
        />
        {/* TASK: EVA-4173 BE doesn't have this parameter's match field */}
        {/* <CoreSummaryNoteFormItem
          name="specialNote"
          placeholder="Talep değiştirme nedeninizi yazın."
          title="Notunuz var mı?"
          titleClassName="!text-xl !text-gray-800"
          className="p-8"
        /> */}
        <Card className="flex items-center justify-between p-8">
          <div>
            <div className="font-medium text-gray-500">Toplam Tutar</div>
            <div className="text-lg font-semibold text-gray-800">
              {PriceManager({
                currency: selectedCar?.totalPrice.slice(0, 3) || "TRY",
                value: +selectedCar?.totalPrice.slice(3),
              })}
            </div>
          </div>
          <div className="flex items-center justify-end gap-4">
            <Button
              variant="outline"
              onClick={() => {
                window.history.back();
              }}
            >
              Vazgeç
            </Button>

            <Dialog
              open={dialogOpen}
              onOpenChange={(open) => {
                if (!open) {
                  setDialogOpen(open);
                }
              }}
            >
              <DialogTrigger asChild>
                <Button
                  type="button"
                  variant="primary"
                  className="w-1/2 md:w-auto"
                  onClick={() => setDialogOpen(true)}
                  disabled={isLoading || dialogOpen}
                >
                  Onayla
                </Button>
              </DialogTrigger>
              <DialogContent className="max-w-[408px]">
                <DialogHeader>
                  <DialogTitle className="!mt-5 !text-lg !font-medium !text-gray-900">
                    Değişiklikleriniz kaydedilecek ve talep onaylanacaktır.
                  </DialogTitle>
                  <p className="text-sm text-gray-500">
                    Yaptığınız değişikliklere göre talep güncellenerek
                    rezervasyona dönüşecektir.
                  </p>
                </DialogHeader>
                <DialogFooter className="mt-4 !flex-col gap-3 sm:!flex-row">
                  <Button
                    className="w-full"
                    data-state="closed"
                    variant="outline"
                    disabled={isLoading}
                    onClick={() => {
                      setDialogOpen(false);
                    }}
                  >
                    Vazgeç
                    <DialogClose />
                  </Button>
                  <Button
                    className="!ml-0 w-full"
                    variant="primary"
                    onClick={handleClickSave}
                    loading={isLoading}
                  >
                    Kaydet ve Onayla
                  </Button>
                </DialogFooter>
              </DialogContent>
            </Dialog>
          </div>
        </Card>
      </div>
    </Form>
  );
};

export default BookingRequestCarRentalSummary;
