import type { Dispatch, SetStateAction } from "react";
import { createContext, useContext, useMemo, useState } from "react";

import type { IRentACarBookingRequest } from "@/models/booking-request.model";
import type {
  Car,
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

interface IBookingRequestRentACarChangeContext {
  activeStep: number;
  searchId: string;
  requestId: number;
  cartId?: string;
  selectedOptions: (CarExtraOption | CarInsurance)[];
  selectedCar?: Car;
  requestData?: IRentACarBookingRequest | undefined;
  setActiveStep: Dispatch<SetStateAction<0 | 1>>;
  setSelectedCar?: Dispatch<SetStateAction<Car | undefined>>;
  setSearchId: Dispatch<SetStateAction<string>>;
  setCartId: Dispatch<SetStateAction<string>>;
}

export const BookingRequestRentACarChangeContext =
  createContext<IBookingRequestRentACarChangeContext>({
    activeStep: 0,
    searchId: "",
    cartId: "",
    requestId: 0,
    selectedOptions: [],
    selectedCar: undefined,
    requestData: undefined,
    setActiveStep: () => {},
    setSelectedCar: () => {},
    setSearchId: () => {},
    setCartId: () => {},
  } as IBookingRequestRentACarChangeContext);

export const BookingRequestRentACarChangeProvider = (props: {
  children: React.ReactNode;
  selectedOptions: (CarExtraOption | CarInsurance)[];
  requestId: number;
  requestData?: IRentACarBookingRequest;
}) => {
  const [activeStep, setActiveStep] = useState<0 | 1>(0);
  const [selectedCar, setSelectedCar] = useState<Car | undefined>();
  const [searchId, setSearchId] = useState("");
  const [cartId, setCartId] = useState("");

  const contextValue = useMemo(
    () => ({
      activeStep,
      searchId,
      cartId,
      requestId: props.requestId,
      selectedCar,
      selectedOptions: props.selectedOptions,
      requestData: props.requestData,
      setSearchId,
      setActiveStep,
      setSelectedCar,
      setCartId,
    }),
    [
      activeStep,
      cartId,
      props.requestData,
      props.requestId,
      props.selectedOptions,
      searchId,
      selectedCar,
    ],
  );

  return (
    <BookingRequestRentACarChangeContext.Provider value={contextValue}>
      {props.children}
    </BookingRequestRentACarChangeContext.Provider>
  );
};
export const useBookingRequestRentACarChangeContext = () => {
  return useContext(BookingRequestRentACarChangeContext);
};
