import dynamic from "next/dynamic";

import type {
  IFlightBookingRequest,
  IRentACarBookingRequest,
  ITransferBookingRequest,
} from "@/models/booking-request.model";
import { useBookingRequestDetailQuery } from "@/services/eva-display/booking-detail-request/booking-detail-service";

const BookingRequestFlightChange = dynamic(
  () => import("./booking-request-flight-change/booking-request-flight-change"),
  { ssr: false },
);

const BookingRequestCarRentalChange = dynamic(
  () =>
    import(
      "./booking-request-car-rental-change/booking-request-car-rental-change"
    ),
  { ssr: false },
);
const BookingRequestTransferChange = dynamic(
  () =>
    import(
      "./booking-request-transfer-change/booking-request-transfer-changer"
    ),
  { ssr: false },
);

interface BookingRequestChangeProps {
  id: number;
}

const BookingRequestChange = (props: BookingRequestChangeProps) => {
  const bookingRequestQuery = useBookingRequestDetailQuery({
    RequestId: props.id,
  });

  if (bookingRequestQuery.isLoading) {
    return null;
  }

  if (bookingRequestQuery.isError) {
    return null;
  }

  if (!bookingRequestQuery.data) {
    return null;
  }

  const bookingRequest = bookingRequestQuery.data;

  if (!bookingRequest) {
    return <div>Booking request not found</div>;
  }

  if (bookingRequest.moduleName === "Flight") {
    return (
      <BookingRequestFlightChange
        flightBookingRequest={bookingRequest as IFlightBookingRequest}
      />
    );
  }
  if (bookingRequest.moduleName === "CarRental") {
    return (
      <BookingRequestCarRentalChange
        carRentalBookingRequest={bookingRequest as IRentACarBookingRequest}
      />
    );
  }

  if (bookingRequest.moduleName === "Transfer") {
    return (
      <BookingRequestTransferChange
        transferBookingRequest={bookingRequest as ITransferBookingRequest}
      />
    );
  }

  return <div />;
};

export default BookingRequestChange;
