import { useRouter } from "next/navigation";

import type { IFlightBookingRequest } from "@/models/booking-request.model";
import { useFlightCreatePostMutation } from "@/services/eva-display/flight/flight-create-post/flight-create-post.service";
import type { IFlightDetailResponse } from "@/services/eva-display/flight/flight-detail/flight-detail.service";

interface UseBookingRequestFlightChangeVariables {
  flightBookingRequest: IFlightBookingRequest;
  searchId: string;
  detailData: IFlightDetailResponse;
  pricingCombinationKeys: string[];
}

export const useBookingRequestFlightChange = (
  variables: UseBookingRequestFlightChangeVariables,
) => {
  const router = useRouter();
  const createPostMutation = useFlightCreatePostMutation({
    onSuccess(data) {
      router.push(`/flight-request-detail?id=${data.requestId}`);
    },
    onError() {},
  });

  function changeBookingRequest(params: { cartId: string }) {
    return createPostMutation.mutateAsync({
      CorpCreateFlightRequest: {
        SearchId: variables.searchId,
        CartId: params.cartId,
        RequestId: variables.flightBookingRequest.id,
        TravelReasonId: variables.flightBookingRequest.travelReasonId,
        LinkId: "",
        SearchProductKey: variables.pricingCombinationKeys[0]!,
        PassengerInformations:
          variables.flightBookingRequest.passengerInformations!,
        IsPreBook: true,
        KvkkStatus: false,
        PriceCombinationKeys: [variables.pricingCombinationKeys[0]!],
        RequesterUserIds: variables.flightBookingRequest.requesterUserIds ?? [],
      },
    });
  }

  return {
    changeBookingRequest,
    isLoading: createPostMutation.isLoading,
  };
};
