/* eslint-disable no-plusplus */
/* eslint-disable no-console */
import dayjs from "dayjs";
import React, { useState } from "react";
import { useUpdateEffect } from "usehooks-ts";

import Container from "@/components/shared/container";
import TinyHeader from "@/components/shared/tiny-header/tiny-header";
import CircleProgressBar from "@/components/ui/circle-progress-bar/circle-progress-bar";
import {
  BookingRequestHotelChangeConfirmationStep,
  BookingRequestHotelChangeHotelStep,
  BookingRequestHotelChangeRoomStep,
} from "@/components/widget/booking-request-hotel-change";
import ListSkeleton from "@/components/widget/list-skeleton/list-skeleton";
import BookingRequestHotelChangeProvider from "@/features/booking-request-change/booking-request-hotel-change/components/booking-request-hotel-change-provider";
import ChoosedRoomCard from "@/features/booking-request-change/shared/choosed-room-card";
import { useHttp } from "@/hooks/useHttp";
import { localeStorageHelper } from "@/libs/helpers/locale-storage-helper";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import stringToJsonHelper from "@/libs/helpers/string-to-json-helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";
import { useBookingRequestDetailQuery } from "@/services/eva-display/booking-detail-request/booking-detail-service";
import type {
  IDisplayInformations,
  ISearchRequest,
} from "@/services/eva-display/demand/display-information/display-information";
import type { IPassengerInformation } from "@/services/eva-display/demand/passenger-information/passenger-information";
import type { IReservationData } from "@/services/eva-display/demand/reservation-data/reservation-data";
import { hotelSearchResultSerializer } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.serializer";
import type { HotelListPassengerList } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

interface BookingRequestHotelChangeDataViewProps {
  pageId?: string | number;
}

const BookingRequestHotelChangeDataView = ({
  pageId,
}: BookingRequestHotelChangeDataViewProps) => {
  const http = useHttp("wl-display-api");
  const { strategyKeys } = useServerDataCtx();

  const [ProgressBarActiveItem, setProgressBarActiveItem] = useState(0);
  const [AlternateHotelList, setAlternateHotelList] = useState<any>([]);
  const [SearchId, setSearchId] = useState("");
  const [passengersState, setPassengers] = useState<HotelListPassengerList[]>(
    [],
  );
  const [HotelListLoading, setHotelListLoading] = useState(false);
  const [SelectedHotel, setSelectedHotel] = useState<any>(null);
  const [SelectedRoom, setSelectedRoom] = useState<any>(null);

  const { isError, isLoading, isSuccess, data } = useBookingRequestDetailQuery(
    {
      RequestId: Number(pageId!),
    },
    {
      onSuccess: async (res) => {
        setHotelListLoading(true);
        const choosedRoom = res;

        const resData = stringToJsonHelper(
          choosedRoom?.reservationData as unknown as string,
        ) as unknown as IReservationData;

        const searchData = stringToJsonHelper(
          choosedRoom?.searchRequest as unknown as string,
        ) as unknown as ISearchRequest;

        const rooms = searchData.Rooms;

        const roomData: any[] = [];
        rooms.forEach((room) => {
          const passengers: any[] = [];
          room.Passengers.forEach((passenger) => {
            const isChild = passenger.PassengerType !== 0;
            passengers.push({
              passengerType: !isChild ? "Adult" : "Child",
              age: isChild ? 1 : undefined,
            });
          });
          roomData.push({ passengers });
        });
        // @ts-ignore

        const values = localeStorageHelper.get("travel-planner");
        localeStorageHelper.set("travel-planner", {
          ...values,
          "date-range": {
            from: searchData.CheckInDate,
            to: searchData.CheckOutDate,
          },
          room: roomData.map((room) => ({
            employee: {
              count: room.passengers.filter(
                (x: any) => x.passengerType === "Adult",
              ).length,
            },
            guest: {
              count: 0,
            },
            child: {
              count: room.passengers.filter(
                (x: any) => x.passengerType === "Child",
              ).length,
              ages: Array.from([
                room.passengers.filter((x: any) => x.passengerType === "Child")
                  .length,
                () => 0,
              ]),
            },
          })),
        });

        const hotelList = http
          .post(
            "/api/v1/strategy/run",
            setParametersToStrategyRunner(
              {
                hotelSearchRequest: {
                  searchId: null,
                  requestKey: null,
                  countryCode: "TR",
                  currency: "TRY",
                  checkInDate: searchData.CheckInDate,
                  checkOutDate: searchData.CheckOutDate,
                  pageSize: 10,
                  pageNumber: 1,
                  destinationId:
                    resData.SearchResponse &&
                    resData.SearchResponse?.Items![0]!.CityId,
                  destinationType: "Destination",
                  destinationSubType: "City",
                  orderBy: "8",
                  rooms: roomData,
                  filter: {
                    hotelName: "",
                    locations: [],
                    mealTypes: [],
                    facilities: [],
                    themes: [],
                    minPrice: null,
                    maxPrice: null,
                  },
                },
              },
              strategyKeys.hotelList,
            ),
          )
          .then((ser) => {
            setHotelListLoading(false);
            return hotelSearchResultSerializer(ser.data);
          });

        const hotelListResponse = await hotelList;
        setAlternateHotelList(hotelListResponse?.hotelList);
        setSearchId(hotelListResponse?.metadata?.searchId);
        setPassengers(hotelListResponse?.passengerList);
      },
    },
  );

  const bookingRequest = data;

  const displayInformations = stringToJsonHelper(
    bookingRequest?.displayInformations as unknown as string,
  ) as unknown as IDisplayInformations;
  const reservationData = stringToJsonHelper(
    bookingRequest?.reservationData as unknown as string,
  ) as unknown as IReservationData;
  const passengerInformations = stringToJsonHelper(
    bookingRequest?.passengerInformations as unknown as string,
  ) as unknown as IPassengerInformation[];

  const roomCollectionResult =
    reservationData?.DetailResponse?.RoomCollectionResult;

  const roomNightlyRate =
    roomCollectionResult &&
    roomCollectionResult![0]!.Rooms![0]!.NightlyRateResults.length;

  const startDate = displayInformations?.SearchRequest?.CheckInDate;
  const endDate = displayInformations?.SearchRequest?.CheckOutDate;

  const items = reservationData?.SearchResponse?.Items;

  const location = items && items![0]!.Location;
  const travelReason = bookingRequest && bookingRequest.travelReasonName;

  const ProgressBarItems = [
    {
      label: "Otel",
    },
    {
      label: "Oda",
    },
    {
      label: "Onay",
    },
  ];

  useUpdateEffect(() => {
    window.scrollTo({
      behavior: "instant",
      top: 0,
    });
  }, [ProgressBarActiveItem]);

  return (
    <>
      {isError && (
        <Container>
          <div className="flex flex-col gap-4 bg-white">
            istek sirasinda bir hata olustu
          </div>
        </Container>
      )}
      {isLoading && (
        <Container>
          <div className="flex flex-col gap-4 bg-white">
            <ListSkeleton size={12} />
          </div>
        </Container>
      )}

      {!isLoading && isSuccess && bookingRequest && (
        <>
          <div className="border-b border-gray-200 bg-white">
            <Container>
              <TinyHeader href="booking-request" title="Talep Değiştir" />
            </Container>
          </div>

          <Container className="py-4">
            <ChoosedRoomCard
              title={`${location && location?.split(",")[0]} Seyahati`}
              description={`${dayjs(startDate).format("DD MMM")} - ${dayjs(
                endDate,
              ).format("DD MMM")} (${roomNightlyRate} gece), ${
                passengerInformations.filter((x) => x.PassengerType === 0)
                  .length
              } Yetişkin - ${roomCollectionResult.length} Oda ${
                travelReason ? `, ${travelReason}` : ""
              }`}
            />
            <div className="mx-auto w-5/12">
              <CircleProgressBar
                items={ProgressBarItems}
                activeIndex={ProgressBarActiveItem}
                itemOnClick={(e) => {
                  setProgressBarActiveItem(e);
                }}
                className="my-8"
              />
            </div>
          </Container>

          <Container className="max-w-[864px]">
            <BookingRequestHotelChangeProvider>
              {ProgressBarActiveItem === 0 && (
                <BookingRequestHotelChangeHotelStep
                  location={location}
                  images={
                    items[0] && items[0].Images.map((imgItem) => imgItem.Url)
                  }
                  hotelName={displayInformations?.HotelName}
                  totalPrice={`TRY${bookingRequest.totalPrice}`}
                  recommended={items![0]?.Recommended}
                  alternateHotels={AlternateHotelList}
                  setSelectedHotel={(e) => {
                    setSelectedHotel(e);
                    setProgressBarActiveItem(1);
                  }}
                  loading={HotelListLoading}
                  nightInfo={
                    (items![0] as any)?.AccommodationDayCountInfo ?? ""
                  }
                />
              )}
              {ProgressBarActiveItem === 1 && (
                <BookingRequestHotelChangeRoomStep
                  selectedHotel={SelectedHotel}
                  setSelectedRoom={(selectedRoom) => {
                    setSelectedRoom(selectedRoom);
                    setProgressBarActiveItem(2);
                  }}
                  searchId={SearchId}
                />
              )}
              {ProgressBarActiveItem === 2 && (
                <BookingRequestHotelChangeConfirmationStep
                  selectedHotel={SelectedHotel}
                  SelectedRoom={SelectedRoom}
                  passengers={passengersState}
                  searchId={SearchId}
                  bookingRequest={bookingRequest}
                />
              )}
            </BookingRequestHotelChangeProvider>
          </Container>
        </>
      )}
    </>
  );
};

export default BookingRequestHotelChangeDataView;
