import { useRouter } from "next/navigation";

import type { IBookingRequest } from "@/models/booking-request.model";
import { useHotelBookingRequestMutation } from "@/services/eva-display/hotel/hotel-booking-request/hotel-booking-request.service";
import type { IHotelDetailResult } from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";
import type { HotelListPassengerList } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

interface UseBookingRequestHotelChangeVariables {
  searchId: string;
  searchProductKey: string;
  detailProductKey: string;
  detailData: IHotelDetailResult;
  bookingRequest: IBookingRequest;
  passengers?: HotelListPassengerList[];
}

export const useBookingRequestHotelChange = (
  variables: UseBookingRequestHotelChangeVariables,
) => {
  const notifyStore = useNotifyStore();
  const router = useRouter();
  const bookingRequestMutation = useHotelBookingRequestMutation({
    onSuccess(data) {
      if (!data.success && data.errors && data.errors.length > 0) {
        notifyStore.setNotify({
          message:
            data?.errors?.[data.errors.length - 1]?.message ??
            "Beklenmeyen hata oluştu!",
          title: "Hata",
          variant: "error",
        });
        return;
      }

      if (data.success && data.informations && data.informations.length > 0) {
        notifyStore.setNotify({
          message:
            data.informations[data.informations.length - 1]?.message ?? "",
          title: "Bilgi",
          variant: "success",
          onClose() {
            router.push(`/booking-request-detail?id=${data?.result.requestId}`);
          },
        });
        return;
      }

      router.push(`/booking-request-detail?id=${data?.result.requestId}`);
    },
    onError() {},
  });

  function changeBookingRequest(params: { cartId: string }) {
    if (
      bookingRequestMutation.data?.result?.requestId &&
      bookingRequestMutation.data?.result?.requestId > 0
    ) {
      router.push(
        `/booking-request-detail?id=${bookingRequestMutation.data?.result?.requestId}`,
      );
      return;
    }

    const passengersL = variables.bookingRequest.passengerInformations?.map(
      (x, i) => ({
        ...x,
        Key: variables.passengers?.[i]!.key!,
      }),
    );

    bookingRequestMutation.mutate({
      CorpCreateHotelRequest: {
        SearchProductKey: variables.searchProductKey,
        SearchId: variables.searchId,
        CartId: params.cartId,
        DetailProductKey: variables.detailProductKey,
        isPreBook: true,
        KvkkStatus: true,
        PassengerInformations: passengersL!,
        LinkId: "",
        TravelReasonId: variables.bookingRequest.travelReasonId,
        RequesterUserIds: variables.bookingRequest.requesterUserIds ?? [],
        RequestId: variables.bookingRequest.id,
      },
    });
  }

  return {
    changeBookingRequest,
    isLoading: bookingRequestMutation.isLoading,
  };
};
