import { useEffect, useState } from "react";

import Container from "@/components/shared/container";
import TinyHeader from "@/components/shared/tiny-header/tiny-header";
import CircleProgressBar from "@/components/ui/circle-progress-bar/circle-progress-bar";
import type { ITransferBookingRequest } from "@/models/booking-request.model";

import BRTransferCurrentItem from "./components/br-transfer-current-item";
import type { BRTransferListSelected } from "./components/br-transfer-list";
import BRTransferList from "./components/br-transfer-list";
import BRTransferSummary from "./components/br-transfer-summary";
import { BookingRequestTransferChangeProvider } from "./context/booking-request-transfer-change-context";

interface BookingRequestTransferChangeProps {
  transferBookingRequest: ITransferBookingRequest;
}

const BookingRequestTransferChange = (
  props: BookingRequestTransferChangeProps,
) => {
  const [step, setStep] = useState(0);
  const [selected, setSelected] = useState<BRTransferListSelected | null>(null);

  useEffect(() => {
    window.scrollTo({
      behavior: "instant",
      top: 0,
    });
  }, [step]);

  return (
    <BookingRequestTransferChangeProvider
      transferBookingRequest={props.transferBookingRequest}
      selectedData={selected}
    >
      <div>
        <div className="border-b border-gray-200 bg-white">
          <Container>
            <TinyHeader href="booking-request" title="Talep Değiştir" />
          </Container>
        </div>
        <Container className="mt-4 max-w-[864px]">
          <BRTransferCurrentItem />
          <div className="mx-auto max-w-[280px]">
            <CircleProgressBar
              items={[{ label: "Transfer" }, { label: "Onay" }]}
              activeIndex={step}
              className="my-8"
              canGoNextStep={false}
              itemOnClick={(index) => {
                if (index === 0) {
                  setSelected(null);
                  setStep(0);
                }
              }}
            />
          </div>
          {step === 0 && (
            <BRTransferList
              onItemSelect={(data) => {
                setSelected(data);
                setStep(1);
              }}
            />
          )}
          {step === 1 && <BRTransferSummary />}
        </Container>
      </div>
    </BookingRequestTransferChangeProvider>
  );
};

export default BookingRequestTransferChange;
