import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import {
  Dialog,
  DialogClose,
  DialogContent,
  DialogDescription,
  DialogFooter,
  DialogHeader,
  DialogTitle,
  DialogTrigger,
} from "@/components/ui/dialog";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import type { ReactQueryReturnProps } from "@/components/widget/booking-request-card-detail/booking-request-card-detail";
import { useAuth } from "@/features/auth/hooks/use-auth";
import PermGuard from "@/features/permission/components/perm-guard";
import type { CancelReasonItem } from "@/services/eva-display/book-cancel-reason/booking-cancel-reason-service.types";
import { requestApprovalAllowPerm } from "@/validations/permissions/request-approval";

interface BookingRequestCardDetailConfirmRejectDeniedButtonListProps {
  status: string;
  createdByUserId: string;
  bookingRequestStatusMutation: ReactQueryReturnProps;
  onAccept: () => void;
  onReject: () => void;
  onDenied: () => void;
  cancelReasonData: CancelReasonItem[];
  setRejectSelectValue: (e: { value: string; name: string }) => void;
  rejectSelectValue: {
    value: string;
    name: string;
  };
}

const BookingRequestCardDetailConfirmRejectDeniedButtonList = ({
  status,
  createdByUserId,
  bookingRequestStatusMutation,
  onAccept,
  onReject,
  onDenied,
  cancelReasonData,
  setRejectSelectValue,
  rejectSelectValue,
}: BookingRequestCardDetailConfirmRejectDeniedButtonListProps) => {
  const { user } = useAuth();
  return (
    <div className="mt-3 flex flex-col gap-3 sm:flex-row lg:mt-0">
      {status === "warning" && user?.userGuidId === createdByUserId && (
        <Dialog modal>
          <DialogTrigger asChild>
            <Button
              type="button"
              variant="outline-error"
              disabled={bookingRequestStatusMutation?.isLoading}
            >
              İptal Et
            </Button>
          </DialogTrigger>
          <DialogContent className="max-w-[408px]">
            <DialogHeader className="text-left">
              <div className="mr-auto inline-flex rounded-full border-8 border-error-50 bg-error-100 p-3">
                <LIcon name="Info" className="text-error-500" />
              </div>
              <DialogTitle className="!mt-5">
                Talebi iptal etmek istediğine emin misin?
              </DialogTitle>
              <DialogDescription>
                İptal Etme işlemini geri alamazsınız.
              </DialogDescription>
            </DialogHeader>
            <DialogFooter className="mt-4 !flex-col gap-3 sm:!flex-row">
              <DialogClose>
                <Button
                  className="w-full"
                  data-state="closed"
                  variant="outline"
                >
                  Vazgeç
                </Button>
              </DialogClose>
              <Button
                className="!ml-0 w-full"
                variant="error"
                onClick={() => onReject()}
              >
                İptal Et
              </Button>
            </DialogFooter>
          </DialogContent>
        </Dialog>
      )}
      <PermGuard permission={requestApprovalAllowPerm}>
        {status === "warning" && (
          <>
            <Dialog modal>
              <DialogTrigger asChild>
                <Button
                  type="button"
                  variant="outline-error"
                  disabled={bookingRequestStatusMutation?.isLoading}
                  className="w-full md:w-auto"
                >
                  Reddet
                </Button>
              </DialogTrigger>
              <DialogContent className="max-w-[408px]">
                <DialogHeader className="text-left">
                  <div className="mr-auto inline-flex rounded-full border-8 border-error-50 bg-error-100 p-3">
                    <LIcon name="Info" className="text-error-500" />
                  </div>
                  <DialogTitle className="!mt-5">
                    Talebi reddetmek istediğine emin misin?
                  </DialogTitle>
                  <DialogDescription>
                    Reddetme işlemini geri alamazsınız.
                  </DialogDescription>
                </DialogHeader>
                <div className="flex flex-col gap-1.5">
                  <p className="text-sm font-medium text-gray-800">
                    Reddetme Nedeni
                  </p>
                  {cancelReasonData && cancelReasonData.length > 0 && (
                    <div>
                      <Select
                        defaultValue={rejectSelectValue.value}
                        onValueChange={(value: string) => {
                          if (value === "0") {
                            setRejectSelectValue({
                              value,
                              name: "diğer",
                            });
                          } else {
                            const name: any = cancelReasonData.find(
                              (item: any) => item.value === value,
                            );
                            setRejectSelectValue({
                              value,
                              name: name.name,
                            });
                          }
                        }}
                      >
                        <SelectTrigger className="inline-flex items-center justify-between rounded-lg border border-gray-200 bg-white px-3.5 py-2.5 text-base shadow-xs outline-none">
                          <SelectValue placeholder="Neden seçiniz" />
                        </SelectTrigger>
                        <SelectContent
                          position="popper"
                          className="w-[358px] max-w-[80vw] overflow-hidden rounded-primary bg-white shadow-md"
                        >
                          {cancelReasonData.map((item: CancelReasonItem) => {
                            return (
                              <SelectItem
                                key={item.value}
                                className="cursor-pointer px-3.5 text-base"
                                value={item.value}
                              >
                                {item.name}
                              </SelectItem>
                            );
                          })}

                          <SelectItem
                            className="cursor-pointer px-3.5 text-base"
                            value="0"
                          >
                            Diğer
                          </SelectItem>
                        </SelectContent>
                      </Select>
                      {rejectSelectValue.value === "0" && (
                        <div className="mt-3.5 flex flex-col gap-1.5">
                          <p className="text-sm font-medium text-gray-800">
                            Diğer
                          </p>
                          <Card className="p-3">
                            <textarea
                              className="w-full outline-none"
                              onChange={(e) =>
                                setRejectSelectValue({
                                  value: "0",
                                  name: e.target.value,
                                })
                              }
                              rows={5}
                              placeholder="Talebi reddetme nedeniniz nedir?"
                            />
                          </Card>
                        </div>
                      )}
                    </div>
                  )}
                </div>

                <DialogFooter className="mt-4 !flex-col gap-3 sm:!flex-row">
                  <DialogClose>
                    <Button
                      className="w-full"
                      data-state="closed"
                      variant="outline"
                      disabled={bookingRequestStatusMutation?.isLoading}
                    >
                      Vazgeç
                    </Button>
                  </DialogClose>
                  <Button
                    className="!ml-0 w-full"
                    variant="error"
                    disabled={
                      rejectSelectValue.name === "diğer" ||
                      rejectSelectValue.value === ""
                    }
                    loading={bookingRequestStatusMutation?.isLoading}
                    onClick={() => onDenied()}
                  >
                    Reddet
                  </Button>
                </DialogFooter>
              </DialogContent>
            </Dialog>

            <Dialog modal>
              <DialogTrigger asChild>
                <Button
                  type="button"
                  variant="primary"
                  disabled={bookingRequestStatusMutation?.isLoading}
                  className="w-full md:w-auto"
                >
                  Onayla
                </Button>
              </DialogTrigger>
              <DialogContent className="max-w-[408px]">
                <DialogHeader className="text-left">
                  <div className="mr-auto inline-flex rounded-full border-8 border-success-50 bg-success-100 p-3">
                    <LIcon name="Check" className="text-success-500" />
                  </div>
                  <DialogTitle className="!mt-5">
                    Talebi onaylamak istediğine emin misin?
                  </DialogTitle>
                </DialogHeader>
                <DialogFooter className="mt-4 !flex-col gap-3 sm:!flex-row">
                  <DialogClose>
                    <Button
                      className="w-full"
                      data-state="closed"
                      variant="outline"
                      disabled={bookingRequestStatusMutation?.isLoading}
                    >
                      Vazgeç
                    </Button>
                  </DialogClose>
                  <Button
                    className="!ml-0 w-full"
                    variant="primary"
                    loading={bookingRequestStatusMutation?.isLoading}
                    onClick={() => onAccept()}
                  >
                    Onayla
                  </Button>
                </DialogFooter>
              </DialogContent>
            </Dialog>
          </>
        )}
      </PermGuard>
    </div>
  );
};

export default BookingRequestCardDetailConfirmRejectDeniedButtonList;
