import { useRouter } from "next/navigation";

import { storageManager } from "@/libs/storage-manager";
import { useSummaryStore } from "@/store/summary-store/use-summary-store";

import type { ICorePassengerInformation } from "../types/core-summary.types";

interface IModulePayloadMeta {
  searchId: string;
  searchItemKey: string;
  detailKey?: string | string[];
  passengersKeys?: {
    type: number;
    key: string;
    age: number;
  }[];
  cartId?: string;
  passengers?: ICorePassengerInformation[];
  productExtraInfo?: any;
}

export interface IModulePayload extends IModulePayloadMeta {}

export const useCoreModuleSummary = <T extends IModulePayload>(params: {
  moduleName: string;
  summaryUrl: string;
}) => {
  const { setModuleData, summaryState } = useSummaryStore();
  const router = useRouter();

  function setModuleDataPersist(payload: any) {
    const storagedPayload = storageManager.get("core-summary")?.payload;
    const payloadWithStoraged = storagedPayload ?? {};

    storageManager.set("core-summary", {
      moduleName: params.moduleName,
      payload: {
        ...payloadWithStoraged,
        ...payload,
      },
    });
    setModuleData({
      moduleName: params.moduleName as any,
      payload,
    });
  }

  function setSearchData(
    payload: Required<Pick<T, "searchId" | "searchItemKey" | "passengersKeys">>,
  ) {
    setModuleDataPersist(payload);
  }

  function setDetailData(payload: Required<Pick<T, "detailKey">>) {
    setModuleDataPersist(payload);
  }

  function setSearchAndDetailData(
    payload: Required<
      Pick<T, "searchId" | "searchItemKey" | "passengersKeys" | "detailKey">
    > &
      Partial<Pick<T, "productExtraInfo">>,
  ) {
    setModuleDataPersist(payload);
  }

  function setCartData(payload: Required<Pick<T, "cartId">>) {
    setModuleDataPersist(payload);
  }

  function goSummary() {
    router.push(params.summaryUrl);
  }

  return {
    setSearchData,
    setDetailData,
    setCartData,
    setSearchAndDetailData,
    goSummary,
    isReady: summaryState.status === "done",
    data: summaryState.data as {
      moduleName: typeof params.moduleName;
      payload: T;
    },
  };
};
