import { useEffect, useRef } from "react";

import FormTextInput from "@/components/form/components/basic/form-text-input";
import FormTextAreaInput from "@/components/form/components/basic/form-textarea-input";
import type { FormCitiesHandles } from "@/components/form/components/related/form-cities-select";
import FormCitiesSelect, {
  useFormCitiesSelect,
} from "@/components/form/components/related/form-cities-select";
import FormCountrySelect from "@/components/form/components/related/form-country-select";
import FormEmailInput from "@/components/form/components/related/form-email-input";
import FormIdentityInput from "@/components/form/components/related/form-identity-input";
import { useLocale } from "@/hooks/useLocale";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

interface CompanyBillingFormProps {
  prefix: string;
  isWithTaxNo?: boolean;
}

const CompanyBillingForm = (props: CompanyBillingFormProps) => {
  const { t } = useLocale();
  const citiesRef = useRef<FormCitiesHandles>(null);
  const { initFormCitiesSelect, getCitiesData } = useFormCitiesSelect(
    citiesRef,
    props.prefix,
  );

  useEffect(() => {
    initFormCitiesSelect();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <div className="grid grid-cols-1 gap-3 md:grid-cols-2">
      <FormTextInput
        fullWidth
        name={`${props.prefix}-companyTitle`}
        label={`${t("Company Title")}*`}
        size="lg"
        rules={{
          required: requiredRule,
        }}
      />
      {props.isWithTaxNo ? (
        <FormTextInput
          fullWidth
          name={`${props.prefix}-taxNo`}
          label={`${t("Tax number")}*`}
          size="lg"
          rules={{
            required: requiredRule,
          }}
        />
      ) : (
        <FormIdentityInput
          fullWidth
          name={`${props.prefix}-tc`}
          size="lg"
          label={`${t("TC Identification Number")}*`}
          rules={{
            required: requiredRule,
          }}
        />
      )}
      <FormTextInput
        fullWidth
        name={`${props.prefix}-companyTaxOffice`}
        label={`${t("Tax Administration")}*`}
        size="lg"
        rules={{
          required: requiredRule,
        }}
      />
      <FormEmailInput
        fullWidth
        name={`${props.prefix}-email`}
        size="lg"
        label={`${t("Email")}*`}
        rules={{
          required: requiredRule,
        }}
      />
      <FormCountrySelect
        onChange={(countriesId) => {
          getCitiesData(countriesId);
        }}
        name={`${props.prefix}-country`}
        rules={{
          required: requiredRule,
        }}
        placeholder={`${t("Country")}*`}
      />

      <FormCitiesSelect
        ref={citiesRef}
        name={`${props.prefix}-city`}
        placeholder={`${t("City")}*`}
        rules={{
          required: requiredRule,
        }}
      />
      <div className="md:col-span-2">
        <FormTextAreaInput
          name={`${props.prefix}-address`}
          placeholder={`${t("Billing address")}*`}
          rules={{
            required: requiredRule,
          }}
        />
      </div>
    </div>
  );
};

export default CompanyBillingForm;
