import { useEffect, useRef } from "react";

import FormTextInput from "@/components/form/components/basic/form-text-input";
import FormTextAreaInput from "@/components/form/components/basic/form-textarea-input";
import type { FormCitiesHandles } from "@/components/form/components/related/form-cities-select";
import FormCitiesSelect, {
  useFormCitiesSelect,
} from "@/components/form/components/related/form-cities-select";
import FormCountrySelect from "@/components/form/components/related/form-country-select";
import FormEmailInput from "@/components/form/components/related/form-email-input";
import FormIdentityOrPassport from "@/components/form/components/related/form-identity-or-passport-input";
import { useLocale } from "@/hooks/useLocale";
import {
  nameValidation,
  surNameValidation,
} from "@/validations/form-rules/rules/name-rule";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

interface PersonBillingFormProps {
  prefix: string;
}

const PersonBillingForm = (props: PersonBillingFormProps) => {
  const { t } = useLocale();
  const citiesRef = useRef<FormCitiesHandles>(null);
  const { initFormCitiesSelect, getCitiesData } = useFormCitiesSelect(
    citiesRef,
    props.prefix,
  );

  useEffect(() => {
    initFormCitiesSelect();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <div className="grid grid-cols-1  gap-3 md:grid-cols-2">
      <FormTextInput
        fullWidth
        name={`${props.prefix}-name`}
        label={`${t("Name")}*`}
        size="lg"
        rules={{
          required: requiredRule,
          validate: (value) => {
            return nameValidation(value);
          },
        }}
      />
      <FormTextInput
        fullWidth
        name={`${props.prefix}-surname`}
        label={`${t("Surname")}*`}
        size="lg"
        rules={{
          required: requiredRule,
          validate: (value) => {
            return surNameValidation(value);
          },
        }}
      />
      <FormIdentityOrPassport
        fullWidth
        name={`${props.prefix}-tc`}
        size="lg"
        label={`${t("TC Identification Number")}*`}
        rules={{
          required: requiredRule,
        }}
      />
      <FormEmailInput
        fullWidth
        name={`${props.prefix}-email`}
        size="lg"
        label={`${t("Email")}*`}
        rules={{
          required: requiredRule,
        }}
      />
      <FormCountrySelect
        onChange={(countriesId) => {
          getCitiesData(countriesId);
        }}
        name={`${props.prefix}-country`}
        rules={{
          required: requiredRule,
        }}
        placeholder={t("Country")}
      />
      <FormCitiesSelect
        ref={citiesRef}
        name={`${props.prefix}-city`}
        placeholder={`${t("City")}*`}
        rules={{
          required: requiredRule,
        }}
      />
      <div className="md:col-span-2">
        <FormTextAreaInput
          name={`${props.prefix}-address`}
          placeholder={`${t("Billing address")}*`}
          rules={{
            required: requiredRule,
          }}
        />
      </div>
    </div>
  );
};

export default PersonBillingForm;
