import FormTextInput from "@/components/form/components/basic/form-text-input";
import FormBirthDateInput from "@/components/form/components/related/form-birthdate-input";
import FormCountrySelect from "@/components/form/components/related/form-country-select";
import FormPassportDateInput from "@/components/form/components/related/form-passport-date-input";
import FormPassportNoInput from "@/components/form/components/related/form-passport-no-inpuıt";
import { useLocale } from "@/hooks/useLocale";
import { requiredRule } from "@/validations/form-rules/rules/required-rule";

interface CustomerChildInfoFormItemsProps {
  customerPrefix: string;
  hasPassportInfos?: boolean;
}

const CustomerChildInfoFormItems = (props: CustomerChildInfoFormItemsProps) => {
  const { t } = useLocale();
  return (
    <div>
      <div className="mt-2 grid grid-cols-1 gap-3 md:grid-cols-3">
        <FormTextInput
          fullWidth
          name={`${props.customerPrefix}-name`}
          label={`${t("Name")}*`}
          size="lg"
          rules={{
            required: requiredRule,
          }}
        />
        <FormTextInput
          fullWidth
          name={`${props.customerPrefix}-surname`}
          label={`${t("Surname")}*`}
          size="lg"
          rules={{
            required: requiredRule,
          }}
        />

        <FormBirthDateInput
          fullWidth
          name={`${props.customerPrefix}-birthDate`}
          size="lg"
          label={`${t("Date of Birth")}* ${t("(dd.mm.yyyy)")}`}
        />
      </div>
      {props.hasPassportInfos && (
        <div className="mt-4">
          <h4 className="mb-4 text-sm font-semibold">Pasaport Bilgileri</h4>
          <div className="mt-2 grid grid-cols-1 gap-3 md:grid-cols-3">
            <FormPassportNoInput
              fullWidth
              name={`${props.customerPrefix}-passport`}
              size="lg"
              label={`${t("Passport number")}*`}
            />
            <FormPassportDateInput
              fullWidth
              name={`${props.customerPrefix}-passportDate`}
              size="lg"
              label="Pasaport Geçerlilik Tarihi"
            />
            <FormCountrySelect
              name={`${props.customerPrefix}-passportCountry`}
              rules={{
                required: requiredRule,
              }}
              placeholder="Pasaport Verilen Ülke"
            />
          </div>
        </div>
      )}
    </div>
  );
};

export default CustomerChildInfoFormItems;
