import * as Select from "@radix-ui/react-select";

import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { SelectItem } from "@/components/ui/select";

interface SelectProps {
  items: any;
  defaultValue?: string;
  onStatusFilterChange?(value: string, isEmpty: boolean): void;
  onProductFilterChange?(value: string): void;
  onSortingChange?(value: string): void;
}

interface BookingRequestListFiltersProps {
  onStatusFilterChange?(value: string, isEmpty: boolean): void;
  onProductFilterChange?(value: string): void;
  onSortingChange?(value: string): void;
}

interface SelectItems {
  label: string;
  val: string;
}

const MultipleSelect = ({
  items,
  defaultValue,
  onStatusFilterChange,
  onProductFilterChange,
  onSortingChange,
  ...args
}: SelectProps) => {
  return (
    <Select.Root
      {...args}
      defaultValue={defaultValue}
      onValueChange={(e) => {
        if (onStatusFilterChange) {
          onStatusFilterChange(e, true);
        } else if (onProductFilterChange) {
          onProductFilterChange(e);
        } else if (onSortingChange) {
          onSortingChange(e);
        }
      }}
    >
      <Select.Trigger className="inline-flex w-[188px] items-center justify-between whitespace-nowrap rounded-lg bg-white px-3.5 py-2.5 text-base shadow-xs outline-none">
        <Select.Value defaultValue={items[0].val} />
        <Select.Icon>
          <LIcon size={20} name="ChevronDown" />
        </Select.Icon>
      </Select.Trigger>
      <Select.Portal>
        <Select.Content
          position="popper"
          className="w-[188px] overflow-hidden rounded-primary bg-white shadow-md"
        >
          <Select.ScrollUpButton className="flex h-6 items-center justify-center bg-white">
            <LIcon size={20} name="ChevronUp" />
          </Select.ScrollUpButton>
          <Select.Viewport className="p-1">
            {items.map((item: SelectItems) => {
              return (
                <SelectItem
                  key={item.label}
                  className="cursor-pointer px-3.5 text-base"
                  value={item.label}
                >
                  {item?.label}
                </SelectItem>
              );
            })}
          </Select.Viewport>
          <Select.ScrollDownButton className="flex h-6 cursor-default items-center justify-center bg-white">
            <LIcon size={20} name="ChevronDown" />
          </Select.ScrollDownButton>
        </Select.Content>
      </Select.Portal>
    </Select.Root>
  );
};

export const statusFilters = [
  { label: "Tümü", val: "-1" },
  { label: "Onay Bekleyen", val: "warning" },
  { label: "Onaylanan", val: "success" },
  { label: "Reddedilen", val: "error" },
];
export const productFilters = [
  { label: "Tümü", val: "-1" },
  { label: "Otel", val: "Hotel" },
  { label: "Uçak", val: "Flight" },
  { label: "Transfer", val: "Transfer" },
  { label: "Araç Kiralama", val: "CarRental" },
];
export const productSorting = [
  { label: "Yeniden eskiye", val: 1 },
  { label: "Eskiden yeniye", val: 2 },
  { label: "Fiyata göre artan", val: 3 },
  { label: "Fiyata göre azalan", val: 4 },
];
const BookingRequestListFilters = (props: BookingRequestListFiltersProps) => {
  return (
    <div className="filter-area relative z-50 mt-6 flex items-center gap-4">
      <div className="filter-icon -mr-2 text-gray-400">
        <LIcon size={16} name="ListFilter" />
      </div>

      <MultipleSelect
        items={statusFilters}
        onStatusFilterChange={props.onStatusFilterChange}
        defaultValue="Tümü"
      />

      <MultipleSelect
        items={productFilters}
        onProductFilterChange={props.onProductFilterChange}
        defaultValue="Tümü"
      />

      <div hidden className="ml-auto hidden items-center gap-2">
        <div className="filter-icon rotate-180 text-gray-400">
          <LIcon size={16} name="ArrowUpNarrowWide" />
        </div>

        <MultipleSelect
          items={productSorting}
          onSortingChange={props.onSortingChange}
          defaultValue="Yeniden eskiye"
        />
      </div>
    </div>
  );
};

export default BookingRequestListFilters;
