import React from "react";

import RentACarRequestCard from "@/components/widget/rent-a-car-request-card/rent-a-car-request-card";
import type { IBookingRequestItem } from "@/services/eva-display/demand/demand-service.types";

interface RentACarRequestItemProps {
  item: IBookingRequestItem;
}

const RentACarRequestListItem = ({ item }: RentACarRequestItemProps) => {
  const { DetailResponse: detailResponse } = item.reservationData as any;
  const carDetail = detailResponse?.Car?.CarDetail;
  const carRentalCompany = detailResponse?.Car?.CarRentalCompany;
  const passengerInformations =
    item.passengerInformations as unknown as Array<any>;
  const destination = carDetail.PickupCode.split(" ")[0]!.replace(",", "");
  return (
    <RentACarRequestCard
      className="mt-4 first:mt-0"
      item={{
        id: item.id,
        fuelType: carDetail.FuelType,
        cardTitle: `${destination}${
          item?.travelReasonName ? ` ${item?.travelReasonName}` : ""
        } Seyahati`,
        automaticTransmission: carDetail.AutomaticTransmission,
        carImageUrl: carDetail.ImageUrl,
        passengerCount: carDetail.PassengerCount,
        returnCode: carDetail.ReturnCode,
        returnDate: carDetail.ReturnDate,
        pickupCode: carDetail.PickupCode,
        pickupDate: carDetail.PickupDate,
        carName: carDetail.Name,
        carType: carDetail.Type,
        totalPrice: `TRY${item.totalPrice}`,
        carRentalCompanyCode: carRentalCompany?.Code,
        requestStatus: item.requestStatus,
        driverFullName: `${passengerInformations[0].Name} ${
          passengerInformations[0]?.Surname || ""
        }`,
      }}
    />
  );
};

export default RentACarRequestListItem;
