"use client";

import { useMediaQuery } from "usehooks-ts";

import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { useLocale } from "@/hooks/useLocale";

import { useFlightSearch } from "../../hooks/use-flight-search";
import FlightListFilterAirlineCompany from "../flight-list/components/flight-list-filter-airline-company";
import FlightListFilterFlightDuration from "../flight-list/components/flight-list-filter-flight-duration";
import FlightListFilterPriceRange from "../flight-list/components/flight-list-filter-price-range";
import FlightListFilterTransferCount from "../flight-list/components/flight-list-filter-transfer-count";
import { useFlightListContext } from "../flight-list/context/flight-list-context";

const FilterModal = () => {
  const { t } = useLocale();
  const {
    closeModal: filterModalClose,
    openModal: filterOpenModal,
    modalOpen: filterModalOpen,
  } = useModal({ open: false });

  const isDesktop = useMediaQuery("(min-width: 768px)");

  const { isReady: isHotelSearchReady } = useFlightSearch();

  const { isLoading, setIsFilterApplicable } = useFlightListContext();

  if (isDesktop || !isHotelSearchReady) return null;

  const handleOk = () => {
    setIsFilterApplicable?.(true);
    filterModalClose();
  };

  const handleOpen = () => {
    setIsFilterApplicable?.(false);
    filterOpenModal();
  };

  const handleClose = () => {
    filterModalClose();
    setIsFilterApplicable?.(null);
  };

  return (
    <>
      <button
        type="button"
        onClick={handleOpen}
        className="flex flex-1 items-center justify-center gap-2 rounded-lg border bg-white py-2 text-gray-600"
      >
        {t("filter")}
      </button>

      <Modal
        size="full"
        open={filterModalOpen}
        onClose={handleClose}
        title="Filtrele"
        footer={false}
        onOkText="Uygula"
        onOk={handleOk}
      >
        <div className="scroll-bar size-full max-h-[calc(100%-100px)] overflow-y-scroll">
          {isLoading ? (
            <div className="flex flex-col gap-4">
              <Skeleton style={{ height: 40 }} />
              <Skeleton style={{ height: 40 }} />
              <Skeleton style={{ height: 40 }} />
            </div>
          ) : (
            <>
              <div className="my-10">
                <span className="text-base font-semibold">Kişi Başı Fiyat</span>
                <FlightListFilterPriceRange />
              </div>
              <FlightListFilterFlightDuration />
              <FlightListFilterTransferCount />
              <FlightListFilterAirlineCompany />
            </>
          )}
        </div>
      </Modal>
    </>
  );
};

export default FilterModal;
