/* eslint-disable radix */

"use client";

import { useSearchParams } from "next/navigation";
import { useMediaQuery } from "usehooks-ts";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { useLocale } from "@/hooks/useLocale";

import { useFlightListContext } from "../flight-list/context/flight-list-context";

const FlightSortModal = () => {
  const {
    closeModal: sortModalClose,
    openModal: sortOpenModal,
    modalOpen: sortModalOpen,
  } = useModal({ open: false });

  const { t } = useLocale();

  const isDesktop = useMediaQuery("(min-width: 768px)");

  const { applyOrderFilter, requestVariables } = useFlightListContext();

  const searchParams = useSearchParams();
  let defaultValue = requestVariables?.Filter.Order;

  if (searchParams.get("orderBy") === "PriceAscending") defaultValue = 1;
  else if (searchParams.get("orderBy") === "PriceDescending") defaultValue = 2;

  const handleChange = (value: number) => {
    if (applyOrderFilter) applyOrderFilter(value);
    sortModalClose();
  };

  if (isDesktop) return null;

  return (
    <>
      <button
        type="button"
        onClick={sortOpenModal}
        className="flex flex-1 items-center justify-center gap-2 rounded-lg border bg-white py-2 text-gray-600"
      >
        {t("Sort by")}
      </button>

      <Modal
        size="sm"
        className="!m-0 !p-0"
        open={sortModalOpen}
        onClose={sortModalClose}
        footer
      >
        <div className="p-4">
          <div className="text-xl font-semibold text-gray-800 ">
            {t("Sort by")}
          </div>
          <div className="flex flex-col gap-2 py-8">
            <Button
              variant={defaultValue === 1 ? "outline-primary" : "outline"}
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => handleChange(1)}
            >
              <LIcon
                name={defaultValue === 1 ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Price (lowest first)")}
            </Button>
            <Button
              variant={defaultValue === 2 ? "outline-primary" : "outline"}
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => handleChange(2)}
            >
              <LIcon
                name={defaultValue === 2 ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Price (highest first)")}
            </Button>
          </div>
        </div>
      </Modal>
    </>
  );
};

export default FlightSortModal;
