import React from "react";

import { Skeleton } from "@/components/ui/skeleton/skeleton";
import type { AppliedFilterData } from "@/components/widget/applied-filter/applied-filter";
import AppliedFilter from "@/components/widget/applied-filter/applied-filter";
import type { AirlineCode } from "@/services/eva-display/flight/flight-search/flight-search-services.types";

import { useFlightListContext } from "../context/flight-list-context";

const FlightListAppliedFilters = () => {
  const {
    isLoading,
    data,
    applyClearFilter,
    refetch,
    applyAirlineFilter,
    applyTransferCountFilter,
  } = useFlightListContext();

  const handleClearFilter = () => {
    if (applyClearFilter) applyClearFilter();
  };

  const handleRemoveItem = (item: AppliedFilterData) => {
    if (item.filterKey === "airlineCodes" && applyAirlineFilter) {
      applyAirlineFilter(
        data?.filterResult.airlineCodes
          ?.filter(
            (filterItem: AirlineCode) =>
              filterItem.selected && filterItem.key !== item.filterValue,
          )
          .map((mapItem: AirlineCode) => mapItem.key) || [],
      );
    } else if (item.filterKey === "layover" && applyTransferCountFilter) {
      applyTransferCountFilter(
        data?.filterResult.layover
          ?.filter(
            (filterItem: AirlineCode) =>
              filterItem.selected && filterItem.key !== item.filterValue,
          )
          .map((mapItem: AirlineCode) => mapItem.key) || [],
      );
    }
    if (refetch)
      refetch({
        stale: true,
      });
  };

  return isLoading ? (
    <Skeleton
      style={{
        height: "50px",
      }}
    />
  ) : (
    <AppliedFilter
      data={[
        ...(data?.filterResult.airlineCodes
          ?.filter((item) => item.selected)
          .map((item) => ({
            filterLabel: item.value,
            filterValue: item.key,
            filterKey: "airlineCodes",
          })) || []),
        ...(data?.filterResult.layover
          ?.filter((item) => item.selected)
          .map((item) => ({
            filterLabel: item.value,
            filterValue: item.key,
            filterKey: "layover",
          })) || []),
      ]}
      onRemoveItem={handleRemoveItem}
      onClearFilter={handleClearFilter}
    />
  );
};

export default FlightListAppliedFilters;
