import React, { useEffect, useState } from "react";

import FilterCheckbox from "@/components/widget/filter-checkbox/filter-checkbox";
import { useLocale } from "@/hooks/useLocale";

import { useFlightListContext } from "../context/flight-list-context";

const FlightListFilterAirlineCompany = () => {
  const { t } = useLocale();
  const { data, applyAirlineFilter, requestVariables } = useFlightListContext();
  const [airlineCodes, setAirlineCodes] = useState(
    data?.filterResult?.airlineCodes || [],
  );

  const handleChange = (values: string[]) => {
    if (applyAirlineFilter) {
      applyAirlineFilter(values);
    }
  };

  useEffect(() => {
    setAirlineCodes(data?.filterResult?.airlineCodes || []);
  }, [data?.filterResult.airlineCodes]);

  return (
    data &&
    airlineCodes.length > 0 && (
      <div className="px-4 pb-4 pt-2">
        <FilterCheckbox
          collapseDefaultOpen
          collapseTitle={t("Airline Company")}
          items={airlineCodes.map((item) => ({
            key: item.key,
            label: `${item.value}`,
            value: item.key,
          }))}
          onChange={handleChange}
          initialSelectedItems={
            airlineCodes
              ?.filter(
                (item) =>
                  item.selected ||
                  requestVariables?.Filter.AirlineCodes?.includes(item.key),
              )
              .map((item) => item.key) || []
          }
        />
      </div>
    )
  );
};

export default FlightListFilterAirlineCompany;
