/* eslint-disable no-console */
import { CollapsibleContent } from "@radix-ui/react-collapsible";
import React from "react";
import { useBoolean } from "usehooks-ts";

import {
  Collapsible,
  CollapsibleTrigger,
} from "@/components/ui/collapsible/collapsible";
import { Divider } from "@/components/ui/divider/divider";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import TimeRange from "@/components/widget/time-range/time-range";
import { cn } from "@/libs/utils";

import { useFlightListContext } from "../context/flight-list-context";

const FlightListFilterDepartureTime = () => {
  const { value: open, setValue } = useBoolean(true);
  const { data, applyDepartureTimeFilter } = useFlightListContext();
  const goingDepartureMaxTime = data?.filterResult.goingDepartureMaxTime || "";
  const goingDepartureMinTime = data?.filterResult.goingDepartureMinTime || "";

  const handleChange = (value: { start: string; end: string }) => {
    if (applyDepartureTimeFilter)
      applyDepartureTimeFilter(`${value.start}:00`, `${value.end}:00`);
  };

  return (
    goingDepartureMaxTime &&
    goingDepartureMinTime && (
      <>
        <Collapsible
          open={open}
          onOpenChange={setValue}
          className="px-4 pb-2 pt-4"
        >
          <CollapsibleTrigger
            className={cn(
              "flex w-full max-w-[300px] items-center justify-between text-sm font-medium leading-tight text-slate-800",
              open && "mb-3",
            )}
          >
            Kalkış Saatleri
            <LIcon name={open ? "ChevronUp" : "ChevronDown"} />
          </CollapsibleTrigger>
          <CollapsibleContent>
            <TimeRange
              stepTime={15}
              onChange={handleChange}
              initialValue={{
                start: goingDepartureMinTime as unknown as string,
                end: goingDepartureMaxTime as unknown as string,
              }}
            />
          </CollapsibleContent>
        </Collapsible>
        <Divider />
      </>
    )
  );
};

export default FlightListFilterDepartureTime;
