/* eslint-disable no-console */
import React from "react";
import { useBoolean } from "usehooks-ts";

import {
  Collapsible,
  CollapsibleContent,
  CollapsibleTrigger,
} from "@/components/ui/collapsible/collapsible";
import { Divider } from "@/components/ui/divider/divider";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import HourRange from "@/components/widget/hour-range/hour-range";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";

import { useFlightListContext } from "../context/flight-list-context";

const FlightListFilterFlightDuration = () => {
  const { t } = useLocale();
  const { value: open, setValue } = useBoolean(true);
  const { data, filterValues, applyFlightDurationFilter } =
    useFlightListContext();

  const handleChange = (value: { start: number; end: number }) => {
    if (applyFlightDurationFilter)
      applyFlightDurationFilter(`${value.start}:00:00`, `${value.end}:00:00`);
  };
  if (
    !data ||
    !data.filterResult.flightMaxTime ||
    !data.filterResult.flightMinTime
  )
    return null;

  const initialStartTime =
    filterValues?.FlightMinTime === "00:00:00"
      ? data?.filterResult.flightMinTime.split(/[:.]/)[0]
      : filterValues?.FlightMinTime.split(/[:.]/)[0];

  const initialEndTime =
    filterValues?.FlightMaxTime === "60:00:00"
      ? data?.filterResult.flightMaxTime.split(/[:.]/)[0]
      : filterValues?.FlightMaxTime.split(/[:.]/)[0];

  return (
    <>
      <Collapsible open={open} onOpenChange={setValue} className="px-4 py-2">
        <CollapsibleTrigger
          className={cn(
            "flex w-full max-w-[300px] items-center justify-between text-sm font-medium leading-tight text-slate-800",
            open && "mb-3",
          )}
        >
          {/* @todo - add translation for this text */}
          {t("Flight Duration")}
          <LIcon name={open ? "ChevronUp" : "ChevronDown"} />
        </CollapsibleTrigger>
        <CollapsibleContent>
          <HourRange
            onChange={handleChange}
            initialValue={{
              start: initialStartTime as unknown as number,
              end: initialEndTime as unknown as number,
            }}
            rangeValue={{
              start: parseInt(
                data?.filterResult.flightMinTime
                  .split(/[:.]/)[0]
                  ?.replace(/^0+/, "") ?? "",
                10,
              ),
              end: parseInt(
                data?.filterResult.flightMaxTime
                  .split(/[:.]/)[0]
                  ?.replace(/^0+/, "") ?? "",
                10,
              ),
            }}
          />
        </CollapsibleContent>
      </Collapsible>
      <Divider />
    </>
  );
};

export default FlightListFilterFlightDuration;
