import React, { useEffect, useState } from "react";

import { Divider } from "@/components/ui/divider/divider";
import FilterCheckbox from "@/components/widget/filter-checkbox/filter-checkbox";
import { useLocale } from "@/hooks/useLocale";
import type { AirlineCode } from "@/services/eva-display/flight/flight-search/flight-search-services.types";

import { useFlightListContext } from "../context/flight-list-context";

const FlightListFilterTransferCount = () => {
  const { t } = useLocale();
  const { data, applyTransferCountFilter, requestVariables } =
    useFlightListContext();
  const [layoverData, setLayoverData] = useState<AirlineCode[]>([]);

  const handleChange = (values: string[]) => {
    if (applyTransferCountFilter) {
      applyTransferCountFilter(values);
    }
  };

  useEffect(() => {
    setLayoverData(data?.filterResult.layover || []);
  }, [data?.filterResult.layover]);

  return (
    layoverData.length > 0 && (
      <div className="px-4 py-2">
        <FilterCheckbox
          collapseDefaultOpen
          collapseTitle={t("Transfer Count")}
          items={layoverData.map((item) => ({
            key: item.key,
            label: `${item.value}`,
            value: item.key,
          }))}
          onChange={handleChange}
          initialSelectedItems={
            layoverData
              .filter(
                (item) =>
                  item.selected ||
                  requestVariables?.Filter.Layover?.includes(item.key),
              )
              .map((item) => item.key) || []
          }
        />
        <Divider />
      </div>
    )
  );
};

export default FlightListFilterTransferCount;
