import React from "react";

import Card from "@/components/ui/card/card";
import { Skeleton } from "@/components/ui/skeleton/skeleton";

import { useFlightListContext } from "../context/flight-list-context";
import FlightListFilterAirlineCompany from "./flight-list-filter-airline-company";
import FlightListFilterFlightDuration from "./flight-list-filter-flight-duration";
import FlightListFilterPriceRange from "./flight-list-filter-price-range";
import FlightListFilterTransferCount from "./flight-list-filter-transfer-count";

const FlightListFilter = () => {
  const { isLoading, data } = useFlightListContext();
  return (
    <>
      {isLoading && <Skeleton style={{ height: 400 }} />}
      {!isLoading &&
        data !== null &&
        data?.combinationGroups &&
        data?.combinationGroups?.length > 0 && (
          <div className="flex w-full max-w-[248px] flex-col gap-4">
            <Card>
              <FlightListFilterPriceRange />
            </Card>
            <Card className="flex flex-col !p-0 !pb-4">
              {/* This field is deprecated by be when it is ready. You can use it when its services is ready */}
              {/* <FlightListFilterDepartureTime /> */}
              <FlightListFilterFlightDuration />
              <FlightListFilterTransferCount />
              <FlightListFilterAirlineCompany />
            </Card>
          </div>
        )}
    </>
  );
};

export default FlightListFilter;
