/* eslint-disable no-nested-ternary */

import { Button } from "@/components/ui/button/button";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import {
  FlightBrand,
  FlightDetail,
  FlightDetailAction,
  FlightDetailCard,
  FlightInformation,
  FlightPrice,
  FlightTime,
} from "@/components/widget/flight-card/flight-card";
import FlightInformationModal from "@/components/widget/flight-information-modal/flight-information-modal";
import {
  DateHelper,
  getFormatedFlightTime,
} from "@/libs/helpers/date-time-helper";
import {
  getAirportCode,
  getCityName,
  getWaitingTime,
  sortFlightSegments,
} from "@/libs/helpers/flight-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { PricingCombinationWithCombinationGroups } from "@/services/eva-display/flight/flight-search/flight-search-services-serializer";

interface FlightListItemContentProps {
  pricingCombination: PricingCombinationWithCombinationGroups;
  combinationGroup: PricingCombinationWithCombinationGroups["combinationGroups"][0];
  onSelect?: (item: PricingCombinationWithCombinationGroups) => void;
  noPricing?: boolean;
  renderActionButton?: () => React.ReactNode;
  passengerCount: number;
  isNoDetail?: boolean;
  hasLocationInfo?: boolean;
  price?: string;
}

const FlightListItemContent = ({
  combinationGroup,
  pricingCombination,
  onSelect,
  noPricing = false,
  renderActionButton,
  passengerCount,
  isNoDetail,
  hasLocationInfo,
  price,
}: FlightListItemContentProps) => {
  const { closeModal, openModal, modalOpen } = useModal({ open: false });
  if (!combinationGroup) return null;

  const flightSegments = sortFlightSegments(combinationGroup.flightSegments);

  const flightSegment = flightSegments[0]!;

  const properties = [
    {
      text: "1 Parça Kabin Bagajı",
    },
    {
      text: "1 Parça Kabin Bagajı",
    },
    {
      text: "1 Parça Kabin Bagajı",
    },
    {
      text: "1 Parça Kabin Bagajı",
    },
    {
      text: "1 Parça Kabin Bagajı",
    },
  ];

  // @todo - add translation fot these text
  const cabinClasses = {
    0: "Ekonomi",
    1: "Comfort",
    2: "Business",
    3: "First Class",
  };

  const directs = flightSegments.map(
    (_flightSegmentItem) => _flightSegmentItem.marketingAirline,
  );

  const departureSegment = flightSegments[0];
  const arrivalSegment = flightSegments[flightSegments.length - 1];

  const getCabinClassTitle = (cabinClass: keyof typeof cabinClasses) => {
    return cabinClasses[cabinClass];
  };

  function getOperatingCompanies(infotext: boolean) {
    const temp: string[] = [];
    flightSegments.forEach((flightSegmentItem) => {
      if (
        flightSegmentItem.marketingAirline !==
        flightSegmentItem.operatingAirline
      ) {
        const result = temp.find(
          (item) => item === flightSegmentItem.operatingAirline,
        );
        if (result === undefined) {
          temp.push(flightSegmentItem.operatingAirline);
        }
      }
    });
    if (infotext) {
      if (temp.length === 0) return "";
      return `Uçuş hizmetinizin bir bölümü ${temp.join(
        ", ",
      )} tarafından yürütülecektir.`;
    }

    return temp;
  }

  return (
    <div>
      {hasLocationInfo && (
        <div className="mb-5 text-sm font-semibold">{`${getCityName(
          flightSegment.origin,
        )} - ${getCityName(flightSegment.destination)}`}</div>
      )}
      <div className="flex flex-col md:gap-2">
        <div className="flex flex-col justify-between gap-4 md:flex-row">
          <FlightBrand
            logoSrc={`https://concorecdn.jollytur.com/concore/media/site/assets/img/theme/${flightSegment.marketingAirlineCode}-42x42.gif?v1040`}
            brandName={flightSegment.marketingAirline as string}
            flightCode={flightSegment.flightNumber as string}
          />
          <FlightTime
            totalFlightHours={getFormatedFlightTime(
              combinationGroup.travelTime,
            )}
            flightStartTime={`${DateHelper.dateToTime(
              departureSegment?.departureTime as unknown as Date,
            )}`}
            endStartTime={DateHelper.dateToTime(
              flightSegments[flightSegments.length - 1]
                ?.arrivalTime as unknown as Date,
            )}
            transferInformation={
              directs.length === 1
                ? "Aktarmasız"
                : /**
                   * Actually 1 length is direct flight. because of that we need to minus 1
                   * @todo - add translation fot these text
                   */
                  `${directs.length - 1} Aktarmalı`
            }
            startIATACode={getAirportCode(departureSegment!.origin!)!}
            endIATACode={getAirportCode(arrivalSegment?.destination!)!}
            transferIATACodes={directs.length === 1 ? "" : ""}
          />

          <div className="flex justify-between border-t pt-4 md:min-w-[250px] md:border-t-0 md:pt-0">
            <div className="min-w-auto md:min-w-[150px]">
              <FlightInformation
                seatInformation={
                  flightSegment.quota === 0
                    ? ""
                    : flightSegment.quota <= 2
                      ? `Son ${flightSegment.quota} koltuk`
                      : ""
                }
                baggageInformation=""
                /**
                 * @todo - add translation fot these text
                 */
                flightClass={
                  combinationGroup.cabinClassTitle ??
                  getCabinClassTitle(
                    departureSegment?.cabinClass as unknown as keyof typeof cabinClasses,
                  )
                }
              >
                {!isNoDetail && (
                  <Button
                    onClick={openModal}
                    className="!p-0"
                    variant="link"
                    size="sm"
                  >
                    Detaylı Bilgi
                  </Button>
                )}
              </FlightInformation>
            </div>

            {!noPricing && (
              <FlightPrice
                price={
                  price ||
                  PriceManager({
                    currency: pricingCombination.totalPrice.slice(0, 3),
                    value:
                      +pricingCombination.totalPrice.slice(3) / passengerCount,
                  })
                }
                isOptimal
              />
            )}
          </div>
        </div>
        <div />
        {!noPricing && (
          <div className="flex flex-col gap-6">
            <FlightDetailAction
              renderActionButton={renderActionButton}
              onClick={() => {
                onSelect?.(pricingCombination);
              }}
              isOpen={false}
              infoText={getOperatingCompanies(true).toString()}
              operatingCompanies={getOperatingCompanies(false) as string[]}
            />
            <FlightDetail active={false}>
              {Array.from({ length: 5 }).map((_, i) => (
                <FlightDetailCard
                  key={+i}
                  flightClass="Economy (B)"
                  price="1500TL"
                  properties={properties}
                />
              ))}
            </FlightDetail>
          </div>
        )}
      </div>
      {modalOpen && (
        <Modal
          size="lg"
          open={modalOpen}
          onClose={closeModal}
          title="Detaylı Bilgi"
          footer
        >
          <div className="mt-5 flex flex-col gap-4 overflow-auto">
            {flightSegments.map((flightSegmentItem, key) => (
              <FlightInformationModal
                key={+key}
                marketingAirlineCode={flightSegmentItem.operatingAirlineCode}
                origin={flightSegmentItem.origin}
                destination={flightSegmentItem.destination}
                departureTime={DateHelper.dayjs(
                  flightSegmentItem.departureTime as unknown as Date,
                ).format("HH:mm , DD MMMM YYYY dddd")}
                arrivalTime={DateHelper.dayjs(
                  flightSegmentItem.arrivalTime as unknown as Date,
                ).format("HH:mm , DD MMMM YYYY dddd")}
                flightTime={getFormatedFlightTime(flightSegmentItem.flightTime)}
                brandName={flightSegmentItem.operatingAirline}
                flightCode={flightSegmentItem.flightNumber}
                infoText={
                  flightSegmentItem.marketingAirline ===
                  flightSegmentItem.operatingAirline
                    ? ""
                    : `Uçuş hizmetinizin bir bölümü ${flightSegmentItem.operatingAirline} tarafından yürütülecektir.`
                }
                lastSegment={key === flightSegments.length - 1}
                waitingTime={getWaitingTime(
                  flightSegmentItem.arrivalTime,
                  flightSegments[key + 1]?.departureTime,
                )}
              />
            ))}
            <div className="flex flex-col gap-2 rounded-primary border p-3">
              <div className="flex justify-between text-sm text-gray-800">
                <span className="font-semibold">Varış Tarihi</span>
                <span className="font-normal">
                  {DateHelper.dayjs(
                    flightSegments[flightSegments.length - 1]
                      ?.arrivalTime as unknown as Date,
                  ).format("DD MMMM YYYY ddd HH:mm")}
                </span>
              </div>
              <div className="flex justify-between text-sm text-gray-800">
                <span className="font-semibold">Seyahat Süresi</span>
                <span className="font-normal">
                  {getFormatedFlightTime(combinationGroup.travelTime)}
                </span>
              </div>
            </div>
          </div>
        </Modal>
      )}
    </div>
  );
};

export default FlightListItemContent;
