import { useBoolean, useMediaQuery } from "usehooks-ts";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type {
  GroupedPricingCombinationWithCombinationGroups,
  PricingCombinationWithCombinationGroups,
} from "@/services/eva-display/flight/flight-search/flight-search-services-serializer";

import { FlightListItem } from "./flight-list-item";

interface FlightListItemProps {
  item: GroupedPricingCombinationWithCombinationGroups;
  passengerCount?: number;
  onPricingCombinationSelect: (
    pricingCombination: PricingCombinationWithCombinationGroups,
  ) => void;
}

interface PriceAndButtonProps {
  pricingCombinationItem: {
    totalPrice: string;
  };
  passengerCount: any;
  onPricingCombinationSelect: (arg0: any) => void;
}

export function PriceAndButton(props: PriceAndButtonProps) {
  return (
    <div className="flex flex-col items-end gap-2">
      <div className="text-base font-semibold">
        {PriceManager({
          currency: props.pricingCombinationItem.totalPrice.slice(0, 3),
          value:
            +props.pricingCombinationItem.totalPrice.slice(3) /
            (props.passengerCount ?? 1),
        })}
      </div>
      <Button
        variant="outline-primary"
        size="sm"
        onClick={() =>
          props.onPricingCombinationSelect(props.pricingCombinationItem)
        }
      >
        Seç
      </Button>
    </div>
  );
}

export const FlightListGroupItem = (props: FlightListItemProps) => {
  const showPricingCombinations = useBoolean();
  const isDesktop = useMediaQuery("(min-width: 768px)");

  const combinationItem = props.item.pricingCombinations[0];
  if (combinationItem?.combinationGroupKeys.length === 0) return null;
  if (!combinationItem) return null;

  return (
    <Card>
      <FlightListItem
        passengerCount={props.passengerCount}
        key={combinationItem.key}
        item={combinationItem}
        renderActionButton={() => (
          <Button
            className="w-24 md:w-auto md:min-w-[100px]"
            variant="primary"
            rightIcon={{
              name: showPricingCombinations.value ? "ChevronUp" : "ChevronDown",
              size: 18,
            }}
            onClick={showPricingCombinations.toggle}
          >
            {showPricingCombinations.value ? "Kapat" : "İncele"}
          </Button>
        )}
      />

      {showPricingCombinations.value && (
        <div className="mt-6 flex max-w-[776px] flex-col overflow-x-auto md:flex-row md:gap-4">
          {props.item.pricingCombinations.map((pricingCombinationItem) => (
            <Card
              key={pricingCombinationItem.key}
              className="w-full border-x-0 border-b-0 border-t md:w-[220px] md:border"
            >
              <div className="flex size-full flex-col items-stretch justify-between md:min-h-[300px] md:w-[188px]">
                <div>
                  <h6 className="text-base font-semibold">
                    {`${pricingCombinationItem.combinationGroups[0]?.cabinClassTitle} (${pricingCombinationItem.combinationGroups[0]?.flightSegments[0]?.bookingCode})`}
                  </h6>
                  <div className="flex items-start justify-between gap-2">
                    <ul className="mt-2">
                      {pricingCombinationItem.combinationGroups[0]
                        ?.cabinClassDescription ? (
                        pricingCombinationItem.combinationGroups[0]?.cabinClassDescription
                          ?.split("//")
                          .filter((x) => x !== "")
                          .map((x) => (
                            <li className="mb-2 text-sm text-gray-500" key={x}>
                              {x}
                            </li>
                          ))
                      ) : (
                        <li className="mb-2 text-sm text-gray-500">
                          {
                            pricingCombinationItem.combinationGroups[0]
                              ?.cabinClassTitle
                          }{" "}
                          uçuş paketi
                        </li>
                      )}
                    </ul>
                    {!isDesktop && (
                      <PriceAndButton
                        pricingCombinationItem={pricingCombinationItem}
                        passengerCount={props.passengerCount}
                        onPricingCombinationSelect={
                          props.onPricingCombinationSelect
                        }
                      />
                    )}
                  </div>
                </div>
                {isDesktop && (
                  <PriceAndButton
                    pricingCombinationItem={pricingCombinationItem}
                    passengerCount={props.passengerCount}
                    onPricingCombinationSelect={
                      props.onPricingCombinationSelect
                    }
                  />
                )}
              </div>
            </Card>
          ))}
        </div>
      )}
    </Card>
  );
};
