/* eslint-disable no-nested-ternary */
/**
 * @todo - add translation fot these text and some data should be dynamic
 */

import type { HTMLAttributes } from "react";

import Card from "@/components/ui/card/card";
import {
  FlightDetailAction,
  FlightPrice,
} from "@/components/widget/flight-card/flight-card";
import { sortCombinationGroups } from "@/libs/helpers/flight-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { cn } from "@/libs/utils";
import type { PricingCombinationWithCombinationGroups } from "@/services/eva-display/flight/flight-search/flight-search-services-serializer";

import FlightListItemContent from "./components/flight-list-item-content";

interface FlightListItemProps {
  item: PricingCombinationWithCombinationGroups;
  onSelect?: (item: PricingCombinationWithCombinationGroups) => void;
  renderActionButton?: () => React.ReactNode;
  passengerCount?: number;
  className?: HTMLAttributes<HTMLDivElement>["className"];
  isNoDetail?: boolean;
  hasLocationInfo?: boolean;
  oneWayStyle?: boolean;
  departureSegmentKey?: string;
}

const FlightListItem = ({
  item: pricingCombination,
  passengerCount = 1,
  onSelect,
  renderActionButton,
  className,
  isNoDetail,
  hasLocationInfo,
  oneWayStyle,
  departureSegmentKey,
}: FlightListItemProps) => {
  if (
    pricingCombination.combinationGroupKeys?.length === 0 &&
    pricingCombination.combinationGroups.length === 0
  )
    return null;

  const isMultipleCombinationGroup =
    pricingCombination?.combinationGroups?.length > 1;

  if (isMultipleCombinationGroup && !oneWayStyle) {
    return (
      <div
        className={cn(
          "flex rounded-primary md:border border-gray-200 bg-white p-3 flex-col md:flex-row",
          className,
        )}
      >
        <div className="flex grow flex-col gap-2">
          {sortCombinationGroups(pricingCombination.combinationGroups).map(
            (combinationGroup) => (
              <Card key={combinationGroup.key}>
                <FlightListItemContent
                  hasLocationInfo={hasLocationInfo}
                  passengerCount={passengerCount}
                  combinationGroup={combinationGroup}
                  renderActionButton={renderActionButton}
                  pricingCombination={pricingCombination}
                  onSelect={onSelect}
                  noPricing
                  isNoDetail={isNoDetail}
                />
              </Card>
            ),
          )}
        </div>
        <div className="ml-4 flex flex-col justify-center gap-5 md:justify-end">
          <div>
            <FlightPrice
              price={PriceManager({
                currency: pricingCombination.totalPrice.slice(0, 3),
                value: +pricingCombination.totalPrice.slice(3) / passengerCount,
              })}
              isOptimal
            />
          </div>
          <div className="flex flex-col items-end gap-6">
            {renderActionButton?.() ?? (
              <FlightDetailAction
                onClick={() => {
                  onSelect?.(pricingCombination);
                }}
                isOpen={false}
              />
            )}
          </div>
        </div>
      </div>
    );
  }

  const combinationGroup =
    !!departureSegmentKey && isMultipleCombinationGroup
      ? pricingCombination.combinationGroups[1]!
      : pricingCombination.combinationGroups[0]!;

  return (
    <FlightListItemContent
      hasLocationInfo={hasLocationInfo}
      passengerCount={passengerCount}
      combinationGroup={combinationGroup}
      pricingCombination={pricingCombination}
      onSelect={onSelect}
      renderActionButton={renderActionButton}
      isNoDetail={isNoDetail}
    />
  );
};

export { FlightListItem };
