/* eslint-disable react-hooks/exhaustive-deps */

"use client";

import { useEffectOnce } from "usehooks-ts";

import FlightSummaryView from "@/features/modules/flight/summary/components/flight-summary-view";
import { SummaryCtxProvider } from "@/features/modules/hotel/summary/context/summary-context";
import { useFlightAddToCartMutation } from "@/services/eva-display/flight/flight-add-to-cart/flight-add-to-cart.service";
import type { IFlightDetailResponse } from "@/services/eva-display/flight/flight-detail/flight-detail.service";

import FlightSummarySkeleton from "./components/flight-summary-skeleton";
import { useFlighSummaryCtx } from "./context/flight-summary-context";

interface FlightSummaryDataProps {
  detailData: IFlightDetailResponse;
}

const FlightSummaryData = (props: FlightSummaryDataProps) => {
  const { searchId, pricingCombinationKeys } = useFlighSummaryCtx();
  const flightAddToCartMutation = useFlightAddToCartMutation();

  useEffectOnce(() => {
    flightAddToCartMutation.mutate({
      FlightCartProductRequest: {
        PreBook: 0,
        cardId: null,
        PricingCombinationKeys: pricingCombinationKeys,
        searchId,
      },
    });
  });

  if (flightAddToCartMutation.isLoading) return <FlightSummarySkeleton />;

  return (
    flightAddToCartMutation.isSuccess &&
    flightAddToCartMutation.data?.cartId && (
      <SummaryCtxProvider
        totalPrice={+flightAddToCartMutation.data.totalPrice.slice(3) ?? 0}
        tryTotalPrice={+flightAddToCartMutation.data.totalPrice.slice(3) ?? 0}
      >
        <FlightSummaryView
          addToCartData={flightAddToCartMutation.data}
          detailData={props.detailData}
        />
      </SummaryCtxProvider>
    )
  );
};

export default FlightSummaryData;
