"use client";

import { useEffectOnce } from "usehooks-ts";

import { useApp } from "@/hooks/useApp";
import { localeStorageHelper } from "@/libs/helpers/locale-storage-helper";
import { ILoaderKeys } from "@/models/loader.model";
import { useLoaderStore } from "@/store/loader-store/use-loader-store";

import { FlightSummaryCtxProvider } from "./context/flight-summary-context";
import FlightSummaryDetail from "./flight-summary-detail";

const FlightSummary = () => {
  const { isB2C } = useApp();
  const { removeLoader } = useLoaderStore();
  function getVariables() {
    const storagedValues = localeStorageHelper.get("flight-cart");
    const storagedTpPassengers = localeStorageHelper.get("travel-planner");
    if (storagedValues && storagedTpPassengers) {
      return {
        searchId: storagedValues.searchId,
        productKey: storagedValues.productKey,
        combinationGroupKeys: storagedValues.combinationGroupKeys,
        pricingCombinationKeys: storagedValues.pricingCombinationKeys,
        passengers: storagedValues.passengers,
        tpPassengers: storagedTpPassengers.passengers,
        employees: storagedTpPassengers.customer,
        isAbroad: storagedValues.isAbroad,
        travelReasonId: isB2C ? 0 : storagedTpPassengers.reason?.value,
        branchOfficeId: isB2C ? 0 : storagedTpPassengers.branchOfficeId,
      };
    }
    return null;
  }

  useEffectOnce(() => {
    removeLoader(ILoaderKeys.FlightDetailLoaderKey);
  });

  const variables = getVariables();
  if (!variables) return <div>No Variables</div>;

  return (
    <FlightSummaryCtxProvider
      value={{
        searchId: variables.searchId,
        pricingCombinationKeys: variables.pricingCombinationKeys,
        combinationGroupKeys: variables.combinationGroupKeys,
        passengers: variables.passengers,
        tpPassengers: variables.tpPassengers,
        employees: variables.employees,
        isAbroad: variables.isAbroad,
        travelReasonId: variables.travelReasonId,
        branchOfficeId: variables.branchOfficeId,
      }}
    >
      <FlightSummaryDetail />
    </FlightSummaryCtxProvider>
  );
};

export default FlightSummary;
