"use client";

import { useMediaQuery } from "usehooks-ts";

import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import HotelListFilterHotelFacilities from "@/features/hotel/components/hotel-list/components/hotel-list-filter-hotel-facilities";
import HotelListFilterHotelType from "@/features/hotel/components/hotel-list/components/hotel-list-filter-hotel-type";
import { useLocale } from "@/hooks/useLocale";

import { useHotelSearch } from "../../hooks/use-hotel-search";
import HotelListFilterAccommodationType from "../hotel-list/components/hotel-list-filter-accommodation-type";
import HotelListFilterDestination from "../hotel-list/components/hotel-list-filter-destination";
import HotelListFilterTotalCount from "../hotel-list/components/hotel-list-filter-total-count";
import { useHotelListContext } from "../hotel-list/context/hotel-list-context";

const FilterModal = () => {
  const {
    closeModal: filterModalClose,
    openModal: filterOpenModal,
    modalOpen: filterModalOpen,
  } = useModal({ open: false });
  const { t } = useLocale();
  const isDesktop = useMediaQuery("(min-width: 768px)");

  const { isReady: isHotelSearchReady } = useHotelSearch();
  const { isLoading, hotelList, onIsApplicable } = useHotelListContext();

  if (isDesktop || !isHotelSearchReady) return null;

  const handleClose = () => {
    filterModalClose();
  };

  const handleOk = () => {
    filterModalClose();
    onIsApplicable?.(true);
  };

  const handleClick = () => {
    onIsApplicable?.(false);
    filterOpenModal();
  };

  return (
    <>
      <button
        type="button"
        onClick={handleClick}
        className="flex flex-1 items-center justify-center gap-2 rounded-lg border bg-white py-2 text-gray-600"
      >
        {t("Filters")}
      </button>

      <Modal
        size="full"
        open={filterModalOpen}
        onClose={handleClose}
        title={t("filter")}
        footer={false}
        onOkText={t("Apply")}
        onOk={handleOk}
      >
        {isLoading && (hotelList?.length || 0) === 0 ? (
          <div className="flex flex-col gap-4">
            <Skeleton style={{ height: 40 }} />
            <Skeleton style={{ height: 40 }} />
            <Skeleton style={{ height: 40 }} />
          </div>
        ) : (
          <div className="scroll-bar mb-5 size-full max-h-[calc(100%-100px)] overflow-y-scroll">
            <div className="my-4">
              <HotelListFilterTotalCount />
            </div>
            <HotelListFilterDestination />
            <HotelListFilterHotelFacilities />
            <HotelListFilterHotelType />
            <HotelListFilterAccommodationType />
          </div>
        )}
      </Modal>
    </>
  );
};

export default FilterModal;
