"use client";

import { useSearchParams } from "next/navigation";
import type { Key } from "react";
import { useMediaQuery } from "usehooks-ts";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { useLocale } from "@/hooks/useLocale";

import { useHotelSearch } from "../../hooks/use-hotel-search";
import { useHotelListContext } from "../hotel-list/context/hotel-list-context";

const SortModal = () => {
  const {
    closeModal: sortModalClose,
    openModal: sortOpenModal,
    modalOpen: sortModalOpen,
  } = useModal({ open: false });

  const isDesktop = useMediaQuery("(min-width: 768px)");

  const { isReady: isHotelSearchReady } = useHotelSearch();
  const { applyOrderBy, requestData } = useHotelListContext();

  const searchParams = useSearchParams();
  let defaultValue = requestData?.orderBy;

  if (searchParams.get("orderBy") === "PriceAscending")
    defaultValue = "PriceAscending";
  else if (searchParams.get("orderBy") === "PriceDescending")
    defaultValue = "PriceDescending";

  const handleChange = (key: Key) => {
    if (applyOrderBy) applyOrderBy(key as string);
    sortModalClose();
  };
  const { t } = useLocale();
  if (isDesktop || !isHotelSearchReady) return null;

  return (
    <>
      <button
        type="button"
        onClick={sortOpenModal}
        className="flex flex-1 items-center justify-center gap-2 rounded-lg border bg-white py-2 text-gray-600"
      >
        {t("Sort by")}
      </button>

      <Modal
        open={sortModalOpen}
        className="!m-0 !p-0"
        onClose={sortModalClose}
        footer
      >
        <div className="p-4">
          <div className="text-xl font-semibold text-gray-800 ">
            {t("Sort by")}
          </div>

          <div className="flex flex-col gap-2 py-8">
            <Button
              variant={
                defaultValue === "Average" ? "outline-primary" : "outline"
              }
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => handleChange("Average")}
            >
              <LIcon
                name={defaultValue === "Average" ? "CircleDot" : "Circle"}
                size={18}
              />
              &nbsp;{t("Recommended Ranking")}
            </Button>
            <Button
              variant={
                defaultValue === "PriceAscending"
                  ? "outline-primary"
                  : "outline"
              }
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => handleChange("PriceAscending")}
            >
              <LIcon
                name={
                  defaultValue === "PriceAscending" ? "CircleDot" : "Circle"
                }
                size={18}
              />
              &nbsp;{t("Price (lowest first)")}
            </Button>
            <Button
              variant={
                defaultValue === "PriceDescending"
                  ? "outline-primary"
                  : "outline"
              }
              className="w-full !justify-start gap-2 text-gray-500"
              onClick={() => handleChange("PriceDescending")}
            >
              <LIcon
                name={
                  defaultValue === "PriceDescending" ? "CircleDot" : "Circle"
                }
                size={18}
              />
              &nbsp;{t("Price (highest first)")}
            </Button>
          </div>
        </div>
      </Modal>
    </>
  );
};

export default SortModal;
