import Card from "@/components/ui/card/card";
import type { HotelProperty } from "@/components/widget/hotel-product-detail/hotel-product-detail-about/hotel-product-detail-about";
import HotelProductDetailAbout from "@/components/widget/hotel-product-detail/hotel-product-detail-about/hotel-product-detail-about";
import { useLocale } from "@/hooks/useLocale";
import type { GeneralInformation } from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";
import type { HotelListLocation } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

export interface HotelDetailAboutProps {
  name: string;
  informationText?: string;
  generalInformation?: GeneralInformation;
  hotelThemes?: HotelListLocation[];
  documentNumber?: string;
}

const HotelDetailAbout = ({
  informationText,
  name,
  generalInformation,
  hotelThemes,
  documentNumber,
}: HotelDetailAboutProps) => {
  const { t } = useLocale();
  function getHotelProperty() {
    const temp: HotelProperty[] = [];

    if (generalInformation?.size) {
      temp.push({
        label: t("Hotel area"),
        value: `${generalInformation.size} m2`,
      });
    }
    if (generalInformation?.roomCount) {
      temp.push({
        label: t("Number of rooms"),
        value: generalInformation.roomCount.toString(),
      });
    }
    if (generalInformation?.buildYear) {
      temp.push({
        label: t("Building age"),
        value: generalInformation.buildYear,
      });
    }
    if (generalInformation?.restaurantCount) {
      temp.push({
        label: t("Number of restaurants"),
        value: generalInformation.restaurantCount.toString(),
      });
    }
    if (generalInformation?.barCount) {
      temp.push({
        label: t("Number of bars"),
        value: generalInformation.barCount.toString(),
      });
    }
    return temp;
  }

  function getHotelPolicies() {
    const temp: Pick<HotelProperty, "label">[] = [];
    if (generalInformation?.checkIn && generalInformation.checkOut) {
      temp.push({
        label: `${t("Check-in time")}: ${generalInformation.checkIn} - ${t(
          "Check-out time",
        )}: ${generalInformation.checkOut}`,
      });
    }
    if (generalInformation?.marriageCertificateRestriction) {
      temp.push({
        label: t("Marriage certificate required."),
      });
    }
    if (generalInformation?.petRestriction) {
      temp.push({
        label: t("Pets are not allowed."),
      });
    }
    if (generalInformation?.childRestriction) {
      temp.push({
        label: `0-${generalInformation?.childRestrictionAge} yaş çocuk ücretsiz..`,
      });
    }

    return temp;
  }

  function getHotelTheme() {
    const temp: string[] = [];
    hotelThemes?.forEach((data) => {
      temp.push(data.value);
    });

    return temp;
  }

  const hotelProperty = getHotelProperty();
  const hotelPolicies = getHotelPolicies();
  const hotelTheme: string[] = getHotelTheme();
  return (
    <Card
      className="flex scroll-mt-16 flex-col gap-6 bg-white p-5 md:scroll-mt-48"
      id="about"
    >
      <HotelProductDetailAbout
        hotelName={name}
        informationText={informationText}
        hotelProperty={hotelProperty}
        hotelPolicies={hotelPolicies}
        hotelTheme={hotelTheme}
        documentNumber={documentNumber}
      />
    </Card>
  );
};

export default HotelDetailAbout;
