import Container from "@/components/shared/container";
import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import type { RoomFacilities } from "@/components/widget/hotel-product-detail/hotel-product-detail-title/hotel-product-detail-title";
import { HotelProductDetailTitle } from "@/components/widget/hotel-product-detail/hotel-product-detail-title/hotel-product-detail-title";
import { useLocale } from "@/hooks/useLocale";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { HotelListItemMealType } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

export interface HotelDetailTitleProps {
  title: string;
}

const HotelDetailTitle = ({ title }: HotelDetailTitleProps) => {
  return <HotelProductDetailTitle title={title} />;
};

export interface HotelDetailTitleSubBarProps {
  nightlyRateDescription?: string;
  price: any;
  recommended?: boolean;
  mealTypes?: HotelListItemMealType[];
  hasHygienicalMeasure?: boolean;
}

export const HotelDetailTitleSubBar = ({
  nightlyRateDescription,
  price,
  recommended = false,
  mealTypes,
  hasHygienicalMeasure,
}: HotelDetailTitleSubBarProps) => {
  const { t } = useLocale();
  function getRoomFacilities() {
    const temp: RoomFacilities[] = [];
    if (recommended) {
      temp.push({ text: t("Recommended"), icon: { name: "ThumbsUp" } });
    }
    if (mealTypes) {
      mealTypes.forEach((item) => {
        if (item.description) {
          temp.push({
            text: item.description,
            icon: { name: "UtensilsCrossed" },
          });
        }
      });
    }
    if (hasHygienicalMeasure) {
      temp.push({
        text: t("Trusted Tourism Certificate"),
        icon: { name: "ShieldCheck" },
      });
    }
    return temp;
  }

  const roomFacilities = getRoomFacilities();
  const formattedPrice = price
    ? PriceManager({
        currency: price.slice(0, 3),
        value: +price.slice(3),
      })
    : null;

  return (
    <div className="bg-white">
      <Container>
        <div className="flex flex-col gap-2 pb-2 transition-all md:flex-row md:justify-between">
          <div className="flex flex-wrap gap-2">
            {roomFacilities &&
              roomFacilities.length > 0 &&
              roomFacilities.map((item, index) => (
                <Badge key={+index} leftIcon={item.icon}>
                  {item.text}
                </Badge>
              ))}
          </div>
          <div className="flex items-center gap-2 md:justify-end">
            {nightlyRateDescription && (
              <span className="text-sm text-gray-500">
                {nightlyRateDescription}
              </span>
            )}
            {price && (
              <span className="text-xl font-semibold text-gray-800">
                {formattedPrice}
              </span>
            )}
          </div>
          <div className="md:hidden">
            <a className="block w-full" href="#rooms">
              <Button className="w-full md:w-[248px]" variant="primary">
                {t("See availability")}
              </Button>
            </a>
          </div>
        </div>
      </Container>
    </div>
  );
};

export default HotelDetailTitle;
