import Card from "@/components/ui/card/card";
import HotelProductDetailCampaign from "@/components/widget/hotel-product-detail/hotel-product-detail-campaign/hotel-product-detail-campaign";
import type { NearDistanceType } from "@/components/widget/hotel-product-detail/hotel-product-detail-location/hotel-product-detail-location";
import HotelProductDetailLocation from "@/components/widget/hotel-product-detail/hotel-product-detail-location/hotel-product-detail-location";
import type { HighlightedFeaturesType } from "@/components/widget/hotel-product-detail/hotel-product-detail-overview/hotel-product-detail-overview";
import HotelProductDetailOverview from "@/components/widget/hotel-product-detail/hotel-product-detail-overview/hotel-product-detail-overview";
import type {
  NearDistance,
  Season,
} from "@/services/eva-display/hotel/hotel-detail/hotel-detail-services.types";
import type { HotelListItemCampaignInformation } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

interface HotelDetailOverviewProps {
  informationText: string;
  season: Season[];
  address: string;
  nearDistances: NearDistance[];
  includedSpecifications?: HotelListItemCampaignInformation[];
  documentNumber?: string;
}

const HotelDetailOverview = ({
  informationText,
  season,
  address,
  nearDistances,
  documentNumber,
  includedSpecifications = [],
}: HotelDetailOverviewProps) => {
  function getHighlightedFeatures() {
    const temp: HighlightedFeaturesType[] = [];
    const item = season.find((Season: Season) => Season.id === 0);

    item?.facilities?.forEach((facilities) => {
      temp.push({
        text: facilities.name,
        icon: facilities.icon,
      });
    });
    return temp;
  }

  function getNearDistances() {
    const temp: NearDistanceType[] = [];
    nearDistances?.forEach((item) => {
      temp.push({
        distanceUnit: item.distanceUnit,
        distance: `${item.distance} ${item.type}`,
        name: item.name,
      });
    });
    return temp;
  }

  const highlightedFeatures: HighlightedFeaturesType[] =
    getHighlightedFeatures();

  const locationDistances: NearDistanceType[] = getNearDistances();
  return (
    <Card
      className="flex scroll-mt-16 flex-col bg-white p-4 md:scroll-mt-44 md:gap-6 md:p-5"
      id="overview"
    >
      <div className="grid grid-cols-1 gap-4 md:grid-cols-4">
        <div className="md:col-span-3">
          <HotelProductDetailOverview
            informationText={informationText}
            highlightedFeatures={highlightedFeatures}
            documentNumber={documentNumber}
          />
        </div>
        <div className="md:col-span-1">
          {address && (
            <HotelProductDetailLocation
              address={address}
              nearDistances={locationDistances}
            />
          )}
        </div>
      </div>
      {includedSpecifications.length > 0 && (
        <HotelProductDetailCampaign items={includedSpecifications} />
      )}
    </Card>
  );
};
export default HotelDetailOverview;
