import React, { useEffect, useState } from "react";

import type { AppliedFilterData } from "@/components/widget/applied-filter/applied-filter";
import AppliedFilter from "@/components/widget/applied-filter/applied-filter";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import type {
  FilterPropertyType,
  HotelListFilterResult,
} from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";
import { FilterPropertyEnum } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import { useHotelListContext } from "../context/hotel-list-context";

const HotelListAppliedFilters = () => {
  const {
    clearFilter,
    hotelListResponse,
    isLoading,
    applyFilter,
    onIsApplicable,
    requestData,
  } = useHotelListContext();
  const { isDesktop } = useBreakpoints();
  const [mainData, setMainData] = useState<AppliedFilterData[]>([]);

  const handleClearFilter = () => {
    if (clearFilter) clearFilter(false);
  };

  const handleRemoveItem = (filterItem: AppliedFilterData) => {
    // This manipulation is for hotel names. Because hotel names filter key is different from hotel name by api service.
    const filterKey =
      filterItem.filterKey === FilterPropertyEnum.HOTEL_NAMES
        ? FilterPropertyEnum.HOTEL_NAME
        : (filterItem.filterKey as FilterPropertyType);

    let filter = requestData?.filter[filterKey];
    if (Array.isArray(filter)) {
      filter = filter.filter((item) => item !== filterItem.filterValue);
    } else if (typeof filter === "string" || typeof filter === "number") {
      filter = null;
    }
    if (applyFilter) {
      if (!isDesktop) {
        onIsApplicable?.({
          filterKey,
          filterValue: filter,
        });
        return;
      }
      applyFilter(filterKey, filter);
    }
  };

  useEffect(() => {
    const prepareData = (data: HotelListFilterResult | undefined) => {
      const preparedData = Object.keys(data || {}).reduce(
        (prev: AppliedFilterData[], current): AppliedFilterData[] => {
          const key = current as keyof HotelListFilterResult;
          const currentFilters: AppliedFilterData[] = [];
          if (data) {
            const currentValues = data[key];
            if (typeof currentValues === "string") {
              currentFilters.push({
                filterLabel: currentValues,
                filterValue: currentValues,
                filterKey: key,
              });
            }
            if (Array.isArray(currentValues)) {
              currentValues
                .filter((item) => item.selected)
                .forEach((item) => {
                  currentFilters.push({
                    filterKey: key, // This key is different according to item.key.
                    filterLabel: item.value,
                    filterValue: item.key,
                  });
                });
            }
          }

          return [...prev, ...currentFilters];
        },
        [],
      );

      return preparedData;
    };

    if (hotelListResponse?.filterResult) {
      setMainData([...prepareData(hotelListResponse?.filterResult)]);
    }
  }, [hotelListResponse?.filterResult]);

  return (
    !isLoading && (
      <AppliedFilter
        data={mainData}
        onClearFilter={handleClearFilter}
        onRemoveItem={handleRemoveItem}
      />
    )
  );
};

export default HotelListAppliedFilters;
