import React from "react";

import FilterCheckbox from "@/components/widget/filter-checkbox/filter-checkbox";
import { useHotelListContext } from "@/features/hotel/components/hotel-list/context/hotel-list-context";
import { useLocale } from "@/hooks/useLocale";
import { FilterPropertyEnum } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

const HotelListFilterAccommodationType = () => {
  const { hotelListResponse, applyFilter, requestData } = useHotelListContext();
  const { t } = useLocale();
  const handleChange = (selectedItems: string[]) => {
    if (applyFilter)
      applyFilter<FilterPropertyEnum.THEMES>(
        FilterPropertyEnum.THEMES,
        selectedItems || [],
      );
  };

  if (!hotelListResponse?.filterResult?.themes) return null;

  return (
    <div className="px-4">
      <FilterCheckbox
        collapseTitle={t("Themes")}
        items={
          hotelListResponse?.filterResult?.themes
            ?.filter((item: any) => item.count > 0)
            ?.map((item) => ({
              key: item.key,
              label: `${item.value} (${item.count})`,
            })) || []
        }
        searchPlaceholder={`${t("Theme")} ${t("Search")}`}
        searchable
        onChange={handleChange}
        initialSelectedItems={requestData?.filter.themes || []}
        collapseDefaultOpen
      />
    </div>
  );
};

export default HotelListFilterAccommodationType;
