import { type PropsWithChildren } from "react";

import Card from "@/components/ui/card/card";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { useLocale } from "@/hooks/useLocale";

import { useHotelListContext } from "../context/hotel-list-context";
import HotelListFilterAccommodationType from "./hotel-list-filter-accommodation-type";
import HotelListFilterDestionation from "./hotel-list-filter-destination";
import HotelListFilterHotelFacilities from "./hotel-list-filter-hotel-facilities";
import HotelListFilterHotelType from "./hotel-list-filter-hotel-type";

const FilterTitle = ({ children }: PropsWithChildren) => (
  <p className="p-4 font-semibold text-slate-800">{children}</p>
);

const HotelListFilterAll = () => {
  const { isLoading, hotelList } = useHotelListContext();
  const { t } = useLocale();
  return isLoading && (hotelList?.length || 0) === 0 ? (
    <Skeleton style={{ height: 400 }} />
  ) : (
    <Card className="flex flex-col !p-0 !pb-4">
      <FilterTitle>{t("All Filters")}</FilterTitle>
      <HotelListFilterHotelFacilities />
      <HotelListFilterDestionation />
      {/* @todo - this area'll be added when service is ready */}
      {/* <HotelListFilterDistance />
      <HotelListFilterDivider /> */}
      <HotelListFilterHotelType />
      <HotelListFilterAccommodationType />
    </Card>
  );
};
export default HotelListFilterAll;
