import React from "react";

import FilterCheckbox from "@/components/widget/filter-checkbox/filter-checkbox";
import { useLocale } from "@/hooks/useLocale";
import { FilterPropertyEnum } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import { useHotelListContext } from "../context/hotel-list-context";
import { HotelListFilterDivider } from "./hotel-list-filter-divider";

const HotelListFilterDestination = () => {
  const {
    hotelListResponse: data,
    applyFilter,
    requestData,
  } = useHotelListContext();
  const { t } = useLocale();
  const handleChange = (selectedItems: string[]) => {
    if (applyFilter)
      applyFilter<FilterPropertyEnum.LOCATIONS>(
        FilterPropertyEnum.LOCATIONS,
        selectedItems || [],
      );
  };

  if (!data?.filterResult.locations) return null;

  return (
    <>
      <div className="px-4">
        <FilterCheckbox
          collapseDefaultOpen
          // @todo - add translation for 'Bölge'
          collapseTitle={t("Locations")}
          items={
            data?.filterResult.locations
              ?.filter((item: any) => item.count > 0)
              ?.map((item: any) => ({
                key: item.key,
                label: `${item.value}`,
                labelExtra: `(${item.count})`,
              })) || []
          }
          onChange={handleChange}
          // @todo - add translation for 'Bölge ara'
          searchPlaceholder={`${t("Location")} ${t("Search")}`}
          searchable
          initialSelectedItems={
            (requestData?.filter.locations || []) as string[]
          }
        />
      </div>
      <HotelListFilterDivider />
    </>
  );
};

export default HotelListFilterDestination;
