import React from "react";

import FilterCheckbox from "@/components/widget/filter-checkbox/filter-checkbox";
import { useLocale } from "@/hooks/useLocale";
import { FilterPropertyEnum } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import { useHotelListContext } from "../context/hotel-list-context";
import { HotelListFilterDivider } from "./hotel-list-filter-divider";

const HotelListFilterHotelType = () => {
  const {
    hotelListResponse: data,
    applyFilter,
    requestData,
  } = useHotelListContext();
  const { t } = useLocale();
  const handleChange = (selectedItems: string[]) => {
    if (applyFilter)
      applyFilter<FilterPropertyEnum.MEAL_TYPES>(
        FilterPropertyEnum.MEAL_TYPES,
        selectedItems || [],
      );
  };
  if (!data?.filterResult.mealTypes) return null;
  return (
    <>
      <div className="px-4">
        <FilterCheckbox
          collapseTitle={t("Food Types")}
          items={
            data?.filterResult.mealTypes
              ?.filter((item: any) => item.count > 0)
              ?.map((item: any) => ({
                key: item.key,
                label: `${item.value}`,
                labelExtra: `(${item.count})`,
              })) || []
          }
          searchPlaceholder={`${t("Food Type")} ${t("Search")}`}
          searchable
          onChange={handleChange}
          initialSelectedItems={requestData?.filter.mealTypes}
          collapseDefaultOpen
        />
      </div>
      <HotelListFilterDivider />
    </>
  );
};

export default HotelListFilterHotelType;
