import { type PropsWithChildren } from "react";

import Card from "@/components/ui/card/card";
import type { RangeValue } from "@/components/ui/range-slider/range-slider";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import PriceRange from "@/components/widget/price-range/price-range";
import { useLocale } from "@/hooks/useLocale";
import { FilterPropertyEnum } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import { useHotelListContext } from "../context/hotel-list-context";

const FilterTitle = ({ children }: PropsWithChildren) => (
  <p className="font-semibold text-slate-800 ">{children}</p>
);

const HotelListFilterTotalCount = () => {
  const {
    hotelListResponse: data,
    isLoading,
    applyPriceFilter,
    requestData,
  } = useHotelListContext();
  const { t } = useLocale();
  if (!data?.filterResult.maxPrice) return null;

  const handleChange = (val: RangeValue) => {
    if (applyPriceFilter) {
      applyPriceFilter(val);
    }
  };

  return isLoading ? (
    <Skeleton style={{ height: "250px" }} />
  ) : (
    <Card className="flex flex-col">
      <FilterTitle>{t("Total Price")}</FilterTitle>
      <PriceRange
        rangeValues={{
          start: data?.filterResult.minPrice || 0,
          end: data?.filterResult.maxPrice || 0,
        }}
        initalRangeValues={{
          start:
            requestData?.filter[FilterPropertyEnum.MIN_PRICES] ||
            data?.filterResult.minPrice ||
            0,
          end:
            requestData?.filter[FilterPropertyEnum.MAX_PRICES] ||
            data?.filterResult.maxPrice ||
            0,
        }}
        currencySymbol={
          data.hotelList?.[0]?.basePrice.slice(0, 3) === "TRY"
            ? "TRY"
            : data.hotelList?.[0]?.basePrice.slice(0, 3)
        }
        onChange={handleChange}
      />
    </Card>
  );
};
export default HotelListFilterTotalCount;
