import React from "react";

import { Button } from "@/components/ui/button/button";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { useLocale } from "@/hooks/useLocale";

import { useHotelListContext } from "../context/hotel-list-context";

const HotelListGetMoreButton = () => {
  const { isLoading, hotelList, hotelListResponse, getMoreData } =
    useHotelListContext();
  const { t } = useLocale();
  const handleClick = () => {
    if (getMoreData)
      getMoreData({
        searchId: hotelListResponse?.metadata.searchId,
        requestKey: hotelListResponse?.metadata.requestKey,
      });
  };
  if (hotelListResponse?.totalHotelCount === 0) return null;

  return (
    <>
      {(hotelList?.length || 0) > 0 && (
        <div className="text-center">
          {isLoading ? (
            <Skeleton style={{ height: 24 }} />
          ) : (
            <p className="text-sm leading-tight text-slate-800">
              <span>
                {t("You have viewed {{number}} of {{count}} results", {
                  count: hotelListResponse?.totalHotelCount || 0,
                  number: hotelList?.length,
                })}
              </span>
            </p>
          )}
        </div>
      )}
      {(isLoading || hotelListResponse?.metadata.hasMorePage) && (
        <div className="flex justify-center">
          <Button
            loading={isLoading}
            variant="outline-primary"
            onClick={handleClick}
          >
            {t("Show more")}
          </Button>
        </div>
      )}
    </>
  );
};

export default HotelListGetMoreButton;
