import { useSearchParams } from "next/navigation";
import type { Key } from "react";
import React from "react";

import { Skeleton } from "@/components/ui/skeleton/skeleton";
import SortButtonGroup from "@/components/widget/sort-button-group/sort-button-group";
import { useLocale } from "@/hooks/useLocale";

import { useHotelListContext } from "../context/hotel-list-context";

const HotelListOrderButtons = () => {
  const { isLoading, applyOrderBy, requestData, hotelList } =
    useHotelListContext();
  const searchParams = useSearchParams();
  let defaultValue = requestData?.orderBy;

  if (searchParams.get("orderBy") === "PriceAscending")
    defaultValue = "PriceAscending";
  else if (searchParams.get("orderBy") === "PriceDescending")
    defaultValue = "PriceDescending";

  const handleChange = (key: Key) => {
    if (applyOrderBy) applyOrderBy(key as string);
  };
  const { t } = useLocale();
  if (hotelList?.length === 0) return null;
  return isLoading ? (
    <Skeleton style={{ height: 40 }} />
  ) : (
    <SortButtonGroup
      onChange={handleChange}
      defaultActive={defaultValue}
      items={[
        {
          label: t("Recommended Ranking"),
          key: "Average",
        },
        {
          label: t("Price (lowest first)"),
          key: "PriceAscending",
        },
        {
          label: t("Price (highest first)"),
          key: "PriceDescending",
        },
      ]}
    />
  );
};

export default HotelListOrderButtons;
