/* eslint-disable no-nested-ternary */
import React from "react";
import { useMediaQuery } from "usehooks-ts";

import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { useLocale } from "@/hooks/useLocale";

const HotelListResultTitle = ({
  title,
  count,
  isLoading,
}: {
  title: string;
  count: number;
  isLoading?: boolean;
}) => {
  const { t } = useLocale();
  const isDesktop = useMediaQuery("(min-width: 768px)");

  return isLoading ? (
    <Skeleton style={{ height: 100 }} />
  ) : !isDesktop ? (
    <div className="w-full text-center text-sm text-gray-800">
      <p>{t("{{count}} results found.", { count })}</p>
    </div>
  ) : (
    <div className="flex items-center justify-start gap-4">
      <h1 className="text-2xl font-semibold leading-loose text-slate-800">
        {title}
      </h1>
      <h2 className="leading-tighy text-sm text-gray-600">
        {/* @todo - add translation for 'sonuç bulundu' */}
        {t("{{count}} results found.", { count })}
      </h2>
    </div>
  );
};

export default HotelListResultTitle;
