import React from "react";
import { useMediaQuery } from "usehooks-ts";

import ListSkeleton from "@/components/widget/list-skeleton/list-skeleton";
import type { IHotelListItem } from "@/services/eva-display/hotel/hotel-search/hotel-search-services.types";

import { useHotelListContext } from "../context/hotel-list-context";
import HotelListAppliedFilters from "./hotel-list-applied-filters";
import HotelListGetMoreButton from "./hotel-list-get-more-button";
import HotelListItem from "./hotel-list-item";
import HotelListNoData from "./hotel-list-no-data";
import HotelListOrderButtons from "./hotel-list-result-order-buttons";
import HotelListResultTitle from "./hotel-list-result-title";

const HotelListResult = () => {
  const { isLoading, hotelList, hotelListResponse, requestData } =
    useHotelListContext();

  const isDesktop = useMediaQuery("(min-width: 768px)");

  function getTitle() {
    if (requestData?.destinationName) {
      if (requestData?.destinationType !== "Destination") {
        return requestData?.destinationName;
      }
      return `${requestData?.destinationName} Otelleri`;
    }

    return "Arama Sonucu";
  }

  return (
    <div className="mb-8 flex w-full flex-col gap-4 md:w-[calc(100%_-_264px)]">
      {isDesktop && (
        <>
          <HotelListResultTitle
            // @todo - add translation for 'Arama sonucu'
            title={getTitle()}
            count={hotelListResponse?.totalHotelCount || 0}
            isLoading={isLoading}
          />
          <HotelListOrderButtons />
        </>
      )}
      {/* Selected Filters */}
      <HotelListAppliedFilters />
      {/* Push skeleton when data is loading */}
      {isLoading && (hotelList?.length || 0) === 0 && <ListSkeleton size={5} />}
      {/* Push data list when fetching is completed and there is many data */}
      {hotelList?.map((item) => (
        // This item keys manipulated for this loop by service merge function
        <HotelListItem item={item as IHotelListItem} key={item.key} />
      ))}
      <HotelListGetMoreButton />
      {/* Push no data component when fetching is completed and there is no any data  */}
      {!isLoading && (hotelList?.length || 0) === 0 && <HotelListNoData />}
    </div>
  );
};

export default HotelListResult;
