"use client";

import { useEffect } from "react";
import { useMediaQuery } from "usehooks-ts";

import { ILoaderKeys } from "@/models/loader.model";
import { useLoaderStore } from "@/store/loader-store/use-loader-store";

import { useHotelSearch } from "../../hooks/use-hotel-search";
import FilterSort from "../filter-sort/filter-sort";
import HotelListFilter from "./components/hotel-list-filter";
import HotelListResult from "./components/hotel-list-result";
import HotelListResultTitle from "./components/hotel-list-result-title";
import {
  HotelListContextProvider,
  useHotelListContext,
} from "./context/hotel-list-context";

const HotelListContent = () => {
  const { hotelListResponse } = useHotelListContext();
  const { removeLoader } = useLoaderStore();

  const isDesktop = useMediaQuery("(min-width: 768px)");

  useEffect(() => {
    setTimeout(() => {
      removeLoader(ILoaderKeys.HotelDetailLoaderKey);
    }, 250);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  return (
    <div className="flex flex-col justify-start gap-4 md:flex-row">
      {!!hotelListResponse?.totalHotelCount && !isDesktop && (
        <HotelListResultTitle
          title=""
          count={hotelListResponse.totalHotelCount}
        />
      )}
      {/* Filter - This contents width is 248px for desktop */}
      {isDesktop ? <HotelListFilter /> : <FilterSort />}
      {/* List - This contents width is 100% - 264px. 264 is came with gap value(16px) for desktop */}
      <HotelListResult />
    </div>
  );
};
const HotelList = () => {
  const { isReady: isHotelSearchReady } = useHotelSearch();

  if (!isHotelSearchReady) return null;

  return (
    <HotelListContextProvider>
      <HotelListContent />
    </HotelListContextProvider>
  );
};

export default HotelList;
