import dayjs from "dayjs";

import { Button } from "@/components/ui/button/button";
import {
  EarlyBookingDiscount,
  HotelDiscountPrice,
  HotelPrice,
  HotelRezervationSummary,
  HotelRezervationSummaryDateInfo,
  HotelRezervationSummaryRoomInfo,
  RezervationSummaryDivider,
  RezervationSummaryProvider,
  RezervationSummaryTitle,
  RezervationSummaryTotalPrice,
} from "@/components/widget/rezervation-summary/rezervation-summary";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { IHotelAddToCartResponse } from "@/services/eva-display/hotel/hotel-add-to-cart/hotel-add-to-card-services.types";

interface HotelSummaryReservationDetailProps {
  data: IHotelAddToCartResponse;
  isLoading?: boolean;
  onClick?: () => void;
}

const HotelSummaryReservationDetail = (
  props: HotelSummaryReservationDetailProps,
) => {
  return (
    <RezervationSummaryProvider>
      <RezervationSummaryTitle title="Rezervasyon Özeti" />
      <HotelRezervationSummary
        hotelName={props.data.hotelName}
        image={props.data.image?.url}
      >
        <RezervationSummaryDivider />
        <HotelRezervationSummaryDateInfo
          startDate={dayjs(props.data.checkInDate).format("DD MMMM YYYY")}
          endDate={dayjs(props.data.checkOutDate).format("DD MMMM YYYY")}
          startTime={dayjs(props.data.checkInDate).format("HH:mm")}
          endTime={dayjs(props.data.checkOutDate).format("HH:mm")}
          nightlyRateDescription={props.data.accommodationCount}
        />
        <RezervationSummaryDivider />
        {props.data.roomItemList &&
          props.data.roomItemList.map((roomItem) => (
            <>
              <HotelRezervationSummaryRoomInfo
                key={roomItem.roomTitle}
                title={`${roomItem.roomTitle}`}
                passengerDescription={roomItem.passengerInformation.description}
                mealDescription={roomItem.mealType}
              >
                <HotelPrice
                  nightlyRateDescription={roomItem.roomPriceDiscountString}
                  discount
                  discountDescription={roomItem.roomPriceDiscountDescription}
                  price={PriceManager({
                    currency: roomItem.totalPrice.slice(0, 3),
                    value: +roomItem.totalPrice.slice(3),
                  })}
                />
                {roomItem.roomPriceDiscountDescription && (
                  <HotelDiscountPrice
                    price={PriceManager({
                      currency: roomItem.basePrice.slice(0, 3),
                      value: +roomItem.basePrice.slice(3),
                    })}
                  />
                )}
              </HotelRezervationSummaryRoomInfo>
              <RezervationSummaryDivider />
            </>
          ))}
      </HotelRezervationSummary>
      {props.data.extendedDiscountInformationList &&
        props.data.extendedDiscountInformationList.map((discount) => (
          <EarlyBookingDiscount
            key={discount.description}
            price={PriceManager({
              currency: discount.price.slice(0, 3),
              value: +discount.price.slice(3),
            })}
            title={discount.description}
          />
        ))}
      <RezervationSummaryTotalPrice
        price={PriceManager({
          currency: props.data.totalPrice.slice(0, 3),
          value: +props.data.totalPrice.slice(3),
        })}
      />
      <Button
        type={props.onClick ? "button" : "submit"}
        variant="primary"
        loading={props.isLoading}
        onClick={props.onClick}
      >
        Talep Oluştur
      </Button>
    </RezervationSummaryProvider>
  );
};

export default HotelSummaryReservationDetail;
