import FormItem from "@/components/form/form-item";
import { Badge } from "@/components/ui/badge/badge";
import CustomerInfoFormItems from "@/features/customer/customer-info/customer-info-form/customer-info-form";
import CustomerInfoSelectInput from "@/features/customer/customer-info-select/customer-info-select-input";
import { useLabels } from "@/hooks/useLabels";

interface HotelSummaryRoomCustomersProps {
  employeeCount: number;
  guestCount: number;
  childCount: number;
  roomIndex: number;
}

const HotelSummaryRoomCustomers = ({
  employeeCount,
  guestCount,
  roomIndex,
  childCount,
}: HotelSummaryRoomCustomersProps) => {
  const labels = useLabels();
  return (
    <div className="mb-8 flex flex-col gap-5">
      {Array.from(Array(employeeCount), (_, roomCustomerIndex) => (
        <FormItem
          name={`${roomIndex}-${roomCustomerIndex}-employee`}
          key={roomCustomerIndex.toString()}
        >
          {({ field, setValue }) => (
            <CustomerInfoSelectInput
              value={field.value ?? null}
              onChange={(value) => setValue(value)}
              label={`${roomCustomerIndex + 1}. Yetişkin`}
            />
          )}
        </FormItem>
      ))}
      {Array.from(Array(guestCount), (_, index) => (
        <div key={index}>
          <div className="mb-2 flex items-center gap-3">
            <h3 className="text-xs font-semibold">
              {employeeCount + index + 1}. Yetişkin
            </h3>
            <Badge variant="primary">{labels.guest.label}</Badge>
          </div>
          <CustomerInfoFormItems
            customerPrefix={`${roomIndex}-${index + employeeCount}-guest`}
            showIdentityWarning
          />
        </div>
      ))}
      {Array.from(Array(childCount), (_, index) => (
        <div key={index}>
          <div className="mb-2 flex items-center gap-3">
            <h3 className="text-xs font-semibold">{index + 1}. Çocuk</h3>
            <Badge variant="primary">Çocuk</Badge>
          </div>
          <CustomerInfoFormItems
            customerPrefix={`${roomIndex}-${
              index + employeeCount + childCount
            }-child`}
            showIdentityWarning
          />
        </div>
      ))}
    </div>
  );
};

export default HotelSummaryRoomCustomers;
