/* eslint-disable react-hooks/exhaustive-deps */
import React, { useEffect } from "react";

import { Button } from "@/components/ui/button/button";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import CoreSummaryAdditionalService, {
  CoreSummaryAdditionalServiceItem,
} from "@/features/core/summary/components/core-summary-additional-service";
import CoreSummaryCancelWarrantyTitle from "@/features/core/summary/components/core-summary-cancel-warranty-title";
import { useApp } from "@/hooks/useApp";
import { useLocale } from "@/hooks/useLocale";
import localStateCache from "@/libs/helpers/local-state-cache-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { CancelWarranty } from "@/services/eva-display/hotel/hotel-add-to-cart/hotel-add-to-card-services.types";

import {
  useSummaryCtxActions,
  useSummaryCtxState,
} from "../context/summary-context";

interface HotelSummaryCancelWarrantyProps {
  cancelWarranty: CancelWarranty;
}

const HotelSummaryCancelWarranty = ({
  cancelWarranty,
}: HotelSummaryCancelWarrantyProps) => {
  const { isB2C } = useApp();
  const { t } = useLocale();
  const summaryState = useSummaryCtxState();
  const { setCancelWarranty } = useSummaryCtxActions();

  function cancelWarrantyAddOrRemoved() {
    if (summaryState.cancelWarranty?.searchId !== cancelWarranty.searchId) {
      setCancelWarranty({
        cancelWarranty,
        totalPrice:
          summaryState.totalPrice + +cancelWarranty.totalExchangePrice.slice(3),
        tryTotalPrice:
          summaryState.tryTotalPrice + +cancelWarranty.totalPrice.slice(3),
      });
    } else {
      setCancelWarranty({
        cancelWarranty: null,
        totalPrice:
          summaryState.totalPrice - +cancelWarranty.totalExchangePrice.slice(3),
        tryTotalPrice:
          summaryState.tryTotalPrice - +cancelWarranty.totalPrice.slice(3),
      });
    }
    localStateCache.set("cancellationPolicy", {
      data: summaryState.cancelWarranty?.searchId !== cancelWarranty.searchId,
    });
  }

  useEffect(() => {
    if (localStateCache.get("cancellationPolicy")?.data)
      setCancelWarranty({
        cancelWarranty,
        totalPrice:
          summaryState.totalPrice + +cancelWarranty.totalExchangePrice.slice(3),
        tryTotalPrice:
          summaryState.tryTotalPrice + +cancelWarranty.totalPrice.slice(3),
      });
  }, []);

  return (
    <CoreSummaryAdditionalService>
      <CoreSummaryCancelWarrantyTitle />
      <CoreSummaryAdditionalServiceItem
        price={PriceManager({
          currency: cancelWarranty.totalExchangePrice.slice(0, 3),
          value: +cancelWarranty.totalExchangePrice.slice(3),
        })}
        title={cancelWarranty.name}
        active={Boolean(summaryState.cancelWarranty)}
        showIcon={isB2C}
        buttonContent={
          summaryState.cancelWarranty ? (
            <Button
              type="button"
              variant="outline-primary"
              onClick={() => cancelWarrantyAddOrRemoved()}
            >
              <LIcon name="X" className="mr-1 w-[20px]" /> {t("Remove")}
            </Button>
          ) : (
            <Button
              type="button"
              variant="outline-primary"
              onClick={() => cancelWarrantyAddOrRemoved()}
            >
              <LIcon name="Plus" className="mr-1 w-[20px]" /> {t("Add")}
            </Button>
          )
        }
      />
    </CoreSummaryAdditionalService>
  );
};

export default HotelSummaryCancelWarranty;
