/* eslint-disable radix */

import type { IHotelTravelPlannerPayload } from "../types/hotel-travel-planner.types";

export class HotelTPHelper {
  public static roomsFromString(rooms: string) {
    if (!rooms) return [];
    const result: IHotelTravelPlannerPayload["rooms"] = [];
    const roomStrings = rooms.split("_");
    roomStrings.forEach((roomString) => {
      const [employeeCount, guestCount, childAges] = roomString.split("-");
      const childAgesArr = childAges === "" ? [] : childAges?.split(",") ?? [];
      const childAgesArray = childAgesArr.filter(
        (age) => age !== "" || age !== null,
      );
      const room = {
        employee: { count: parseInt(employeeCount ?? "0") },
        guest: { count: parseInt(guestCount ?? "0") },
        child: {
          count: childAgesArray.length,
          ages: childAgesArray.map((age) => parseInt(age)),
        },
      };
      result.push(room);
    });

    return result;
  }

  public static roomsFromStringB2C(rooms: string) {
    if (!rooms) return [];
    const result: IHotelTravelPlannerPayload["rooms"] = [];
    const roomStrings = rooms.split(",");
    roomStrings.forEach((roomString) => {
      const [guestCount, ...childAgesArr] = roomString.split("-");

      const childAgesArray = childAgesArr.filter(
        (age) => age !== "" || age !== null,
      );

      const room = {
        employee: { count: parseInt("0") },
        guest: { count: parseInt(guestCount ?? "0") },
        child: {
          count: childAgesArray.length,
          ages: childAgesArray.map((age) => parseInt(age)),
        },
      };

      result.push(room);
    });

    return result;
  }

  public static roomsToString(rooms: IHotelTravelPlannerPayload["rooms"]) {
    if (!rooms) return "";
    const result: string[] = [];
    rooms.forEach((room) => {
      const roomString = `${room.employee?.count ?? 0}-${
        room.guest?.count ?? 0
      }${
        room.child?.ages?.length && room.child?.ages?.length > 0
          ? `-${room.child?.ages?.join(",")}`
          : ""
      }`;
      const str = roomString.split("-").map((x) => {
        if (!x || x === "") return "0";

        return x;
      });
      result.push(str.join("-"));
    });

    return result.join("_");
  }

  public static roomsToStringB2C(rooms: IHotelTravelPlannerPayload["rooms"]) {
    if (!rooms) return "";
    const result: string[] = [];
    rooms.forEach((room) => {
      const roomString = `${room.guest?.count ?? 0}${
        room.child?.ages?.length && room.child?.ages?.length > 0
          ? `-${room.child?.ages?.join("-")}`
          : ""
      }`;
      const str = roomString.split("-").map((x) => {
        if (!x || x === "") return "0";

        return x;
      });
      result.push(str.join("-"));
    });

    return result.join(",");
  }
}
