import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import Counter from "@/components/ui/counter/counter";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { Tooltip } from "@/components/ui/tooltip/tooltip";

interface RentACarAdditionalCardProps {
  id: string;
  name: string;
  tooltip: string;
  info?: string;
  unitPrice: string;
  priceText: string;
  count: 0 | 1;
  onChange: (id: string, count: 0 | 1) => void;
}

export const RentACarAdditionalCard = ({
  id,
  name,
  tooltip,
  info,
  unitPrice,
  priceText,
  count,
  onChange,
}: RentACarAdditionalCardProps) => {
  return (
    <Card>
      <div className="flex w-full items-center justify-between gap-2">
        <div className="block grow items-center justify-between gap-2 md:flex">
          <p className="text-gray-800">{name}</p>
          {info && <p className="text-xs text-gray-500">{info}</p>}
          {!!tooltip && (
            <Tooltip
              position="bottom"
              label={
                <div>
                  <div>{name}</div>
                  <div>{tooltip}</div>
                </div>
              }
            >
              <LIcon
                name="Info"
                size={16}
                className="cursor-pointer text-gray-500"
              />
            </Tooltip>
          )}
          <div className="pt-2 text-xs md:pt-0">
            <span className=" text-gray-500">{priceText} / </span>
            <span className="font-semibold text-gray-800">{unitPrice}</span>
          </div>
        </div>
        <div className="flex items-center gap-2">
          <div>
            {count > 0 && (
              <Counter
                onChange={(value) => {
                  if (value < 2) {
                    onChange(id, value >= 1 ? 1 : 0);
                  }
                }}
                value={count}
                max={1}
                maxText="Bu üründen 1'den fazla seçemezsiniz."
              />
            )}
            {count === 0 && (
              <Button
                variant="outline"
                onClick={() => {
                  onChange(id, 1);
                }}
              >
                <LIcon name="Plus" size={16} className="text-blue-500" />
              </Button>
            )}
          </div>
        </div>
      </div>
    </Card>
  );
};
