import { useState } from "react";

import { Button } from "@/components/ui/button/button";
import CoreSummaryHeader from "@/features/core/summary/components/core-summary-header";
import CoreSummaryMainColumn from "@/features/core/summary/components/core-summary-main-column";
import { PriceManager } from "@/libs/price-manager/price-manager";

import { useRentACarSummaryCtx } from "../rent-a-car-summary.provider";
import { RentACarAdditionalCard } from "./rent-a-car-additional-card";

const initialExtraOptionLength = 8;

export const RentACarAdditionalServices = () => {
  const [extraOptionLength, setExtraOptionLength] = useState(
    initialExtraOptionLength,
  );
  const {
    state: { extras, insurances, data },
    setState,
  } = useRentACarSummaryCtx();

  const addOrRemoveArrayItem = (
    array: string[],
    arrayKey: "extras" | "insurances",
    id: string,
  ) => {
    if (array.includes(id)) {
      setState((prev) => ({
        ...prev,
        [arrayKey]: prev[arrayKey].filter((item) => item !== id),
      }));
    } else {
      setState((prev) => ({
        ...prev,
        [arrayKey]: [...prev[arrayKey], id],
      }));
    }
  };

  const handleShowMore = () => {
    setExtraOptionLength((prev) =>
      prev === initialExtraOptionLength
        ? data?.car?.carExtraOption?.length || 0
        : initialExtraOptionLength,
    );
  };

  return (
    <CoreSummaryMainColumn>
      <CoreSummaryHeader hideBackButton>Ek Hizmetler</CoreSummaryHeader>
      {data?.car?.carExtraOption?.slice(0, extraOptionLength).map((item) => (
        <RentACarAdditionalCard
          key={item.name}
          name={item.name}
          unitPrice={
            PriceManager({
              currency: item.unitPrice.slice(0, 3) || "TRY",
              value: +`${item.unitPrice}0`.slice(3),
            }) || "Ücretsiz"
          }
          priceText="Günlük"
          onChange={() => addOrRemoveArrayItem(extras, "extras", item.code)}
          count={extras.includes(item.code) ? 1 : 0}
          id={item.code}
          tooltip=""
        />
      ))}

      {(data?.car?.carExtraOption?.length || 0) > initialExtraOptionLength && (
        <div className="flex w-full justify-center">
          <Button
            onClick={handleShowMore}
            variant="link"
            rightIcon={{
              name:
                extraOptionLength === initialExtraOptionLength
                  ? "ChevronDown"
                  : "ChevronUp",
              size: 18,
            }}
          >
            {extraOptionLength === initialExtraOptionLength
              ? `Daha Fazla Göster (${
                  (data?.car?.carExtraOption.length || extraOptionLength) -
                  extraOptionLength
                })`
              : "Daha Az Göster"}
          </Button>
        </div>
      )}

      <CoreSummaryHeader hideBackButton>Ek Güvence Paketleri</CoreSummaryHeader>
      {data?.car?.carInsurances?.map((item) => (
        <RentACarAdditionalCard
          key={item.description}
          name={item.description}
          unitPrice={
            PriceManager({
              currency: item.unitPrice.slice(0, 3) || "TRY",
              value: +`${item.unitPrice}0`.slice(3),
            }) || "Ücretsiz"
          }
          priceText="Günlük"
          onChange={() =>
            addOrRemoveArrayItem(insurances, "insurances", item.code)
          }
          count={insurances.includes(item.code) ? 1 : 0}
          id={item.code}
          tooltip=""
        />
      ))}
    </CoreSummaryMainColumn>
  );
};
