import { useState } from "react";
import { useDebounceCallback } from "usehooks-ts";

import Form from "@/components/form/form";
import Card from "@/components/ui/card/card";
import {
  RadioGroup,
  RadioGroupItem,
} from "@/components/ui/radio-button/radio-group";
import CoreSummaryHeader from "@/features/core/summary/components/core-summary-header";
import CoreSummaryMainColumn from "@/features/core/summary/components/core-summary-main-column";
import CoreSummaryNoteFormItem from "@/features/core/summary/components/core-summary-note-form-input";
import CoreSummaryPolicyFormItem from "@/features/core/summary/components/core-summary-policy-form-item";
import { useApp } from "@/hooks/useApp";
import localStateCache from "@/libs/helpers/local-state-cache-helper";

import { useRentACarSummaryCtx } from "../rent-a-car-summary.provider";
import { RentACarGuestDriverForm } from "./rent-a-car-guest-driver-form";
import { RentACarWorkerDriverForm } from "./rent-a-car-worker-driver-form";

const RentACarInformationForms = {
  "1": {
    comp: <RentACarGuestDriverForm />,
    label: "Kurum Dışı (Misafir)",
  },
  "0": {
    comp: <RentACarWorkerDriverForm />,
    label: "Kurum Çalışanı",
  },
};

export const RentACarDriverInformation = () => {
  const {
    state: { kvkkText },
    form: { methods },
  } = useRentACarSummaryCtx();
  const { isB2E, isB2C } = useApp();
  const [activeForm, setActiveForm] = useState<"0" | "1">("0");

  const handleChange = useDebounceCallback((values: any) => {
    localStateCache.set("form", values);
  }, 500);

  return (
    <CoreSummaryMainColumn>
      <CoreSummaryHeader hideBackButton>Sürücü Bilgileri</CoreSummaryHeader>
      <Form
        methods={methods}
        onSubmit={(): unknown => {
          throw new Error("Function not implemented.");
        }}
        onChange={handleChange}
      >
        <div className="flex flex-col gap-4">
          <Card>
            <p className="text-sm font-semibold text-gray-800">
              Kişisel Bilgiler
            </p>
            <RadioGroup
              defaultValue="1"
              value={activeForm}
              className="my-4 flex gap-2"
              id="workerOrGuest"
            >
              {isB2E &&
                Object.entries(RentACarInformationForms).map(([key, value]) => (
                  <RadioGroupItem
                    key={key}
                    value={key}
                    label={value.label}
                    className="text-sm font-medium text-gray-800"
                    onClick={() => {
                      setActiveForm(key as "0" | "1");
                      methods?.reset({
                        reservationNote: methods.getValues("reservationNote"),
                        projectCode: methods.getValues("projectCode"),
                      });
                    }}
                  />
                ))}
            </RadioGroup>
            {isB2E && RentACarInformationForms[activeForm].comp}
            {isB2C && <RentACarGuestDriverForm />}
          </Card>

          {isB2E && (
            <>
              <CoreSummaryNoteFormItem
                name="reservationNote"
                placeholder="Notunuzu buraya giriniz."
                title="Talebi onaylayacak kişiye bir notunuz var mı?"
                open
              />
              <CoreSummaryNoteFormItem
                name="projectCode"
                placeholder="Notunuzu buraya giriniz."
                title="Fatura Notu"
                open
              />
            </>
          )}
          {isB2C && (
            <CoreSummaryNoteFormItem
              name="reservationNote"
              placeholder="Talebinizi buraya giriniz."
              title="Özel bir talebiniz var mı?"
              open={methods?.getValues("reservationNote") !== ""}
            />
          )}

          <CoreSummaryPolicyFormItem kvkkAgreementText={kvkkText} />
        </div>
      </Form>
    </CoreSummaryMainColumn>
  );
};
