import { useEffect, useRef } from "react";

import FormTextAreaInput from "@/components/form/components/basic/form-textarea-input";
import type { FormCitiesHandles } from "@/components/form/components/related/form-cities-select";
import FormCitiesSelect, {
  useFormCitiesSelect,
} from "@/components/form/components/related/form-cities-select";
import FormCountrySelect from "@/components/form/components/related/form-country-select";
import FormEmailInput from "@/components/form/components/related/form-email-input";
import FormPhoneInput from "@/components/form/components/related/form-phone-input";
import CustomerInfoFormItems from "@/features/customer/customer-info/customer-info-form/customer-info-form";
import { useLocale } from "@/hooks/useLocale";

import {
  rentACarDriverPrefix,
  rentACarFormNameGenerator,
  useRentACarSummaryCtx,
} from "../rent-a-car-summary.provider";

export const RentACarGuestDriverForm = () => {
  const citiesRef = useRef<FormCitiesHandles>(null);
  const { t } = useLocale();
  const {
    form: { methods },
  } = useRentACarSummaryCtx();
  const { getCitiesData, initFormCitiesSelect } = useFormCitiesSelect(
    citiesRef,
    rentACarDriverPrefix,
  );

  useEffect(() => {
    initFormCitiesSelect();
  }, [initFormCitiesSelect]);

  useEffect(() => {
    return () => {
      methods?.unregister("CustomerSelect");
    };
  }, [methods]);

  return (
    <>
      <CustomerInfoFormItems
        customerPrefix={rentACarDriverPrefix}
        noContactInfo
      />
      <div className="my-4">
        <p className="text-sm font-semibold leading-8 text-gray-800">
          İletişim ve Fatura Bilgileri
        </p>
        <p className="pb-4 text-sm text-gray-500">
          {t(
            "We will forward your reservation information via e-mail and free SMS.",
          )}
        </p>
      </div>
      <div className="grid grid-cols-1 gap-3 md:grid-cols-2">
        <div className="col-span-2 md:col-span-1">
          <FormPhoneInput
            fullWidth
            name={rentACarFormNameGenerator("phone")}
            size="lg"
            label="Telefon Numarası*"
            rules={{
              required: {
                value: true,
                message: "Bu alanın doldurulması zorunludur!",
              },
              validate: (value) => {
                if (!value || value?.phoneNumber === "")
                  return "Bu alanın doldurulması zorunludur!";

                return true;
              },
            }}
          />
        </div>
        <div className="col-span-2 md:col-span-1">
          <FormEmailInput
            fullWidth
            name={rentACarFormNameGenerator("email")}
            size="lg"
            label="E-posta*"
            rules={{
              required: true,
            }}
          />
        </div>

        <FormCountrySelect
          name={rentACarFormNameGenerator("country")}
          rules={{
            required: true,
          }}
          onChange={(countriesId) => getCitiesData(countriesId)}
          placeholder="Ülke"
        />

        <FormCitiesSelect
          ref={citiesRef}
          name={rentACarFormNameGenerator("city")}
          placeholder="Şehir*"
          rules={{
            required: true,
          }}
        />
        <div className="col-span-2">
          <FormTextAreaInput
            name={rentACarFormNameGenerator("address")}
            placeholder="Adres (Opsiyonel)"
          />
        </div>
      </div>
    </>
  );
};
