/* eslint-disable react-hooks/exhaustive-deps */
import React, { useEffect, useRef } from "react";

import type { FormHandles } from "@/components/form/form";
import Form from "@/components/form/form";
import CoreSummaryHeader from "@/features/core/summary/components/core-summary-header";
import CoreSummaryMainColumn from "@/features/core/summary/components/core-summary-main-column";
import PaymentList from "@/features/modules/payment/payment-list";

import { usePayment } from "../../payment/hooks/use-rent-a-car-payment";
import { useRentACarSummaryCtx } from "../rent-a-car-summary.provider";

export interface RentACarPaymentListHandles extends FormHandles {}

const RentACarPaymentList = () => {
  const {
    state: { searchId, cartId },
    setState,
  } = useRentACarSummaryCtx();
  const rentACarPaymentRef = useRef<RentACarPaymentListHandles>(null);
  const paymentFormRef = useRef<RentACarPaymentListHandles>(null);
  const { paymentState } = usePayment();

  useEffect(() => {
    if (rentACarPaymentRef?.current?.submit) {
      setState((prev) => ({
        ...prev,
        paymentSubmit: () => paymentFormRef.current?.submit(),
      }));
    }
  }, []);

  return (
    <div>
      <CoreSummaryHeader hideBackButton>Ödeme Bilgileri</CoreSummaryHeader>
      <CoreSummaryMainColumn>
        <Form
          ref={paymentFormRef}
          onSubmit={() => rentACarPaymentRef.current?.submit()}
          shouldAutoScroll
        >
          <div className="mt-4">
            <PaymentList
              ref={rentACarPaymentRef}
              cartId={cartId || ""}
              searchId={searchId || ""}
              transactionId={paymentState.payload.transactionId!}
            />
          </div>
        </Form>
      </CoreSummaryMainColumn>
    </div>
  );
};

export default RentACarPaymentList;
