/* eslint-disable no-nested-ternary */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import { useRouter } from "next/navigation";
import { useEffect } from "react";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import CoreSummarySideColumn from "@/features/core/summary/components/core-summary-side-column";
import { useApp } from "@/hooks/useApp";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { getManagerHelper } from "@/libs/storage-manager/get-manager-helper";
import { CarType } from "@/services/eva-display/rent-a-car/rent-a-car.enums";
import { useRentACarAddToCart } from "@/services/eva-display/rent-a-car/rent-a-car-add-to-cart/rent-a-car-add-to-cart-service";
import type {
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";
import type { CarRentalCreateRequestRequest } from "@/services/eva-display/rent-a-car/rent-a-car-request-create/rent-a-car-request-create.types";
import { useRentACarRequestCreate } from "@/services/eva-display/rent-a-car/rent-a-car-request-create/rent-a-car-request-create-service";
import { useRentACarValidateMutation } from "@/services/eva-display/rent-a-car/rent-a-car-validate/rent-a-car-validate-service";
import type { CarRentalValidateBookingRequest } from "@/services/eva-display/rent-a-car/rent-a-car-validate/rent-a-car-validate-service.types";
import { useUserInformationsMutation } from "@/services/eva-display/user/user-information.service";
import { useUserDepartmentQuery } from "@/services/eva-display/user-department/user-department.service";
import { useMasterpassStore } from "@/store/masterpass-store/use-masterpass-store";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

import { usePayment } from "../../payment/hooks/use-rent-a-car-payment";
import { useRentACarSummary } from "../hook/use-rent-a-car-summary";
import {
  rentACarDriverPrefix,
  useRentACarSummaryCtx,
} from "../rent-a-car-summary.provider";
import {
  serializeGuestToDriver,
  serializeGuestToDriverForB2C,
} from "../rent-a-car-summary.serializer";

export const RentACarSummaryTotalCard = () => {
  const { isB2E } = useApp();
  const router = useRouter();
  const {
    state: {
      data,
      activeStep,
      searchId,
      cartId,
      requesterId,
      requesterDepartments,
      travelReasonId,
      branchOfficeId,
      paymentSubmit,
    },
    setState,
    form: { methods },
  } = useRentACarSummaryCtx();
  const { setNotify } = useNotifyStore();
  const { mutateAsync: addToCardMutate, isLoading: addToCardLoading } =
    useRentACarAddToCart();
  const {
    mutateAsync: requestCreateMutate,
    isLoading: requestCreateIsLoading,
  } = useRentACarRequestCreate();
  const validateMutation = useRentACarValidateMutation();
  const { data: userList, isSuccess } = useUserDepartmentQuery();
  const { mutateAsync: userInformationMutation } =
    useUserInformationsMutation();
  const { setBookingData } = usePayment();
  const { setMasterpassData } = useMasterpassStore();
  const { get } = getManagerHelper("core-travel-planner");
  const { data: summaryData } = useRentACarSummary();

  const selectedOptions = [
    ...(data?.car?.carExtraOption?.filter((item) => item.selected) || []),
    ...(data?.car?.carInsurances?.filter((item) => item.selected) || []),
  ];

  const oneWayPrice = PriceManager({
    currency: data?.car.oneWay.slice(0, 3) || "TRY",
    value: +`${data?.car.oneWay}0`.slice(3),
  });

  const locationFee = PriceManager({
    currency: data?.car.locationFee.slice(0, 3) || "TRY",
    value: +`${data?.car.locationFee}0`.slice(3),
  });

  const getTotalDay = () => {
    const totalHours = dayjs(data?.car.carDetail.returnDate).diff(
      dayjs(data?.car.carDetail.pickupDate),
      "minute",
    );

    return Math.ceil(totalHours / 24 / 60);
  };
  const totalDay = getTotalDay();

  const subTotal =
    selectedOptions.reduce((acc, item) => {
      return acc + +`${item.totalPrice}0`.slice(3);
    }, 0) +
    +`${data?.car.oneWay}0`.slice(3) +
    +`${data?.car.locationFee}0`.slice(3);

  // const intlSubTotal = new Intl.NumberFormat("ne-NE", {
  //   currency: "EUR",
  // }).format(subTotal);

  // const allTotal = new Intl.NumberFormat("ne-NE", {
  //   currency: "EUR",
  // }).format(+`${data?.car.totalPrice}0`.slice(3) + subTotal);

  const intlSubTotal = PriceManager({
    currency: data?.car.oneWay.slice(0, 3) || "TRY",
    value: subTotal,
  });

  const allTotal = PriceManager({
    currency: data?.car?.totalPrice.slice(0, 3) || "TRY",
    value: +`${data?.car?.totalPrice}0`.slice(3) + subTotal,
  });

  const handleClick = async () => {
    if (activeStep === 1) {
      addToCardMutate({
        searchId: searchId || "",
        productKey: data?.car.key || "",
        cardId: null,
      })
        .then((e) => {
          try {
            if (e?.cartId) {
              setState((prev) => ({
                ...prev,
                activeStep: 2,
                kvkkText: e.kvkkAgreementText,
                cartId: e.cartId,
              }));
            } else {
              throw new Error();
            }
          } catch (_) {
            throw new Error();
          }
        })
        .catch(() => {
          setNotify({
            message:
              "Sepete eklenirken bir hata oluştu. Lütfen tekrar deneyin.",
            title: "Hata",
            variant: "error",
          });
        });
    }

    if (activeStep === 2 && isB2E) {
      methods?.handleSubmit((formData) => {
        let requestData: CarRentalCreateRequestRequest = {} as any;

        requestData = serializeGuestToDriver(
          searchId || "",
          data?.car.key || "",
          cartId || "", // cartId
          formData,
          requesterId || [],
          requesterDepartments || [],
          Number(travelReasonId || ""),
          branchOfficeId ? Number(branchOfficeId) : undefined,
        );

        requestCreateMutate(requestData)
          .then((e) => {
            if (!e?.errors && e?.success === true)
              router.push(
                `/booking-request-success?bookingId=${e.result.requestId}`,
              );
            else
              throw new Error(
                e?.errors?.[0]?.message ||
                  "Bir hata oluştu. Lütfen tekrar deneyin.",
              );
          })
          .catch((e) => {
            setNotify({
              message: e?.message,
              title: "Hata",
              variant: "error",
            });
          });
      })();
    } else if (activeStep === 2 && !isB2E) {
      methods?.handleSubmit(async (formData) => {
        let requestData: CarRentalValidateBookingRequest = {} as any;

        requestData = serializeGuestToDriverForB2C(
          searchId || "",
          cartId || "",
          formData,
        );

        const bookingPassengersWithKeys = requestData.BookingPassengers.map(
          (psg, index) => ({
            ...psg,
            Key: summaryData?.payload?.passengersKeys?.[index]?.key ?? "",
          }),
        );

        requestData.BookingPassengers = bookingPassengersWithKeys;

        try {
          const resp = await validateMutation.mutateAsync({
            CarRentalValidateBookingRequest: {
              CartId: requestData.CartId,
              ReservationNotes: requestData.ReservationNotes || "",
              AddOnsKeyList: requestData.AddOnsKeyList,
              CancelWarrantySearchId: requestData.CancelWarrantySearchId,
              SearchId: requestData.SearchId,
              KvkkApproval: requestData.KvkkApproval,
              BookingPassengers: requestData.BookingPassengers,
              BillingRequest: requestData.BillingRequest,
            },
          });

          setBookingData({
            cartId: cartId || "",
            searchId: searchId || "",
            transactionId:
              resp.data.result.serviceResponse.result.transactionKey,
            preSaleAgreementText:
              resp.data.result.serviceResponse.result.preSaleAgreementText,
            saleAgreementText:
              resp.data.result.serviceResponse.result.saleAgreementText,
          });

          if (resp.data.result.serviceResponse.result.masterPassUserData) {
            setMasterpassData({
              moduleName: "RentACar",
              payload: {
                masterpassLoginState: false,
                masterpassOtherUser: false,
                cardList: [],
                masterpassUserData:
                  resp.data.result.serviceResponse.result.masterPassUserData,
                customerEmail: requestData.BookingPassengers[0]?.Email,
                masterPassengerName:
                  requestData.BookingPassengers[0]!.Name +
                  requestData.BookingPassengers[0]!.Surname,
              },
            });
          }

          setState((prev) => ({
            ...prev,
            activeStep: 3,
          }));
        } catch (error) {
          setNotify({
            title: "Bir Hata Oluştu!",
            message: "Bir hata oluştu",
            variant: "error",
          });
        }
      })();
    }

    if (activeStep === 3) {
      paymentSubmit();
    }
  };

  // add hide values to form
  useEffect(() => {
    if (isSuccess) {
      const tpData = get("core-travel-planner").payload;
      const requesterUser = userList?.filter(
        (item) => item.value === tpData.employees?.[0]?.value,
      )[0];
      if (isB2E) {
        userInformationMutation({
          userIds: [Number(requesterUser?.value)],
        }).then((e) => {
          if (e?.[0]?.userGuidId) {
            setState((prev) => ({
              ...prev,
              requesterId: [e?.[0]?.userGuidId || ""],
              requesterDepartments:
                requesterUser?.properties.departments?.map((item) => item.id) ||
                [],
              travelReasonId: tpData?.reason?.value,
              branchOfficeId: tpData?.branchOffice?.value,
            }));
            methods?.setValue(
              `${rentACarDriverPrefix}-identity`,
              e?.[0]?.passaportDetail?.citizenNo || "",
            );
            methods?.setValue(
              `${rentACarDriverPrefix}-name`,
              e?.[0].userDetail.firstName || "",
            );
            methods?.setValue(
              `${rentACarDriverPrefix}-surname`,
              e?.[0].userDetail.lastName || "",
            );
            methods?.setValue(
              `${rentACarDriverPrefix}-country`,
              e?.[0]?.passaportDetail?.nationality,
            );
          }
        });
      }
    }
  }, [
    get,
    methods,
    userList,
    isSuccess,
    userInformationMutation,
    setState,
    isB2E,
  ]);

  return (
    <CoreSummarySideColumn
      price={PriceManager({
        currency: data?.car.totalPrice.slice(0, 3) || "TRY",
        value: +`${data?.car.totalPrice}0`.slice(3),
      })}
      button={
        <Button
          variant="primary"
          onClick={handleClick}
          loading={
            addToCardLoading ||
            requestCreateIsLoading ||
            validateMutation.isLoading
          }
        >
          {activeStep === 1
            ? "Devam Et"
            : activeStep === 2 && isB2E
              ? "Talep Oluştur"
              : activeStep === 2 && !isB2E
                ? "Rezervasyonu tamamla"
                : activeStep === 3
                  ? "Ödeme Yap"
                  : ""}
        </Button>
      }
    >
      <Card className="mt-24">
        <div className="flex justify-between text-base font-semibold">
          <p>Rezervasyon Özeti</p>
        </div>
        <div className="mt-4 flex items-center gap-2">
          <div className="h-14 w-24 ">
            <img
              src={data?.car.carDetail.imageUrl}
              alt={data?.car.carDetail.name}
              className="size-full object-contain"
            />
          </div>
          <div>
            <p className="font-semibold text-gray-800">
              {CarType[data?.car.carDetail.type || 0]}
            </p>
            <p className="text-xs text-gray-500">{data?.car.carDetail.name}</p>
          </div>
        </div>
        <hr className="my-4" />
        <div>
          <div className="flex items-center justify-between">
            <span className="text-sm font-semibold">Alış Noktası</span>
            <span className="text-xs">
              {dayjs(data?.car.carDetail.pickupDate).format(
                "DD MMM YYYY, HH:mm",
              )}
            </span>
          </div>
          <div className="my-2 flex items-center gap-1 text-sm text-gray-800">
            <LIcon name="MapPin" size={14} />
            <span>{data?.car.carDetail.pickupCode}</span>
          </div>
        </div>
        <div>
          <div className="flex items-center justify-between">
            <span className="text-sm font-semibold">Teslim Noktası</span>
            <span className="text-xs">
              {dayjs(data?.car.carDetail.returnDate).format(
                "DD MMM YYYY, HH:mm",
              )}
            </span>
          </div>
          <div className="my-2 flex items-center gap-1 text-sm text-gray-800">
            <LIcon name="MapPin" size={14} />
            <span>{data?.car.carDetail.returnCode}</span>
          </div>
        </div>
        {selectedOptions.length > 0 && (
          <>
            <hr className="my-4" />
            <div>
              <span className="text-sm font-semibold">
                Ek Hizmetler ve Güvence Paketi
              </span>
              {selectedOptions.map((item) => (
                <div
                  key={item.code}
                  className="flex items-center justify-between text-sm text-gray-800"
                >
                  <span>
                    {(item as CarInsurance).description ||
                      (item as CarExtraOption).name}
                  </span>
                  <span className="min-w-[75px] text-right">
                    {PriceManager({
                      currency: item.totalPrice.slice(0, 3) || "TRY",
                      value: +`${item.totalPrice}0`.slice(3),
                    })}
                  </span>
                </div>
              ))}
            </div>
          </>
        )}
      </Card>
      <Card className="my-4">
        <div className="mb-4 flex justify-between text-base font-semibold">
          <p>Tutar Bilgisi</p>
        </div>
        {(subTotal > 0 || oneWayPrice || locationFee) && (
          <>
            <div className="rounded bg-blue-50 p-4">
              <p className="text-xs">
                Ofiste ödenecek tutarı, aracınızı teslim alırken hizmeti
                sağlayan firmaya ödeyeceksiniz.
              </p>
            </div>
            <div>
              <div className="my-2 text-sm font-semibold">
                Ofiste Ödenecek Tutar
              </div>
              {selectedOptions.length > 0 &&
                selectedOptions.map((item) => (
                  <div
                    key={item.code}
                    className="my-1 flex items-center justify-between gap-1 text-sm text-gray-800"
                  >
                    <span>
                      {(item as CarInsurance).description ||
                        (item as CarExtraOption).name}
                      &nbsp;
                      <span className="text-xs text-gray-500">
                        ({totalDay} gün&nbsp;x&nbsp;
                        {PriceManager({
                          currency: item.unitPrice.slice(0, 3) || "TRY",
                          value: +`${item.unitPrice}0`.slice(3),
                        })}
                        )
                      </span>
                    </span>
                    <span className="min-w-[75px] text-right">
                      {PriceManager({
                        currency: item.totalPrice.slice(0, 3) || "TRY",
                        value: +`${item.totalPrice}0`.slice(3),
                      })}
                    </span>
                  </div>
                ))}

              {oneWayPrice && (
                <div className="my-1 flex items-center justify-between text-sm text-gray-800">
                  <span>Tek Yön Ücreti</span>
                  <span>{oneWayPrice}</span>
                </div>
              )}
              {locationFee && (
                <div className="my-1 flex items-center justify-between text-sm text-gray-800">
                  <span>Ofis Hizmet Ücreti</span>
                  <span>{locationFee}</span>
                </div>
              )}
              <div className="my-4 flex items-center justify-between text-sm font-semibold text-gray-800 ">
                <span>Ara Toplam</span>
                <span>{intlSubTotal} TL</span>
              </div>
            </div>
          </>
        )}
        <div className="my-2 text-sm font-semibold">Şimdi Ödenecek Tutar</div>
        <div className="my-1 flex items-center justify-between text-sm text-gray-800">
          <span>
            Araç Kiralama{" "}
            <span className="text-xs text-gray-500">
              ({totalDay} gün x{" "}
              {PriceManager({
                currency: data?.car.basePrice.slice(0, 3) || "TRY",
                value: +`${data?.car.basePrice}0`.slice(3),
              })}
              )
            </span>
          </span>
          <span>
            {PriceManager({
              currency: data?.car.totalPrice.slice(0, 3) || "TRY",
              value: +`${data?.car.totalPrice}0`.slice(3),
            })}
          </span>
        </div>
        <hr className="my-4" />
        <div className="flex justify-between text-sm font-semibold">
          <span>Toplam Tutar</span>
          <span>{allTotal} TL</span>
        </div>
        <Button
          variant="primary"
          className="mt-4 w-full"
          onClick={handleClick}
          loading={
            addToCardLoading ||
            requestCreateIsLoading ||
            validateMutation.isLoading
          }
        >
          {activeStep === 1
            ? "Devam Et"
            : activeStep === 2 && isB2E
              ? "Talep Oluştur"
              : activeStep === 2 && !isB2E
                ? "Rezervasyonu tamamla"
                : activeStep === 3
                  ? "Ödeme Yap"
                  : ""}
        </Button>
      </Card>
    </CoreSummarySideColumn>
  );
};
