"use client";

import type { Dispatch, PropsWithChildren } from "react";
import React, { createContext, useContext, useMemo, useState } from "react";
import type { UseFormReturn } from "react-hook-form";
import { useForm } from "react-hook-form";

import type { IUserItem } from "@/components/widget/travel-planner/components/user-select/user-select";
import { useLocalStateCache } from "@/libs/helpers/local-state-cache-helper";
import type { IRentACarDetailResponse } from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

export const rentACarDriverPrefix = "group_key_0-rentACarDriver-guest"; // This format prepared according to base summary form sturucture. You can check that at src/features/core/summary/components/core-summary-form.tsx

export interface IDriverInformation {
  "group_key_0-rentACarDriver-guest-id": number;
  "group_key_0-rentACarDriver-guest-name": string;
  "group_key_0-rentACarDriver-guest-surname": string;
  "group_key_0-rentACarDriver-guest-email": string;
  "group_key_0-rentACarDriver-guest-phone": {
    dialCode: string;
    phoneNumber: string;
    areaCode: string;
  };
  "group_key_0-rentACarDriver-guest-gender": "0" | "1";
  "group_key_0-rentACarDriver-guest-identity": string;
  "group_key_0-rentACarDriver-guest-identityCheck": boolean | undefined;
  "group_key_0-rentACarDriver-guest-birthDate": string;
  kvkk: boolean | undefined;
  "group_key_0-rentACarDriver-guest-address": string;
  "group_key_0-rentACarDriver-guest-city": string;
  "group_key_0-rentACarDriver-guest-country": {
    id: number;
    name: string;
  };
  reservationNote: string;
  projectCode: string;
  "group_key_0-rentACarDriver-guest-departments": number[];
  specialNote?: string;
  CustomerSelect: IUserItem[] | undefined;
}

export const rentACarFormNameGenerator = (name: string) =>
  `${rentACarDriverPrefix}-${name}` as keyof IDriverInformation;

type StateType = {
  extras: string[];
  insurances: string[];
  data: IRentACarDetailResponse | undefined;
  searchId?: string;
  cartId?: string;
  isLoading?: boolean;
  kvkkText: string;
  activeStep: 1 | 2 | 3;
  travelReasonId?: string;
  branchOfficeId?: string;
  requesterId?: string[];
  requesterDepartments?: number[];
  citizenNo: string;
  paymentSubmit: () => void;
};

interface RentACarSummaryCtxProps {
  steps: {
    stepList: { label: string }[];
  };
  state: StateType;
  setState: Dispatch<React.SetStateAction<StateType>>;
  form: {
    methods?: UseFormReturn<IDriverInformation, any, undefined>;
  };
}

const stepList = [
  {
    label: "Araç Seçimi",
  },
  {
    label: "Ekstralar",
  },
  {
    label: "Sürücü Bilgileri",
  },
];

const initialState: StateType = {
  extras: [],
  insurances: [],
  data: undefined,
  searchId: undefined,
  cartId: undefined,
  kvkkText: "",
  isLoading: true,
  activeStep: 1,
  travelReasonId: "",
  branchOfficeId: "",
  requesterId: [],
  requesterDepartments: [],
  citizenNo: "",
  paymentSubmit: () => {},
};

const initinalSteps = {
  stepList,
};

const initialCtxValue: RentACarSummaryCtxProps = {
  steps: initinalSteps,
  state: initialState,
  setState: () => {},
  form: {},
};

const defaultValues: Partial<IDriverInformation> = {
  "group_key_0-rentACarDriver-guest-id": 0,
  "group_key_0-rentACarDriver-guest-gender": "0",
};

export const RentACarSummaryCtx =
  createContext<RentACarSummaryCtxProps>(initialCtxValue);

const RentACarSummaryCtxProvider = (props: PropsWithChildren) => {
  const [state, setState] = useState<StateType>(initialState);
  const { getLocalStateCacheValues } = useLocalStateCache(
    "rentACarFormFields",
    [
      [
        {
          type: "guest",
          label: "Yetişkin",
          key: "rentACarDriver",
        },
      ],
    ],
  );

  const cachedDefaultValues = getLocalStateCacheValues();

  const methods = useForm<IDriverInformation>({
    defaultValues: cachedDefaultValues ?? defaultValues,
  });

  const memoCtxValue = useMemo(
    () => ({
      ...initialCtxValue,
      form: {
        methods,
      },
      state,
      setState,
    }),
    [methods, state],
  );

  return <RentACarSummaryCtx.Provider value={memoCtxValue} {...props} />;
};

export const useRentACarSummaryCtx = () => {
  return useContext(RentACarSummaryCtx);
};

export default RentACarSummaryCtxProvider;
