import dayjs from "dayjs";

import type {
  CarRentalCreateRequestRequest,
  PhoneNumber,
} from "@/services/eva-display/rent-a-car/rent-a-car-request-create/rent-a-car-request-create.types";
import type { CarRentalValidateBookingRequest } from "@/services/eva-display/rent-a-car/rent-a-car-validate/rent-a-car-validate-service.types";

import {
  type IDriverInformation,
  rentACarDriverPrefix,
} from "./rent-a-car-summary.provider";

export function serializeGuestToDriver(
  SearchId: string,
  ProductKey: string,
  CartId: string,
  guest: IDriverInformation,
  RequesterUserIds: string[],
  RequestDepartmentIds: number[],
  TravelReasonId: number,
  BranchId?: number,
): CarRentalCreateRequestRequest {
  let birthDate = "";

  if (
    guest[`${rentACarDriverPrefix}-birthDate`].includes("T") ||
    guest[`${rentACarDriverPrefix}-birthDate`].includes("Z")
  ) {
    birthDate = guest[`${rentACarDriverPrefix}-birthDate`];
  } else {
    const customParseFormat = require("dayjs/plugin/customParseFormat");
    dayjs.extend(customParseFormat);
    const serializedDate = dayjs(
      guest[`${rentACarDriverPrefix}-birthDate`],
      "DD-MM-YYYY",
    );
    birthDate = `${serializedDate.format("YYYY-MM-DDTHH:mm:ss")}Z`;
  }
  const PhoneNumbers: PhoneNumber[] = [];

  if (!guest[`${rentACarDriverPrefix}-id`]) {
    PhoneNumbers.push({
      CountryCode: Number(guest[`${rentACarDriverPrefix}-phone`].dialCode),
      AreaCode: guest[`${rentACarDriverPrefix}-phone`].phoneNumber?.slice(0, 3),
      Number: guest[`${rentACarDriverPrefix}-phone`].phoneNumber?.slice(
        3,
        guest[`${rentACarDriverPrefix}-phone`].phoneNumber.length,
      ),
      Type: 3,
    });
  } else {
    PhoneNumbers.push({
      CountryCode: Number(guest[`${rentACarDriverPrefix}-phone`].dialCode),
      AreaCode: guest[`${rentACarDriverPrefix}-phone`].areaCode,
      Number: guest[`${rentACarDriverPrefix}-phone`].phoneNumber,
      Type: 3,
    });
  }

  return {
    SearchId,
    CartId,
    SearchProductKey: ProductKey,
    DetailProductKey: ProductKey,
    RequestId: null,
    TravelReasonId,
    BranchId,
    LinkId: "",
    KvkkStatus: guest.kvkk || false,
    RequesterUserIds,
    RequestDepartmentIds,
    PassengerInformations: [
      {
        Id: guest[`${rentACarDriverPrefix}-id`],
        IsMaster: true,
        Address: {
          AddressName: guest[`${rentACarDriverPrefix}-address`],
          City: guest[`${rentACarDriverPrefix}-city`],
          Country: {
            Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
            Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
            ParentId: null,
            ParentRegion: null,
          },
          PostalCode: "",
          Street: "",
        },
        Email: guest[`${rentACarDriverPrefix}-email`],
        Prefix: "",
        Suffix: "",
        PhoneNumbers,
        Country: {
          Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
          Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
          ParentId: null,
          ParentRegion: null,
        },
        LoyaltyCode: "",
        TcKimlikNo: guest[`${rentACarDriverPrefix}-identity`],
        SpecialServiceRequests: [],
        ZipCode: "",
        SecretCustomer: null,
        PassportTypeId: 0,
        MernisQueryStatus: 0,
        Key: "",
        Name: guest[`${rentACarDriverPrefix}-name`],
        Surname: guest[`${rentACarDriverPrefix}-surname`],
        Age: 0,
        PassengerType: 0,
        Birthday: birthDate,
        Gender: Number(
          guest?.[`${rentACarDriverPrefix}-gender`]
            ? guest[`${rentACarDriverPrefix}-gender`]
            : "0",
        ),
        CrmCode: "",
        HesCode: "",
        PassportNumber: "",
      },
    ],
    ProjectCode: guest.projectCode,
    ReservationNote: guest.reservationNote,
    CancelWarrantySearchId: null,
  };
}

export function serializeGuestToDriverForB2C(
  SearchId: string,
  CartId: string,
  guest: IDriverInformation,
): CarRentalValidateBookingRequest {
  let birthDate = "";

  if (
    guest[`${rentACarDriverPrefix}-birthDate`].includes("T") ||
    guest[`${rentACarDriverPrefix}-birthDate`].includes("Z")
  ) {
    birthDate = guest[`${rentACarDriverPrefix}-birthDate`];
  } else {
    const customParseFormat = require("dayjs/plugin/customParseFormat");
    dayjs.extend(customParseFormat);
    const serializedDate = dayjs(
      guest[`${rentACarDriverPrefix}-birthDate`],
      "DD-MM-YYYY",
    );
    birthDate = `${serializedDate.format("YYYY-MM-DDTHH:mm:ss")}Z`;
  }
  return {
    CartId,
    ReservationNotes: guest.reservationNote,
    AddOnsKeyList: [],
    CancelWarrantySearchId: "",
    SearchId,
    KvkkApproval: guest.kvkk || false,
    BookingPassengers: [
      {
        Id: guest[`${rentACarDriverPrefix}-id`],
        IsMaster: true,
        Address: {
          AddressName: guest[`${rentACarDriverPrefix}-address`],
          Street: "",
          City: guest[`${rentACarDriverPrefix}-city`],
          Country: {
            Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
            ParentId: null,
            ParentRegion: null,
            Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
          },
          PostalCode: "",
        },
        Email: guest[`${rentACarDriverPrefix}-email`],
        Prefix: "",
        Suffix: "",
        PhoneNumbers: [
          {
            CountryCode: Number(
              guest[`${rentACarDriverPrefix}-phone`].dialCode,
            ),
            AreaCode: guest[`${rentACarDriverPrefix}-phone`].phoneNumber.slice(
              0,
              3,
            ),
            Number: guest[`${rentACarDriverPrefix}-phone`].phoneNumber.slice(3),
            Type: 3,
          },
        ] as any,
        Country: {
          Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
          ParentId: null,
          ParentRegion: null,
          Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
        },
        LoyaltyCode: "",
        TcKimlikNo: guest[`${rentACarDriverPrefix}-identity`],
        SpecialServiceRequests: [],
        ZipCode: "",
        SecretCustomer: null,
        PassportTypeId: 0,
        MernisQueryStatus: 0,
        Key: "",
        Name: guest[`${rentACarDriverPrefix}-name`],
        Surname: guest[`${rentACarDriverPrefix}-surname`],
        Age: 0,
        PassengerType: 0,
        Birthday: birthDate,
        Gender: Number(
          guest?.[`${rentACarDriverPrefix}-gender`]
            ? guest[`${rentACarDriverPrefix}-gender`]
            : "0",
        ),
        CrmCode: "",
        HesCode: "",
        MilesCode: "",
        PassportNumber: "",
      },
    ],
    BillingRequest: {
      IsInvoiceInformationDifferent: false,
      Type: 0,
      InvoiceAccountCode: null,
      InvoiceFirstName: guest[`${rentACarDriverPrefix}-name`],
      InvoiceLastName: guest[`${rentACarDriverPrefix}-surname`],
      Gender: Number(
        guest?.[`${rentACarDriverPrefix}-gender`]
          ? guest[`${rentACarDriverPrefix}-gender`]
          : "0",
      ),
      InvoiceTitle: "",
      InvoiceTaxOffice: "",
      InvoiceIdentityNumber: guest[`${rentACarDriverPrefix}-identity`],
      InvoiceEmail: guest[`${rentACarDriverPrefix}-email`],
      InvoicePhone: guest[`${rentACarDriverPrefix}-phone`].phoneNumber,
      InvoiceAddress: {
        AddressName: guest[`${rentACarDriverPrefix}-address`],
        Street: "",
        City: guest[`${rentACarDriverPrefix}-city`],
        Country: {
          Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
          Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
          ParentId: null,
          ParentRegion: null,
        },
        PostalCode: "",
      },
      InvoiceCountry: {
        Id: guest[`${rentACarDriverPrefix}-country`]?.id || 0,
        ParentId: null,
        ParentRegion: null,
        Label: guest[`${rentACarDriverPrefix}-country`]?.name || "",
      },
    } as any,
  };
}
