/* eslint-disable react-hooks/exhaustive-deps */

"use client";

import React, { useCallback, useEffect } from "react";

import Container from "@/components/shared/container";
import { CoreSummaryContent } from "@/features/core/summary/components/core-summary";
import CoreSummarySkeleton from "@/features/core/summary/components/core-summary-skeleton";
import CoreSummarySteps from "@/features/core/summary/components/core-summary-steps";
import { CoreSummaryCtxProvider } from "@/features/core/summary/context/core-summary-context";
import { useApp } from "@/hooks/useApp";
import { ILoaderKeys } from "@/models/loader.model";
import type { CarRentalDetailRequest } from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";
import { useRentACarDetail } from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail-service";
import { useLoaderStore } from "@/store/loader-store/use-loader-store";

import { RentACarAdditionalServices } from "./components/rent-a-car-additional-services";
import { RentACarDriverInformation } from "./components/rent-a-car-driver-information";
import RentACarPaymentList from "./components/rent-a-car-payment-list";
import { RentACarSummaryTotalCard } from "./components/rent-a-car-summary-total-card";
import { useRentACarSummary } from "./hook/use-rent-a-car-summary";
import RentACarSummaryCtxProvider, {
  useRentACarSummaryCtx,
} from "./rent-a-car-summary.provider";

const RentACarSummaryStepScreens = {
  1: <RentACarAdditionalServices />,
  2: <RentACarDriverInformation />,
  3: <RentACarPaymentList />,
};

const RentACarSummaryContent = () => {
  const {
    steps: { stepList },
    setState,
    state: { extras, insurances, activeStep },
  } = useRentACarSummaryCtx();
  const { isB2C } = useApp();

  const { mutateAsync, isLoading } = useRentACarDetail();
  const { data: summaryData, isReady: summaryIsReady } = useRentACarSummary();

  const { removeLoader } = useLoaderStore();

  const getData = useCallback(() => {
    const payload: CarRentalDetailRequest = {
      searchId: summaryData?.payload.searchId,
      ProductKey: summaryData?.payload.detailKey || "",
      ExtraOptions: extras,
      InsuranceOptions: insurances,
    };
    if (!payload?.searchId || !payload?.ProductKey) {
      window.open("/rentcar", "_self");
    }

    setState((prev) => ({
      ...prev,
      isLoading: true,
      searchId: summaryData?.payload.searchId,
    }));

    mutateAsync(payload).then((e) => {
      if (!e?.car) {
        window.open("/rentcar", "_self");
      }
      setState((prev) => ({
        ...prev,
        data: e,
      }));
    });
  }, [
    summaryData?.payload?.searchId,
    summaryData?.payload?.detailKey,
    extras,
    insurances,
    mutateAsync,
    setState,
  ]);

  useEffect(() => {
    if (summaryIsReady) {
      getData();
    }

    setTimeout(() => {
      removeLoader(ILoaderKeys.SummaryLoaderKey);
    }, 250);
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [getData, summaryData, summaryIsReady, extras, insurances]);

  return (
    <>
      {isLoading && <CoreSummarySkeleton />}
      {!isLoading && (
        <CoreSummaryCtxProvider>
          <CoreSummarySteps
            activeIndex={activeStep}
            steps={isB2C ? [...stepList, { label: "Ödeme" }] : stepList}
            onStepChange={(index) => {
              if (index > 0 && index < 4) {
                setState((prev) => ({
                  ...prev,
                  activeStep: index as 1 | 2 | 3,
                }));
              }
            }}
          />
          <Container className="pb-20">
            <CoreSummaryContent>
              {RentACarSummaryStepScreens[activeStep]}
              <RentACarSummaryTotalCard />
            </CoreSummaryContent>
          </Container>
        </CoreSummaryCtxProvider>
      )}
    </>
  );
};

const RentACarSummary = () => {
  return (
    <RentACarSummaryCtxProvider>
      <RentACarSummaryContent />
    </RentACarSummaryCtxProvider>
  );
};

export default RentACarSummary;
