/* eslint-disable @typescript-eslint/no-shadow */
import React, { useEffect, useState } from "react";

import TourProductDetailAbout from "@/components/widget/tour-product-detail/tour-product-detail-about/tour-product-detail-about";
import type { TourInformation } from "@/services/eva-display/tour/tour-detail/tour-detail-service";

interface ITourDetailAboutProps {
  item: TourInformation;
}

export default function TourDetailAbout({ item }: ITourDetailAboutProps) {
  const uniqueSet = new Set<string>();
  const [departurePoints, setDeparturePoints] = useState<string | undefined>();

  const priceIncluded = item.tourDescriptions?.find((item) => item.type === 1);
  const priceExternal = item.tourDescriptions?.find((item) => item.type === 2);

  const extendIncludedDepaturePoints = (item.depaturePoints || [])
    .slice(1)
    .map(({ city }, key) => {
      if (city !== item?.depaturePoints?.[0]?.city && !uniqueSet.has(city)) {
        uniqueSet.add(city);
        return <li key={+key}>{city}</li>;
      }
      return null;
    })
    .filter(Boolean);

  useEffect(() => {
    if (item) {
      item.depaturePoints?.map((item) => setDeparturePoints(item.city));
    }
  }, [item]);

  return (
    <TourProductDetailAbout
      departurePoints={item.depaturePoints}
      departurePointsText={departurePoints}
      extendIncludedDepaturePoints={extendIncludedDepaturePoints}
      minDay={item.minDay}
      minNight={item.minNight}
      transportReturnTypeName={item.transportReturnTypeName}
      transportTypeName={item.transportTypeName}
      priceIncluded={priceIncluded}
      priceExternal={priceExternal}
    />
  );
}
