import React, { useState } from "react";

import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import type { DepaturePoints } from "@/services/eva-display/tour/tour-search/tour-search.types";

interface TourDetailDeparturePointsProps {
  departurePoints: DepaturePoints[];
}

export default function TourDetailDeparturePoints({
  departurePoints,
}: TourDetailDeparturePointsProps) {
  const [selectedCity, setSelectedCity] = useState<string | null>(
    departurePoints?.[0]?.city || null,
  );

  const handleCityChange = (city: string) => setSelectedCity(city);

  const cities = [...new Set(departurePoints?.map((point) => point.city))];

  const filteredDeparturePoints = selectedCity
    ? departurePoints.filter((point) => point.city === selectedCity)
    : departurePoints;

  return (
    <Card className="col-span-8">
      <div className="mb-4 flex flex-col gap-2">
        <h1 className="text-xl font-semibold text-gray-800">
          Hareket Noktaları
        </h1>
      </div>

      <Select
        defaultValue={selectedCity ?? undefined}
        onValueChange={handleCityChange}
      >
        <SelectTrigger>
          <SelectValue placeholder="Şehir Seçiniz" />
        </SelectTrigger>
        <SelectContent>
          {cities.map((city) => (
            <SelectItem key={city} value={city}>
              {city}
            </SelectItem>
          ))}
        </SelectContent>
      </Select>

      {filteredDeparturePoints?.map((item) => (
        <div key={item.key} className="mt-3 flex items-baseline gap-[6px]">
          <LIcon name="Circle" size={8} className="text-gray-600" />
          <div className="flex flex-col gap-1 ">
            <span className="text-sm text-gray-800">{item.name}</span>
            <span className="text-xs text-gray-500">{item.time}</span>
          </div>
        </div>
      ))}
    </Card>
  );
}
