/* eslint-disable no-unsafe-optional-chaining */
import dayjs from "dayjs";
import React from "react";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { RezervationSummaryDivider } from "@/components/widget/rezervation-summary/rezervation-summary";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { PriceManager } from "@/libs/price-manager/price-manager";

import { useTourDetailCtx } from "../context/tour-detail-ctx";

interface TourDetailReservationInfoContentProps {
  selectedPriceGroup: any;
  getProductKey: () => void;
}

const TourDetailReservationInfoContent = ({
  selectedPriceGroup,
  getProductKey,
}: TourDetailReservationInfoContentProps) => {
  const { data } = useTourDetailCtx();
  const { isDesktop } = useBreakpoints();
  return (
    <Card className="border-border border-0 md:!border">
      <div className="flex flex-col gap-4 border-b-gray-200 pb-4 md:border-b">
        <h3 className="font-semibold text-gray-800">Rezervasyon Özeti</h3>
        <p className="text-sm font-semibold text-gray-800">
          {data?.selectedOption?.tourName}
        </p>
      </div>
      <div className="my-4 flex flex-col gap-4">
        <div className="flex justify-between gap-4">
          <div className="flex flex-col gap-1 text-sm">
            <p className="text-gray-500">Başlangıç Tarihi:</p>
            <span className="font-semibold text-gray-800">
              {dayjs(selectedPriceGroup?.startDate).format("DD MMMM YYYY ddd")}
            </span>
          </div>
          <div className="flex flex-col gap-1 text-sm">
            <p className="text-gray-500">Bitiş Tarihi:</p>
            <span className="font-semibold text-gray-800">
              {dayjs(selectedPriceGroup?.endDate).format("DD MMMM YYYY ddd")}
            </span>
          </div>
        </div>
        <RezervationSummaryDivider />
        <div className="flex flex-col gap-3">
          <p className="text-sm font-semibold text-gray-800">
            {data?.option?.title}
          </p>
          <div className="flex flex-col items-start gap-2">
            <div className="flex items-center gap-1">
              <LIcon name="Bed" className="mr-2" size={12} />
              <span className="text-sm text-gray-800">
                {data?.detailData?.description}
              </span>
            </div>
            <div className="flex items-center gap-1">
              <LIcon name="Check" className="mr-2" size={12} />
              <span className="text-sm text-gray-800">
                {data?.searchData?.option.boardType}
              </span>
            </div>
          </div>
        </div>
      </div>
      <div className="mb-4 flex items-center justify-between border border-gray-200 p-3">
        <p className="text-sm text-gray-500">Toplam Tutar</p>
        <p className="text-xl font-semibold text-gray-800">
          {PriceManager({
            currency: data?.option?.totalPrice?.slice(0, 3),
            value: +data?.option?.totalPrice?.slice(3),
          })}
        </p>
      </div>
      {isDesktop && (
        <Button
          onClick={() => getProductKey()}
          className="w-full whitespace-nowrap"
          variant="primary"
        >
          Rezervasyon yap
        </Button>
      )}
    </Card>
  );
};

export default TourDetailReservationInfoContent;
