/* eslint-disable no-unsafe-optional-chaining */

"use client";

import { t } from "i18next";
import { useRouter } from "next/navigation";

import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { RezervationSummaryTotalPriceMobile } from "@/components/widget/rezervation-summary/rezervation-summary";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { PriceManager } from "@/libs/price-manager/price-manager";

import { useTourSummary } from "../../summary/hooks/use-tour-summary";
import { useTourDetailCtx } from "../context/tour-detail-ctx";
import TourDetailReservationInfoContent from "./tour-detail-reservation-info-content";

const TourDetailReservationInfo = () => {
  const { isDesktop } = useBreakpoints();
  const { data } = useTourDetailCtx();
  const navigate = useRouter();
  const { setDetailData } = useTourSummary();
  const { closeModal, openModal, modalOpen } = useModal({ open: false });

  if (!data?.selectedOption) {
    return (
      <Card className="t-0 sticky flex items-center gap-2 md:block">
        <div className="w-full bg-white text-sm md:pb-4">
          Rezervasyon yapmak için önce bir seçim yapmalısınız.
        </div>
        <Button className="w-full whitespace-nowrap" variant="disable">
          Rezervasyon yap
        </Button>
      </Card>
    );
  }

  if (data.loading) {
    return (
      <div className="relative flex h-full items-center justify-center">
        <div className="animate-spin rounded-full bg-gradient-to-tr from-primary-500 to-transparent p-1">
          <div className="rounded-full bg-white">
            <div className="size-6 rounded-full" />
          </div>
        </div>
      </div>
    );
  }

  const selectedPriceGroup = data.detailData?.pricePeriods.find(
    (x) => x.optionKey === data.selectedOption?.optionKey,
  );

  function getProductKey() {
    const rooms: any[] = [];
    rooms.push({
      room: data?.rooms,
      option: data?.selectedOption,
    });
    setDetailData({
      rooms,
    });
    return navigate.push("/tour/summary");
  }

  if (!isDesktop) {
    return (
      <div className="fixed inset-x-0 bottom-0 z-[100] w-full bg-white">
        <div className="border-t p-4">
          <div className="flex w-full items-center justify-between">
            <div className="flex gap-2">
              <Button
                className="!h-auto !p-0"
                leftIcon={{ name: "ChevronUp", size: 20 }}
                onClick={openModal}
              />
              <RezervationSummaryTotalPriceMobile
                price={PriceManager({
                  currency: data?.option?.totalPrice?.slice(0, 3),
                  value: +data?.option?.totalPrice?.slice(3),
                })}
              />
            </div>
            <Button onClick={() => getProductKey()} variant="primary">
              Rezervasyon yap
            </Button>
          </div>
        </div>

        <Modal
          size="full"
          open={modalOpen}
          onClose={closeModal}
          title={t("Booking Details")}
          footer
        >
          <TourDetailReservationInfoContent
            selectedPriceGroup={selectedPriceGroup}
            getProductKey={() => getProductKey()}
          />
        </Modal>
      </div>
    );
  }

  return (
    <TourDetailReservationInfoContent
      selectedPriceGroup={selectedPriceGroup}
      getProductKey={() => getProductKey()}
    />
  );
};

export default TourDetailReservationInfo;
