/* eslint-disable react/no-unescaped-entities */
/* eslint-disable @typescript-eslint/no-shadow */
/* eslint-disable no-console */
/* eslint-disable react/no-danger */

import dayjs from "dayjs";
import _groupBy from "lodash-es/groupBy";
import { useState } from "react";

import Card from "@/components/ui/card/card";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import TourProductDetailRoom from "@/features/modules/tour/detail/components/tour-product-detail-room";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { TourOptionItem } from "@/services/eva-display/tour/tour-search/tour-search.types";

import TourDetailReservationInfo from "./tour-detail-reservation-info";

interface TourDetailRoomProps {
  allOptionList: TourOptionItem[];
  tourDetailRoomPrice: string;
  // passengerList?: PassengerList[];
}

export default function TourDetailRoom({
  allOptionList,
  tourDetailRoomPrice,
}: TourDetailRoomProps) {
  const [selectedMonth, setSelectedMonth] = useState<string | null>(null);

  const groupedOptions = _groupBy(allOptionList, "startDate");

  const transformedGroupedOptions = Object.entries(groupedOptions)
    .sort(([a], [b]) => new Date(a).getTime() - new Date(b).getTime())
    .map(([date, options]) => ({ date, options }));

  const uniqueMonths = [
    ...new Set(
      transformedGroupedOptions?.map((item) => dayjs(item.date).format("MMMM")),
    ),
  ];

  const selectMonth = uniqueMonths.map((month) => ({
    value: month,
    label: month,
  }));

  const filteredOptions = selectedMonth
    ? transformedGroupedOptions.filter(
        (item) => dayjs(item.date).format("MMMM") === selectedMonth,
      )
    : transformedGroupedOptions;

  const handleMonthChange = (month: string) => setSelectedMonth(month);

  return (
    <div
      className="flex scroll-mt-20 flex-col gap-4 md:scroll-mt-48"
      id="rooms"
    >
      <Card className="col-span-8">
        <div className="mb-4 flex flex-col gap-2">
          <h1 className="text-xl font-semibold text-gray-800">
            Gitmek istediğiniz dönem
          </h1>
        </div>

        <Select defaultValue="" onValueChange={handleMonthChange}>
          <SelectTrigger>
            <SelectValue placeholder="Dönem Seçiniz" />
          </SelectTrigger>
          <SelectContent>
            {selectMonth?.map((item) => (
              <SelectItem key={item.value} value={item.value}>
                {item.label}
              </SelectItem>
            ))}
          </SelectContent>
        </Select>
      </Card>

      <div className="grid grid-cols-12 gap-4">
        <Card className="col-span-12 md:col-span-8">
          <div className="mb-4 flex flex-col gap-2">
            <h1 className="font-semibold">Tur başlangıç tarihleri</h1>
            <p className="text-sm">
              {allOptionList?.length > 0 &&
                PriceManager({
                  currency: tourDetailRoomPrice?.slice(0, 3) || "",
                  value: tourDetailRoomPrice?.slice(3) as unknown as number,
                })}
              'den başlayan fiyatlarla
            </p>
          </div>

          <TourProductDetailRoom groupedOptions={filteredOptions} />
        </Card>
        <div className="fixed inset-x-0 bottom-0 z-[100] w-full md:static md:z-0 md:col-span-4 md:h-full ">
          <div className="sticky top-[184px]">
            <TourDetailReservationInfo />
          </div>
        </div>
      </div>
    </div>
  );
}
