import Container from "@/components/shared/container";
import { Badge } from "@/components/ui/badge/badge";
import { Button } from "@/components/ui/button/button";
import { ProductDetailTitle } from "@/components/widget/product-detail/product-detail-title/product-detail-title";
import { PriceManager } from "@/libs/price-manager/price-manager";

interface TourDetailTitleProps {
  tourName: string;
}

const TourDetailTitle = ({ tourName }: TourDetailTitleProps) => {
  return <ProductDetailTitle title={tourName || ""} />;
};

interface TourDetailTitleInformationProps {
  basePrice: string;
  boardType: string;
}

export const TourDetailTitleInformation = ({
  basePrice,
  boardType,
}: TourDetailTitleInformationProps) => {
  const price = PriceManager({
    currency: basePrice?.slice(0, 3) || "TRY",
    value: +(basePrice?.slice(3) as unknown as number) || 0,
  });

  return (
    <Container>
      <div className="flex flex-col items-start justify-between gap-4 bg-white md:flex-row">
        <div>
          <Badge className="w-fit">{boardType}</Badge>
        </div>
        <div className="flex items-center gap-2 md:justify-end">
          {price && (
            <span className="text-xl font-semibold text-gray-800">
              {price}
              <span className="text-sm text-gray-500">`den başlayan</span>
            </span>
          )}
        </div>
        <a className="block w-full md:hidden" href="#rooms">
          <Button className="w-full md:w-[248px]" variant="primary">
            Rezervasyon Yap
          </Button>
        </a>
      </div>
    </Container>
  );
};

export default TourDetailTitle;
