/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable no-console */
/* eslint-disable @typescript-eslint/no-shadow */

"use client";

import { useEffect, useRef, useState } from "react";

import Container from "@/components/shared/container";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import ProductDetailCoverGallery from "@/components/widget/product-detail/product-detail-cover-gallery/product-detail-cover-gallery";
import ProductDetailGallery from "@/components/widget/product-detail/product-detail-gallery/product-detail-gallery";
import type { MenuItem } from "@/components/widget/product-detail/product-detail-menu/product-detail-menu";
import { ProductDetailMenu } from "@/components/widget/product-detail/product-detail-menu/product-detail-menu";
import HotelDetailSkeleton from "@/features/hotel/components/hotel-detail/components/hotel-detail-skeleton";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { localeStorageHelper } from "@/libs/helpers/locale-storage-helper";
import type { CampaignInformation } from "@/services/eva-display/tour/tour-detail/tour-detail-service";
import { useTourDetailMutation } from "@/services/eva-display/tour/tour-detail/tour-detail-service";
import type { ITourSearchResponse } from "@/services/eva-display/tour/tour-search/tour-search.types";
import {
  useTourDetailSearchMutation,
  useTourSearchMutation,
} from "@/services/eva-display/tour/tour-search/tour-search-service";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

import { useTourSearch } from "../../list/hook/use-tour-search";
import { useTourSummary } from "../../summary/hooks/use-tour-summary";
import { useTourTravelPlanner } from "../../travel-planner/hooks/use-tour-travel-planner";
import { useTourDetailCtx } from "../context/tour-detail-ctx";
import { convertToDesiredFormat } from "../libs/tour-helper";
import TourDetailAbout from "./tour-detail-about";
import TourDetailCampaignAdvanteges from "./tour-detail-campaign-advanteges";
import TourDetailDeparturePoints from "./tour-detail-departure-points";
import TourDetailOtherInfo from "./tour-detail-other-info";
import TourDetailRoom from "./tour-detail-room";
import TourDetailTitle, {
  TourDetailTitleInformation,
} from "./tour-detail-title";
import TourDetailTourProgram from "./tour-detail-tour-program";

export const removeDuplicateCampaigns = (tours: CampaignInformation[]) => {
  const uniqueTours: CampaignInformation[] = [];
  tours.forEach((tour) => {
    if (
      uniqueTours.findIndex((uniqueTour) => uniqueTour.name === tour.name) ===
      -1
    ) {
      uniqueTours.push(tour);
    }
  });
  return uniqueTours;
};

const TourDetail = () => {
  const [state, setState] = useState<ITourSearchResponse>();
  const { isDesktop } = useBreakpoints();
  const { setNotify } = useNotifyStore();
  const { t } = useLocale();

  const tourDetailCtx = useTourDetailCtx();
  const tourListSearchMutation = useTourSearchMutation();
  const { isReady: tpIsReady } = useTourTravelPlanner();
  const tourDetailMutation = useTourDetailMutation();
  const tourDetailSearchMutation = useTourDetailSearchMutation();
  const { getTourSearchParameters } = useTourSearch();
  const { setSearchData } = useTourSummary();
  const headerWrapperRef = useRef<HTMLDivElement>(null);
  const menuWrapperRef = useRef<HTMLDivElement>(null);

  function getMenuItem() {
    const temp: MenuItem[] = [];
    temp.push({ text: "Genel Bakış", id: "overview" });
    temp.push({ text: "Tur Programı", id: "tourProgram" });

    if (tourDetailCtx.data?.detailData?.campaignInformations) {
      temp.push({ text: "Kampanya & Avantajlar", id: "campaignAndAdvantages" });
    }

    temp.push({ text: "Rezervasyon", id: "rooms" });
    temp.push({ text: "Merak Edilenler", id: "curiosities" });

    return temp;
  }

  async function getData(rooms?: any) {
    tourDetailCtx.setData((prev) => ({ ...prev!, loading: true }));
    const parameters = getTourSearchParameters();

    const searchResponse = await tourListSearchMutation.mutateAsync(
      {
        ...parameters!,
        rooms: [
          {
            passengers: [
              {
                passengerType: 0,
              },
              {
                passengerType: 0,
              },
            ],
          },
        ],
      },
      {
        onSuccess: (data) => {
          setState(data);
        },
      },
    );

    if (
      rooms &&
      rooms.length > 0 &&
      parameters &&
      tourDetailCtx.data?.selectedOption
    ) {
      parameters.rooms = rooms;
    } else {
      parameters!.rooms = [
        {
          passengers: [
            {
              passengerType: 0,
            },
            {
              passengerType: 0,
            },
          ],
        },
      ];
    }
    const detailSearchResponse = await tourDetailSearchMutation.mutateAsync(
      parameters!,
      {
        onSuccess: (data) => {
          if (!data.items) {
            setNotify({
              title: "Bir Hata Oluştu!",
              message: "Uygun tur bulunamadı. Lütfen tekrar deneyiniz.",
              variant: "error",
              onClose() {
                window.location.reload();
              },
            });
          }
          setSearchData({
            searchId: data.searchId,
            isDomestic: localeStorageHelper.get("isDomestic") ?? true,
            option:
              data.items?.[0]?.allOptionList?.find(
                (item) =>
                  item.optionKey === tourDetailCtx.data?.isSelectedOptionKey,
              ) ?? "",
            passengersKeys: data.passengerList?.map((item) => ({
              age: item.age,
              key: item.key,
              type: item.type,
            })),
            departurePoints: data.items?.[0]?.depaturePoints ?? [],
          });
          tourDetailCtx.setData((prev) => ({
            ...prev!,
            searchData: data.items?.[0]!,
            option:
              data.items?.[0]?.allOptionList?.find(
                (item) =>
                  item.optionKey === tourDetailCtx.data?.isSelectedOptionKey,
              ) ?? "",
          }));
        },
      },
    );

    const detailResponse = await tourDetailMutation.mutateAsync({
      TourDetailRequest: {
        searchId: searchResponse.searchId,
        ProductKey: searchResponse.items?.[0]!.option?.key,
      },
    });
    tourDetailCtx.setData((prev) => ({
      ...prev!,
      loading: false,
      searchData: detailSearchResponse.items?.[0]!,
      detailData: detailResponse?.result,
    }));
  }

  useEffect(() => {
    if (tpIsReady) {
      getData(convertToDesiredFormat(tourDetailCtx.data?.rooms! ?? []));
    }
  }, [
    tpIsReady,
    tourDetailCtx.data?.selectedOption,
    tourDetailCtx.data?.rooms,
  ]);

  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  if (!tpIsReady) {
    return <Skeleton />;
  }

  // I used setTimeout because of the headerWrapperRef and menuWrapperRef are not ready when the page is loaded.
  setTimeout(() => {
    const headerWrapper = headerWrapperRef.current;
    const menuWrapper = menuWrapperRef.current;

    if (isDesktop && headerWrapper && menuWrapper) {
      // note: why I did this?
      // hotel title word length is no matter what,
      // menu wrapper's top value'll be equal according to title wrapper height
      menuWrapperRef.current.style.top = `${headerWrapper.offsetHeight}px`;
    }
  }, 1000);

  return (
    <div className="flex flex-col">
      {!tourDetailCtx.data && <HotelDetailSkeleton />}
      {!!tourDetailCtx.data?.detailData && (
        <>
          <div>
            {!isDesktop && (
              <Container>
                <ProductDetailGallery
                  images={tourDetailCtx.data?.detailData.tourInformation.images}
                />
              </Container>
            )}
          </div>
          <div
            ref={headerWrapperRef}
            id="headerWrapper"
            className="top-0 z-50 bg-white md:sticky"
          >
            <Container>
              <TourDetailTitle
                tourName={tourDetailCtx.data?.detailData.tourInformation?.title}
              />
            </Container>
          </div>
          <div className="bg-white md:py-2">
            <TourDetailTitleInformation
              basePrice={tourDetailCtx.data?.detailData.totalPrice}
              boardType={
                tourDetailCtx.data?.detailData.tourInformation.boardType
              }
            />
          </div>
          <div className="hidden w-full flex-col bg-white md:flex  md:flex-col-reverse">
            <div className="!mx-0 w-full">
              <ProductDetailCoverGallery
                images={tourDetailCtx.data?.detailData.tourInformation.images}
                noImageText={t(
                  "This tour's images are in the process of being prepared.",
                )}
              />
            </div>
          </div>
          <div
            ref={menuWrapperRef}
            className="sticky top-0 z-50 !mx-0 w-full bg-white md:top-20"
          >
            <Container>
              <ProductDetailMenu menuItems={getMenuItem()} />
            </Container>
          </div>
          <Container className="px-0 md:px-5">
            <div className="my-4">
              <TourDetailAbout
                item={tourDetailCtx.data?.detailData.tourInformation}
              />
            </div>
          </Container>

          <Container className="px-0 md:px-5">
            <div className="my-4">
              <TourDetailTourProgram
                tourProgramList={
                  tourDetailCtx.data?.detailData.tourInformation.tourProgram
                }
              />
            </div>
          </Container>
          <Container className="px-0 md:px-5">
            <div className="my-4">
              {tourDetailCtx.data?.searchData && (
                <TourDetailDeparturePoints
                  departurePoints={
                    tourDetailCtx.data?.searchData.depaturePoints
                  }
                />
              )}
            </div>
          </Container>

          <Container className="px-0 md:px-5">
            <div className="my-4">
              {tourDetailCtx.data?.detailData.campaignInformations && (
                <TourDetailCampaignAdvanteges
                  tourCampaignInformationsList={removeDuplicateCampaigns(
                    tourDetailCtx.data?.detailData.campaignInformations,
                  )}
                />
              )}
            </div>
          </Container>

          <Container className="px-0 md:px-5">
            <div className="my-4">
              <TourDetailRoom
                tourDetailRoomPrice={tourDetailCtx.data?.detailData.totalPrice}
                allOptionList={state?.items[0]?.allOptionList ?? []}
              />
            </div>
          </Container>

          <Container
            className="scroll-mt-12 px-0 md:scroll-mt-48 md:px-5"
            id="curiosities"
          >
            <div className="my-4  overflow-x-hidden">
              <TourDetailOtherInfo
                tourDescriptionsList={
                  tourDetailCtx.data?.detailData.tourInformation
                    .tourDescriptions
                }
              />
            </div>
          </Container>
        </>
      )}
    </div>
  );
};

export default TourDetail;
