import React from "react";

import {
  Tabs,
  TabsContent,
  TabsList,
  TabsTrigger,
} from "@/components/ui/tabs/tabs";
import RoomPriceDetail from "@/components/widget/room/room-price-detail/room-price-detail";
import type { TourOptionItem } from "@/services/eva-display/tour/tour-search/tour-search.types";

import { useTourDetailCtx } from "../context/tour-detail-ctx";

interface TourProductDetailRoomDetailModalProps {
  option: TourOptionItem;
}

const TourProductDetailRoomDetailModal = ({
  option,
}: TourProductDetailRoomDetailModalProps) => {
  const { data } = useTourDetailCtx();

  const roomPriceDetails = [
    { title: "İki Kişilik Oda Kişi Başı", price: option.priceDetail.doublePp },
    { title: "Tek Kişilik Oda", price: option.priceDetail.singlePp },
    { title: "İlave Yatak", price: option.priceDetail.extraBed },
    { title: "1.Çocuk (7-12 Yaş)", price: option.priceDetail.firstChild },
    { title: "2.Çocuk (2-7 Yaş)", price: option.priceDetail.secondChild },
    { title: "Bebek (0-2 Yaş)", price: option.priceDetail.infant },
  ];

  return (
    <Tabs defaultValue="1" className="w-full bg-white">
      <TabsList className="mt-6 w-full justify-between gap-4 pb-1.5 font-medium">
        <TabsTrigger value="1" className="w-full px-7 py-3">
          Konaklama Bilgileri
        </TabsTrigger>
        <TabsTrigger value="2" className="w-full px-7 py-3">
          Fiyat Bilgileri
        </TabsTrigger>
      </TabsList>
      <TabsContent value="1" className="flex flex-col gap-4">
        <div className="mt-4 rounded-2xl border p-4">
          {data?.detailData?.description}
        </div>
        <div>
          <p className="text-sm text-gray-500">
            Belirtilen tesisler turumuzun konaklama önceliğinin bulunduğu
            tesislerdir. Müsaitlikler doğrultusunda otel isimleri turun
            kalkışından 48 saat öncesinde talep edilmesi durumunda
            bildirilecektir. Yoğunluk ve mücbir sebepler nedeniyle standart
            bakımından aynı olmak kaydıyla oteller değişiklik gösterebilir.
            Böyle bir durumda misafirlerimiz Jolly Tur temsilcisi tarafından
            bilgilendirilir.
          </p>
        </div>
      </TabsContent>
      <TabsContent value="2">
        <div className="flex flex-col gap-4">
          {roomPriceDetails.map((detail) => (
            <RoomPriceDetail
              key={detail.title}
              title={detail.title}
              price={detail.price}
            />
          ))}
        </div>
      </TabsContent>
    </Tabs>
  );
};

export default TourProductDetailRoomDetailModal;
