import React, { useCallback } from "react";

import { Button } from "@/components/ui/button/button";
import { Modal } from "@/components/ui/modal/modal";
import { useModal } from "@/components/ui/modal/modal.hook";
import { useTourDetailCtx } from "@/features/modules/tour/detail/context/tour-detail-ctx";
import { useTourSearch } from "@/features/modules/tour/list/hook/use-tour-search";
import { useTourTravelPlanner } from "@/features/modules/tour/travel-planner/hooks/use-tour-travel-planner";
import { TpTourPassengerSelect } from "@/features/travel-planner/components/travel-planner/components/tp-tour-passenger-select";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { TourOptionItem } from "@/services/eva-display/tour/tour-search/tour-search.types";

import TourProductDetailRoomDetailModal from "./tour-product-detail-room-detail-modal";

interface TourProductDetailRoomInfoProps {
  option: TourOptionItem;
}

export default function TourProductDetailRoomInfo({
  option,
}: TourProductDetailRoomInfoProps) {
  const { isDesktop } = useBreakpoints();
  const { getVariables } = useTourSearch();
  const { data, setPartialData } = useTourTravelPlanner();
  const { setData, data: tourDetailCtxData } = useTourDetailCtx();
  const variables = getVariables();

  const { closeModal, openModal, modalOpen } = useModal({ open: false });

  const handleOpenModal = useCallback(() => {
    openModal();
  }, [openModal]);

  const isSelected =
    tourDetailCtxData?.selectedOption?.optionKey === option.optionKey;

  return (
    <>
      <div className="grid grid-cols-5 gap-4 py-4">
        <div className="col-span-3 flex flex-col items-start gap-2 pt-4">
          <h4 className="font-semibold text-blue-900">{option.tourName}</h4>
          <Button
            onClick={handleOpenModal}
            className="!p-0"
            variant="link"
            size="sm"
          >
            Detayları gör
          </Button>
        </div>
        <div className="col-span-2 flex flex-col items-center justify-end gap-6 md:flex-row">
          <div className="flex flex-col text-right">
            <span className="whitespace-nowrap text-lg font-semibold text-blue-900">
              {PriceManager({
                currency: option.priceDetail.doublePp.slice(0, 3),
                value: +option.priceDetail.doublePp.slice(3),
              })}
            </span>
            <span className="text-gray-500">
              Çift kişilik odada <br /> kişi başı
            </span>
          </div>
          <div className="pr-1">
            <TpTourPassengerSelect
              onAcceptClick={() => {
                if (variables) {
                  setData((prev) => ({
                    ...prev,
                    selectedOption: option,
                    rooms: data.payload.rooms,
                    isSelectedOptionKey: option.optionKey,
                  }));
                }
              }}
              value={
                data?.payload?.rooms || [
                  {
                    employee: { count: 0 },
                    guest: { count: 2 },
                    child: { count: 0, ages: [] },
                  },
                ]
              }
              tourQuota={option?.tourQuota}
              onChange={(value) => {
                setPartialData({ ...data?.payload, rooms: value });
              }}
              renderTriggerElement={() => (
                <Button
                  disabled={isSelected}
                  className="whitespace-nowrap"
                  variant="outline-primary"
                >
                  {isSelected ? "Seçildi" : "Seçim yap"}
                </Button>
              )}
            />
          </div>
        </div>
      </div>
      <Modal
        size={isDesktop ? "xl" : "full"}
        open={modalOpen}
        onClose={closeModal}
        title="Opsiyon Detayları"
        footer
      >
        <TourProductDetailRoomDetailModal option={option} />
      </Modal>
    </>
  );
}
