/* eslint-disable react/no-array-index-key */
import dayjs from "dayjs";
import React, { useState } from "react";

import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from "@/components/ui/accordion/accordion";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import TourProductDetailQuotaLimit from "@/features/modules/tour/detail/components/tour-product-detail-quota-limit";
import { useTourDetailCtx } from "@/features/modules/tour/detail/context/tour-detail-ctx";
import type { TourOptionItem } from "@/services/eva-display/tour/tour-search/tour-search.types";

import TourProductDetailRoomInfo from "./tour-product-detail-room-info";

export interface IconWithTextTypes {
  quotoText: string;
  date: string;
  textColor: string;
}

interface TourProductDetailRoomProps {
  groupedOptions: {
    date: string;
    options: TourOptionItem[];
  }[];
}

const IconWithText = ({ quotoText, date, textColor }: IconWithTextTypes) => {
  return (
    <div className="flex w-full items-center justify-between gap-2 pr-4">
      <p className="font-semibold"> {date}</p>
      <p className={`${textColor} text-sm font-normal`}>{quotoText}</p>
    </div>
  );
};

const TourProductDetailRoom = ({
  groupedOptions,
}: TourProductDetailRoomProps) => {
  const { data } = useTourDetailCtx();
  const [visibleActionPointsCount, setVisibleActionPointsCount] = useState(4);
  const [isShowMoreButtonVisible, setIsShowMoreButtonVisible] = useState(true);

  function getSelectedGroupDate() {
    const selectedGroup = groupedOptions.find((x) =>
      x.options.some((y) => y.optionKey === data?.selectedOption?.optionKey),
    );

    if (selectedGroup) {
      return selectedGroup.date;
    }

    return null;
  }

  const selectedGroupDate = getSelectedGroupDate();

  const handleShowMore = () => {
    setVisibleActionPointsCount((prevCount) => prevCount + 4);
  };

  const handleShowLess = () => {
    setVisibleActionPointsCount(4);
    setIsShowMoreButtonVisible(true);
  };

  return (
    <div className="flex flex-col gap-6">
      <Accordion
        type="single"
        collapsible
        className="space-y-3"
        defaultValue={
          selectedGroupDate ? selectedGroupDate.toString() : undefined
        }
      >
        {groupedOptions
          .slice(0, visibleActionPointsCount)
          .map(({ date, options }, index) => {
            const isLimit =
              options?.[0]?.tourQuota === 0 ||
              !options?.[0]?.hasQuota ||
              options?.[0]?.onRequest ||
              options?.[0]?.closedGroup;

            return (
              <AccordionItem
                value={date.toString()}
                className="border-b-0"
                key={date.toString()}
              >
                <Card key={index}>
                  <AccordionTrigger className="p-0">
                    <IconWithText
                      key={index}
                      textColor={`${((options?.[0]?.tourQuota! < 5 && options?.[0]?.tourQuota! !== 0) || isLimit) && "text-red-500"}`}
                      date={dayjs(date).format("DD MMMM YYYY - ddd")}
                      quotoText={`${
                        isLimit
                          ? "Kontenjan Dolu"
                          : `${options?.[0]?.tourQuota} kişilik yer kaldı`
                      }`}
                    />
                  </AccordionTrigger>
                  <AccordionContent>
                    {isLimit ? (
                      <TourProductDetailQuotaLimit />
                    ) : (
                      options.map((item, optionIndex) => (
                        <div key={optionIndex}>
                          <TourProductDetailRoomInfo option={item} />
                        </div>
                      ))
                    )}
                  </AccordionContent>
                </Card>
              </AccordionItem>
            );
          })}
      </Accordion>
      {groupedOptions.length > visibleActionPointsCount &&
        isShowMoreButtonVisible && (
          <Button
            onClick={handleShowMore}
            className="cursor-pointer text-blue-500"
          >
            Daha Fazla Göster
          </Button>
        )}
      {groupedOptions?.length <= visibleActionPointsCount &&
        groupedOptions.length > 4 && (
          <Button
            onClick={handleShowLess}
            className="cursor-pointer text-red-500"
          >
            Daha Az Göster
          </Button>
        )}
    </div>
  );
};

export default TourProductDetailRoom;
