/* eslint-disable default-case */
/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable radix */
import dayjs from "dayjs";
import { useEffect, useState } from "react";

import { usePageInfo } from "@/hooks/use-page-info";
import useRoom from "@/hooks/use-room/useRoom";
import { DateHelper } from "@/libs/helpers/date-time-helper";
import { storageManager } from "@/libs/storage-manager";
import { useLocalizationStore } from "@/store/localization-store/use-localization-store";
import { useTravelPlannerStore } from "@/store/travel-planner-store/use-travel-planner-store";

import type { ITourTravelPlannerPayload } from "../types/tour-travel-planner.types";

type SearchPayload = Partial<
  Pick<
    ITourTravelPlannerPayload,
    "rooms" | "dates" | "destination" | "isDomestic" | "periodType"
  >
>;

export const useTourTravelPlanner = () => {
  const { setModuleData, setData, travelPlannerState } =
    useTravelPlannerStore();
  const { setQueryParams, info, isDone } = usePageInfo();
  const [state, setState] = useState({
    isReady: false,
  });
  const {
    tp: { roomsToString, roomsFromString },
  } = useRoom();
  const { localizationState } = useLocalizationStore();

  function setSearchData(payload: SearchPayload) {
    storageManager.set("core-travel-planner", {
      moduleName: "Tour",
      payload,
    });
    setModuleData({
      moduleName: "Tour",
      payload,
    });
  }

  function setPartialData(payload: Omit<SearchPayload, "destination">) {
    const storagedTpData = storageManager.get("core-travel-planner");
    const newPayload: SearchPayload = {
      ...storagedTpData?.payload,
      ...payload,
    };
    storageManager.set("core-travel-planner", {
      moduleName: "Tour",
      payload: newPayload,
    });
    setModuleData({
      moduleName: "Tour",
      payload: newPayload,
    });
  }

  function navigateToTourList(payload: SearchPayload) {
    setSearchData(payload);
    const pushUrl = ["tour", "Tour"].includes(
      payload.destination?.typeName ?? "",
    )
      ? "/tour/detail"
      : "/tour/list";

    let destinationTypeId = 3;
    if (payload.destination) {
      switch (payload.destination.typeName) {
        case "Bölge":
          destinationTypeId = 1;
          break;
        case "Kategori":
          destinationTypeId = 3;
          break;
        case "Hareket Noktası":
        case "Çıkış Noktası":
          destinationTypeId = 4;
          break;
        case "Destinations":
          destinationTypeId = 6;
          break;
      }
    }

    const queryParams = payload.destination?.id
      ? {
          destination: payload.destination!.value ?? "",
          destinationId: payload.destination!.id?.toString() ?? "",
          destinationType: destinationTypeId?.toString() ?? "",
          destinationTypeName: payload.destination!.typeName ?? "",
          checkinDate: DateHelper.isoStringToFullYearString(
            payload.dates!.checkIn!,
            "-",
          ),
          checkoutDate: DateHelper.isoStringToFullYearString(
            payload.dates!.checkOut!,
            "-",
          ),
          rooms: roomsToString(payload.rooms!),
          isDomestic: payload.isDomestic as undefined,
          periodType: payload.periodType?.toString(),
          lng: localizationState.data.language,
        }
      : {
          destination: undefined,
          destinationId: undefined,
          destinationType: undefined,
          destinationTypeName: undefined,
          checkinDate: DateHelper.isoStringToFullYearString(
            payload.dates!.checkIn!,
            "-",
          ),
          checkoutDate: DateHelper.isoStringToFullYearString(
            payload.dates!.checkOut!,
            "-",
          ),
          rooms: roomsToString(payload.rooms!),
          isDomestic: payload.isDomestic as undefined,
          periodType: payload.periodType?.toString(),
          lng: localizationState.data.language,
          rgn: localizationState.data.region,
          cur: localizationState.data.currency,
        };

    setQueryParams(
      queryParams,
      pushUrl,
      pushUrl === "/tour/detail" ? "_blank" : "_self",
    );
  }

  function getSearchPayloadFromQueryParams() {
    const { queryParams } = info!;
    const storagedTpData = storageManager.get("core-travel-planner");
    const payload: SearchPayload = {
      ...storagedTpData?.payload,
      destination: {
        id: parseInt(queryParams.destinationId ?? ""),
        value: queryParams.destination ?? "",
        type: parseInt(queryParams.destinationType ?? ""),
        typeName: queryParams.destinationTypeName ?? "",
        destinationBreadCrumb: queryParams.destinationBreadCrumb ?? "",
      },
      dates: {
        checkIn: DateHelper.dateToISOString(
          dayjs(queryParams.checkinDate).toDate(),
        ),
        checkOut: DateHelper.dateToISOString(
          dayjs(queryParams.checkoutDate).toDate(),
        ),
      },
      rooms: roomsFromString(queryParams.rooms ?? ""),
      isDomestic: queryParams.isDomestic === "true",
      periodType: parseInt(queryParams.periodType ?? "3"),
    };

    if (payload) {
      setSearchData(payload);
    }

    return payload;
  }

  useEffect(() => {
    if (isDone && travelPlannerState?.data?.moduleName !== "Tour") {
      setData(undefined);
    }
    if (isDone && travelPlannerState.status === "done") {
      if (info?.path === "/tour/list") {
        getSearchPayloadFromQueryParams();
      }
      setState(() => ({
        isReady: true,
      }));
    }
  }, [travelPlannerState.status, isDone]);

  return {
    setSearchData,
    navigateToTourList,
    data: travelPlannerState.data as {
      moduleName: "Tour";
      payload: ITourTravelPlannerPayload;
    },
    isReady: state.isReady,
    setPartialData,
  };
};
