/* eslint-disable no-nested-ternary */
/* eslint-disable no-console */

"use client";

import dayjs from "dayjs";
import { useRouter } from "next/navigation";
import React, { useEffect, useRef } from "react";
import { useBoolean } from "usehooks-ts";

import type { FormHandles } from "@/components/form/form";
import Form from "@/components/form/form";
import Container from "@/components/shared/container";
import Card from "@/components/ui/card/card";
import {
  ReservationSummaryImage,
  ReservationSummaryPriceBox,
  ReservationSummaryProvider,
  ReservationSummaryRoutes,
  ReservationSummarySeperator,
  ReservationSummaryTitle,
} from "@/components/widget/reservation-summary/reservation-summary";
import {
  CoreSummaryHeader,
  CoreSummaryPassengerGroup,
} from "@/features/core/summary/components/core-summary";
import CoreSummaryActionButton from "@/features/core/summary/components/core-summary-action-button";
import { CoreSummaryAdditionalPrices } from "@/features/core/summary/components/core-summary-additional-prices";
import CoreSummaryContent from "@/features/core/summary/components/core-summary-content";
import CoreSummaryCouponCode from "@/features/core/summary/components/core-summary-coupon-code/core-summary-coupon-code";
import type { CoreSummaryHandles } from "@/features/core/summary/components/core-summary-form";
import CoreSummaryForm, {
  GROUP_KEY_PREFIX,
} from "@/features/core/summary/components/core-summary-form";
import CoreSummaryInvoiceNoteFormItem from "@/features/core/summary/components/core-summary-invoice-note-form-item";
import CoreSummaryMainColumn from "@/features/core/summary/components/core-summary-main-column";
import CoreSummaryNoteFormItem from "@/features/core/summary/components/core-summary-note-form-input";
import CoreSummaryPolicyFormItem from "@/features/core/summary/components/core-summary-policy-form-item";
import CoreSummaryRequestNoteFormItem from "@/features/core/summary/components/core-summary-request-note-form-item";
import CoreSummarySideColumn from "@/features/core/summary/components/core-summary-side-column";
import CoreSummarySteps from "@/features/core/summary/components/core-summary-steps";
import { CoreSummaryCtxProvider } from "@/features/core/summary/context/core-summary-context";
import { getBillingRequestDataFromPassengerInfo } from "@/features/core/summary/libs/billing-helper";
import type { ICoreSummaryPassenger } from "@/features/core/summary/types/core-summary.types";
import BillingInfoForm from "@/features/customer/billing-info/billing-info-form";
import PaymentList from "@/features/modules/payment/payment-list";
import { useApp } from "@/hooks/useApp";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { useLocalStateCache } from "@/libs/helpers/local-state-cache-helper";
import { CorePassengerHelper } from "@/libs/helpers/passenger-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import DefautlImage from "@/public/assets/images/defaultImage.jpg";
import type { ITransferAddToCartResponse } from "@/services/eva-display/transfer/transfer-cart/transfer-add-to-cart.service";
import { useTransferCreatePostMutation } from "@/services/eva-display/transfer/transfer-create-post/transfer-create-post.service";
import { useTransferValidateMutation } from "@/services/eva-display/transfer/transfer-validate/transfer-validate.service";
import { useMasterpassStore } from "@/store/masterpass-store/use-masterpass-store";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

import { usePayment } from "../../payment/hooks/use-transfer-payment";
import { useTransferTravelPlanner } from "../../travel-planner/hooks/use-transfer-travel-planner";
import { useTransferSummary } from "../hooks/use-transfer-summary";
import TransferSummaryInfoForm from "./transfer-summary-info-form";

interface TransferSummaryViewProps {
  addToCardData: ITransferAddToCartResponse;
  passengersGroups: Array<ICoreSummaryPassenger[]>;
}

export interface TransferPaymentListHandles extends FormHandles {}

export default function TransferSummaryView(props: TransferSummaryViewProps) {
  const router = useRouter();
  const coreSummaryRef = useRef<CoreSummaryHandles>(null);
  const { isB2E, isB2C } = useApp();
  const { setNotify } = useNotifyStore();
  const bookingRequestMutation = useTransferCreatePostMutation();
  const { data: tpData } = useTransferTravelPlanner();
  const { data: summaryData } = useTransferSummary();
  const { paymentState, setBookingData } = usePayment();
  const { setMasterpassData } = useMasterpassStore();
  const diffrentBillingInfoBoolean = useBoolean();
  const transferPaymentRef = useRef<TransferPaymentListHandles>(null);
  const paymentFormRef = useRef<TransferPaymentListHandles>(null);
  const validateMutation = useTransferValidateMutation();
  const { t } = useLocale();

  const { getLocalStateCacheValues } = useLocalStateCache(
    "transferFormFields",
    props.passengersGroups,
  );

  function getDefaultValues() {
    const defaultValues: any = getLocalStateCacheValues();
    if (defaultValues) {
      return defaultValues;
    }
    props.passengersGroups.forEach((passengerGroup) => {
      passengerGroup.forEach((passenger) => {
        if (passenger.type === "employee") {
          defaultValues[`${GROUP_KEY_PREFIX}_${0}-${passenger.key}-employee`] =
            passenger.defaultValue;
        }
      });
    });

    return defaultValues;
  }

  const defaultValues = getDefaultValues();

  const { isDesktop } = useBreakpoints();

  const isReturn = props.addToCardData.transferItemList.length > 1;

  const sortedTransferItemsByGroupId =
    props.addToCardData.transferItemList.sort((a, b) => a.groupId - b.groupId);

  function handleSubmitButtonClick() {
    if (paymentState?.payload.paymentStatus === "payment") {
      paymentFormRef.current?.submit();
      transferPaymentRef.current?.onlyValidate();
    } else {
      coreSummaryRef.current?.submit();
    }
  }

  function renderCouponCode() {
    if (isB2C && !!paymentState?.payload?.transactionId) {
      return (
        <CoreSummaryCouponCode
          cartId={props.addToCardData.cartId}
          transactionKey={paymentState.payload.transactionId}
        />
      );
    }

    return null;
  }

  useEffect(() => {
    window.scrollTo(0, 0);
  }, [paymentState?.payload?.paymentStatus]);

  return (
    <CoreSummaryCtxProvider>
      {({ discounts }) => (
        <div className="pb-10">
          <div>
            {isB2C && (
              <CoreSummarySteps
                steps={[
                  {
                    label: "Seçiminiz",
                  },
                  {
                    label: "Yolcu bilgileri",
                  },
                  {
                    label: t("Payment"),
                  },
                ]}
                activeIndex={
                  paymentState?.payload?.paymentStatus === "payment" ? 2 : 1
                }
              />
            )}
            <Container>
              <div>
                <CoreSummaryHeader hideBackButton>
                  {isB2C
                    ? paymentState?.payload?.paymentStatus === "payment"
                      ? t("Ödeme Seçenekleri")
                      : "Yolcu Bilgileri"
                    : "Kişi Bilgileri"}
                </CoreSummaryHeader>
                <CoreSummaryContent>
                  {isB2C &&
                  paymentState?.payload?.paymentStatus === "payment" ? (
                    <CoreSummaryMainColumn>
                      {!isDesktop && renderCouponCode()}
                      <Form
                        ref={paymentFormRef}
                        onSubmit={() => transferPaymentRef.current?.submit()}
                        shouldAutoScroll
                      >
                        <PaymentList
                          ref={transferPaymentRef}
                          cartId={props.addToCardData.cartId}
                          searchId={summaryData.payload.searchId!}
                          transactionId={paymentState.payload.transactionId!}
                          noCampaign={Boolean(
                            discounts.find((x) => x.type === "CouponCode"),
                          )}
                        />
                      </Form>
                    </CoreSummaryMainColumn>
                  ) : (
                    <CoreSummaryMainColumn>
                      <CoreSummaryForm<{
                        departureInfo: {
                          airlineName: string;
                          flightDate: {
                            date: Date;
                          };
                          flightNo: string;
                          address: string;
                          departureTime?: string;
                          arrivalTime?: string;
                        };
                        arrivalInfo?: {
                          airlineName: string;
                          flightDate: {
                            date: Date;
                          };
                          flightNo: string;
                          address: string;
                          departureTime?: string;
                          arrivalTime?: string;
                        };
                      }>
                        ref={coreSummaryRef}
                        wrapperClassName="space-y-4"
                        formItemPrefixes={[
                          "departureInfo",
                          "arrivalInfo",
                          "billingInfo",
                        ]}
                        onSubmit={async (values) => {
                          const passengersInformations = values.passengers.map(
                            (psg) =>
                              CorePassengerHelper.corePassengerToPassengerInformation(
                                psg,
                              ),
                          );
                          const passengerWithBillingInfo =
                            passengersInformations.find(
                              (x) => x.Address.Street !== "",
                            );
                          // const billingInfo = diffrentBillingInfoBoolean.value
                          //   ? getBillingRequestDataFromBillingForm(
                          //       values.values?.billingInfo!,
                          //     ) :
                          const billingInfo =
                            getBillingRequestDataFromPassengerInfo(
                              passengerWithBillingInfo!,
                            );

                          if (isB2E) {
                            const passengersWithoutGenderInfo =
                              CorePassengerHelper.getPassengersWithoutGenderInfo(
                                values.passengers,
                              );

                            if (passengersWithoutGenderInfo.length > 0) {
                              setNotify({
                                variant: "error",
                                title: "Bir Hata Oluştu!",
                                message: `${"Seçilen kullanıcının cinsiyet bilgisini doldurunuz."} \n ${passengersWithoutGenderInfo.reduce((acc, curr) => `${acc} ${curr.name} ${curr.surname},`, "").slice(0, -1)}`,
                              });
                              return;
                            }
                            const resp =
                              await bookingRequestMutation.mutateAsync({
                                CorpCreateTransferRequest: {
                                  CartId: "",
                                  IsPreBook: true,
                                  KvkkStatus: true,
                                  PassengerInformations:
                                    passengersInformations as any,
                                  LinkId: "",
                                  TravelReasonId: tpData.payload?.reason?.value
                                    ? +tpData.payload.reason.value
                                    : 0,
                                  BranchId: tpData.payload?.branchOffice?.value
                                    ? +tpData.payload.branchOffice.value
                                    : undefined,
                                  RequesterUserIds: values.passengers
                                    .filter((x) => x.type === "employee")
                                    .map((x) => x.employeeGUID ?? ""),
                                  ProjectCode: values.invoiceNote ?? "",
                                  ReservationNote: values.requestNote ?? "",
                                  ProductKeys: summaryData.payload
                                    .detailKey as string[],
                                  SearchId: summaryData.payload.searchId ?? "",
                                  SearchProductKey:
                                    summaryData.payload.searchItemKey ?? "",
                                  CancelWarrantySearchId: "",
                                  RequestId: null,
                                  RoundTripInformations: [
                                    {
                                      SegmentGroupId: 0,
                                      TransferProductFlightDetails: {
                                        FlightDate: values.values?.departureInfo
                                          ?.flightDate?.date
                                          ? dayjs(
                                              values.values?.departureInfo
                                                .flightDate.date,
                                            ).format("YYYY-MM-DD")
                                          : null,
                                        FlightNumber:
                                          values.values?.departureInfo
                                            ?.flightNo ?? null,
                                        FlightTimeDeparture:
                                          values.values?.departureInfo
                                            ?.departureTime,
                                        FlightTimeArrival:
                                          values.values?.departureInfo
                                            ?.arrivalTime,
                                        FlightAirline:
                                          values.values?.departureInfo
                                            ?.airlineName,
                                        FlightAirport: null,
                                        FlightAddressDeparture: null,
                                        FlightAddressArrival:
                                          values.values?.departureInfo
                                            .address ?? null,
                                      },
                                    },
                                    ...(values.values?.arrivalInfo
                                      ? [
                                          {
                                            SegmentGroupId: 1,
                                            TransferProductFlightDetails: {
                                              FlightDate: values.values
                                                ?.arrivalInfo?.flightDate?.date
                                                ? dayjs(
                                                    values.values?.arrivalInfo
                                                      .flightDate.date,
                                                  ).format("YYYY-MM-DD")
                                                : null,
                                              FlightNumber:
                                                values.values?.arrivalInfo
                                                  ?.flightNo ?? null,
                                              FlightTimeDeparture:
                                                values.values?.arrivalInfo
                                                  ?.departureTime,
                                              FlightTimeArrival:
                                                values.values?.arrivalInfo
                                                  ?.arrivalTime,
                                              FlightAirline:
                                                values.values?.arrivalInfo
                                                  ?.airlineName,
                                              FlightAirport: null,
                                              FlightAddressDeparture: null,
                                              FlightAddressArrival:
                                                values.values?.arrivalInfo
                                                  ?.address ?? null,
                                            },
                                          },
                                        ]
                                      : []),
                                  ],
                                },
                              });

                            if (
                              !!resp?.result?.requestId &&
                              resp?.result?.requestId !== 0
                            ) {
                              router.push(
                                `/booking-request-success?bookingId=${resp.result.requestId}`,
                              );
                            } else {
                              setNotify({
                                message:
                                  resp?.errors?.[0]?.message ??
                                  "Bir hata oluştu",
                                title: "Hata",
                                variant: "error",
                              });
                            }
                          } else {
                            try {
                              const resp = await validateMutation.mutateAsync({
                                TransferValidateBookingRequest: {
                                  AddOnsKeyList: [],
                                  CartId: props.addToCardData.cartId,
                                  SearchId: summaryData.payload.searchId!,
                                  BookingPassengers: passengersInformations.map(
                                    (x) => ({
                                      ...x,
                                      PhoneNumbers:
                                        x.PhoneNumbers as unknown as string[],
                                      Gender: x.Gender ? +x.Gender : 0,
                                    }),
                                  ),
                                  KvkkApproval: true,
                                  CancelWarrantySearchId: "",
                                  BillingRequest: billingInfo as any,
                                  ReservationNotes:
                                    (values as any).specialNote ?? "",
                                },
                              });
                              setBookingData({
                                cartId: props.addToCardData.cartId,
                                searchId: summaryData.payload.searchId!,
                                transactionId:
                                  resp.data.result.serviceResponse.result
                                    .transactionKey,
                                preSaleAgreementText:
                                  resp.data.result.serviceResponse.result
                                    .preSaleAgreementText,
                                saleAgreementText:
                                  resp.data.result.serviceResponse.result
                                    .saleAgreementText,
                              });
                              if (
                                resp.data.result.serviceResponse.result
                                  .masterPassUserData
                              ) {
                                setMasterpassData({
                                  moduleName: "Transfer",
                                  payload: {
                                    masterpassLoginState: false,
                                    masterpassOtherUser: false,
                                    cardList: [],
                                    masterpassUserData:
                                      resp.data.result.serviceResponse.result
                                        .masterPassUserData,
                                    customerEmail: values.passengers[0]!.email,
                                    masterPassengerName:
                                      values.passengers[0]!.name! +
                                      values.passengers[0]!.surname!,
                                  },
                                });
                              }
                            } catch (error) {
                              setNotify({
                                title: "Bir Hata Oluştu!",
                                message: "Bir hata oluştu",
                                variant: "error",
                              });
                            }
                          }
                        }}
                        defaultValues={defaultValues}
                      >
                        <CoreSummaryPassengerGroup
                          hasReservationNote={!isB2E}
                          hasBadge={isB2C}
                          groupTitle={
                            props.addToCardData.transferItemList[0]
                              ?.transferName ?? ""
                          }
                          groupKey={`${GROUP_KEY_PREFIX}_${0}`}
                          groupProperties={[]}
                          passengers={props.passengersGroups[0] ?? []}
                        />

                        <Card>
                          <div className="flex flex-col">
                            <span className="text-sm font-semibold text-gray-800">
                              Seyahat Bilgileriniz
                            </span>
                            <span className="text-sm text-gray-500">
                              Transferinizi size uygun şekilde planlayabilmemiz
                              için lütfen aşağıdaki bilgileri dikkatlice
                              doldurun.
                            </span>
                          </div>
                          <hr className="my-2" />
                          <div className="my-4 text-sm font-semibold">
                            Gidiş Bilgileriniz
                          </div>
                          <TransferSummaryInfoForm prefix="departureInfo" />
                          {isReturn && (
                            <>
                              <div className="my-4 text-sm font-semibold">
                                Dönüş Bilgileriniz
                              </div>
                              <TransferSummaryInfoForm prefix="arrivalInfo" />
                            </>
                          )}
                        </Card>
                        {isB2E && (
                          <>
                            <CoreSummaryRequestNoteFormItem />
                            <CoreSummaryInvoiceNoteFormItem />
                          </>
                        )}
                        {isB2C && (
                          <>
                            <BillingInfoForm
                              prefix="billingInfo"
                              onChangeDiffrentBillingInfoValue={(value) => {
                                diffrentBillingInfoBoolean.setValue(value);
                              }}
                            />
                            <CoreSummaryNoteFormItem
                              name="specialNote"
                              placeholder="Talebinizi buraya yazın..."
                              title="Özel bir talebiniz mi var?"
                            />
                          </>
                        )}

                        <CoreSummaryPolicyFormItem
                          kvkkAgreementText={
                            props.addToCardData.kvkkAgreementText
                          }
                        />
                      </CoreSummaryForm>
                    </CoreSummaryMainColumn>
                  )}
                  <CoreSummarySideColumn
                    price={PriceManager({
                      currency: props.addToCardData.totalPrice.slice(0, 3),
                      value:
                        +props.addToCardData.totalPrice.slice(3) -
                        discounts.reduce((acc, item) => acc + +item.price, 0),
                    })}
                    button={
                      <CoreSummaryActionButton
                        status={
                          isB2C
                            ? paymentState?.payload?.paymentStatus === "payment"
                              ? "booking-payment"
                              : "booking-validation"
                            : "booking-request"
                        }
                        onClick={() => {
                          handleSubmitButtonClick();
                        }}
                        variant="primary"
                        loading={
                          bookingRequestMutation.isLoading
                          // || validateMutation.isLoading
                        }
                      />
                    }
                  >
                    <ReservationSummaryProvider>
                      <ReservationSummaryTitle text="Rezervasyon Özeti" />
                      {sortedTransferItemsByGroupId.map((item, index) => (
                        <>
                          {index !== 0 && (
                            <div>
                              <ReservationSummarySeperator />
                            </div>
                          )}
                          <div key={item.cartId}>
                            {isReturn && (
                              <div className="mb-1">
                                <span className="text-sm text-gray-500">
                                  {index === 0
                                    ? "Gidiş Transferi"
                                    : "Dönüş Transferi"}
                                </span>
                              </div>
                            )}
                            <div
                              className="flex items-start gap-2"
                              key={item.cartId}
                            >
                              <ReservationSummaryImage
                                reservationSummaryImage={
                                  summaryData.payload.productExtraInfo
                                    ?.images?.[index] ?? DefautlImage
                                }
                              />
                              <div className="flex flex-col gap-1">
                                <span className="text-sm font-semibold text-gray-800">
                                  {item.transferName}
                                </span>
                                <span className="text-sm text-gray-500">
                                  {dayjs
                                    .utc(item.startDate)
                                    .format("DD MMMM YYYY HH:mm")}
                                </span>
                              </div>
                            </div>
                            <ReservationSummaryRoutes
                              destination={item?.destination}
                              origin={item?.origin}
                            />
                          </div>
                        </>
                      ))}

                      <ReservationSummarySeperator />
                      <div>
                        <div className="flex items-center justify-between">
                          <span className="text-sm font-semibold text-gray-800">
                            Yolcu Sayısı
                          </span>
                          <span className="text-sm text-gray-600">
                            {props.addToCardData.passengersCount}
                          </span>
                        </div>

                        <div>
                          <span className="text-sm font-medium text-gray-600">
                            {`${
                              (tpData.payload.passengers.employee?.count ?? 0) +
                              (tpData.payload.passengers.guest?.count ?? 0)
                            } Yetişkin${
                              (tpData.payload.passengers.child?.count ?? 0) > 0
                                ? `, ${tpData.payload.passengers.child?.count} Çocuk`
                                : ""
                            }`}
                          </span>
                        </div>
                      </div>

                      <ReservationSummarySeperator />

                      {isReturn && (
                        <div>
                          {sortedTransferItemsByGroupId.map((item, index) => (
                            <div
                              key={item.groupId}
                              className="flex items-center justify-between"
                            >
                              <span className="text-sm">
                                {index === 0
                                  ? "Gidiş Transferi"
                                  : "Dönüş Transferi"}
                              </span>
                              <span className="text-sm">
                                {PriceManager({
                                  currency: item.totalPrice.slice(0, 3),
                                  value: +item.totalPrice.slice(3),
                                })}
                              </span>
                            </div>
                          ))}
                        </div>
                      )}
                      <CoreSummaryAdditionalPrices />

                      <ReservationSummaryPriceBox
                        price={PriceManager({
                          currency: props.addToCardData.totalPrice.slice(0, 3),
                          value:
                            +props.addToCardData.totalPrice.slice(3) -
                            discounts.reduce(
                              (acc, item) => acc + +item.price,
                              0,
                            ),
                        })}
                      />
                      {isDesktop && renderCouponCode()}
                      <CoreSummaryActionButton
                        status={
                          isB2C
                            ? paymentState?.payload?.paymentStatus === "payment"
                              ? "booking-payment"
                              : "booking-validation"
                            : "booking-request"
                        }
                        onClick={() => {
                          handleSubmitButtonClick();
                        }}
                        variant="primary"
                        loading={
                          bookingRequestMutation.isLoading
                          // || validateMutation.isLoading
                        }
                      />
                    </ReservationSummaryProvider>
                  </CoreSummarySideColumn>
                </CoreSummaryContent>
              </div>
            </Container>
          </div>
        </div>
      )}
    </CoreSummaryCtxProvider>
  );
}
