/* eslint-disable @typescript-eslint/no-use-before-define */
/* eslint-disable no-console */
/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable jsx-a11y/iframe-has-title */
/* eslint-disable react/jsx-key */

"use client";

import type { ElementRef } from "react";
import { useEffect, useRef } from "react";
import { useEffectOnce } from "usehooks-ts";

import { DialogContent } from "@/components/ui/dialog";
import Spinner from "@/components/ui/spinner";
import { useLocale } from "@/hooks/useLocale";
import {
  useGet3DParametersMutation,
  useGetPoll3DService,
} from "@/services/eva-booking/payment/payment.service";
import type {
  I3DParametersVariables,
  I3DPollVariables,
  I3DResponse,
} from "@/services/eva-booking/payment/payment-service.types";

interface ThreeDSecureModalProps {
  data: I3DParametersVariables;
  onDone: (isSuccess: boolean) => void;
  onError?: (message: string) => void;
}

const ThreeDSecureModalContent = (props: ThreeDSecureModalProps) => {
  const get3DMutation = useGet3DParametersMutation();
  const { t } = useLocale();

  async function mutateAsync() {
    try {
      const response = await get3DMutation.mutateAsync(props.data);
      if (!response.data?.success) {
        props.onError?.(t("Something went wrong!"));
      }
    } catch (error) {
      props.onError?.(t("Something went wrong!"));
    }
  }

  useEffectOnce(() => {
    mutateAsync();
  });

  useEffect(() => {}, []);

  return (
    <DialogContent
      className="h-[500px] w-[600px] p-0 pt-[50px]"
      onEscapeKeyDown={(e) => e.preventDefault()}
      onPointerDown={(e) => e.preventDefault()}
      onInteractOutside={(e) => e.preventDefault()}
    >
      <div className="scroll-bar max-h-[450px] p-5 text-center">
        {get3DMutation.isLoading && (
          <div>
            <Spinner />
          </div>
        )}
        {get3DMutation.isError && <div>Error</div>}
        {get3DMutation.isSuccess && get3DMutation.data?.data?.result?.url && (
          <div>
            <ThreeDForm
              result={get3DMutation.data?.data?.result}
              onDone={(status) => {
                props.onDone(status === 2);
              }}
              pollParams={{
                ...props.data,
              }}
            />
          </div>
        )}
      </div>
    </DialogContent>
  );
};

const ThreeDForm = (props: {
  result: I3DResponse["result"];
  pollParams: I3DPollVariables;
  onDone: (status: number) => void;
}) => {
  const { get3DPollService } = useGetPoll3DService();
  const ref = useRef<ElementRef<"form">>(null);
  const interval = useRef<any>(null);

  async function controllPoll3D() {
    const resp = await get3DPollService(props.pollParams);
    if (resp.data.result === 2) {
      props.onDone(2);
      if (interval.current) {
        clearInterval(interval.current);
        interval.current = null;
      }
    }
  }

  useEffect(() => {
    if (ref.current) {
      ref.current.submit();
      interval.current = setInterval(() => {
        controllPoll3D();
      }, 1000);
    }
    return () => {
      if (interval.current) {
        clearInterval(interval.current);
        interval.current = null;
      }
    };
  }, []);

  return (
    <div>
      <div>
        <form
          ref={ref}
          target="3dpamyment_iframe"
          encType="application/x-www-form-urlencoded"
          method="post"
          action={props.result.url}
          onSubmit={() => {}}
        >
          {Object.entries(props.result.parameters).map(([key, value]) => (
            <input
              hidden
              type="text"
              id={key}
              name={key}
              defaultValue={value}
            />
          ))}
          <input type="submit" hidden />
        </form>
        <iframe
          style={{ minHeight: 500, minWidth: "100%" }}
          name="3dpamyment_iframe"
        />
      </div>
    </div>
  );
};

export default ThreeDSecureModalContent;
