import { DialogContent } from "@/components/ui/dialog";
import Spinner from "@/components/ui/spinner";
import { useLocale } from "@/hooks/useLocale";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { useGetAllInstallmentsQuery } from "@/services/eva-booking/payment/payment.service";

interface AllInstallmentsModalContentProps {
  searchId: string;
  productKey: string;
}

const AllInstallmentsModalContent = (
  props: AllInstallmentsModalContentProps,
) => {
  const { data, isLoading, isFetching } = useGetAllInstallmentsQuery({
    productKey: props.productKey,
    searchId: props.searchId,
  });
  const { t } = useLocale();
  return (
    <DialogContent className="h-[542px] max-w-[1200px] overflow-auto">
      <h3 className="text-2xl font-bold">{t("Payment Options")}</h3>

      {data?.data?.errors && data?.data?.errors.length > 0 && (
        <div className="p-10 text-center">
          {data?.data?.errors.map((error) => (
            <div key={error}>{error.message}</div>
          ))}
        </div>
      )}

      {isLoading || (isFetching && <Spinner />)}

      {!isLoading && !isFetching && data?.data?.result && (
        <div className="grid grid-cols-2 gap-4">
          {data?.data?.result?.bankInstallments?.map((bankInstallment) => (
            <div key={bankInstallment.providerText}>
              <div className="border bg-gray-50 p-2">
                {bankInstallment.providerText}
              </div>
              <table
                className="w-full border"
                key={bankInstallment.providerText}
              >
                <thead>
                  <tr>
                    <th className="border p-2 text-sm font-normal">
                      {t("Installment")}
                    </th>
                    <th className="border p-2 text-sm font-normal">
                      {t("Amount")}
                    </th>
                    <th className="border p-2 text-sm font-normal">
                      {t("Total")}
                    </th>
                  </tr>
                </thead>
                <tbody>
                  {bankInstallment.installments
                    .sort((a, b) => a.installmentCount - b.installmentCount)
                    .map((installment) => (
                      <tr key={installment.totalAmount}>
                        <td className="border p-1 text-center text-sm font-semibold">
                          {installment.installmentCount}
                        </td>
                        <td className="border p-1 text-center text-sm font-semibold">
                          {PriceManager({
                            currency: installment.totalAmount.slice(0, 3),
                            value: +installment.monthlyPayTotal,
                          })}
                        </td>
                        <td className="border p-1 text-center text-sm font-semibold">
                          {PriceManager({
                            currency: installment.totalAmount.slice(0, 3),
                            value: +installment.totalAmount.slice(3),
                          })}
                        </td>
                      </tr>
                    ))}
                </tbody>
              </table>
            </div>
          ))}
        </div>
      )}
    </DialogContent>
  );
};

export default AllInstallmentsModalContent;
