/* eslint-disable react-hooks/exhaustive-deps */
/* eslint-disable react/no-unused-prop-types */
/* eslint-disable no-unsafe-optional-chaining */
/* eslint-disable no-alert */

"use client";

import Image from "next/image";
import { useRouter } from "next/navigation";
import type { ForwardedRef } from "react";
import { forwardRef, useEffect, useImperativeHandle, useState } from "react";
import { useFormContext } from "react-hook-form";
import { useBoolean, useIsMounted } from "usehooks-ts";

import FormMaskInput from "@/components/form/components/basic/form-mask-input";
import FormTextInput from "@/components/form/components/basic/form-text-input";
import Card from "@/components/ui/card/card";
import { Dialog } from "@/components/ui/dialog";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import Spinner from "@/components/ui/spinner";
import { useCoreSummaryCtx } from "@/features/core/summary/context/core-summary-context";
import {
  useSummaryCtxActions,
  useSummaryCtxState,
} from "@/features/modules/hotel/summary/context/summary-context";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";
import {
  useGetCampaignsMutation,
  useGetInstallmentsMutation,
} from "@/services/eva-booking/payment/payment.service";
import { useNotifyStore } from "@/store/notify-store/use-notify-store";

import PaymentBookingModalContent from "../../payment-booking/components/payment-booking-modal-content";
import ThreeDSecureModalContent from "./3d-modal";
import CreditCardCampaignsSelect from "./credit-card-campaigns";
import FormCreditCardInput from "./credit-card-input";
import CreditCardInstallmentsSelect from "./credit-card-installments";

interface CreditCardInfosProps {
  metadata: {
    transactionKey: string;
    cartId: string;
    searchId: string;
    reservationNote: string;
  };
  handles?: {
    onBookSuccess: (payload: { bookingCode: string }) => void;
    onBookFail: (payload: { message: string; data?: any }) => void;
  };
  noCampaign?: boolean;
}

export interface CreditCardInfosHandles {
  payAndBook: VoidFunction;
  setNullCampaign: VoidFunction;
}

const CreditCardInfos = (
  props: CreditCardInfosProps,
  ref: ForwardedRef<CreditCardInfosHandles>,
) => {
  const isMounted = useIsMounted();
  const threeDSecureBoolean = useBoolean();
  const bookingPaymentBoolean = useBoolean();
  const goCampaingRequest = useBoolean();
  const showCampaigns = useBoolean();
  const methods = useFormContext();
  const campaignsMutation = useGetCampaignsMutation();
  const installmentsMutation = useGetInstallmentsMutation();
  const { t } = useLocale();
  const { setNotify } = useNotifyStore();
  const router = useRouter();

  const summaryState = useSummaryCtxState();
  const { setCampaing } = useSummaryCtxActions();
  const coreSummaryCtx = useCoreSummaryCtx();
  const [selectState, setSelectState] = useState<{
    campaignKey: string;
    installmentKey: string;
  }>({
    campaignKey: "",
    installmentKey: "",
  });

  function valueOrPlaceholder(value: string | undefined, placeholder: string) {
    if (!value || value === "") return placeholder;
    return value;
  }

  const { watch } = methods;

  async function getInstallments() {
    const resp = await installmentsMutation.mutateAsync({
      transactionKey: props.metadata.transactionKey,
      cartId: props.metadata.cartId,
      creditCartNumber: watch("creditCard"),
      campaignKey: null,
    });
    if (resp.data?.result?.installmentList) {
      setSelectState((prev) => ({
        ...prev,
        installmentKey:
          resp.data.result.installmentList[0]?.installmentKey ?? "",
      }));
    }
  }

  useImperativeHandle(ref, () => ({
    payAndBook: () => {
      threeDSecureBoolean.setTrue();
    },
    setNullCampaign: () => {
      setSelectState((prev) => ({
        ...prev,
        campaignKey: "null",
      }));
      if (coreSummaryCtx.state.hasCreditCardCampaign) {
        coreSummaryCtx.actions.clearCreditCardCampaigns();
      }
      if (summaryState.campaing) {
        setCampaing({
          campaing: null,
          totalPrice:
            summaryState.totalPrice +
            +summaryState?.campaing?.discountAmount.slice(3),
          tryTotalPrice:
            summaryState.tryTotalPrice +
            +summaryState?.campaing?.discountAmountDefaultCurrency.slice(3),
        });
      }
      setTimeout(() => {
        getInstallments();
      }, 500);
    },
  }));

  async function getCampaings(creditCartNumber: string) {
    showCampaigns.setTrue();
    goCampaingRequest.setFalse();
    const result = await campaignsMutation.mutateAsync({
      transactionKey: props.metadata.transactionKey,
      cartId: props.metadata.cartId,
      creditCartNumber,
    });
    if (summaryState?.campaing) {
      setCampaing({
        campaing: null,
        totalPrice:
          summaryState.totalPrice +
          +summaryState?.campaing?.discountAmount.slice(3),
        tryTotalPrice:
          summaryState.tryTotalPrice +
          +summaryState?.campaing?.discountAmountDefaultCurrency.slice(3),
      });
    }
    if (result?.data?.result?.availableCampaignList) {
      setSelectState((prev) => ({
        ...prev,
        campaignKey: "null",
      }));
      getInstallments();
    }
  }

  useEffect(() => {
    if (isMounted()) {
      if (
        watch("creditCard")?.length === 16 &&
        campaignsMutation.status !== "idle"
      ) {
        getCampaings(watch("creditCard"));
      }
    }
  }, [coreSummaryCtx.state.hasCouponCode]);

  return (
    <div>
      <Card className="border-none bg-transparent">
        <div className="grid grid-cols-1 gap-4 md:grid-cols-2 ">
          <div>
            <div className="mb-4 inline-flex w-auto items-center gap-2 rounded-primary bg-success-50 px-4 py-2 text-green-500">
              <LIcon name="Shield" className="size-4" />
              <span className="text-xs">
                {t("Secure payment with 3D Secure")}
              </span>
            </div>
            <div className="flex flex-col items-stretch gap-3">
              <FormCreditCardInput
                placeholder={`${t("Card number")}*`}
                name="creditCard"
                rules={{
                  required: {
                    value: true,
                    message: t("This field is required"),
                  },
                }}
                onKeyDown={(e) => {
                  if (
                    e.key === "Backspace" &&
                    watch("creditCard")?.length <= 6
                  ) {
                    showCampaigns.setFalse();
                  }
                }}
                onValueChange={async (value) => {
                  if (
                    (value.length >= 6 && goCampaingRequest.value) ||
                    value.length === 16
                  ) {
                    showCampaigns.setTrue();
                    await getCampaings(value);
                    goCampaingRequest.setFalse();
                    const result = await campaignsMutation.mutateAsync({
                      transactionKey: props.metadata.transactionKey,
                      cartId: props.metadata.cartId,
                      creditCartNumber: value,
                    });
                    if (summaryState?.campaing) {
                      setCampaing({
                        campaing: null,
                        totalPrice:
                          summaryState.totalPrice +
                          +summaryState?.campaing?.discountAmount.slice(3),
                        tryTotalPrice:
                          summaryState.tryTotalPrice +
                          +summaryState?.campaing?.discountAmountDefaultCurrency.slice(
                            3,
                          ),
                      });
                    }
                    if (result?.data?.result?.availableCampaignList) {
                      setSelectState((prev) => ({
                        ...prev,
                        campaignKey: "null",
                      }));
                      getInstallments();
                    }
                  } else if (value.length >= 6) {
                    goCampaingRequest.setFalse();
                  } else {
                    goCampaingRequest.setTrue();
                  }
                }}
              />
              <FormTextInput
                name="fullname"
                rules={{
                  required: {
                    value: true,
                    message: t("This field is required"),
                  },
                }}
                fullWidth
                placeholder={`${t("Name and Surname on the Card")}*`}
                className="placeholder:text-sm placeholder:text-gray-500"
              />
              <div className="grid grid-cols-2 gap-3">
                <FormMaskInput
                  rules={{
                    required: {
                      value: true,
                      message: t("This field is required"),
                    },
                  }}
                  mask="creditCardExpire"
                  name="cardExpire"
                  placeholder={`${t("Expiration date")}*`}
                />
                <FormMaskInput
                  rules={{
                    required: {
                      value: true,
                      message: t("This field is required"),
                    },
                  }}
                  mask="creditCardCvc"
                  name="cardCvv"
                  placeholder="CVV*"
                />
              </div>
            </div>
          </div>
          <div className="hidden sm:block">
            <div className="h-[202px] w-full rounded-lg border bg-gray-50 px-6 py-4">
              <div className="flex size-full flex-col justify-between font-medium text-gray-400">
                <div className="flex justify-between">
                  <div>
                    {installmentsMutation.isSuccess && (
                      <Image
                        src="/assets/images/mastercard.png"
                        alt="chip"
                        width={24}
                        height={16}
                      />
                    )}
                  </div>
                  <Image
                    src="/assets/images/chip.png"
                    alt="chip"
                    width={31}
                    height={22}
                  />
                </div>
                <div>
                  <div
                    className={cn({ "text-gray-500": !!watch("creditCard") })}
                  >
                    {valueOrPlaceholder(
                      watch("creditCard"),
                      "0000 0000 0000 0000",
                    )}
                  </div>
                  <div
                    className={cn("mt-2 text-sm", {
                      "text-gray-500": !!watch("fullname"),
                    })}
                  >
                    {valueOrPlaceholder(watch("fullname"), t("Card Owner"))}
                  </div>
                  <div className="mt-6 flex gap-2 text-sm">
                    <span
                      className={cn({ "text-gray-500": watch("cardExpire") })}
                    >
                      {valueOrPlaceholder(
                        watch("cardExpire")?.replace(/(\d{2})(\d{2})/, "$1/$2"),
                        t("MM/YY"),
                      )}
                    </span>
                    <span className={cn({ "text-gray-500": watch("cardCvv") })}>
                      {valueOrPlaceholder(watch("cardCvv"), "CVV")}
                    </span>
                  </div>
                </div>
              </div>
            </div>
            <div className="mt-4 flex justify-end gap-2">
              <Image
                src="/assets/images/visa.png"
                alt="chip"
                width={24}
                height={16}
                className="object-contain"
              />
              <Image
                src="/assets/images/mastercard.png"
                alt="chip"
                width={24}
                height={16}
                className="object-contain"
              />
              <Image
                src="/assets/images/american-express.png"
                alt="chip"
                width={24}
                height={16}
                className="object-contain"
              />
              <Image
                src="/assets/images/troy.png"
                alt="chip"
                width={24}
                height={16}
                className="object-contain"
              />
            </div>
          </div>
        </div>
        <div className="mt-2">
          <div className=" flex items-center gap-2 text-gray-500">
            <LIcon name="AlertCircle" className="size-5" />
            <span className="text-xs">
              {t(
                "Installment options and campaigns will be updated according to your card information.",
              )}
            </span>
          </div>
          {showCampaigns.value &&
            (installmentsMutation.isLoading || campaignsMutation.isLoading ? (
              <div className="mt-4">
                <Spinner />
              </div>
            ) : (
              <>
                {!installmentsMutation.isLoading &&
                  installmentsMutation.data?.data.result?.installmentList && (
                    <div className="mt-4">
                      <h3 className="mb-4 font-medium">
                        {t("Installment Options")}
                      </h3>
                      <CreditCardInstallmentsSelect
                        options={installmentsMutation.data?.data.result?.installmentList.map(
                          (installment) => ({
                            monthlyPrice:
                              installment.monthlyPayTotal.toString(),
                            title: installment.installmentCountText,
                            totalPrice: installment.totalAmount,
                            value: installment.installmentKey,
                          }),
                        )}
                        onChange={(value) =>
                          setSelectState((prev) => ({
                            ...prev,
                            installmentKey: value,
                          }))
                        }
                        value={selectState.installmentKey}
                      />
                    </div>
                  )}
                {!campaignsMutation.isLoading &&
                  campaignsMutation.data?.data.result
                    ?.availableCampaignList && (
                    <div className="mt-6">
                      <h3 className="mb-4 font-medium">
                        {t("Current Campaigns")}
                      </h3>
                      {coreSummaryCtx.state.hasCouponCode && (
                        <div className="mb-4 flex gap-4 rounded border border-orange-300 bg-orange-50 p-4">
                          <LIcon name="Info" />
                          {t(
                            "Coupon codes cannot be used together with different campaigns. If you want to use the campaign, remove the discount coupon.",
                          )}
                        </div>
                      )}
                      <CreditCardCampaignsSelect
                        onChange={async (value) => {
                          const campaingData =
                            campaignsMutation.data?.data.result?.availableCampaignList?.find(
                              (cmp) => cmp.key === value,
                            );

                          if (value !== "null" && campaingData) {
                            coreSummaryCtx.actions.addCampaign({
                              code: campaingData.code,
                              currency:
                                campaingData.discountAmountDefaultCurrency,
                              title: campaingData.name,
                              price: +campaingData.discountAmount.slice(3),
                              type: "CreditCard",
                            });
                          } else {
                            coreSummaryCtx.actions.clearCreditCardCampaigns();
                          }

                          if (
                            summaryState.campaing?.key !== value &&
                            campaingData
                          ) {
                            setCampaing({
                              campaing: campaingData,
                              totalPrice: summaryState.campaing
                                ? summaryState.totalPrice +
                                  +summaryState.campaing.discountAmount.slice(
                                    3,
                                  ) -
                                  +campaingData.discountAmount.slice(3)
                                : summaryState.totalPrice -
                                  +campaingData.discountAmount.slice(3),
                              tryTotalPrice: summaryState.campaing
                                ? summaryState.tryTotalPrice +
                                  +summaryState.campaing.discountAmount.slice(
                                    3,
                                  ) -
                                  +campaingData.discountAmountDefaultCurrency.slice(
                                    3,
                                  )
                                : summaryState.tryTotalPrice -
                                  +campaingData.discountAmountDefaultCurrency.slice(
                                    3,
                                  ),
                            });
                          } else if (
                            summaryState.campaing?.key !== value &&
                            !campaingData &&
                            summaryState.campaing
                          ) {
                            setCampaing({
                              campaing: null,
                              totalPrice:
                                summaryState.totalPrice +
                                +summaryState?.campaing.discountAmount.slice(3),
                              tryTotalPrice:
                                summaryState.tryTotalPrice +
                                +summaryState?.campaing.discountAmountDefaultCurrency.slice(
                                  3,
                                ),
                            });
                          }

                          const resp = await installmentsMutation.mutateAsync({
                            transactionKey: props.metadata.transactionKey,
                            cartId: props.metadata.cartId,
                            creditCartNumber: watch("creditCard"),
                            campaignKey: value,
                          });
                          if (resp.data?.result?.installmentList) {
                            setSelectState((prev) => ({
                              ...prev,
                              installmentKey:
                                resp.data.result.installmentList[0]
                                  ?.installmentKey ?? "",
                            }));
                          }
                          setSelectState((prev) => ({
                            ...prev,
                            campaignKey: value,
                          }));
                        }}
                        value={selectState.campaignKey ?? "null"}
                        options={campaignsMutation.data?.data.result?.availableCampaignList
                          ?.filter((cmp) => {
                            if (!coreSummaryCtx.state.hasCouponCode)
                              return true;

                            return cmp.key === null;
                          })
                          ?.map((cmp) => ({
                            title: cmp.name,
                            value: cmp.key ?? "null",
                          }))}
                      />
                    </div>
                  )}
              </>
            ))}
        </div>
      </Card>

      <Dialog
        modal
        open={threeDSecureBoolean.value}
        onOpenChange={threeDSecureBoolean.setValue}
      >
        {threeDSecureBoolean.value && (
          <ThreeDSecureModalContent
            onDone={(isSuccess) => {
              if (isSuccess) {
                bookingPaymentBoolean.setTrue();
                threeDSecureBoolean.setFalse();
              } else {
                setNotify({
                  title: "Bir hata oluştu",
                  message: "",
                  variant: "error",
                });
                threeDSecureBoolean.setFalse();
              }
            }}
            onError={(message) => {
              threeDSecureBoolean.setFalse();
              setNotify({
                title: message,
                message: "",
                variant: "error",
              });
            }}
            data={{
              campaignKey:
                selectState.campaignKey === "null"
                  ? null
                  : selectState.campaignKey,
              installmentKey: selectState.installmentKey,
              transactionKey: props.metadata.transactionKey,
              cartId: props.metadata.cartId,
              searchId: props.metadata.searchId,
              cardNumber: watch("creditCard"),
              expireMonth: watch("cardExpire")?.slice(0, 2),
              expireYear: watch("cardExpire")?.slice(2, 4),
              cvv: watch("cardCvv"),
              cardOwner: watch("fullname"),
            }}
          />
        )}
      </Dialog>
      <Dialog modal open={bookingPaymentBoolean.value}>
        {bookingPaymentBoolean.value && (
          <PaymentBookingModalContent
            onBookSuccess={({ bookingCode }) => {
              if (props.handles?.onBookSuccess) {
                props.handles.onBookSuccess({ bookingCode });
              } else {
                router.push(
                  `/booking-success?code=${encodeURIComponent(bookingCode)}`,
                );
              }
              bookingPaymentBoolean.setFalse();
            }}
            onBookFail={({ message }) => {
              bookingPaymentBoolean.setFalse();
              if (props.handles?.onBookFail) {
                props.handles?.onBookFail({ message });
              } else {
                setNotify({
                  title: message,
                  message: "",
                  variant: "error",
                });
              }
            }}
            data={{
              campaignKey:
                selectState.campaignKey === "null"
                  ? null
                  : selectState.campaignKey,
              installmentKey: selectState.installmentKey,
              transactionKey: props.metadata.transactionKey,
              cartId: props.metadata.cartId,
              searchId: props.metadata.searchId,
              reservationNote: props.metadata.reservationNote,
              cardNumber: watch("creditCard"),
              expireMonth: watch("cardExpire")?.slice(0, 2),
              expireYear: watch("cardExpire")?.slice(2, 4),
              cvv: watch("cardCvv"),
              cardOwner: watch("fullname"),
            }}
          />
        )}
      </Dialog>
    </div>
  );
};

export default forwardRef(CreditCardInfos);
