import type { ValidateResult } from "react-hook-form";

import type { FormItemProps } from "@/components/form/form-item";
import FormItem from "@/components/form/form-item";
import type { InputProps } from "@/components/ui/input/input";
import MaskedInput from "@/components/ui/masked-input/masked-input";

interface FormCreditCardInputProps
  extends FormItemProps,
    Omit<InputProps, "name" | "onChange"> {
  validate?: (value: string) => ValidateResult | Promise<ValidateResult>;
  onValueChange?: (value: string) => void;
}

const FormCreditCardInput = ({ name, ...props }: FormCreditCardInputProps) => {
  return (
    <FormItem name={name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <MaskedInput
          fullWidth
          defaultValue={field.value}
          onChangeUnMasked={(value) => {
            props.onValueChange?.(value);
            setValue(value);
          }}
          onBlur={field.onBlur}
          mask="creditCard"
          isInvalid={Boolean(fieldState.error)}
          errorMessage={fieldState.error?.message}
          {...props}
        />
      )}
    </FormItem>
  );
};

export default FormCreditCardInput;
