import type { ForwardedRef } from "react";
import { forwardRef, useImperativeHandle, useRef } from "react";

import type { FormHandles } from "@/components/form/form";
import Form from "@/components/form/form";

import type { CreditCardInfosHandles } from "./credit-card-infos";
import CreditCardInfos from "./credit-card-infos";

interface CreditCardPaymentProps {
  metadata: {
    transactionKey: string;
    cartId: string;
    searchId: string;
    reservationNote: string;
  };
  handles?: {
    onBookSuccess: (payload: { bookingCode: string }) => void;
    onBookFail: (payload: { message: string; data?: any }) => void;
  };
  noCampaign?: boolean;
}

export interface CreditCardPaymentHandles extends FormHandles {
  clearSelectedCampaign?: VoidFunction;
}

const CreditCardPayment = (
  props: CreditCardPaymentProps,
  ref: ForwardedRef<CreditCardPaymentHandles>,
) => {
  const formRef = useRef<FormHandles>(null);
  const creditCardInfoRef = useRef<CreditCardInfosHandles>(null);

  useImperativeHandle(ref, () => ({
    submit: () => {
      formRef.current?.submit();
    },
    onlyValidate: () => {
      formRef.current?.onlyValidate();
    },
    clearSelectedCampaign: () => {
      creditCardInfoRef.current?.setNullCampaign();
    },
  }));

  return (
    <Form
      onSubmit={() => {
        creditCardInfoRef.current?.payAndBook();
      }}
      ref={formRef}
    >
      <CreditCardInfos
        noCampaign={props.noCampaign}
        metadata={props.metadata}
        ref={creditCardInfoRef}
        handles={props.handles}
      />
    </Form>
  );
};

export default forwardRef(CreditCardPayment);
