/* eslint-disable react-hooks/exhaustive-deps */

"use client";

import { useMemo } from "react";
import { useForm } from "react-hook-form";

import Form from "@/components/form/form";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import {
  DefaultPBTpPassenger,
  DefaultRBTpPassenger,
} from "@/data/default/tp-passenger";
import { useHotelTravelPlanner } from "@/features/modules/hotel/travel-planner/hooks/use-hotel-travel-planner";
import { TpDateRangePickerWrappedFormItem } from "@/features/travel-planner/components/travel-planner/components/tp-date-range-picker-form";
import { TpRoomSelectWrappedFormItem } from "@/features/travel-planner/components/travel-planner/components/tp-room-select-form";
import type { ITravelPlannerForm } from "@/features/travel-planner/components/travel-planner/travel-planner-form";
import { useApp } from "@/hooks/useApp";
import { useLocale } from "@/hooks/useLocale";
import { DateHelper } from "@/libs/helpers/date-time-helper";

const RoomTravelPlanner = () => {
  const { isB2C } = useApp();
  const { data, navigateToHotelList } = useHotelTravelPlanner();
  const { t } = useLocale();

  const defaultValues = useMemo(() => {
    return {
      "date-range": {
        from:
          data?.payload.dates && data.payload.dates.checkIn
            ? DateHelper.dateFromISOString(data.payload.dates.checkIn)
            : new Date(),
        to:
          data?.payload.dates && data.payload.dates.checkOut
            ? DateHelper.dateFromISOString(data.payload.dates.checkOut)
            : new Date(),
      },
      room: data?.payload?.rooms
        ? data.payload.rooms?.map((item) => ({
            employee: {
              count: item.employee?.count ?? 0,
            },
            guest: { count: item.guest?.count ?? 0 },
            child: {
              count: item.child?.count ?? 0,
              ages: item.child?.ages ?? [],
            },
          }))
        : [isB2C ? DefaultPBTpPassenger : DefaultRBTpPassenger],
    };
  }, [data]);

  const tpHotelForm = useForm<Pick<ITravelPlannerForm, "date-range" | "room">>({
    defaultValues,
  });
  return (
    <Card className="flex flex-col gap-4 p-5">
      <span className="text-xl font-semibold text-gray-800">
        {t("Room Options")}
      </span>
      <Form
        methods={tpHotelForm}
        onSubmit={(values: Pick<ITravelPlannerForm, "date-range" | "room">) => {
          if (data.payload) {
            navigateToHotelList(
              {
                ...data.payload,
                dates: {
                  checkIn: DateHelper.dateToISOString(
                    values["date-range"].from!,
                  ),
                  checkOut: DateHelper.dateToISOString(
                    values["date-range"].to!,
                  ),
                },
                rooms: values.room,
              },
              "_self",
            );
          }
        }}
      >
        <div className="flex flex-col items-center gap-4 md:grid md:grid-cols-12">
          <div className="w-full md:col-span-5">
            <TpDateRangePickerWrappedFormItem name="date-range" />
          </div>
          <div className="w-full md:col-span-5">
            <TpRoomSelectWrappedFormItem
              checkInDate={tpHotelForm.watch("date-range")?.from}
              name="room"
            />
          </div>
          <div className="w-full md:col-span-2">
            <Button className="w-full" type="submit" variant="outline-primary">
              {t("Update")}
            </Button>
          </div>
        </div>
      </Form>
    </Card>
  );
};

export default RoomTravelPlanner;
