/* eslint-disable no-nested-ternary */
/* eslint-disable @next/next/no-img-element */

import { useDemandListQuery } from "@/services/eva-display/demand/demand.services";

import BookingRequestSkeleton from "./components/booking-request-skeleton";
import FlightSuccess from "./components/flight-success";
import HotelSuccess from "./components/hotel-success";
import RentACarSuccess from "./components/rent-a-car-success";
import TransferSuccess from "./components/transfer-success";

interface BookingRequestSuccessProps {
  bookingRequestId: string;
  withoutApprove: boolean;
}

const BookingRequestSuccess = (props: BookingRequestSuccessProps) => {
  const demandListQuery = useDemandListQuery({
    bookingRequestId: +props.bookingRequestId,
  });
  if (demandListQuery.isLoading) {
    return <BookingRequestSkeleton />;
  }
  if (!demandListQuery.isSuccess) {
    return <div />;
  }

  const bookingRequest = demandListQuery.data?.find(
    (demandItem) => demandItem.id.toString() === props.bookingRequestId,
  );

  if (!bookingRequest) {
    return <div>Bir hata oluştu.</div>;
  }

  const { passengerInformations } = bookingRequest;

  const { displayInformations } = bookingRequest as any;
  const { reservationData } = bookingRequest as any;

  switch (bookingRequest.moduleName) {
    case "HotelModule":
      return (
        <HotelSuccess
          passengerInformations={JSON.parse(passengerInformations)}
          displayInformations={JSON.parse(displayInformations)}
          reservationData={JSON.parse(reservationData).DetailResponse}
          rezervationSearchData={JSON.parse(reservationData).SearchResponse}
          withoutApprove={props.withoutApprove}
          corpBookingRecords={bookingRequest}
        />
      );
    case "FlightModule":
      return (
        <FlightSuccess
          passengerInformations={JSON.parse(passengerInformations)}
          reservationData={JSON.parse(reservationData)}
        />
      );
    case "TransferModule":
      return (
        <TransferSuccess
          reservationData={JSON.parse(reservationData)}
          data={bookingRequest}
        />
      );
    case "CarRentalModule":
      return (
        <RentACarSuccess
          reservationData={JSON.parse(reservationData)}
          data={bookingRequest}
        />
      );

    default:
      return <div>{bookingRequest.moduleName}</div>;
  }
};

export default BookingRequestSuccess;
