import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import type { RezervationInfo } from "@/components/widget/booking-request/booking-request-rezervation-information/booking-request-rezervation-information";
import {
  BookingRequestRezervationInformation,
  RezervationFlightCard,
  RezervationFlightInfo,
  RezervationSuccessTotalPrice,
} from "@/components/widget/booking-request/booking-request-rezervation-information/booking-request-rezervation-information";
import { BookingRequestSuccess } from "@/components/widget/booking-request/booking-request-success/booking-request-success";
import {
  DateHelper,
  getFormatedFlightTime,
} from "@/libs/helpers/date-time-helper";
import {
  getAirportCode,
  getCityName,
  sortCombinationGroupsForBookingRequest,
  sortFlightSegmentsForBookingRequest,
} from "@/libs/helpers/flight-helper";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type {
  PassengerInformations,
  ReservationData,
} from "@/services/eva-display/demand/demand-service.types";

interface FlightSuccessProps {
  passengerInformations: PassengerInformations[];
  reservationData: ReservationData;
}

const FlightSuccess = ({
  passengerInformations,
  reservationData,
}: FlightSuccessProps) => {
  function getReservationInfo() {
    const temp: RezervationInfo[] = [];
    let formattedNames = "";
    passengerInformations.forEach((person) => {
      if (person.Name && person.Surname) {
        formattedNames += `${person.Name} ${person.Surname},`;
      }
    });
    temp.push({
      label: "Uçuş Tipi",
      value:
        reservationData.DetailResponse.PricingCombinations[0]!.CombinationGroups
          .length > 1 ||
        reservationData.DetailResponse.PricingCombinations.length > 1
          ? "Gidiş Dönüş"
          : "Tek yön",
      icon: <LIcon name="Plane" size="18" />,
    });
    temp.push({
      label: "Kişi Sayısı",
      value: `${passengerInformations.length} Kişi`,
      icon: <LIcon name="User" size="18" />,
    });
    temp.push({
      label: "Kişi Bilgisi",
      value: formattedNames.slice(0, -1),
    });
    return temp;
  }

  const mainCurrency =
    reservationData!.DetailResponse!.PricingCombinations[0]!.TotalPrice.slice(
      0,
      3,
    );
  const totalledPrice =
    reservationData.DetailResponse.PricingCombinations.length > 1
      ? reservationData.DetailResponse.PricingCombinations.reduce(
          (acc, item) => acc + +item.TotalPrice.slice(3),
          0,
        )
      : +reservationData.DetailResponse.PricingCombinations[0]!.TotalPrice.slice(
          3,
        );

  const totalPrice = PriceManager({
    currency: mainCurrency,
    value: totalledPrice,
  });

  const sortingData = sortCombinationGroupsForBookingRequest(
    reservationData.DetailResponse.PricingCombinations.length > 1
      ? reservationData.DetailResponse.PricingCombinations.flatMap(
          (item) => item.CombinationGroups,
        )
      : reservationData.DetailResponse.PricingCombinations[0]!
          .CombinationGroups,
  );

  return (
    <div className="flex flex-col gap-4 pb-4">
      <BookingRequestSuccess passengerInformations={passengerInformations} />
      <BookingRequestRezervationInformation>
        <RezervationFlightInfo data={getReservationInfo()} />
        <div className="flex flex-col gap-4">
          {sortingData.map((item) => {
            const flightSegments = sortFlightSegmentsForBookingRequest(
              item.FlightSegments,
            );

            const flightSegment = flightSegments[0]!;
            const arrivalSegment = flightSegments[flightSegments.length - 1]!;
            const directs = flightSegments.map(
              (_flightSegmentItem) => _flightSegmentItem.MarketingAirline,
            );
            return (
              <RezervationFlightCard
                key={item.Key}
                destination={getCityName(arrivalSegment!.Destination)}
                origin={getCityName(flightSegment!.Origin)}
                date={DateHelper.dayjs(
                  flightSegment!.DepartureTime as unknown as Date,
                ).format("D MMMM YYYY ddd")}
                logoSrc={`https://concorecdn.jollytur.com/concore/media/site/assets/img/theme/${
                  flightSegment!.OperatingAirlineCode
                }-42x42.gif?v1040`}
                brandName={flightSegment!.OperatingAirline}
                flightCode={flightSegment!.FlightNumber}
                totalFlightHours={getFormatedFlightTime(item.TravelTime)}
                flightStartTime={DateHelper.dateToTime(
                  flightSegment!.DepartureTime as unknown as Date,
                )}
                endStartTime={DateHelper.dateToTime(
                  arrivalSegment!.ArrivalTime as unknown as Date,
                )}
                transferInformation={`${
                  directs.length === 1
                    ? "Aktarmasız"
                    : `${directs.length - 1} Aktarmalı`
                }, ${item.CabinClassTitle}`}
                startIATACode={getAirportCode(flightSegment!.Origin)!}
                endIATACode={getAirportCode(arrivalSegment!.Destination)!}
                // totalPrice={PriceManager({
                //   currency: totalPrice.slice(0, 3),
                //   value: +totalPrice.slice(3),
                // })}
              />
            );
          })}
        </div>
        {/* <RezervationSuccessFlightPrice priceDescription={priceDescription} /> */}
        <RezervationSuccessTotalPrice price={totalPrice} />
      </BookingRequestRezervationInformation>
    </div>
  );
};

export default FlightSuccess;
