/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";
import Image from "next/image";

import NoImage from "@/assets/svg/images/no-image.svg";
import Card from "@/components/ui/card/card";
import {
  Collapsible,
  CollapsibleContent,
  CollapsibleTrigger,
} from "@/components/ui/collapsible/collapsible";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import type {
  DisplayInformations,
  HotelDetailResponse,
  PassengerInformations,
  RezervationHotelSearchResponse,
} from "@/services/eva-display/demand/demand-service.types";

interface HotelSuccessProps {
  passengerInformations: PassengerInformations[];
  displayInformations: DisplayInformations;
  reservationData: HotelDetailResponse;
  rezervationSearchData: RezervationHotelSearchResponse;
  withoutApprove: boolean;
  corpBookingRecords?: any;
}

const HotelSuccess = (props: HotelSuccessProps) => {
  function getPassengerNameSurname(filter: any) {
    let formattedNames = "";
    props.passengerInformations.filter(filter).forEach((person) => {
      if (person.Name && person.Surname) {
        formattedNames += `${person.Name} ${person.Surname},`;
      }
    });
    return formattedNames.slice(0, -1);
  }
  return (
    <div className="pb-10">
      <Card>
        <div>
          <div className="flex items-center gap-3 text-lg text-success-500 md:text-2xl">
            <LIcon name="CheckCircle" className="gap-6" />
            <h2 className="font-semibold">
              {props.withoutApprove
                ? "Rezervasyon Oluşturuldu"
                : "Rezervasyon talebiniz gönderildi."}
            </h2>
          </div>

          {props.withoutApprove ? (
            <div className="mt-4 flex flex-col gap-4">
              <div className="flex items-center gap-2">
                <LIcon name="Check" className="size-5" />
                <span className="text-sm font-normal ">
                  Rezervasyon numaranız:
                </span>
                <span className="text-lg font-medium">
                  {props.corpBookingRecords.corpBookingRecords[0].bookingKey}
                </span>
              </div>
              <div className="flex items-center gap-2">
                <LIcon name="Check" className="size-5" />
                <span className="text-sm font-normal ">
                  Rezervasyon bilgileriniz rezervasyon kişilerine e-posta olarak
                  gönderilmiştir.
                </span>
              </div>
            </div>
          ) : (
            <div className="mt-4 flex items-stretch gap-4 md:mt-6">
              <div className="flex shrink-0 flex-col items-center justify-between pb-9">
                <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
                  1
                </div>
                <div className="w-px grow bg-primary-500" />
                <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
                  2
                </div>
                <div className="w-px grow bg-gray-100" />
                <div className="flex size-6 items-center justify-center rounded-full bg-gray-100 text-sm text-gray-400">
                  3
                </div>
              </div>
              <div className="flex flex-col gap-6">
                <div>
                  <p className="font-medium text-primary-500">
                    Talep Oluşturuldu
                  </p>
                  <p className="text-sm">Rezervasyon talebiniz oluşturuldu.</p>
                </div>
                <div>
                  <p className="font-medium text-primary-500">
                    Onay Bekleniyor
                  </p>
                  <p className="text-sm">
                    Rezervasyonunuz yetkili kişilere kontrol edip onaylaması
                    için gönderildi.
                  </p>
                </div>
                <div>
                  <p className="font-medium text-gray-400">
                    Rezervasyon oluşturuldu.
                  </p>
                  <p className="text-sm">
                    Rezervasyon numaranız talebiniz onaylandıktan sonra
                    rezervasyon kişilerine e-posta olarak iletilecektir.
                  </p>
                </div>
              </div>
            </div>
          )}

          {props.reservationData.RoomCollectionResult.map(
            (roomCollectionResult) =>
              roomCollectionResult.Rooms.filter(
                (x) => x.PassengerKeys?.length > 0,
              ).map((room, roomIndex) => (
                <div className="mt-6  pl-10" key={room.Key}>
                  <h4 className="mb-2 text-sm font-semibold">
                    {`${roomIndex + 1}. Oda ${roomCollectionResult.Title}`}
                  </h4>
                  <div
                    key={room.Key}
                    className="grid gap-2  md:grid-cols-2 md:gap-4"
                  >
                    {props.passengerInformations
                      .filter((x) => room.PassengerKeys.includes(x.Key))
                      .map((passengerInformation, index) => (
                        <div
                          className="flex min-h-[80px] flex-col justify-center rounded-primary border border-gray-200 bg-gray-50 p-4"
                          key={passengerInformation.Id}
                        >
                          <div className="flex flex-col text-sm md:flex-row md:items-center md:gap-2">
                            <span className="text-gray-500">
                              {index + 1}.kişi
                            </span>
                            <span className="font-medium">
                              {`${passengerInformation.Name} ${passengerInformation.Surname}`}
                            </span>
                          </div>
                          {/* <div className="mt-2">
                          <span className="text-sm">
                            {passengerInformation.Email}
                          </span>
                        </div> */}
                        </div>
                      ))}
                  </div>
                </div>
              )),
          )}

          {/* <div className="mt-4">
            <div className="flex items-center gap-1">
              <LIcon name="Check" className="w-3" />
              <span className="text-sm">Rezervasyon Numaranız:</span>
              <span className="text-lg">23189135</span>
            </div>
            <div className="flex items-center gap-1 mt-4">
              <LIcon name="Check" className="w-3" />
              <span className="text-sm">
                Rezervasyon bilgileriniz rezervasyon kişilerine e-posta olarak
                gönderilmiştir.
              </span>
            </div>
            <div className="mt-4 gap-4 grid grid-cols-2  gap-4">
              <div className="bg-gray-50 min-h-[80px] flex flex-col justify-center border border-gray-200 rounded-primary p-4">
                <div className="flex items-center gap-2 text-sm">
                  <span className="text-gray-500">1.kişi</span>
                  <span className="font-medium">Can Yılmazer</span>
                </div>
                <div className="mt-2">
                  <span className="text-sm">canyılmazer@gordiontech.com</span>
                </div>
              </div>
              <div className="bg-gray-50 h-[30px]">A</div>
            </div>
          </div> */}
        </div>
      </Card>
      <Card className="mt-6">
        <Collapsible defaultOpen>
          <CollapsibleTrigger className="group w-full">
            <div className="flex items-center justify-between">
              <h2 className="text-left text-lg font-semibold md:text-2xl">
                Rezervasyon ve Tesis Bilgileri
              </h2>
              <div className="cursor-pointer group-data-[state=open]:rotate-180">
                <LIcon name="ChevronDown" className="w-6" />
              </div>
            </div>
          </CollapsibleTrigger>
          <CollapsibleContent>
            <div>
              <div className="mt-4 flex flex-col justify-between gap-3 rounded-primary border border-gray-200 bg-gray-50 p-4 md:flex-row md:gap-0">
                <div className="flex flex-col text-sm">
                  <span className="text-gray-500">Giriş Tarihi</span>
                  <span className="mt-0.5 font-semibold">
                    {dayjs(
                      props.displayInformations.SearchRequest.CheckInDate,
                    ).format("D MMMM YYYY ddd")}
                  </span>
                </div>
                <div className="flex flex-col text-sm">
                  <span className="text-gray-500">Çıkış Tarihi</span>
                  <span className="mt-0.5 font-semibold">
                    {dayjs(
                      props.displayInformations.SearchRequest.CheckOutDate,
                    ).format("D MMMM YYYY ddd")}
                  </span>
                </div>
                <div className="flex flex-col text-sm">
                  <span className="text-gray-500">Gece Sayısı</span>
                  <span className="mt-0.5 font-semibold">
                    {
                      props.reservationData.RoomCollectionResult[0]?.Rooms[0]
                        ?.NightlyRateDescription
                    }
                  </span>
                </div>
              </div>

              <div className="primary mt-4 rounded border border-gray-200 bg-gray-50 p-4">
                <div className="flex gap-4">
                  <img
                    src={props.rezervationSearchData.Items[0]!.Images[0]!.Url}
                    className="h-[86px] w-[125px] rounded-primary"
                    alt="img"
                  />
                  <div>
                    <h3 className="text-base font-semibold md:text-xl">
                      {props.reservationData.Name}
                    </h3>
                    <p className="mt-2 text-sm text-gray-500">
                      {props.rezervationSearchData.Items[0]?.Location.replace(
                        ",",
                        " /",
                      )}
                    </p>
                  </div>
                </div>
                {/* <hr className="my-4" /> */}
                {/* <div className="flex flex-col gap-3">
                  <h3 className="text-sm font-semibold">Adres</h3>
                  <div className="flex items-center gap-2">
                    <LIcon name="MapPin" className="w-4" />
                    <p className="text-sm">
                      Kundu, Kavaklı Sarnıç Cad, 1531. Sk. No:6, 48470
                      Lara/Antalya
                    </p>
                  </div>
                  <div className="flex items-center gap-2">
                    <LIcon name="Phone" className="w-4" />
                    <p className="text-sm">444 00 73</p>
                  </div>
                </div> */}
              </div>
              {props.reservationData.RoomCollectionResult.map((item) => {
                return item.Rooms.filter(
                  (x) => x.PassengerKeys?.length > 0,
                ).map((room) => {
                  return (
                    <div
                      key={room.Key}
                      className="primary mt-4 rounded border border-gray-200 bg-gray-50 p-4"
                    >
                      <div className="flex gap-4 text-sm">
                        {item.Images?.[0]?.Url ? (
                          <img
                            src={item.Images?.[0]?.Url}
                            className="h-[86px] w-[125px] rounded-primary"
                            alt="img"
                          />
                        ) : (
                          <div className="relative h-[86px] w-[125px]">
                            <Image
                              src={NoImage}
                              alt="no-img"
                              className="rounded-primary"
                              objectFit="cover"
                              fill
                            />
                          </div>
                        )}
                        <div>
                          <h3 className="font-semibold">{item?.Title}</h3>
                          <div className="flex flex-col gap-0 md:flex-row md:gap-2">
                            <div className="flex  items-center gap-1 text-sm text-gray-500">
                              <LIcon
                                name="User"
                                className="hidden w-3 md:block"
                              />
                              <span>{room.PassengerKeys.length} kişi</span>
                            </div>
                            <div className="flex items-center gap-1 text-sm text-gray-500">
                              <LIcon
                                name="Check"
                                className="hidden w-3 md:block"
                              />
                              <span>{item.Rooms[0]?.MealType.Description}</span>
                            </div>
                          </div>
                          <div className="flex gap-2 text-gray-500">
                            {getPassengerNameSurname((p: any) =>
                              room.PassengerKeys.includes(p.Key),
                            )}
                          </div>
                        </div>
                      </div>
                    </div>
                  );
                });
              })}
            </div>
          </CollapsibleContent>
        </Collapsible>
      </Card>
    </div>
  );
};

export default HotelSuccess;
