/* eslint-disable jsx-a11y/img-redundant-alt */
/* eslint-disable @next/next/no-img-element */
import dayjs from "dayjs";

import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { carRentalProviderImageUrl } from "@/components/widget/rent-a-car-card/rent-a-car-card";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { CarType } from "@/services/eva-display/rent-a-car/rent-a-car.enums";
import type {
  CarExtraOption,
  CarInsurance,
} from "@/services/eva-display/rent-a-car/rent-a-car-detail/rent-a-car-detail.types";

interface RentACarSuccessProps {
  reservationData: any;
  data: any;
}

const RentACarSuccess = ({ reservationData, data }: RentACarSuccessProps) => {
  const car = reservationData?.DetailResponse?.Car;
  const carDetail = car?.CarDetail;
  const carExtraOption = car?.CarExtraOption;
  const carInsurances = car?.CarInsurances;
  const passengerInformations = JSON.parse(data.passengerInformations);
  const selectedOptions = [
    ...(carExtraOption.filter((item: CarExtraOption) => item.Selected) || []),
    ...(carInsurances.filter((item: CarInsurance) => item.Selected) || []),
  ];

  const getTotalDay = () => {
    const totalHours = dayjs(carDetail?.ReturnDate).diff(
      dayjs(carDetail?.PickupDate),
      "minute",
    );

    return Math.ceil(totalHours / 24 / 60);
  };
  const totalDay = getTotalDay();

  const oneWayPrice = PriceManager({
    currency: car.OneWay.slice(0, 3) || "TRY",
    value: +`${car.OneWay}0`.slice(3),
  });
  const locationFee = PriceManager({
    currency: car.LocationFee.slice(0, 3) || "TRY",
    value: +`${car.LocationFee}0`.slice(3),
  });
  const subTotal =
    selectedOptions.reduce((acc, item) => {
      return acc + +`${item.TotalPrice}0`.slice(3);
    }, 0) +
    +`${car.OneWay}0`.slice(3) +
    +`${car.LocationFee}0`.slice(3);

  const intlSubTotal = PriceManager({
    currency: car.OneWay.slice(0, 3) || "TRY",
    value: subTotal,
  });

  const allTotal = PriceManager({
    currency: car?.TotalPrice.slice(0, 3) || "TRY",
    value: +`${car?.TotalPrice}0`.slice(3) + subTotal,
  });

  return (
    <div className="space-y-4 pb-10">
      {/* Reservation Status Info */}
      <Card>
        <div className="flex items-center gap-3 text-2xl text-success-500">
          <LIcon name="CheckCircle" className="gap-6" />
          <h2 className="font-semibold">Rezervasyon talebiniz gönderildi.</h2>
        </div>
        <div className="mt-6 flex items-stretch gap-4">
          <div className="flex shrink-0 flex-col items-center justify-between pb-9">
            <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
              1
            </div>
            <div className="w-px grow bg-primary-500" />
            <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
              2
            </div>
            <div className="w-px grow bg-gray-100" />
            <div className="flex size-6 items-center justify-center rounded-full bg-gray-100 text-sm text-gray-400">
              3
            </div>
          </div>
          <div className="flex flex-col gap-6">
            <div>
              <p className="font-medium text-primary-500">Talep Oluşturuldu</p>
              <p className="text-sm">Rezervasyon talebiniz oluşturuldu.</p>
            </div>
            <div>
              <p className="font-medium text-primary-500">Onay Bekleniyor</p>
              <p className="text-sm">
                Rezervasyonunuz yetkili kişilere kontrol edip onaylaması için
                gönderildi.
              </p>
            </div>
            <div>
              <p className="font-medium text-gray-400">
                Rezervasyon oluşturuldu.
              </p>
              <p className="text-sm">
                Rezervasyon numaranız talebiniz onaylandıktan sonra&nbsp;
                {passengerInformations?.[0]?.Email && (
                  <>
                    <span className="font-bold">
                      {passengerInformations?.[0]?.Email}
                    </span>
                    &nbsp;adresine
                  </>
                )}
                &nbsp;e-posta olarak iletilecektir.
              </p>
            </div>
          </div>
        </div>
      </Card>
      {/* Reservation Summary */}
      <Card>
        <div className="text-xl font-semibold">Rezervasyon Özeti</div>
        <div className="mt-4 flex items-center gap-2">
          <div className="relative h-14 w-24">
            <img
              className="absolute left-0 top-0 w-16 object-cover"
              src={
                carRentalProviderImageUrl[
                  car?.CarRentalCompany
                    ?.Code as keyof typeof carRentalProviderImageUrl
                ]
              }
              alt="provider image"
            />
            <img
              src={carDetail?.ImageUrl}
              alt={carDetail?.Name}
              className="size-full object-contain"
            />
          </div>
          <div>
            <p className="text-sm font-semibold text-gray-800">
              {CarType[carDetail?.Type || 0]}
            </p>
            <p className="text-sm text-gray-500">{carDetail?.Name}</p>
          </div>
        </div>
        <div className="my-6 flex items-start justify-between border-y border-gray-200 py-3">
          <div className="w-1/2 border-r border-gray-200 pr-2">
            <div className="flex items-center justify-between">
              <div className="text-sm font-semibold text-gray-800">
                Alış Noktası
              </div>
              <div className="text-sm">
                {dayjs(carDetail?.PickupDate).format("DD MMM YYYY, HH:mm")}
              </div>
            </div>
            <div className="mt-2 flex items-center gap-3 text-sm text-gray-800">
              <LIcon name="MapPin" size={14} /> {carDetail?.PickupCode}
            </div>
          </div>
          <div className="w-1/2 pl-2">
            <div className="flex items-center justify-between">
              <div className="text-sm font-semibold text-gray-800">
                Teslim Noktası
              </div>
              <div className="text-sm">
                {dayjs(carDetail?.ReturnDate).format("DD MMM YYYY, HH:mm")}
              </div>
            </div>
            <div className="mt-2 flex items-center gap-3 text-sm text-gray-800">
              <LIcon name="MapPin" size={14} />
              {carDetail?.ReturnCode}
            </div>
          </div>
        </div>
        <div>
          <div className="text-sm font-semibold text-gray-800">
            Ek Hizmetler ve Güvence Paketi
          </div>
          <div>
            {selectedOptions.map((item: any, index: number) => (
              <div
                key={+index}
                className="my-1 flex w-full justify-between text-sm text-gray-800"
              >
                <span>{item.Name || item.Description}</span>
                {/* @todo - This field is static because BE Team said this field is have to be like this. */}
                <span className="text-gray-800">1 Adet</span>
              </div>
            ))}
          </div>
        </div>
      </Card>
      {/* Price Summary */}
      <Card>
        <div className="text-xl font-semibold">Fiyat Özeti</div>
        {(subTotal > 0 || oneWayPrice || locationFee) && (
          <div className="my-4 rounded bg-blue-50 p-4">
            <p className="text-xs">
              Ek hizmet ücretini ve hizmet bedelini, aracınızı teslim alırken
              hizmeti sağlayan firmaya ofiste ödeyeceksiniz.
            </p>
          </div>
        )}
        <div>
          {(subTotal > 0 || oneWayPrice || locationFee) && (
            <div className="text-sm font-semibold text-gray-800">
              Ofiste Ödenecek Tutar
            </div>
          )}
          <div>
            {(subTotal > 0 || oneWayPrice || locationFee) && (
              <>
                {/* Selected Options */}
                {selectedOptions.length > 0 &&
                  selectedOptions.map((item) => (
                    <div
                      key={item.Code}
                      className="my-1 flex w-full justify-between text-sm text-gray-800"
                    >
                      <span>
                        {(item as CarInsurance).Description ||
                          (item as CarExtraOption).Name}
                        &nbsp;
                        <span className="text-xs text-gray-500">
                          ({totalDay} gün&nbsp;x&nbsp;
                          {PriceManager({
                            currency: item.UnitPrice.slice(0, 3) || "TRY",
                            value: +`${item.UnitPrice}0`.slice(3),
                          })}
                          )
                        </span>
                      </span>
                      <span className="text-gray-800">
                        {PriceManager({
                          currency: item.TotalPrice.slice(0, 3) || "TRY",
                          value: +`${item.TotalPrice}0`.slice(3),
                        })}
                      </span>
                    </div>
                  ))}
                {/* One Way Price */}
                {oneWayPrice && (
                  <div className="my-1 flex w-full justify-between text-sm text-gray-800">
                    <span>Tek Yön Ücreti</span>
                    <span className="text-gray-800">{oneWayPrice}</span>
                  </div>
                )}
                {/* Location Fee */}
                {locationFee && (
                  <div className="my-1 flex w-full justify-between text-sm text-gray-800">
                    <span>Ofis Hizmet Ücreti</span>
                    <span className="text-gray-800">{locationFee}</span>
                  </div>
                )}
                <div className="my-1 flex w-full justify-between text-sm font-semibold text-gray-800">
                  <span>Ara Toplam</span>
                  <span className="text-lg text-gray-800">
                    {intlSubTotal} TL
                  </span>
                </div>
              </>
            )}

            {/* Ödenmiş Tutar */}
            <div className="my-4 flex w-full justify-between text-sm font-semibold text-gray-800">
              <span>Ödenmiş Tutar</span>
            </div>
            <div className="my-1 flex w-full justify-between text-sm text-gray-800">
              <span>
                Araç Kiralama&nbsp;
                <span className="text-xs text-gray-500">
                  ({totalDay} Gün x{" "}
                  {PriceManager({
                    currency: car.BasePrice.slice(0, 3) || "TRY",
                    value: +`${car.BasePrice}0`.slice(3),
                  })}
                  )
                </span>
              </span>
              <span className="text-lg font-semibold text-gray-800">
                {PriceManager({
                  currency: car?.TotalPrice.slice(0, 3) || "TRY",
                  value: +`${car?.TotalPrice}0`.slice(3),
                })}
              </span>
            </div>
            <div className="mt-3 rounded-primary border border-gray-200 p-4">
              <div className="flex items-center justify-between">
                <span className="text-sm text-gray-500">Toplam Tutar</span>
                <span className="text-xl font-semibold">{allTotal} TL</span>
              </div>
            </div>
          </div>
        </div>
      </Card>
    </div>
  );
};

export default RentACarSuccess;
