import dayjs from "dayjs";

import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import TransferMultipleWayCard from "@/components/widget/request-card/transfer-request-card/transfer-multiple-way-card";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { ITransferReservationData } from "@/services/eva-display/demand/transfer-reservation-data/transfer-reservation-data";

interface TransferSuccessProps {
  reservationData: any;
  data: any;
}

const TransferSuccess = ({ reservationData, data }: TransferSuccessProps) => {
  let transferSegmentGroupItems =
    reservationData.DetailResponse.TransferSegmentGroupItem.filter((x: any) =>
      reservationData.ProductKeys.includes(x.Key),
    );

  transferSegmentGroupItems = transferSegmentGroupItems.sort(
    (a: any, b: any) =>
      dayjs(a.Items[0]?.DepartureTime).valueOf() -
      dayjs(b.Items[0]?.DepartureTime).valueOf(),
  );

  const originSegmentGroup = transferSegmentGroupItems[0]?.Items[0];
  const destinationSegmentGroup =
    transferSegmentGroupItems.length === 1
      ? null
      : transferSegmentGroupItems[1]?.Items[0];
  return (
    <div className="space-y-4 pb-10">
      <Card>
        <div className="flex items-center gap-3 text-2xl text-success-500">
          <LIcon name="CheckCircle" className="gap-6" />
          <h2 className="font-semibold">Rezervasyon talebiniz gönderildi.</h2>
        </div>
        <div className="mt-6 flex items-stretch gap-4">
          <div className="flex shrink-0 flex-col items-center justify-between pb-9">
            <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
              1
            </div>
            <div className="w-px grow bg-primary-500" />
            <div className="flex size-6 items-center justify-center rounded-full bg-primary-50 text-sm text-primary-500">
              2
            </div>
            <div className="w-px grow bg-gray-100" />
            <div className="flex size-6 items-center justify-center rounded-full bg-gray-100 text-sm text-gray-400">
              3
            </div>
          </div>
          <div className="flex flex-col gap-6">
            <div>
              <p className="font-medium text-primary-500">Talep Oluşturuldu</p>
              <p className="text-sm">Rezervasyon talebiniz oluşturuldu.</p>
            </div>
            <div>
              <p className="font-medium text-primary-500">Onay Bekleniyor</p>
              <p className="text-sm">
                Rezervasyonunuz yetkili kişilere kontrol edip onaylaması için
                gönderildi.
              </p>
            </div>
            <div>
              <p className="font-medium text-gray-400">
                Rezervasyon oluşturuldu.
              </p>
              <p className="text-sm">
                Rezervasyon numaranız talebiniz onaylandıktan sonra rezervasyon
                kişilerine e-posta olarak iletilecektir.
              </p>
            </div>
          </div>
        </div>
      </Card>

      <Card>
        <div>
          <TransferMultipleWayCard
            reservationData={reservationData as ITransferReservationData}
          />
        </div>
      </Card>

      <Card className="space-y-4">
        <h3 className="text-xl font-semibold">Fiyat Özeti</h3>
        <div className="space-y-2">
          {originSegmentGroup && (
            <div className="flex items-center justify-between">
              <span className="text-sm">Gidiş Transferi</span>
              <span className="text-base font-semibold">
                {PriceManager({
                  currency: originSegmentGroup.TotalPrice.slice(0, 3) as string,
                  value: +originSegmentGroup.TotalPrice.slice(3),
                })}
              </span>
            </div>
          )}
          {destinationSegmentGroup && (
            <div className="flex items-center justify-between">
              <span className="text-sm">Dönüş Transferi</span>
              <span className="text-base font-semibold">
                {PriceManager({
                  currency: destinationSegmentGroup.TotalPrice.slice(
                    0,
                    3,
                  ) as string,
                  value: +destinationSegmentGroup.TotalPrice.slice(3),
                })}
              </span>
            </div>
          )}
        </div>

        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">Toplam Tutar</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: (originSegmentGroup?.TotalPrice, "TRY").slice(
                  0,
                  3,
                ) as string,
                value: +data.totalPrice,
              })}
            </span>
          </div>
        </div>
      </Card>
    </div>
  );
};

export default TransferSuccess;
