/* eslint-disable react/jsx-no-useless-fragment */
/* eslint-disable react-hooks/exhaustive-deps */
import { useEffect } from "react";

import Container from "@/components/shared/container";
import { Skeleton } from "@/components/ui/skeleton/skeleton";
import { usePayment } from "@/features/modules/hotel/payment/hooks/use-hotel-payment";
import { storageManager } from "@/libs/storage-manager";
import { useFlightRetrieveMutation } from "@/services/eva-display/flight/flight-retrieve/flight-retrieve.service";
import { useHotelRetrieveMutation } from "@/services/eva-display/hotel/hotel-retrieve/hotel-retrieve.service";
import { useRentACarRetrieveMutation } from "@/services/eva-display/rent-a-car/rent-a-car-retrieve/rent-a-car-retrieve.services";
import { useTourRetrieveMutation } from "@/services/eva-display/tour/tour-retrieve/tour-retrieve.service";
import { useTransferRetrieveMutation } from "@/services/eva-display/transfer/transfer-retrieve/transfer-retrieve.services";

import FlightBookingSuccess from "./components/flight-booking-success";
import HotelBookingSuccess from "./components/hotel-booking-success";
import RentACarBookingSuccess from "./components/rent-a-car-booking-success";
import TourBookingSuccess from "./components/tour-booking-success";
import TransferBookingSuccess from "./components/transfer-booking-success";

const BookingSuccess = () => {
  const retrieveMutation = useHotelRetrieveMutation();
  const retrieveTourMutation = useTourRetrieveMutation();
  const retrieveTransferMutation = useTransferRetrieveMutation();
  const retrieveFlightMutation = useFlightRetrieveMutation();
  const retrieveRentACarMutation = useRentACarRetrieveMutation();
  const { paymentState, isReady } = usePayment();

  const { moduleName } = storageManager.get("core-payment");

  useEffect(() => {
    if (isReady) {
      const {
        payload: { cartId, searchId, transactionId },
      } = paymentState;

      switch (moduleName) {
        case "Hotel":
          retrieveMutation.mutate({
            RetrieveRecordRequest: {
              cartId,
              searchId,
              transactionKey: transactionId,
            },
          });
          break;
        case "Transfer":
          retrieveTransferMutation.mutate({
            RetrieveRecordRequest: {
              cartId,
              searchId,
              transactionKey: transactionId,
            },
          });
          break;
        case "Tour":
          retrieveTourMutation.mutate({
            RetrieveRecordRequest: {
              cartId,
              searchId,
              transactionKey: transactionId,
            },
          });
          break;
        case "Flight":
        case "Core":
          retrieveFlightMutation.mutate({
            FlightRetrieveRecordRequest: {
              cartId,
              searchId,
              transactionKey: transactionId,
            },
          });
          break;
        case "RentACar":
          retrieveRentACarMutation.mutate({
            RetrieveRecordRequest: {
              cartId,
              searchId,
              transactionKey: transactionId,
            },
          });
          break;
        default:
          break;
      }
    }
  }, [isReady]);

  // TODO: Implement the logic to render the booking success component based on the moduleName
  // useEffect(() => {
  //   if (isReady) {
  //     const {
  //       payload: { cartId, searchId, transactionId },
  //     } = paymentState;

  //     const mutations: { [key: string]: (args: any) => void } = {
  //       Hotel: retrieveMutation.mutate,
  //       Transfer: retrieveTransferMutation.mutate,
  //       Tour: retrieveTourMutation.mutate,
  //       RentACar: retrieveRentACarMutation.mutate,
  //     };

  //     const mutationFunction = mutations[moduleName];
  //     if (mutationFunction) {
  //       mutationFunction({
  //         RetrieveRecordRequest: {
  //           cartId,
  //           searchId,
  //           transactionKey: transactionId,
  //         },
  //       });
  //     }
  //   }
  // }, [isReady]);

  if (
    !retrieveMutation?.data?.result &&
    !retrieveTourMutation?.data?.result &&
    !retrieveFlightMutation?.data?.result &&
    !retrieveTransferMutation?.data?.result &&
    !retrieveRentACarMutation?.data?.result
  ) {
    return (
      <Container>
        <Skeleton className="h-[500px] w-full" />
      </Container>
    );
  }

  switch (moduleName) {
    case "Hotel":
      return <HotelBookingSuccess data={retrieveMutation.data!.result} />;

    case "Transfer":
      return (
        <TransferBookingSuccess data={retrieveTransferMutation.data!.result} />
      );

    case "Tour":
      return <TourBookingSuccess data={retrieveTourMutation.data!.result} />;

    case "Flight":
    case "Core":
      return (
        <FlightBookingSuccess
          data={retrieveFlightMutation.data!.result as any}
          cartId={paymentState.payload.cartId}
        />
      );
    case "RentACar":
      return (
        <RentACarBookingSuccess data={retrieveRentACarMutation.data!.result} />
      );
    default:
      return <div>{moduleName}</div>;
  }
};

export default BookingSuccess;
