/* eslint-disable jsx-a11y/control-has-associated-label */
/* eslint-disable react/no-danger */
/* eslint-disable @next/next/no-img-element */

import Container from "@/components/shared/container";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import {
  HoverCard,
  HoverCardContent,
  HoverCardTrigger,
} from "@/components/ui/hover-card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { useLocale } from "@/hooks/useLocale";
import { getLoyaltyAddon } from "@/libs/helpers/addon-helper";
import { DownloadVoucherPdfHelper } from "@/libs/helpers/download-voucher-pdf";
import { PriceManager } from "@/libs/price-manager/price-manager";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";
import type { IHotelRetrieveResponse } from "@/services/eva-display/hotel/hotel-retrieve/hotel-retrieve.service";
import { useVoucherService } from "@/services/eva-display/voucher/voucher.services";

import BookingSuccessHeadingInfos from "./booking-success-heading-infos";
import { BookingSuccessDiscounts } from "./shareds/booking-success-discounts";

interface HotelBookingSuccessProps {
  data: IHotelRetrieveResponse;
}

const HotelBookingSuccess = ({ data }: HotelBookingSuccessProps) => {
  const { addonList } = useServerDataCtx();
  const { t } = useLocale();

  const loyaltyAddon = getLoyaltyAddon(addonList);
  const voucherMutationServices = useVoucherService({
    onSuccess: (responseData) => {
      DownloadVoucherPdfHelper(responseData, data?.bookingCode);
    },
  });

  return (
    <Container className="mx-auto max-w-[688px] space-y-4">
      <Card>
        <div className="flex items-center gap-3">
          <span className="text-2xl">🎉</span>
          <h3 className="text-2xl font-semibold text-success-500">
            {data.resultString}
          </h3>
        </div>
        <BookingSuccessHeadingInfos
          className="mt-4"
          infoItems={data.descriptionList.map((desc) => ({
            text: desc,
          }))}
        />
        <Card className="mt-4 flex flex-col items-center justify-center gap-4 border border-gray-200 bg-gray-50 py-2 lg:flex-row">
          {data.information?.description && (
            <div className="flex items-center gap-2">
              <span>
                <LIcon name="AlertCircle" className="size-5" />
              </span>
              <span className="text-xs">{data.information?.description}</span>
            </div>
          )}
          <div className="flex w-full justify-center lg:justify-end">
            <Button
              className="text-nowrap text-sm"
              variant="primary"
              loading={voucherMutationServices.isLoading}
              leftIcon={{ name: "Download", className: "w-4 h-4" }}
              size="sm"
              onClick={() => voucherMutationServices.mutate(data.bookingCode)}
            >
              {t(data.voucherButtonString)}
            </Button>
          </div>
        </Card>
      </Card>

      {data.hotelInformation && (
        <Card>
          <h3 className="mb-4 text-xl font-semibold">
            {t("Facility Information")}
          </h3>

          <div className="flex items-start gap-4">
            <div>
              <img
                className="h-[86px] w-[125px] rounded-primary object-cover"
                src={data.hotelInformation?.showcaseImage?.url}
                alt={data.hotelInformation?.hotelName}
              />
            </div>
            <div className="space-y-4">
              <h5 className="text-xl font-semibold">
                {data.hotelInformation?.hotelName}
              </h5>
              <span className="text-sm text-gray-500">
                {data.hotelInformation?.location?.replaceAll(",", " /")}
              </span>
            </div>
          </div>

          <hr className="my-4" />

          <div className="space-y-3">
            <h6 className="text-sm font-semibold">{t("Address")}</h6>
            {data.hotelInformation?.address && (
              <div className="flex items-center gap-2">
                <LIcon name="MapPin" className="size-4" />
                <p className="text-sm">{data.hotelInformation.address}</p>
              </div>
            )}
            {data.hotelInformation?.phoneNumber && (
              <div className="flex items-center gap-2">
                <LIcon name="Phone" className="size-4" />
                <p className="text-sm">{data.hotelInformation.phoneNumber}</p>
              </div>
            )}
          </div>
        </Card>
      )}

      {data.bookingInformation && (
        <Card className="space-y-4">
          <h3 className="text-xl font-semibold">{t("Booking Details")}</h3>
          <div className="flex justify-between rounded-primary border border-gray-200 bg-gray-50 p-4">
            <div className="flex flex-col text-sm">
              <span className="text-gray-500">{t("Check-in")}</span>
              <span className="mt-0.5 font-semibold">
                {data.bookingInformation.checkInDate}
              </span>
              <span className="mt-0.5 text-xs text-gray-500">
                ({data.bookingInformation.checkInHour})
              </span>
            </div>
            <div className="flex flex-col text-sm">
              <span className="text-gray-500">{t("Check-out")}</span>
              <span className="mt-0.5 font-semibold">
                {data.bookingInformation.checkOutDate}
              </span>
              <span className="mt-0.5 text-xs text-gray-500">
                ({data.bookingInformation.checkOutHour})
              </span>
            </div>
            <div className="flex flex-col text-sm">
              <span className="text-gray-500">{t("Number of Nights")}</span>
              <span className="mt-0.5 font-semibold">
                {t("Total {{night}} Nights", {
                  night: data.bookingInformation.accommodationCount,
                })}
              </span>
            </div>
          </div>
          {data.roomInformations.map((roomInfo) => (
            <div
              className="flex flex-col items-start gap-4 rounded-primary border border-gray-200 bg-gray-50 p-4 lg:flex-row"
              key={roomInfo.title}
            >
              <img
                src={roomInfo?.images?.[0]?.url}
                alt=""
                className="h-[86px] w-[125px] rounded-primary object-cover"
              />
              <div>
                <h6 className="text-sm font-semibold">{roomInfo.title}</h6>
                <div className="flex flex-wrap items-center text-sm text-gray-500">
                  <div className="mr-2 flex flex-nowrap items-center gap-1">
                    <LIcon name="User" className="size-3" />
                    <span className="text-nowrap">{`${roomInfo.passengerDetail.description}`}</span>
                  </div>
                  <div className="mr-2 flex flex-nowrap items-center gap-1">
                    <LIcon name="BedDouble" className="size-3" />
                    <span className="text-nowrap">{`${
                      roomInfo.bedType.description === "Single"
                        ? t("Single bed")
                        : t("Double bed")
                    }`}</span>
                  </div>
                  <div className="mr-2 flex flex-nowrap items-center gap-1">
                    <LIcon name="Check" className="size-3" />
                    <span className="text-nowrap">{`${roomInfo.mealType.description}`}</span>
                  </div>
                </div>
                <p className="mt-1 text-sm text-gray-500">
                  {roomInfo.passengerNames}
                </p>
              </div>
            </div>
          ))}
        </Card>
      )}

      <Card className="space-y-4">
        <h3 className="text-xl font-semibold">{t("Price Summary")}</h3>
        <div className="space-y-2">
          <h6 className="text-sm font-semibold">{t("Room Selection")}</h6>
          {data.priceSummary.roomPrices.map((roomPrice) => (
            <div
              key={roomPrice.description}
              className="flex items-center justify-between"
            >
              <span className="text-sm">
                {`${roomPrice.description} (${data.bookingInformation.accommodationCount} ${t("night")} )`}
              </span>
              <span className="text-lg font-semibold">
                {PriceManager({
                  currency: roomPrice.basePrice.slice(0, 3) as string,
                  value: +roomPrice.basePrice.slice(3),
                })}
              </span>
            </div>
          ))}
        </div>

        {data?.additionalProductInformation?.additionalProducts?.length > 0 && (
          <div className="space-y-2 border-t pt-4">
            <h6 className="text-sm font-semibold">
              {t("Additional services")}
            </h6>
            {data?.additionalProductInformation?.additionalProducts?.map(
              (additionalProduct) =>
                !additionalProduct.isRequired && (
                  <div
                    key={additionalProduct.description}
                    className="flex items-center justify-between"
                  >
                    <span className="text-sm">
                      {additionalProduct.description}
                    </span>
                    <span className="text-lg font-semibold">
                      {PriceManager({
                        currency: additionalProduct.totalPrice.slice(
                          0,
                          3,
                        ) as string,
                        value: +additionalProduct.totalPrice.slice(3),
                      })}
                    </span>
                  </div>
                ),
            )}
          </div>
        )}

        <BookingSuccessDiscounts
          discountsCoupon={data.discountCoupons?.discountCoupons}
          discounts={data.priceSummary.discounts}
          title={data.priceSummary.discountString}
        />

        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">{`${t("Total")} ${t("Amount")}`}</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: data.priceSummary.totalPrice.slice(0, 3) as string,
                value: +data.priceSummary.totalPrice.slice(3),
              })}
            </span>
          </div>
        </div>
        {!!loyaltyAddon &&
          data.priceSummary.loyaltyItem &&
          data.priceSummary.loyaltyItem?.loyalities?.[0]?.value &&
          data.priceSummary.loyaltyItem?.loyalities?.[0]?.value > 0 && (
            <Card className="mt-4 bg-blue-50 py-3">
              <div className="flex items-center justify-between">
                <span className="text-sm font-medium text-blue-500">
                  {t("Congratulations, you've earned {{mile}} Miles!", {
                    mile: data.priceSummary.loyaltyItem?.loyalities?.[0]?.value,
                  })}
                </span>
                <div>
                  <HoverCard openDelay={100}>
                    <HoverCardTrigger>
                      <div role="button" className="ring-0 hover:ring-0">
                        <LIcon name="Info" className="size-5 text-blue-500" />
                      </div>
                    </HoverCardTrigger>
                    <HoverCardContent>
                      <p className="text-xs">
                        {t(
                          "The miles you earn will be uploaded to your account after your checkout process.",
                        )}
                      </p>
                    </HoverCardContent>
                  </HoverCard>
                </div>
              </div>
            </Card>
          )}
      </Card>

      <Card>
        <div className="rouned-primary border border-gray-200 bg-gray-50 p-4 text-sm">
          <h3 className="mb-4 text-base font-medium">
            {t("Important Informations")}
          </h3>
          <div
            className="text-gray-700 [&>ul>li]:mb-1 [&>ul>li]:list-disc [&>ul]:ml-4"
            dangerouslySetInnerHTML={{ __html: data.relevantInformations }}
          />
        </div>
      </Card>

      <Card>
        <div className="flex gap-4">
          <LIcon name="Phone" className="mt-1.5 size-[20px] shrink-0" />
          <div
            className="[&>b]:!text-sm [&>p>b]:text-gray-500 [&>p]:mt-1 [&>p]:!text-xs"
            dangerouslySetInnerHTML={{ __html: data.needHelp }}
          />
        </div>
      </Card>
    </Container>
  );
};
export default HotelBookingSuccess;
