/* eslint-disable @next/next/no-img-element */
/* eslint-disable react/no-danger */
import Container from "@/components/shared/container";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { IRentACarRetrieveResponse } from "@/services/eva-display/rent-a-car/rent-a-car-retrieve/rent-a-car-retrieve.services";

import BookingSuccessHeadingInfos from "./booking-success-heading-infos";

interface RentACarSuccessProps {
  data: IRentACarRetrieveResponse;
}

const RentACarBookingSuccess = ({ data }: RentACarSuccessProps) => {
  function getExtrasTotalPrice() {
    const extraOption =
      data.carExtraOption
        ?.filter((x) => x.selected)
        .reduce((acc, item) => acc + +item.totalPrice.slice(3), 0) ?? 0;
    const insurances =
      data.carInsurances
        ?.filter((x) => x.selected)
        .reduce((acc, item) => acc + +item.totalPrice.slice(3), 0) ?? 0;

    return extraOption + insurances;
  }

  return (
    <Container className="mx-auto max-w-[688px] space-y-4">
      <Card>
        <div className="flex items-center gap-3">
          <span className="text-2xl">🎉</span>
          <h3 className="text-2xl font-semibold text-success-500">
            {data.resultString}
          </h3>
        </div>
        <BookingSuccessHeadingInfos
          className="mt-4"
          infoItems={data.descriptionList.map((desc) => ({
            text: desc,
          }))}
        />
      </Card>

      <div className="mt-4 flex justify-end">
        <Button
          className="!hidden"
          variant="primary"
          leftIcon={{ name: "Download", className: "w-4 h-4" }}
          size="sm"
        >
          Rezervasyon Belgesi İndir
        </Button>
      </div>

      <Card className="space-y-4">
        <h3 className="text-xl font-semibold">Rezarvasyon Özeti</h3>
        <div className="flex items-center gap-4 text-sm">
          <div className="h-[70px] w-[120px] rounded p-2">
            <img
              src={data.carRentalInformation.showcaseImage}
              className="size-full object-contain"
              alt="Car"
            />
          </div>
          <div className="space-y-1">
            <h6 className="font-semibold">
              {data.carRentalInformation.carName}
            </h6>
          </div>
        </div>
        <div className="space-y-3 text-sm">
          <hr />
          <div className="flex gap-4">
            <div className="flex-1 space-y-2">
              <div className="flex items-center justify-between">
                <span className="font-semibold">Alış Noktası</span>
                <span className="text-xs">{`${data.bookingInformation.checkInDate} ${data.bookingInformation.checkInHour}`}</span>
              </div>
              <div>
                <div className="flex items-center gap-0.5">
                  <LIcon name="MapPin" className="size-4" />
                  <span>{data.bookingInformation.pickupStation}</span>
                </div>
              </div>
            </div>
            <div className="h-[50px] w-px bg-gray-200" />
            <div className="flex-1 space-y-2">
              <div className="flex items-center justify-between">
                <span className="font-semibold">Teslim Noktası</span>
                <span className="text-xs">{`${data.bookingInformation.checkOutDate} ${data.bookingInformation.checkOutHour}`}</span>
              </div>
              <div>
                <div className="flex items-center gap-0.5">
                  <LIcon name="MapPin" className="size-4" />
                  <span>{data.bookingInformation.returnStation}</span>
                </div>
              </div>
            </div>
          </div>
          <hr />
        </div>
        {(data.carExtraOption || data.carInsurances) && (
          <div className="space-y-3 text-sm">
            <div className="font-semibold">Ek Hizmetler ve Güvence Paketi</div>
            <div className="space-y-2">
              {data.carExtraOption
                ?.filter((x) => x.selected)
                .map((extra) => (
                  <div
                    className="flex items-center justify-between"
                    key={extra.code}
                  >
                    <span>{extra.name}</span>
                    <span>1 Adet</span>
                  </div>
                ))}
              {data.carInsurances
                ?.filter((x) => x.selected)
                .map((extra) => (
                  <div
                    className="flex items-center justify-between"
                    key={extra.code}
                  >
                    <span>{extra.description}</span>
                    <span>1 Adet</span>
                  </div>
                ))}
            </div>
          </div>
        )}
      </Card>

      <Card className="space-y-4 text-sm">
        <h3 className="text-xl font-semibold">Fiyat Özeti</h3>

        {(data.carExtraOption || data.carInsurances) && (
          <>
            <div className="rounded-primary border border-blue-100 bg-blue-50 p-4 text-xs">
              Ofiste ödenecek tutarı, aracınızı teslim alırken hizmeti sağlayan
              firmaya ödeyeceksiniz.
            </div>
            <div className="pb-4">
              <div className="mb-2 font-semibold">Ofiste Ödenecek Tutar</div>
              <div className="space-y-2">
                {data.carExtraOption
                  ?.filter((x) => x.selected)
                  .map((extra) => (
                    <div
                      className="flex items-center justify-between"
                      key={extra.code}
                    >
                      <div className="flex grow items-center gap-1">
                        <span>{extra.name}</span>
                        {+extra.totalPrice.slice(3) !== 0 && (
                          <span className="text-xs text-gray-500">
                            (
                            {`${data.bookingInformation.accommodationCount} x ${PriceManager(
                              {
                                currency: extra.unitPrice.slice(0, 3) as string,
                                value: +extra.unitPrice.slice(3),
                              },
                            )}`}
                            )
                          </span>
                        )}
                      </div>
                      <span>
                        {+extra.totalPrice.slice(3) === 0
                          ? "Ücretsiz"
                          : PriceManager({
                              currency: extra.totalPrice.slice(0, 3) as string,
                              value: +extra.totalPrice.slice(3),
                            })}
                      </span>
                    </div>
                  ))}
                {data.carInsurances
                  ?.filter((x) => x.selected)
                  .map((extra) => (
                    <div
                      className="flex items-center justify-between"
                      key={extra.code}
                    >
                      <div className="flex grow items-center gap-1">
                        <span>{extra.description}</span>
                        {+extra.totalPrice.slice(3) !== 0 && (
                          <span className="text-xs text-gray-500">
                            (
                            {`${data.bookingInformation.accommodationCount} x ${PriceManager(
                              {
                                currency: extra.unitPrice.slice(0, 3) as string,
                                value: +extra.unitPrice.slice(3),
                              },
                            )}`}
                            )
                          </span>
                        )}
                      </div>
                      <span>
                        {+extra.totalPrice.slice(3) === 0
                          ? "Ücretsiz"
                          : PriceManager({
                              currency: extra.totalPrice.slice(0, 3) as string,
                              value: +extra.totalPrice.slice(3),
                            })}
                      </span>
                    </div>
                  ))}
              </div>
              <div className="mt-2 flex items-center justify-between">
                <span className="font-semibold">Ara Toplam</span>
                <span className="text-base font-semibold">
                  {PriceManager({
                    currency: data.priceSummary.totalPrice.slice(
                      0,
                      3,
                    ) as string,
                    value: getExtrasTotalPrice(),
                  })}
                </span>
              </div>
            </div>
          </>
        )}
        <div>
          <div className="mb-4 font-semibold">Ödenmiş Tutar</div>
          <div className="flex items-center justify-between">
            <div className="flex items-center gap-1">
              <span>Araç Kiralama</span>
              <span className="text-xs text-gray-500">
                ({data.bookingInformation.accommodationCount})
              </span>
            </div>
            <span className="text-base font-semibold">
              {PriceManager({
                currency: data.priceSummary.totalPrice.slice(0, 3) as string,
                value: +data.priceSummary.totalPrice.slice(3),
              })}
            </span>
          </div>
        </div>
        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">Toplam Tutar</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: data.priceSummary.totalPrice.slice(0, 3) as string,
                value:
                  +data.priceSummary.totalPrice.slice(3) +
                  getExtrasTotalPrice(),
              })}
            </span>
          </div>
        </div>
      </Card>
    </Container>
  );
};

export default RentACarBookingSuccess;
