import { PriceManager } from "@/libs/price-manager/price-manager";
import type { Discount } from "@/services/eva-display/hotel/hotel-retrieve/hotel-retrieve.service";
import type { IDiscountCoupon } from "@/services/eva-display/shared/eva-display-shared-types";

interface BookingSuccessDiscountsProps {
  discountsCoupon?: IDiscountCoupon[];
  discounts?: Discount[];
  title: string;
}

export function BookingSuccessDiscounts(props: BookingSuccessDiscountsProps) {
  if (!props.discountsCoupon && !props.discounts) {
    return null;
  }
  return (
    <div className="space-y-2 border-t pt-4">
      <h6 className="text-sm font-semibold">{props.title}</h6>
      {props.discounts &&
        Array.isArray(props.discounts) &&
        props.discounts.length > 0 &&
        props.discounts?.map((additionalProduct) => (
          <div
            key={additionalProduct.description}
            className="flex items-center justify-between"
          >
            <span className="text-sm">{additionalProduct.description}</span>
            <span className="text-lg font-semibold text-success-500">
              -{" "}
              {PriceManager({
                currency: additionalProduct.totalPrice.slice(0, 3) as string,
                value: +additionalProduct.totalPrice.slice(3),
              })}
            </span>
          </div>
        ))}
      {props.discountsCoupon &&
        Array.isArray(props.discountsCoupon) &&
        props.discountsCoupon.length > 0 &&
        props.discountsCoupon.map((discount) => (
          <div key={discount.key} className="flex items-center justify-between">
            <span className="text-sm">{discount.description}</span>
            <span className="text-lg font-semibold text-success-500">
              -
              {PriceManager({
                currency: discount.price.slice(0, 3),
                value: +discount.price.slice(3),
              })}
            </span>
          </div>
        ))}
    </div>
  );
}
