/* eslint-disable react/no-danger */
/* eslint-disable @next/next/no-img-element */
import Container from "@/components/shared/container";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { DownloadVoucherPdfHelper } from "@/libs/helpers/download-voucher-pdf";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { ITourRetrieveResponse } from "@/services/eva-display/tour/tour-retrieve/tour-retrieve.service";
import { useVoucherService } from "@/services/eva-display/voucher/voucher.services";

import BookingSuccessHeadingInfos from "./booking-success-heading-infos";

interface TourBookingSuccessProps {
  data: ITourRetrieveResponse;
}

const TourBookingSuccess = ({ data }: TourBookingSuccessProps) => {
  const voucherMutationServices = useVoucherService({
    onSuccess: (responseData) => {
      DownloadVoucherPdfHelper(responseData, data?.bookingCode);
    },
  });
  return (
    <Container className="mx-auto max-w-[688px] space-y-4">
      <Card>
        <div className="flex items-center gap-3">
          <span className="text-2xl">🎉</span>
          <h3 className="text-2xl font-semibold text-success-500">
            {data.resultString}
          </h3>
        </div>
        <BookingSuccessHeadingInfos
          className="mt-4"
          infoItems={data.descriptionList.map((desc) => ({
            text: desc,
          }))}
        />
        <div className="mt-4 flex justify-end">
          <Button
            className="text-nowrap text-sm"
            variant="primary"
            leftIcon={{ name: "Download", className: "w-4 h-4" }}
            size="sm"
            loading={voucherMutationServices.isLoading}
            onClick={() => voucherMutationServices.mutate(data.bookingCode)}
          >
            Rezervasyon Belgesi İndir
          </Button>
        </div>
      </Card>

      {data.bookingInformation && (
        <Card className="space-y-4">
          <h3 className="text-xl font-semibold">Rezervasyon Bilgileri</h3>
          <div className="flex flex-col justify-between rounded-primary">
            <div className="flex items-start gap-4 pb-4">
              <img
                loading="lazy"
                src={
                  data.tourInformation.showcaseImage ||
                  "/assets/images/defaultImage.jpg"
                }
                alt={data.tourInformation.tourName}
                className="rounded-primary object-cover"
                width="125px"
                height="86px"
              />
              <div>
                <h6 className="text-sm font-semibold">
                  {data.tourInformation.tourName}
                </h6>
              </div>
            </div>
            <hr />
            <div className="flex pt-4 sm:gap-8">
              <div className="flex flex-col text-sm">
                <span className="text-gray-500">Giriş Tarihi</span>
                <span className="mt-0.5 font-semibold">
                  {data.bookingInformation.checkInDate}
                </span>
                <span className="mt-0.5 text-xs text-gray-500">
                  {data.bookingInformation.checkInHour}
                </span>
              </div>
              <div className="flex flex-col text-sm">
                <span className="text-gray-500">Çıkış Tarihi</span>
                <span className="mt-0.5 font-semibold">
                  {data.bookingInformation.checkOutDate}
                </span>
                <span className="mt-0.5 text-xs text-gray-500">
                  {data.bookingInformation.checkOutHour}
                </span>
              </div>
              <div className="flex flex-col text-sm">
                <span className="text-gray-500">Gece Sayısı</span>
                <span className="mt-0.5 font-semibold">
                  {`${data.bookingInformation.accommodationCount}`}
                </span>
              </div>
            </div>
          </div>
        </Card>
      )}

      <Card className="space-y-4">
        <h3 className="text-xl font-semibold">Fiyat Özeti</h3>
        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">Toplam Tutar</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: data.priceSummary.totalPrice.slice(0, 3) as string,
                value: +data.priceSummary.totalPrice.slice(3),
              })}
            </span>
          </div>
        </div>
      </Card>
      {data.relevantInformations && (
        <Card>
          <div className="rouned-primary border border-gray-200 bg-gray-50 p-4 text-sm">
            <h3 className="mb-4 text-base font-medium">Önemli Bilgiler</h3>
            <div
              className="text-gray-700 [&>ul>li]:mb-1 [&>ul>li]:list-disc [&>ul]:ml-4"
              dangerouslySetInnerHTML={{ __html: data.relevantInformations }}
            />
          </div>
        </Card>
      )}
      {data.needHelp && (
        <Card>
          <div className="flex gap-4">
            <LIcon name="Phone" className="mt-1.5 size-[20px] shrink-0" />
            <div
              className="[&>b]:!text-sm [&>p>b]:text-gray-500 [&>p]:mt-1 [&>p]:!text-xs"
              dangerouslySetInnerHTML={{ __html: data.needHelp }}
            />
          </div>
        </Card>
      )}
    </Container>
  );
};
export default TourBookingSuccess;
