/* eslint-disable react/no-danger */
import Container from "@/components/shared/container";
import { Button } from "@/components/ui/button/button";
import Card from "@/components/ui/card/card";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import { PriceManager } from "@/libs/price-manager/price-manager";
import type { ITransferRetrieveResponse } from "@/services/eva-display/transfer/transfer-retrieve/transfer-retrieve.services";

import BookingSuccessHeadingInfos from "./booking-success-heading-infos";
import { BookingSuccessDiscounts } from "./shareds/booking-success-discounts";

interface TransferSuccessProps {
  // reservationData?: any;
  data: ITransferRetrieveResponse;
}

const TransferBookingSuccess = (props: TransferSuccessProps) => {
  // let transferSegmentGroupItems =
  //   reservationData.DetailResponse.TransferSegmentGroupItem.filter((x: any) =>
  //     reservationData.ProductKeys.includes(x.Key),
  //   );

  // transferSegmentGroupItems = transferSegmentGroupItems.sort(
  //   (a: any, b: any) =>
  //     dayjs(a.Items[0]?.DepartureTime).valueOf() -
  //     dayjs(b.Items[0]?.DepartureTime).valueOf(),
  // );

  // const originSegmentGroup = transferSegmentGroupItems[0]?.Items[0];
  // const destinationSegmentGroup =
  //   transferSegmentGroupItems.length === 1
  //     ? null
  //     : transferSegmentGroupItems[1]?.Items[0];

  const { data } = props;
  return (
    <Container className="mx-auto max-w-[688px] space-y-4">
      <Card>
        <div className="flex items-center gap-3">
          <span className="text-2xl">🎉</span>
          <h3 className="text-2xl font-semibold text-success-500">
            {data.resultString}
          </h3>
        </div>
        <BookingSuccessHeadingInfos
          className="mt-4"
          infoItems={data.descriptionList.map((desc) => ({
            text: desc,
          }))}
        />
      </Card>
      <Card className="mt-4 border border-gray-200 bg-gray-50 py-2">
        {data.information?.description && (
          <div className="flex items-center gap-2">
            <span>
              <LIcon name="AlertCircle" className="size-5" />
            </span>
            <span className="text-xs">{data.information?.description}</span>
          </div>
        )}
      </Card>
      <div className="mt-4 flex justify-end">
        <Button
          className="!hidden"
          variant="primary"
          leftIcon={{ name: "Download", className: "w-4 h-4" }}
          size="sm"
        >
          Rezervasyon Belgesi İndir
        </Button>
      </div>
      {/* 
      <Card>
        <div>
          <TransferMultipleWayCard
            reservationData={reservationData as ITransferReservationData}
          />
        </div>
      </Card> */}
      <Card className="space-y-4">
        <h3 className="text-xl font-semibold">Fiyat Özeti</h3>
        {/* <div className="space-y-2">
          {originSegmentGroup && (
            <div className="flex items-center justify-between">
              <span className="text-sm">Gidiş Transferi</span>
              <span className="text-base font-semibold">
                {PriceManager({
                  currency: originSegmentGroup.TotalPrice.slice(0, 3) as string,
                  value: +originSegmentGroup.TotalPrice.slice(3),
                })}
              </span>
            </div>
          )}
          {destinationSegmentGroup && (
            <div className="flex items-center justify-between">
              <span className="text-sm">Dönüş Transferi</span>
              <span className="text-base font-semibold">
                {PriceManager({
                  currency: destinationSegmentGroup.TotalPrice.slice(
                    0,
                    3,
                  ) as string,
                  value: +destinationSegmentGroup.TotalPrice.slice(3),
                })}
              </span>
            </div>
          )}
        </div>

        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">Toplam Tutar</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: (originSegmentGroup?.TotalPrice, "TRY").slice(
                  0,
                  3,
                ) as string,
                value: +data.totalPrice,
              })}
            </span>
          </div>
        </div> */}
        <div>
          <BookingSuccessDiscounts
            discountsCoupon={data?.discountCoupons?.discountCoupons}
            title="İndirimler"
          />
        </div>
        <div className="rounded-primary border border-gray-200 p-4">
          <div className="flex items-center justify-between">
            <span className="text-sm">Toplam Tutar</span>
            <span className="text-xl font-semibold">
              {PriceManager({
                currency: data.priceSummary.totalPrice.slice(0, 3) as string,
                value: +data.priceSummary.totalPrice.slice(3),
              })}
            </span>
          </div>
        </div>
      </Card>
      <Card>
        <div className="rouned-primary border border-gray-200 bg-gray-50 p-4 text-sm">
          <h3 className="mb-4 text-base font-medium">Önemli Bilgiler</h3>
          <div
            className="text-gray-700 [&>ul>li]:mb-1 [&>ul>li]:list-disc [&>ul]:ml-4"
            dangerouslySetInnerHTML={{ __html: data.relevantInformations }}
          />
        </div>
      </Card>
      <Card>
        <div className="flex gap-4">
          <LIcon name="Phone" className="mt-1.5 size-[20px] shrink-0" />
          <div
            className="[&>b]:!text-sm [&>p>b]:text-gray-500 [&>p]:mt-1 [&>p]:!text-xs"
            dangerouslySetInnerHTML={{ __html: data.needHelp }}
          />
        </div>
      </Card>
    </Container>
  );
};

export default TransferBookingSuccess;
