/* eslint-disable react/no-unstable-nested-components */
/* eslint-disable react/jsx-no-useless-fragment */
import FormItem from "@/components/form/form-item";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu/dropdown-menu";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import TpValidationMessage from "@/components/widget/travel-planner/components/tp-validation-message/tp-validation-message";
import { useBranchOfficeQuery } from "@/services/eva-display/branch-office/branch-office.service";

import type { IReasonItem } from "./tp-reason-dropdown-form";

export interface IBranchOfficeItem {
  name: string;
  value: string;
  order: number;
  properties?: any;
}

export const TpBranchOfficeDropdownWrappedFormItem = (props: {
  name: string;
  rules?: any;
}) => {
  const branchOfficeListQuery = useBranchOfficeQuery();

  const NullComponent = () => <></>;

  if (!branchOfficeListQuery.isSuccess) {
    return <NullComponent />;
  }

  if (
    !branchOfficeListQuery?.data?.data ||
    !branchOfficeListQuery?.data?.data?.result?.items
  ) {
    return <NullComponent />;
  }

  const items = branchOfficeListQuery?.data?.data?.result?.items?.filter(
    (x: IReasonItem) => x.value !== "",
  );

  if (!items || items.length === 0) {
    return <NullComponent />;
  }

  return (
    <div className="flex-1 shrink-0">
      <FormItem name={props.name} rules={props.rules}>
        {({ field, setValue, fieldState }) => (
          <div className="relative">
            <DropdownMenu>
              <DropdownMenuTrigger className="w-full min-w-full max-w-full">
                <TriggerButton
                  label="Şube"
                  fullWidth
                  size="lg"
                  value={field.value?.name}
                  rightIcon={<LIcon name="ChevronDown" />}
                />
              </DropdownMenuTrigger>
              <DropdownMenuContent className="w-full min-w-[325px] max-w-full">
                {branchOfficeListQuery.isSuccess &&
                  branchOfficeListQuery.data?.data.result?.items.map(
                    (item: IBranchOfficeItem) => (
                      <DropdownMenuItem
                        key={item.value}
                        onClick={() => {
                          setValue(item);
                        }}
                      >
                        {item.name}
                      </DropdownMenuItem>
                    ),
                  )}
              </DropdownMenuContent>
            </DropdownMenu>
            {fieldState.error?.message && (
              <TpValidationMessage
                position="bottom"
                message={fieldState.error?.message}
              />
            )}
          </div>
        )}
      </FormItem>
    </div>
  );
};
