import FormItem from "@/components/form/form-item";
import FlightCustomerGroupSelect from "@/components/widget/travel-planner/components/flight-customer-group-select/flight-customer-group-select";
import { usePermGuard } from "@/features/permission/components/perm-guard";
import { useApp } from "@/hooks/useApp";
import { useLabels } from "@/hooks/useLabels";
import { useLocale } from "@/hooks/useLocale";
import { requestAddGuestPassengersAllowPerm } from "@/validations/permissions/request-add-guest-passengers";

export const TpCabinSelectWrappedFormItem = (props: { name: string }) => {
  const { t } = useLocale();
  const { isB2E } = useApp();
  const { guest } = useLabels();

  const { isCheck } = usePermGuard({
    permission: requestAddGuestPassengersAllowPerm,
  });

  let items: any[] = [];

  if (isB2E) {
    if (isCheck) {
      items = [
        { label: "Kurum Çalışanı", name: "employee", min: 0 },
        { label: guest.label, name: "guest", min: guest.min },
        { label: t("Child"), name: "child", min: 0 },
        { label: t("Class"), name: "cabinType" },
      ];
    } else {
      items = [
        { label: "Kurum Çalışanı", name: "employee", min: 0 },
        { label: t("Class"), name: "cabinType" },
      ];
    }
  } else {
    items = [
      { label: guest.label, name: "guest", min: guest.min },
      { label: t("Child"), name: "child", min: 0 },
      { label: t("Class"), name: "cabinType" },
    ];
  }

  return (
    <FormItem name={props.name}>
      {({ field, setValue }) => (
        <FlightCustomerGroupSelect
          value={field.value}
          cabinValue={field.value}
          cabinOnchangeValue={setValue}
          onChange={setValue}
          items={items}
        />
      )}
    </FormItem>
  );
};
