import FormItem from "@/components/form/form-item";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import TpValidationMessage from "@/components/widget/travel-planner/components/tp-validation-message/tp-validation-message";
import type { IUserItem } from "@/components/widget/travel-planner/components/user-select/user-select";
import UserSelect from "@/components/widget/travel-planner/components/user-select/user-select";
import { useUserDepartmentQuery } from "@/services/eva-display/user-department/user-department.service";

interface CustomerSelectProps {
  value?: IUserItem[];
  placeholder?: string;
  onChange?: (value: IUserItem[]) => void;
  errorMessages?: string;
}

export const CustomerSelect = (props: CustomerSelectProps) => {
  const userDepartmentQuery = useUserDepartmentQuery();
  return (
    <div className="relative">
      <Popover>
        <PopoverTrigger className="group w-full">
          <TriggerButton
            size="lg"
            fullWidth
            className="w-full group-data-[state=open]:border-primary-200 group-data-[state=open]:ring-2 group-data-[state=open]:ring-primary-50"
            label={props.placeholder ?? "Kişi Seçimi"}
            value={
              props.value ? `${props.value.length} Kişi Seçildi` : undefined
            }
            rightIcon={<LIcon name="ChevronDown" />}
          />
        </PopoverTrigger>
        <PopoverContent className="max-h-[360px] w-full min-w-[350px] overflow-auto">
          <div>
            <UserSelect
              value={props.value ?? []}
              onChange={props.onChange}
              users={
                userDepartmentQuery.data?.map((userItem) => ({
                  name: userItem.name,
                  value: userItem.value,
                })) ?? []
              }
              placeholder={props.placeholder}
            />
          </div>
        </PopoverContent>
      </Popover>
      {props.errorMessages && (
        <TpValidationMessage
          className="!left-[-20%]"
          position="bottom"
          message={props.errorMessages}
        />
      )}
    </div>
  );
};

export const CustomerSelectWrappedFormItem = (props: {
  name: string;
  rules?: any;
  placeholder?: string;
}) => {
  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <CustomerSelect
          value={field.value}
          onChange={(value) => {
            setValue(value);
          }}
          errorMessages={fieldState.error?.message}
          placeholder={props.placeholder}
        />
      )}
    </FormItem>
  );
};
