import dayjs from "dayjs";

import FormItem from "@/components/form/form-item";
import TpDateRangePicker from "@/components/widget/travel-planner/components/tp-date-range-picker/tp-date-range-picker";
import TpDateRangePickerMobile from "@/components/widget/travel-planner/components/tp-date-range-picker/tp-date-range-picker.mobile";
import { useApp } from "@/hooks/useApp";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { useSize } from "@/hooks/useSize";
import { DateHelper } from "@/libs/helpers/date-time-helper";

import { TP_POPOVER_OFFSET } from "./tp-date-picker-form";

export const TpDateRangePickerWrappedFormItem = (props: {
  name: string;
  rules?: any;
  showNightInfo?: boolean;
  untilDay?: number;
}) => {
  const { isOtel } = useApp();
  const { isDesktop } = useBreakpoints();
  const windowSize = useSize();
  const { t } = useLocale();

  const TpDateRangePickerComp =
    isDesktop &&
    windowSize.getWindowSize().height > (isOtel ? 600 : TP_POPOVER_OFFSET)
      ? TpDateRangePicker
      : TpDateRangePickerMobile;

  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <TpDateRangePickerComp
          value={field.value}
          minDate={2}
          onChange={(value) => {
            setValue(value);
          }}
          errorMessage={fieldState.error?.message}
          showNightInfo={props.showNightInfo}
          untilDay={
            props.untilDay && field?.value?.from
              ? DateHelper.calculateDaysBetweenDates(
                  dayjs().toDate(),
                  field.value.from,
                ) + props.untilDay
              : undefined
          }
        >
          {!field.value && (
            <TpDateRangePicker.MessageBox>
              {t("Select a date to see hotel availability and prices")}
            </TpDateRangePicker.MessageBox>
          )}
        </TpDateRangePickerComp>
      )}
    </FormItem>
  );
};
