/* eslint-disable jsx-a11y/interactive-supports-focus */
/* eslint-disable jsx-a11y/click-events-have-key-events */
import dayjs from "dayjs";
import { useBoolean } from "usehooks-ts";

import type { FormItemProps } from "@/components/form/form-item";
import FormItem from "@/components/form/form-item";
import { Button } from "@/components/ui/button/button";
import { Calendar } from "@/components/ui/calendar/calendar";
import { DialogContent } from "@/components/ui/dialog";
import { Dialog } from "@/components/ui/dialog/dialog";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import TimePicker from "@/components/widget/time-picker/time-picker";
import TpBottomBox from "@/components/widget/travel-planner/components/tp-bottom-box/tp-bottom-box";
import TpDateRangePickerCloseButton from "@/components/widget/travel-planner/components/tp-date-range-picker/components/tp-date-range-picker-close-button";
import TpDateRangePickerMessageBox from "@/components/widget/travel-planner/components/tp-date-range-picker/components/tp-date-range-picker-message-box";
import TpValidationMessage from "@/components/widget/travel-planner/components/tp-validation-message/tp-validation-message";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";

interface TpDateTimePickerWrappedFormItemProps
  extends Omit<FormItemProps, "children"> {
  label?: string;
  fromDate?: Date;
  onChange?: (value: { date?: Date; time?: string }) => void;
}

const TpDateTimePickerWrappedFormItem = (
  props: TpDateTimePickerWrappedFormItemProps,
) => {
  const { isDesktop } = useBreakpoints();
  const { t } = useLocale();

  const dateBoolean = useBoolean();
  const timeBoolean = useBoolean();

  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue, fieldState }) => {
        const hasDateValue = dayjs(field?.value?.date).isValid();
        const hasTimeValue =
          field.value?.time && field.value?.time !== "Invalid Date";

        if (!isDesktop) {
          return (
            <div className="relative">
              <div className="flex h-[54px] w-full cursor-pointer select-none items-center justify-between rounded-primary border border-gray-200 text-sm text-gray-500 shadow-sm">
                <div className="h-full grow">
                  <div
                    role="button"
                    onClick={dateBoolean.toggle}
                    className="h-full"
                  >
                    <div className="flex h-full items-center gap-3 py-[10px] pl-[12px]">
                      <LIcon className="w-[20px] text-[14px]" name="Calendar" />
                      <div className="flex flex-col items-start">
                        <span className="text-nowrap text-xs">
                          {props?.label || "Gidiş Tarihi"}
                        </span>
                        <span
                          className={cn(
                            "text-gray-500 text-nowrap text-left overflow-ellipsis line-clamp-1",
                            {
                              "text-black": hasDateValue,
                            },
                          )}
                        >
                          {hasDateValue && field.value?.date
                            ? dayjs(field.value.date).format("DD MMM YYYY")
                            : "Tarih Seçin"}
                        </span>
                      </div>
                    </div>
                  </div>
                </div>
                <div className="mx-0.5 mr-1 h-1/2 w-px min-w-px basis-px bg-gray-200" />
                <div className="h-full w-[100px] max-w-[100px] basis-[100px]">
                  <div
                    role="button"
                    onClick={timeBoolean.toggle}
                    className="-mt-px w-full pr-2"
                  >
                    <div className="flex h-full items-center justify-between gap-3 py-[10px] pl-2">
                      <div className="flex flex-col items-start">
                        <span className="text-xs ">{t("Time")}</span>
                        <span
                          className={cn(
                            "text-gray-500 text-nowrap whitespace-nowrap",
                            {
                              "text-black": hasTimeValue,
                            },
                          )}
                        >
                          {hasTimeValue ? field.value?.time : "Saat Seçin"}
                        </span>
                      </div>
                      <LIcon
                        className="w-[20px] text-[14px]"
                        name="ChevronDown"
                      />
                    </div>
                  </div>
                </div>
              </div>

              <Dialog
                modal
                open={dateBoolean.value}
                onOpenChange={dateBoolean.setValue}
              >
                <DialogContent noShowClose className="z-[101] size-full p-0">
                  <div className="flex flex-col justify-between">
                    <div className="shrink-0 px-4 pt-1">
                      <TpDateRangePickerCloseButton
                        className="mb-2"
                        onClick={() => {
                          dateBoolean.setFalse();
                        }}
                      />
                      <TpDateRangePickerMessageBox>
                        {props.label}
                      </TpDateRangePickerMessageBox>
                      <hr className="mt-4" />
                    </div>
                    <div className="flex max-h-[calc(100dvh-175px)] grow flex-col items-center overflow-y-auto px-4">
                      <Calendar
                        initialFocus
                        mode="single"
                        fromDate={props?.fromDate || dayjs().toDate()}
                        toYear={dayjs().year() + 1}
                        selected={field.value?.date}
                        onSelect={(value) => {
                          setValue({
                            ...field.value,
                            date: value,
                          });
                          dateBoolean.setFalse();
                          timeBoolean.setTrue();

                          props.onChange?.({
                            date: value,
                            time: field.value?.time,
                          });
                        }}
                        numberOfMonths={2}
                      />
                    </div>
                    <div className="shrink-0 p-4">
                      <Button
                        variant="primary"
                        className="w-full"
                        onClick={() => {
                          dateBoolean.setFalse();
                        }}
                      >
                        {t("Apply")}
                      </Button>
                    </div>
                    {/* <div>
                      <TpBottomBox
                        label={
                          <div className="flex gap-2 font-medium">
                            {props.label}
                          </div>
                        }
                        onApplyClick={dateBoolean.setFalse}
                      />
                    </div> */}
                  </div>
                </DialogContent>
              </Dialog>
              <Dialog
                modal
                open={timeBoolean.value}
                onOpenChange={timeBoolean.setValue}
              >
                <DialogContent noShowClose className="z-[101] size-full p-0">
                  <div className="flex flex-col justify-between">
                    <div className="shrink-0 px-4 pt-1">
                      <TpDateRangePickerCloseButton
                        className="mb-2"
                        onClick={() => {
                          timeBoolean.setFalse();
                        }}
                      />
                      <TpDateRangePickerMessageBox>
                        {field.value?.time ?? t("Select Time")}
                      </TpDateRangePickerMessageBox>
                      <hr className="mt-4" />
                    </div>
                    <div className="flex max-h-[calc(100vh-180px)] grow flex-col  overflow-y-scroll px-4">
                      <TimePicker
                        placeholder=""
                        startTime="00:00"
                        endTime="24:00"
                        value="12:00"
                        rangeMinute={30}
                        errorMessages=""
                        onChange={(value) => {
                          setValue({
                            ...field.value,
                            time: value,
                          });
                          timeBoolean.setFalse();
                        }}
                      />
                    </div>
                    <div className="shrink-0 p-4">
                      <Button
                        variant="primary"
                        className="w-full"
                        onClick={() => {
                          timeBoolean.setFalse();
                        }}
                      >
                        {t("Apply")}
                      </Button>
                    </div>
                    {/* <div>
                      <TpBottomBox
                        label={
                          <div className="flex gap-2 font-medium">
                            {field.value?.time}
                          </div>
                        }
                        onApplyClick={timeBoolean.setFalse}
                      />
                    </div> */}
                  </div>
                </DialogContent>
              </Dialog>
            </div>
          );
        }

        return (
          <div className="relative">
            <div className="flex h-[54px] w-full cursor-pointer select-none items-center justify-between rounded-primary border border-gray-200 text-sm text-gray-500 shadow-sm">
              <div className="h-full grow">
                <Popover
                  open={dateBoolean.value}
                  onOpenChange={dateBoolean.setValue}
                >
                  <PopoverTrigger className="h-full">
                    <div className="flex h-full items-center gap-3 py-[10px] pl-[12px]">
                      <LIcon className="w-[20px] text-[14px]" name="Calendar" />
                      <div className="flex flex-col items-start">
                        <span className="text-nowrap text-xs">
                          {props?.label || t("Return Date")}
                        </span>
                        <span
                          className={cn(
                            "text-gray-500 text-nowrap text-left overflow-ellipsis line-clamp-1",
                            {
                              "text-black": hasDateValue,
                            },
                          )}
                        >
                          {hasDateValue && field.value?.date
                            ? dayjs(field.value.date).format("DD MMM YYYY")
                            : t("Select Date")}
                        </span>
                      </div>
                    </div>
                  </PopoverTrigger>
                  <PopoverContent
                    className="w-auto pb-0"
                    side="bottom"
                    avoidCollisions={false}
                  >
                    <div>
                      <Calendar
                        className="p-0 pb-3"
                        initialFocus
                        mode="single"
                        fromDate={props?.fromDate || dayjs().toDate()}
                        toYear={dayjs().year() + 1}
                        selected={field.value?.date}
                        onSelect={(value) => {
                          setValue({
                            ...field.value,
                            date: value,
                          });
                          dateBoolean.setFalse();
                          timeBoolean.setTrue();

                          props.onChange?.({
                            date: value,
                            time: field.value?.time,
                          });
                        }}
                        numberOfMonths={1}
                      />
                      <TpBottomBox
                        className="-mx-4 mb-0"
                        onApplyClick={() => {
                          dateBoolean.setFalse();
                        }}
                        label={<div />}
                      />
                    </div>
                  </PopoverContent>
                </Popover>
              </div>
              <div className="mx-0.5 mr-1 h-1/2 w-px min-w-px basis-px bg-gray-200" />
              <div className="h-full w-[100px] max-w-[100px] basis-[100px]">
                <Popover
                  open={timeBoolean.value}
                  onOpenChange={timeBoolean.setValue}
                >
                  <PopoverTrigger className="-mt-px w-full pr-2">
                    <div className="flex h-full items-center justify-between gap-3 py-[10px] pl-2">
                      <div className="flex flex-col items-start">
                        <span className="text-xs ">{t("Time")}</span>
                        <span
                          className={cn("text-gray-500 text-nowrap", {
                            "text-black": hasTimeValue,
                          })}
                        >
                          {hasTimeValue ? field.value?.time : t("Select Time")}
                        </span>
                      </div>
                      <LIcon
                        className="w-[20px] text-[14px]"
                        name="ChevronDown"
                      />
                    </div>
                  </PopoverTrigger>
                  <PopoverContent className="scroll-bar max-h-[300px] max-w-[100px] p-0">
                    <TimePicker
                      placeholder=""
                      startTime="00:00"
                      endTime="24:00"
                      value="12:00"
                      rangeMinute={30}
                      errorMessages=""
                      onChange={(value) => {
                        setValue({
                          ...field.value,
                          time: value,
                        });
                        timeBoolean.setFalse();
                      }}
                    />
                  </PopoverContent>
                </Popover>
              </div>
            </div>
            {fieldState?.error?.message && (
              <TpValidationMessage message={fieldState?.error?.message} />
            )}
          </div>
        );
      }}
    </FormItem>
  );
};

export default TpDateTimePickerWrappedFormItem;
