/* eslint-disable react/no-unused-prop-types */
import { useBoolean } from "usehooks-ts";

import type { FormItemProps } from "@/components/form/form-item";
import FormItem from "@/components/form/form-item";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import GroupCustomerCounter from "@/components/widget/travel-planner/components/customer-group-select/components/room-and-customer-counter";
import TpBottomBox from "@/components/widget/travel-planner/components/tp-bottom-box/tp-bottom-box";
import PermGuard from "@/features/permission/components/perm-guard";
import { useApp } from "@/hooks/useApp";
import { useLabels } from "@/hooks/useLabels";
import { useLocale } from "@/hooks/useLocale";
import { requestAddGuestPassengersAllowPerm } from "@/validations/permissions/request-add-guest-passengers";

interface TpPassengerSelectWrappedFormItemProps
  extends Omit<FormItemProps, "children"> {}

interface TpPassengerSelectProps {
  value: any;
  onChange: (value: any) => void;
  onAcceptClick?: VoidFunction;
  hasAge?: boolean;
  renderTriggerElement?: (value: any) => React.ReactNode;
}

export const TpPassengerSelect = (props: TpPassengerSelectProps) => {
  const boolean = useBoolean();
  const { isB2E } = useApp();
  const { guest } = useLabels();
  const { t } = useLocale();

  const check = PermGuard({ permission: requestAddGuestPassengersAllowPerm });

  function getValue() {
    let tmpValue = "";
    if (props.value?.employee?.count) {
      tmpValue += `${props.value.employee.count} Çalışan`;
    }
    if (props.value?.guest?.count) {
      tmpValue += `${tmpValue === "" ? "" : ", "}${props.value.guest.count} ${
        guest.label
      }`;
    }
    if (props.value?.child?.count) {
      tmpValue += `${tmpValue === "" ? "" : ", "}${props.value.child.count} ${t(
        "Child",
      )}`;
    }

    if (tmpValue === "") {
      tmpValue = t("Passengers");
    }

    return tmpValue;
  }

  let items = [];

  if (isB2E) {
    if (check) {
      items = [
        { label: "Kurum Çalışanı", name: "employee", min: 0 },
        { label: guest.label, name: "guest", min: guest.min },
        { label: t("Child"), name: "child", min: 0 },
      ];
    } else {
      items = [{ label: "Kurum Çalışanı", name: "employee", min: 0 }];
    }
  } else {
    items = [
      { label: guest.label, name: "guest", min: guest.min },
      {
        label: t("Child"),
        name: "child",
        min: 0,
        hasAge: props.hasAge ?? false,
      },
    ];
  }

  const label = getValue();
  return (
    <Popover open={boolean.value} onOpenChange={boolean.setValue}>
      <PopoverTrigger className="group w-full">
        {props.renderTriggerElement?.(props.value) ?? (
          <TriggerButton
            isFocus={boolean.value}
            size="lg"
            fullWidth
            className="w-full group-data-[state=open]:border-primary-200 group-data-[state=open]:ring-2 group-data-[state=open]:ring-primary-50"
            label={t("Passengers")}
            leftIcon={<LIcon name="User" />}
            iconHiddenOnMobile={false}
            value={label}
          />
        )}
      </PopoverTrigger>
      <PopoverContent className="w-full p-0">
        <div className="scroll-bar mb-3 max-h-[300px] min-w-[325px] overflow-y-scroll p-4">
          <GroupCustomerCounter
            value={props.value}
            items={items}
            onChange={(changedValue) => {
              props.onChange(changedValue);
            }}
          />
        </div>
        <TpBottomBox
          onApplyClick={() => {
            boolean.setValue(false);
            props.onAcceptClick?.();
          }}
          label={label}
        />
      </PopoverContent>
    </Popover>
  );
};

export const TpPassengerSelectWrappedFormItem = (
  props: TpPassengerSelectWrappedFormItemProps,
) => {
  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue }) => {
        return (
          <TpPassengerSelect
            value={field.value}
            onChange={(value) => {
              setValue(value);
            }}
          />
        );
      }}
    </FormItem>
  );
};
