/* eslint-disable react-hooks/rules-of-hooks */
/* eslint-disable react/jsx-no-useless-fragment */
import dayjs from "dayjs";
import { AlertCircleIcon } from "lucide-react";
import { useSearchParams } from "next/navigation";
import { useEffect, useState } from "react";
import { useBoolean } from "usehooks-ts";

import type { FormItemProps } from "@/components/form/form-item";
import FormItem from "@/components/form/form-item";
import { Calendar } from "@/components/ui/calendar/calendar";
import { Dialog, DialogContent } from "@/components/ui/dialog";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover/popover";
import {
  Tabs,
  TabsContent,
  TabsList,
  TabsTrigger,
} from "@/components/ui/tabs/tabs";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import PeriodPicker from "@/components/widget/period-picker/period-picker";
import TpBottomBox from "@/components/widget/travel-planner/components/tp-bottom-box/tp-bottom-box";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLocale } from "@/hooks/useLocale";
import { useSize } from "@/hooks/useSize";
import { useMessageByDates } from "@/libs/get-message-by-dates/get-message-by-dates";
import { DateHelper } from "@/libs/helpers/date-time-helper";

import { TP_POPOVER_OFFSET } from "./tp-date-picker-form";

interface TpPeriodDateWrappedFormItemProps
  extends Omit<FormItemProps, "children"> {}

const TpPeriodDateWrappedFormItem = (
  props: TpPeriodDateWrappedFormItemProps,
) => {
  const { t } = useLocale();
  const boolean = useBoolean();
  const searchParams = useSearchParams();
  const [anySelected, setAnySelected] = useState<boolean>(false);
  const { isDesktop } = useBreakpoints();
  const windowSize = useSize();

  const checkinDate = searchParams.get("checkinDate");
  const checkoutDate = searchParams.get("checkoutDate");
  const isPeriodType = searchParams.get("periodType");

  useEffect(() => {
    setAnySelected(isPeriodType === "3");
  }, [isPeriodType]);

  const getValue = (
    value: any,
    any: boolean,
    periodType: string | null,
    checkin: string | null,
    checkout: string | null,
  ) => {
    let result: string;
    const today = dayjs();

    if (value?.anySelected || (any && !value?.date && !value?.period)) {
      result = t("Any Season");
    } else if (value?.fullDate) {
      result = dayjs(value.fullDate).format("MMMM");
    } else if (value?.date) {
      result = `${DateHelper.formatDateToString(
        value.date.from,
      )} - ${DateHelper.formatDateToString(value.date.to)}`;
    } else if (periodType === "1") {
      result = dayjs(checkin).format("MMMM");
    } else if (checkin && checkout) {
      result = `${dayjs(checkin).format("DD MMM YYYY")} - ${dayjs(
        checkout,
      ).format("DD MMM YYYY")}`;
    } else if (
      dayjs(checkin).isSame(today, "day") &&
      dayjs(checkout).diff(checkin, "year") === 1
    ) {
      result = t("Any Season");
    } else {
      result = t("Any Season");
    }

    return result;
  };

  const renderContent = (field: any, setValue: any) => (
    <Tabs defaultValue="1">
      <TabsList className="flex items-center justify-between">
        <TabsTrigger className="w-full pb-4 pt-5" value="1">
          {t("Season")}
        </TabsTrigger>
        <TabsTrigger className="w-full pb-4 pt-5" value="2">
          {t("Date")}
        </TabsTrigger>
      </TabsList>
      <TabsContent value="1">
        <PeriodPicker
          onPeriodSelect={(value) => {
            setValue({
              ...field.value,
              date: undefined,
              period: value.date,
              fullDate: value.fullDate,
              anySelected: value.anySelected,
            });
          }}
        />

        <TpBottomBox
          onApplyClick={() => {
            boolean.setFalse();
          }}
          label={
            <div>
              {(field.value?.fullDate &&
                dayjs(field.value?.fullDate).format("MMMM")) ||
                t("Any Season")}
            </div>
          }
        />
      </TabsContent>
      <TabsContent value="2">
        <div>
          <div className="mx-auto my-4 w-full max-w-[510px]">
            <div className="flex gap-3 rounded-full bg-warning-50 px-[10px] py-[4px]">
              <div className="flex size-[24px] items-center justify-center rounded-full border bg-white">
                <AlertCircleIcon className="w-4 text-[8px] text-warning-500" />
              </div>
              <div className="text-sm font-medium text-warning-700">
                {t("Select Date For Tours")}
              </div>
            </div>
          </div>
          <Calendar
            className="p-0 pb-3"
            initialFocus
            mode="range"
            fromDate={dayjs().toDate()}
            toYear={dayjs().year() + 1}
            selected={field.value?.date}
            onSelect={(value) => {
              setValue({
                ...field.value,
                date: value,
                period: undefined,
                fullDate: undefined,
                anySelected: false,
              });
            }}
            numberOfMonths={2}
          />
          <TpBottomBox
            onApplyClick={() => {
              boolean.setFalse();
            }}
            label={<div>{useMessageByDates(field.value?.date)}</div>}
          />
        </div>
      </TabsContent>
    </Tabs>
  );

  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue }) => (
        <>
          {isDesktop &&
          windowSize.getWindowSize().height > TP_POPOVER_OFFSET ? (
            <div className="relative grid gap-2">
              <Popover open={boolean.value} onOpenChange={boolean.setValue}>
                <PopoverTrigger>
                  <TriggerButton
                    isFocus={boolean.value}
                    size="lg"
                    leftIcon={<LIcon name="Calendar" />}
                    fullWidth
                    value={getValue(
                      field.value,
                      anySelected,
                      isPeriodType,
                      checkinDate,
                      checkoutDate,
                    )}
                  />
                </PopoverTrigger>
                <PopoverContent
                  side="bottom"
                  className="scroll-bar w-auto p-0"
                  avoidCollisions={false}
                >
                  {renderContent(field, setValue)}
                </PopoverContent>
              </Popover>
            </div>
          ) : (
            <div>
              <TriggerButton
                onClick={boolean.setTrue}
                isFocus={boolean.value}
                size="lg"
                leftIcon={<LIcon name="Calendar" />}
                fullWidth
                value={getValue(
                  field.value,
                  anySelected,
                  isPeriodType,
                  checkinDate,
                  checkoutDate,
                )}
              />
              <Dialog
                modal
                open={boolean.value}
                onOpenChange={boolean.setValue}
              >
                <DialogContent className="z-[101] size-full p-0">
                  <div className="flex flex-col pt-4">
                    <div className="flex grow flex-col items-center pt-4">
                      <Tabs
                        defaultValue="1"
                        className="flex size-full flex-col"
                      >
                        <TabsList className="flex items-center justify-between">
                          <TabsTrigger className="w-full pb-4 pt-5" value="1">
                            {t("Season")}
                          </TabsTrigger>
                          <TabsTrigger className="w-full pb-4 pt-5" value="2">
                            {t("Date")}
                          </TabsTrigger>
                        </TabsList>
                        <TabsContent
                          value="1"
                          className="flex grow flex-col justify-between"
                        >
                          <PeriodPicker
                            onPeriodSelect={(value) => {
                              setValue({
                                ...field.value,
                                date: undefined,
                                period: value.date,
                                fullDate: value.fullDate,
                                anySelected: value.anySelected,
                              });
                            }}
                          />
                          <TpBottomBox
                            onApplyClick={() => {
                              boolean.setFalse();
                            }}
                            label={
                              <div>
                                {(field.value?.fullDate &&
                                  dayjs(field.value?.fullDate).format(
                                    "MMMM",
                                  )) ||
                                  t("Any Season")}
                              </div>
                            }
                          />
                        </TabsContent>
                        <TabsContent
                          value="2"
                          className="flex grow flex-col justify-between"
                        >
                          <div className="mx-auto my-4 w-full max-w-[510px]">
                            <div className="flex gap-3 rounded-full bg-warning-50 px-[10px] py-[4px]">
                              <div className="flex size-[24px] items-center justify-center rounded-full border bg-white">
                                <AlertCircleIcon className="w-4 text-[8px] text-warning-500" />
                              </div>
                              <div className="text-sm font-medium text-warning-700">
                                {t("Select Date For Tours")}
                              </div>
                            </div>
                          </div>
                          <div className="flex grow flex-col items-center px-4 pt-4">
                            <Calendar
                              initialFocus
                              mode="range"
                              fromDate={dayjs().toDate()}
                              toYear={dayjs().year() + 1}
                              selected={field.value?.date}
                              onSelect={(value) => {
                                setValue({
                                  ...field.value,
                                  date: value,
                                  period: undefined,
                                  fullDate: undefined,
                                  anySelected: false,
                                });
                              }}
                              numberOfMonths={1}
                            />
                          </div>
                          <TpBottomBox
                            onApplyClick={() => {
                              boolean.setFalse();
                            }}
                            label={
                              <div>{useMessageByDates(field.value?.date)}</div>
                            }
                          />
                        </TabsContent>
                      </Tabs>
                    </div>
                  </div>
                </DialogContent>
              </Dialog>
            </div>
          )}
        </>
      )}
    </FormItem>
  );
};

export default TpPeriodDateWrappedFormItem;
