import FormItem from "@/components/form/form-item";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu/dropdown-menu";
import LIcon from "@/components/ui/lucid-icon/lucid-icon";
import TriggerButton from "@/components/ui/trigger-button/trigger-button";
import TpValidationMessage from "@/components/widget/travel-planner/components/tp-validation-message/tp-validation-message";
import { useReasonListQuery } from "@/services/eva-display/travel-reason/travel-reason.service";

export interface IReasonItem {
  name: string;
  value: string;
  order: number;
  properties?: any;
}

export const TpReasonDropdownWrappedFormItem = (props: {
  name: string;
  rules?: any;
}) => {
  const reasonListQuery = useReasonListQuery();

  return (
    <FormItem name={props.name} rules={props.rules}>
      {({ field, setValue, fieldState }) => (
        <div className="relative">
          <DropdownMenu>
            <DropdownMenuTrigger className="w-full min-w-full max-w-full">
              <TriggerButton
                label="Seyahat Nedeni"
                fullWidth
                size="lg"
                value={field.value?.name}
                rightIcon={<LIcon name="ChevronDown" />}
              />
            </DropdownMenuTrigger>
            <DropdownMenuContent className="w-full min-w-[325px] max-w-full">
              {reasonListQuery.isSuccess &&
                reasonListQuery.data?.data.result?.items.map(
                  (item: IReasonItem) => (
                    <DropdownMenuItem
                      key={item.value}
                      onClick={() => {
                        setValue(item);
                      }}
                    >
                      {item.name}
                    </DropdownMenuItem>
                  ),
                )}
            </DropdownMenuContent>
          </DropdownMenu>
          {fieldState.error?.message && (
            <TpValidationMessage
              position="bottom"
              message={fieldState.error?.message}
            />
          )}
        </div>
      )}
    </FormItem>
  );
};
