"use client";

import FormItem from "@/components/form/form-item";
import CustomerGroupSelect from "@/components/widget/travel-planner/components/customer-group-select/customer-group-select";
import { CUSTOMER_GROUP_DEFAULT_VALUE } from "@/components/widget/travel-planner/components/customer-group-select/customer-group-select-constants";
import CustomerGroupSelectMobile from "@/components/widget/travel-planner/components/customer-group-select/customer-group-select-mobile";
import { usePermGuard } from "@/features/permission/components/perm-guard";
import { useApp } from "@/hooks/useApp";
import { useBreakpoints } from "@/hooks/useBreakpoints";
import { useLabels } from "@/hooks/useLabels";
import { useLocale } from "@/hooks/useLocale";
import { requestAddGuestPassengersAllowPerm } from "@/validations/permissions/request-add-guest-passengers";

export const TpRoomSelectWrappedFormItem = (props: {
  name: string;
  checkInDate?: Date;
}) => {
  const { isB2C, isOtel } = useApp();
  const { guest } = useLabels();
  const { t } = useLocale();
  const permGuard = usePermGuard({
    permission: requestAddGuestPassengersAllowPerm,
  });

  const isCheck = isB2C || isOtel ? true : permGuard;

  const { isDesktop } = useBreakpoints();

  const CustomerGroupSelectComponent = isDesktop
    ? CustomerGroupSelect
    : CustomerGroupSelectMobile;

  return (
    <FormItem name={props.name}>
      {({ field, setValue }) => (
        <CustomerGroupSelectComponent
          value={field.value}
          checkInDate={props.checkInDate}
          onChange={(value) => {
            setValue(value);
          }}
          onNewGroup={() => {
            setValue([
              ...field.value,
              isB2C || isOtel
                ? {
                    employee: { count: 0 },
                    guest: { count: 1 },
                    child: { count: 0, ages: [] },
                  }
                : CUSTOMER_GROUP_DEFAULT_VALUE,
            ]);
          }}
          onRemoveGroup={(index) => {
            const newValue = [...field.value];
            newValue.splice(index, 1);
            setValue(newValue);
          }}
          items={() =>
            isCheck
              ? [
                  {
                    label: "Kurum Çalışanı",
                    name: "employee",
                    min: 0,
                    max: 5,
                  },
                  {
                    label: guest.label,
                    name: "guest",
                    min: isB2C ? 1 : 0,
                    max: 5,
                  },
                  {
                    label: t("Child"),
                    name: "child",
                    min: 0,
                    max: 4,
                    hasAge: true,
                    agesLabel: (ageIndex: number) =>
                      `${ageIndex + 1}${t(". child age")}`,
                  },
                ].filter((item) =>
                  isB2C || isOtel ? item.name !== "employee" : true,
                )
              : [
                  {
                    label: "Kurum Çalışanı",
                    name: "employee",
                    min: 0,
                    max: 5,
                  },
                ].filter((item) =>
                  isB2C || isOtel ? item.name !== "employee" : true,
                )
          }
        />
      )}
    </FormItem>
  );
};
