/* eslint-disable consistent-return */
/* eslint-disable no-nested-ternary */
import "./travel-planner.css";

import { usePathname } from "next/navigation";
import type { PropsWithChildren } from "react";

import Container from "@/components/shared/container";
import { useApp } from "@/hooks/useApp";
import { useLocale } from "@/hooks/useLocale";
import { cn } from "@/libs/utils";

interface TravelPlannerBoxProps extends PropsWithChildren {
  contentData?: {
    title: string;
    subTitle: string;
    titleStyle: Object;
    subTitleStyle: Object;
    backgroundImagePath: string;
    backgroundColor: string;
  };
}
const TravelPlannerBox = (props: TravelPlannerBoxProps) => {
  const { isB2C, isB2E } = useApp();
  const pathName = usePathname();
  const { t } = useLocale();

  const appTpText = () => {
    let headerText = "";
    let descriptionText = "";

    if (props.contentData) {
      headerText = props.contentData.title;
      descriptionText = props.contentData.subTitle;
    } else if (isB2C) {
      if (pathName.includes("/tour")) {
        headerText = "Hayalinizdeki turu keşfedin!";
        descriptionText = "Muhteşem turlar için fırsatları kaçırmayın";
      } else if (pathName.includes("/hotel") || (isB2C && pathName === "/")) {
        headerText = t("Find your accommodation.");
        descriptionText = t(
          "Do not miss the opportunities for hotels, villas and much more...",
        );
      } else if (pathName.includes("/flight")) {
        headerText = "Hayalinizdeki uçuş deneyimi çok yakın!";
        descriptionText = "";
      } else if (pathName.includes("/rentcar")) {
        headerText = "Anahtarınızı çevirin ve yolcuğunuzu başlatın.";
        descriptionText = "";
      }
    } else {
      headerText = "İş seyahatleri için planlayın";
      descriptionText = "Kendiniz veya iş arkadaşlarınız için ayarlayın.";
    }

    return (
      <div className="flex flex-col gap-2">
        <h1
          className="heading-h1 text-2xl font-bold !leading-[normal] text-slate-800 drop-shadow-lg dark:text-white md:text-3xl xl:text-[calc(var(--font-multiplier-value)*36vmax)]"
          style={props.contentData?.titleStyle}
        >
          {headerText}
        </h1>
        <span
          className="heading-h5 text-base font-medium !leading-[normal] text-gray-500 drop-shadow-lg dark:text-white xl:text-[calc(var(--font-multiplier-value)*20vmax)]"
          style={props.contentData?.subTitleStyle}
        >
          {descriptionText}
        </span>
      </div>
    );
  };
  return (
    <div
      className={cn(
        "flex flex-col items-center justify-center bg-gray-100 bg-cover bg-center bg-no-repeat",
        {
          "lg:py-0": isB2C,
          "lg:py-16": isB2E,
        },
      )}
      style={{
        backgroundImage: `url(${props.contentData?.backgroundImagePath})`,
        backgroundColor: props.contentData?.backgroundColor,
      }}
    >
      <Container className="flex min-h-[316px] flex-col justify-center gap-4 py-16">
        {appTpText()}

        {props.children}
      </Container>
    </div>
  );
};

export default TravelPlannerBox;
