/* eslint-disable react-hooks/exhaustive-deps */

"use client";

import isUndefined from "lodash-es/isUndefined";
import { usePathname, useSearchParams } from "next/navigation";

import { usePageInfoStore } from "@/store/page-info-store/use-page-info-store";

import type { QueryParamsKeyType } from "./use-page-info.types";

export const usePageInfo = () => {
  const { setPageInfo: setPageInfoAction, status, info } = usePageInfoStore();
  const pathName = usePathname();

  const searchParams = useSearchParams();

  function paramsToJson(_params: URLSearchParams) {
    const queryParams: Record<string, string> = {};
    _params.forEach((value, key) => {
      queryParams[key] = value;
    });
    return queryParams;
  }

  // If there is a value you want to delete from query parameters, send it as undefined in queryParams
  function setQueryParams(
    queryParams: { [k in QueryParamsKeyType]?: string },
    _pathname?: string,
    target?: "_blank" | "_self" | "_parent" | "_top",
  ) {
    const params = new URLSearchParams(searchParams.toString());
    Object.keys(queryParams).forEach((key) => {
      if (params.has(key)) {
        params.delete(key);
      }

      if (!isUndefined(queryParams[key as QueryParamsKeyType])) {
        params.set(key, queryParams[key as QueryParamsKeyType]!);
      }
    });

    const queryParamsJson = paramsToJson(params);

    if (target !== "_blank") {
      setPageInfoAction({
        path: pathName,
        queryParams: queryParamsJson,
      });
    }

    window.open(`${_pathname ?? pathName}?${params.toString()}`, target);
  }

  function initialize() {
    const queryParams = paramsToJson(searchParams as any);
    setPageInfoAction({
      path: pathName,
      queryParams,
    });
  }

  return {
    info,
    isDone: status === "done",
    setQueryParams,
    initializePageInfo: initialize,
  };
};
