import type { DomainProduct } from "@/models/client-configs.model";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";
import {
  type Result,
  useGetUsetSettingsQuery,
} from "@/services/eva-panel/get-user-settings/get-user-settings";

const getDataByPropertyId = (data: Result[], name: string) => {
  return data?.find((item) => item?.PropertyName === name);
};

const useWidgetHotel = (): {
  selectedWidgetHotel: DomainProduct | undefined;
  phoneData: Result | undefined;
} => {
  const getUserSettings = useGetUsetSettingsQuery();
  const { clientConfig } = useServerDataCtx();
  const tpData = sessionStorage.getItem("core-travel-planner");
  const choosedHotel = tpData ? JSON.parse(tpData).payload.destinationId : null;
  const selectedWidgetHotel =
    clientConfig?.domainProducts.find((item) => item.id === +choosedHotel) ||
    clientConfig?.domainProducts.find(
      (item) => item.name === clientConfig?.clientScope,
    ) ||
    clientConfig?.domainProducts[0];

  const phoneData = getDataByPropertyId(
    getUserSettings?.data?.Result ?? [],
    "Çağrı Merkezi",
  );

  return {
    selectedWidgetHotel,
    phoneData,
  };
};

export default useWidgetHotel;
