"use client";

import { useTranslation } from "next-i18next";

import { useLocalizationStore } from "@/store/localization-store/use-localization-store";

const cultureCodes = {
  tr: "tr-TR",
  "tr-TR": "tr-TR",
  en: "en-US",
  "en-US": "en-US",
  de: "de-DE",
  "de-DE": "de-DE",
};

export const useLocale = () => {
  const { t, i18n } = useTranslation();
  const { localizationState } = useLocalizationStore();

  function changeLanguage(lang: string) {
    i18n.changeLanguage(lang);
  }

  function getCultureCode() {
    if (
      localizationState.data.language &&
      localizationState.data.language in cultureCodes
    ) {
      return cultureCodes[
        localizationState.data.language as keyof typeof cultureCodes
      ];
    }

    return cultureCodes.tr;
  }

  return { t, i18n, changeLanguage, lng: i18n.language, getCultureCode };
};
