export interface PriceDTO {
  currency: string;
  value: number;
  __typename?: string;
  currencyDisplay?: "symbol" | "code" | "name";
}

export const PriceManager = ({
  currency,
  value,
  currencyDisplay = "symbol",
}: PriceDTO) => {
  if (!currency || !value) return "";

  const isCurrencySymbol = currency.length === 1;
  let currencyName = isCurrencySymbol ? "TRY" : currency;

  if (currencyDisplay === "symbol" && isCurrencySymbol) {
    switch (currency) {
      case "₺":
        currencyName = "TRY";
        break;
      case "$":
        currencyName = "USD";
        break;
      case "€":
        currencyName = "EUR";
        break;
      default:
        currencyName = "TRY";
        break;
    }
  }

  const formattedValue = new Intl.NumberFormat("tr-TR", {
    style: "currency",
    currency: currencyName,
    minimumFractionDigits: 2,
    currencyDisplay,
  }).format(value);

  return currencyDisplay === "code"
    ? `${value.toLocaleString("tr-TR")} ${currency.replace("TRY", "TL")}`
    : formattedValue.replace("TRY", "TL");
};
