import { type NextRequest, NextResponse } from "next/server";

import { getBaseUrl } from "./libs/servers/get-url";

export const config = {
  matcher: ["/((?!api|_next/static|_next/image|favicon.ico|public/).*)"],
};

export async function middleware(request: NextRequest) {
  const baseUrl = getBaseUrl(request);
  request.headers.set("x-url", baseUrl);
  const headers = new Headers({
    ...request.headers,
    "x-url": baseUrl,
  });

  if (request.nextUrl.pathname.startsWith("/search")) {
    return NextResponse.rewrite(new URL(`/hotel-list`, request.url), {
      headers,
    });
  }

  if (request.nextUrl.pathname.startsWith("/detail")) {
    return NextResponse.rewrite(new URL(`/hotel-detail`, request.url), {
      headers,
    });
  }

  return NextResponse.next({
    headers,
  });
}
