/* eslint-disable no-console */
import { useEffectOnce } from "usehooks-ts";

import { storageManager } from "@/libs/storage-manager";
import { useMasterpassStore } from "@/store/masterpass-store/use-masterpass-store";
import { usePaymentStore } from "@/store/payment-store/use-payment-store";
import { useSummaryStore } from "@/store/summary-store/use-summary-store";
import { useTravelPlannerStore } from "@/store/travel-planner-store/use-travel-planner-store";

export const useCore = () => {
  const {
    summaryState: { status },
    setSummaryData,
  } = useSummaryStore();
  const { setData: setTPData } = useTravelPlannerStore();
  const { setPaymentData } = usePaymentStore();
  const { setMasterpassData } = useMasterpassStore();

  function initCoreSummary() {
    const coreSummaryStoragedData = storageManager.get("core-summary");
    setSummaryData(coreSummaryStoragedData ?? undefined);
  }
  function initCoreTravelPlanner() {
    const coreTPStoragedData = storageManager.get("core-travel-planner");
    setTPData(coreTPStoragedData ?? undefined);
  }

  function initCorePayment() {
    const corePaymentStoragedData = storageManager.get("core-payment");
    setPaymentData(corePaymentStoragedData);
  }

  function initMasterpass() {
    const coreMasterpassStoragedData = storageManager.get("masterpass");
    setMasterpassData(coreMasterpassStoragedData);
  }

  useEffectOnce(() => {
    initCoreSummary();
    initCoreTravelPlanner();
    initCorePayment();
    initMasterpass();
  });

  return {
    isSummaryReady: status === "done",
  };
};
