import type { z } from "zod";

import type { applyDiscountCouponResponseScheme } from "./payment-service.scheme";

interface IServiceError {
  code?: any;
  innerExceptionDetail?: any;
  exceptionDetail?: any;
  message: string;
  source: number;
}

interface IPaymentMetadata {
  cartId: string;
  transactionKey: string;
  creditCartNumber: string;
}

export interface IGetCampaignsBody extends IPaymentMetadata {}
export interface IGetInstallmentsBody extends IPaymentMetadata {
  campaignKey: string | null;
}

export interface IAvailableCampaignResponse {
  errors: IServiceError[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: Result;
}

interface Result {
  availableCampaignList: IAvailableCampaignItem[];
}

export interface IAvailableCampaignItem {
  key?: any;
  code?: any;
  name: string;
  discountAmount?: any;
  discountAmountDefaultCurrency?: any;
}

export interface I3DParametersVariables {
  transactionKey: string;
  cardNumber: string;
  cardOwner: string;
  cvv: string;
  expireMonth: string;
  expireYear: string;
  installmentKey: string;
  cartId: string;
  searchId: string;
  campaignKey: string | null;
}
export interface I3DResponse {
  errors: any[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: Result;
}

interface Result {
  url: string;
  parameters: Parameters;
}

interface Parameters {
  clientid: string;
  amount: string;
  oid: string;
  okUrl: string;
  failUrl: string;
  rnd: string;
  hash: string;
  storetype: string;
  lang: string;
  currency: string;
  pan: string;
  Ecom_Payment_Card_ExpDate_Year: string;
  Ecom_Payment_Card_ExpDate_Month: string;
  cv2: string;
  pgscardholder: string;
  pgscardnumber: string;
  pgscardmonth: string;
  pgscardyear: string;
  pgsorderid: string;
  fcdscp: string;
}

export interface I3DPollVariables {
  transactionKey: string;
  cardNumber: string;
  cardOwner: string;
  cvv: string;
  expireMonth: string;
  expireYear: string;
  installmentKey: string;
  cartId: string;
  campaignKey: string | null;
  searchId: string;
}

export interface I3DPollResponse {
  errors: any[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: number;
}

export interface IPayCCResponse {
  errors: IServiceError[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: boolean;
}

export interface IAllInstallmentsResponse {
  errors: any[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: Result;
}

interface Result {
  bankInstallments: BankInstallment[];
}

interface BankInstallment {
  provider: number;
  providerText: string;
  campaigns?: Campaign[];
  installments: Installment[];
}

interface Installment {
  installmentCount: number;
  installmentAdditionalCount: number;
  installmentTotalCount: number;
  installmentCountText: string;
  installmentAmount: string;
  totalAmount: string;
  installmentKey: string;
  monthlyPayTotal: number;
  macroMerchantId: string;
  providerName: string;
  paymentProvider: string;
  discountRate: string;
  selected: boolean;
}

interface Campaign {
  title: string;
  description: string;
}

export interface IApplyDiscountCouponResponseResult {
  loyalty?: ILoyalty;
  discountCoupons: IDiscountCoupon[];
}

export interface IDiscountCoupon {
  key: string;
  description: string;
  price: string;
  priceExchange: string;
  isExchangePrice: boolean;
}

export interface IApplyDiscountCouponVariables {
  cartId: string;
  transactionKey: string;
  code: string;
}

interface ILoyalty {
  productKey: string;
  loyalities: ICouponCodeLoyality[];
}

export interface ICouponCodeLoyality {
  key: string;
  value: number;
  productPrice: string;
  loyaltyPrice: string;
}

export type IApplyDiscountCouponResponse = z.infer<
  typeof applyDiscountCouponResponseScheme
>;
