import { useQuery } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import { BookingCancelReasonServiceSerializer } from "./booking-cancel-reason-service-serializer";

export const useBookingCancelReasonQuery = () => {
  const http = useHttp("wl-display-api");
  const { strategyKeys } = useServerDataCtx();

  const service = () =>
    http
      .post(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            Name: "Talep Ret Nedeni",
          },
          strategyKeys.bookCancelReasonList,
        ),
      )
      .then((res) => BookingCancelReasonServiceSerializer(res.data));

  return useQuery({
    queryFn: service,
    queryKey: ["booking-detail-cancel-reason-list"],
  });
};
