import { JsonParserHelper } from "@/libs/helpers/string-to-json-helper";
import type { IBookingRequest } from "@/models/booking-request.model";

import type { IBookingDetailResponse } from "./booking-detail-service.types";

export const bookingDetailSerializer = (
  bookingRequestData: IBookingDetailResponse,
) => {
  function getModuleName() {
    switch (bookingRequestData.moduleName) {
      case "HotelModule":
        return "Hotel";
      case "Hotel":
        return "Hotel";
      case "FlightModule":
        return "Flight";
      case "Flight":
        return "Flight";
      default:
        return undefined;
    }
  }

  const bookingRequestItem: IBookingRequest = {
    id: bookingRequestData.id,
    moduleName: getModuleName(),
    displayInformations: JsonParserHelper.jsonParseOrUndefined(
      bookingRequestData.displayInformations,
    ),
    passengerInformations: JsonParserHelper.jsonParseOrUndefined(
      bookingRequestData.passengerInformations,
    ),
    searchId: bookingRequestData.searchId,
    userId: bookingRequestData.userId,
    masterUserId: bookingRequestData.masterUserId,
    travelReasonId: bookingRequestData.travelReasonId,
    travelReasonName: bookingRequestData.travelReasonName,
    bookedProduct: JsonParserHelper.jsonParseOrUndefined(
      bookingRequestData.bookedProduct,
    ),
    predictedPriceTry: bookingRequestData.predictedPriceTry,
    extraServiceRequests: bookingRequestData.extraServiceRequests,
    reservationData: JsonParserHelper.jsonParseOrUndefined(
      bookingRequestData.reservationData,
    ),
    searchRequest: bookingRequestData.searchRequest,
    bookedPriceTry: bookingRequestData.bookedPriceTry,
    budgetRoleId: bookingRequestData.budgetRoleId,
    requestStatus: bookingRequestData.requestStatus,
    beforeRequestId: bookingRequestData.beforeRequestId,
    totalPrice: bookingRequestData.totalPrice,
    netPrice: bookingRequestData.netPrice,
    createDate: bookingRequestData.createDate,
    updateDate: bookingRequestData.updateDate,
    createdByUserId: bookingRequestData.createdByUserId,
    createdByUserName: bookingRequestData.createdByUserName,
    updatedByUserId: bookingRequestData.updatedByUserId,
    updatedByUserName: bookingRequestData.updatedByUserName,
    status: bookingRequestData.status,
    cancelRequest: bookingRequestData.cancelRequest,
    corpRequestHistories: bookingRequestData.corpRequestHistories,
  };

  return bookingRequestItem;
};
