import { useQuery } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import type { IBookingRequest } from "@/models/booking-request.model";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import { bookingRequestSerializer } from "../booking-request/booking-request-service.serializer";
import type { IBookingDetailResponse } from "./booking-detail-service.types";
import { bookingDetailSerializer } from "./booking-detail-service-serializer";

export const useBookingDetailQuery = (
  variables: {
    RequestId: number;
  },
  queryOptions?: MutationOptions<IBookingRequest[]>,
) => {
  const http = useHttp("wl-display-api");
  const { strategyKeys } = useServerDataCtx();

  const service = () =>
    http
      .post<
        IStrategyRunnerResponse<IBookingDetailResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.bookRequestDetail))
      .then((res) =>
        bookingDetailSerializer(res.data.result.serviceResponse.result),
      );

  return useQuery({
    queryFn: service,
    queryKey: ["booking-detail-item-list"],
    ...queryOptions,
  });
};

export const useBookingRequestDetailQuery = (
  variables: {
    RequestId: number;
  },
  queryOptions?: MutationOptions<IBookingRequest>,
) => {
  const http = useHttp("wl-display-api");
  const { strategyKeys } = useServerDataCtx();

  const service = () =>
    http
      .post<
        IStrategyRunnerResponse<IBookingDetailResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.bookRequestDetail))
      .then((res) =>
        bookingRequestSerializer(res.data.result.serviceResponse.result),
      );

  return useQuery({
    queryFn: service,
    queryKey: ["booking-detail-item-list"],
    ...queryOptions,
  });
};
