import { useMutation } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type { IBookingRequestChangeStatusParameters } from "./booking-request-status-services.types";

export const useBookingRequestStatusMutation = () => {
  const http = useHttp("wl-display-api");
  const { strategyKeys } = useServerDataCtx();

  const service = (variables: IBookingRequestChangeStatusParameters) => {
    return http.post(
      "/api/v1/strategy/run",
      setParametersToStrategyRunner(
        variables,
        strategyKeys.requestChangeStatus,
      ),
    );
  };

  return useMutation({
    mutationFn: service,
    mutationKey: "booking-request-status",
  });
};
