import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import type { StatusVariants } from "@/components/ui/status-text/status-text.variants";
import type { IDisplayInformations } from "@/services/eva-display/demand/display-information/display-information";

export type IBookingRequestListResponse = IStrategyRunnerResponse<
  IBookingRequestItem[]
>;

export interface IBookingRequestItem {
  id: number;
  displayInformations: IDisplayInformations;
  moduleName:
    | "Hotel"
    | "HotelModule"
    | "Flight"
    | "FlightModule"
    | "TransferModule"
    | "CarRentalModule";
  totalPrice?: number;
  passengerInformations: string;
  searchId: string;
  userId: string;
  masterUserId: any;
  travelReasonId: number;
  travelReasonName: string;
  bookedProduct?: string;
  predictedPriceTry: number;
  extraServiceRequests?: string;
  reservationData: string;
  searchRequest: string;
  bookedPriceTry?: number;
  budgetRoleId?: number;
  linkId: string;
  expensivePriceTry?: number;
  requestStatus: number;
  beforeRequestId?: number;
  netPrice?: number;
  taxPrice?: number;
  thycorporateCode?: string;
  scopePath: string;
  createDate: string;
  updateDate: string;
  createdByUserId: string;
  createdByUserName: string;
  updatedByUserId: string;
  updatedByUserName: string;
  status: number;
  cancelRequest: number;
  corpBookingRecords?: IDemandCorpBookingRecord[];
}

export interface IDemandCorpBookingRecord {
  id: number;
  approvedById: string;
  bookingKey: string;
  requestId: number;
  searchId: string;
  serviceBookingRecord: string;
  status: number;
  createDate: string;
  updateDate: string;
  createdByUserId: string;
  updatedByUserId: string;
  exchangeRates: any;
  requestStatus: number;
  version: number;
}

export interface IBookingRequestItemPassengerInformation {
  $id: string;
  Id: number;
  IsMaster: boolean;
  Address: Address;
  Email: string;
  Prefix: string;
  Suffix: string;
  PhoneNumbers: PhoneNumber[];
  Country: Country;
  TcKimlikNo: string;
  SpecialServiceRequests: any[];
  ZipCode: string;
  SecretCustomer: boolean;
  PassportTypeId: number;
  MernisQueryStatus: number;
  LoyaltyCode: string;
  Key: string;
  Name: string;
  Surname: string;
  Age: number;
  PassengerType: number;
  Birthday: string;
  Gender: number;
  CrmCode: string;
  MilesCode: string;
  HesCode: string;
  PassportNumber: string;
}

interface PhoneNumber {
  $id: string;
  CountryCode: number;
  AreaCode: number;
  Number: string;
  Type: number;
}

interface Address {
  $id?: string;
  AddressName: string;
  Street: string;
  City: string;
  Country: Country;
  PostalCode: string;
}

interface Country {
  $id?: string;
  Id: number;
  ParentId?: any;
  ParentRegion?: any;
  Label: string;
}

export interface PassengerInformations {
  Id: number;
  IsMaster: boolean;
  Address: Address;
  Email: string;
  Prefix: string;
  Suffix: string;
  PhoneNumbers: PhoneNumber[];
  Country: Country;
  TcKimlikNo: string;
  SpecialServiceRequests: any[];
  ZipCode: string;
  SecretCustomer: boolean;
  PassportTypeId: number;
  MernisQueryStatus: number;
  LoyaltyCode: string;
  Key: string;
  Name: string;
  Surname: string;
  Age: number;
  PassengerType: number;
  Birthday: string;
  Gender: number;
  CrmCode: string;
  MilesCode: string;
  HesCode: string;
  PassportNumber: string;
}

interface PhoneNumber {
  CountryCode: number;
  AreaCode: number;
  Number: string;
  Type: number;
}

interface Address {
  AddressName: string;
  Street: string;
  City: string;
  Country: Country;
  PostalCode: string;
}

interface Country {
  Id: number;
  ParentId?: any;
  ParentRegion?: any;
  Label: string;
  LocalizedLabels?: any;
  IsParentsLoaded: boolean;
  ParentIds?: any;
}

export interface DisplayInformations {
  SearchRequest: SearchRequest;
  HotelName: string;
  RoomType: string;
  UserName: string;
  UserEmail: string;
  UserDepartment?: any;
  UserDepartmentId: number;
  MasterUserName?: any;
}

interface SearchRequest {
  HotelId?: any;
  SearchId?: any;
  RequestKey?: any;
  CountryCode: string;
  Currency: string;
  CheckInDate: string;
  CheckOutDate: string;
  PageSize: number;
  PageNumber: number;
  DestinationId: number;
  DestinationCode?: any;
  OriginCode?: any;
  TrfSrc?: any;
  DestinationType: number;
  DestinationSubType: number;
  OrderBy: number;
  Rooms: Room[];
  Filter: Filter;
  ExtraFilterLocationId?: any;
  TravelReason: number;
  DestinationName: string;
}

interface Filter {
  HotelName: string;
  Locations: any[];
  MealTypes: any[];
  Facilities: any[];
  Themes: any[];
  MinPrice?: any;
  MaxPrice?: any;
}

interface Room {
  Passengers: Passenger[];
}

interface Passenger {
  Key?: any;
  Name?: any;
  Surname?: any;
  Age: number;
  PassengerType: number;
  Birthday: string;
  Gender: number;
  CrmCode?: any;
  MilesCode?: any;
  HesCode?: any;
  PassportNumber?: any;
}

export interface ReservationData {
  SearchProductKey: string;
  PriceCombinationKeys: string[];
  BookingCode: string;
  SaleCode: string;
  SearchResponse: SearchResponse;
  DetailResponse: DetailResponse;
}
export interface HotelDetailResponse {
  Name: string;
  Information: string;
  Images?: any;
  Seasons?: any;
  HygienicalMeasures?: any;
  RoomGroupResult: RoomGroupResult[];
  RoomCollectionResult: RoomCollectionResult[];
  HotelAddons?: any;
  GeneralInformation?: any;
  HotelThemes?: any;
  NearDistances?: any;
  FoodDrinks?: any;
}

interface RoomCollectionResult {
  RoomId: number;
  Title: string;
  ViewType: string;
  Description: string;
  ShowcaseImage?: any;
  Images: Image[];
  Attributes: any[];
  Facilities: Facility[];
  HotelAvailabilityItems?: any;
  Rooms: Room[];
}

interface Room {
  RoomIndex: number;
  Key: string;
  LowestPrice: boolean;
  LowestPriceDescription: string;
  BasePrice: string;
  TotalPrice: string;
  Discount: string;
  DiscountRate: number;
  DiscountRateDescription?: any;
  NightlyRateDescription: string;
  OnDemand: boolean;
  OnDemandDescription: string;
  RoomHeadings: string[];
  PassengerKeys: string[];
  Addons?: any;
  RestrictionList: any[];
  NightlyRateResults: NightlyRateResult[];
  DiscountInformations: any[];
  CampaignInformations: CampaignInformation[];
  MealType: MealType;
  FreeChildStatus?: any;
  CancellationPolicy: CancellationPolicy;
}

interface CancellationPolicy {
  Key?: any;
  Icon?: any;
  Description: string;
  Tooltip: string;
  Refundable: boolean;
  CartDescription?: any;
}

interface MealType {
  Key: string;
  Icon?: any;
  Description: string;
  Tooltip?: any;
  Order: number;
}

interface NightlyRateResult {
  Date: string;
  BasePrice: string;
  TotalPrice: string;
  Discount: string;
}

interface Facility {
  Key: string;
  Icon?: any;
  Description: string;
  Tooltip: string;
  Order: number;
}

interface Image {
  CategoryType: string;
  Url: string;
  ThumbnailUrl: string;
  HighResolutionUrl?: any;
}

interface RoomGroupResult {
  RoomKeys: string[];
  Type: number;
  Key: string;
  UseCancelWarranty: boolean;
  BasePrice: string;
  TotalPrice: string;
  Discount: string;
  TaxPrice: string;
  CheckInDate: string;
  CheckOutDate: string;
  MasterHotelId: number;
  CampaignInformations: CampaignInformation[];
  OptionalAddOns: any[];
  ExchangeRates: ExchangeRates;
  LoyaltyItem?: any;
}

interface ExchangeRates {
  TRY: TRY;
}

interface TRY {
  Currency: number;
  RateCode: string;
  Value: number;
}

interface CampaignInformation {
  Key: string;
  Icon: string;
  Description: string;
  Tooltip: string;
  Order: number;
}

interface DetailResponse {
  Name?: any;
  PricingCombinations: PricingCombination2[];
}

export interface PricingCombination2 {
  Key: string;
  TotalPrice: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate?: any;
  BankCampaingId?: any;
  PosKey: string;
  CombinationGroups: BookingRequestCombinationGroup[];
  CombinationGroupKeys: string[];
  Type: string;
}

export interface BookingRequestCombinationGroup {
  Key: string;
  TotalPrice: string;
  TotalPriceCast: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate?: any;
  BankCampaingId?: any;
  PosKey?: any;
  GroupId: number;
  FlightSegmentKeys?: any;
  FlightSegments: BookingRequestFlightSegment[];
  TravelTime: string;
  IsOneWayCombinable: boolean;
  Type: string;
  CabinClassTitle?: any;
  CabinClassDescription?: any;
  Tags?: any;
  Quota: number;
}

export interface BookingRequestFlightSegment {
  map(arg0: (_flightSegmentItem: any) => any): unknown;
  Key: string;
  GroupId: number;
  Origin: string;
  Destination: string;
  DepartureTime: string;
  ArrivalTime: string;
  FlightTime: string;
  OperatingAirline: string;
  OperatingAirlineIconUrl: string;
  OperatingAirlineCode: string;
  MarketingAirline: string;
  MarketingAirlineIconUrl: string;
  MarketingAirlineCode: string;
  FlightNumber: string;
  CabinClass: number;
  BookingCode: string;
  Quota: number;
  VoyageCode?: any;
}

interface SearchResponse {
  SearchId?: any;
  HasMorePage: boolean;
  TotalRecord: number;
  FlightSegments: any[];
  CombinationGroups: any[];
  PricingCombinations: PricingCombination[];
  PassengerList: any[];
  Filter?: any;
  IsAbroad: boolean;
}

interface PricingCombination {
  Key: string;
  TotalPrice: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate?: any;
  BankCampaingId?: any;
  PosKey?: any;
  CombinationGroups: CombinationGroup[];
  CombinationGroupKeys: string[];
  Type: string;
}

interface CombinationGroup {
  Key: string;
  TotalPrice: string;
  TotalPriceCast: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate?: any;
  BankCampaingId?: any;
  PosKey?: any;
  GroupId: number;
  FlightSegmentKeys?: any;
  FlightSegments?: any;
  TravelTime: string;
  IsOneWayCombinable: boolean;
  Type: string;
  CabinClassTitle?: any;
  CabinClassDescription?: any;
  Tags?: any;
  Quota: number;
}

export interface RezervationHotelSearchResponse {
  SearchId: string;
  RequestKey?: any;
  HasMorePage: boolean;
  TotalHotelCount: number;
  Items: Item[];
  PassengerList: any[];
  FilterResult: FilterResult;
}

interface FilterResult {
  Locations: any[];
  MealTypes: any[];
  Facilities: any[];
  Themes: any[];
  HotelNames: any[];
  MinPrice: number;
  MaxPrice: number;
}

interface Item {
  HotelId: number;
  Key: string;
  Name: string;
  Location: string;
  DestinationId: number;
  CityId: number;
  Recommended: boolean;
  IsAlternative: boolean;
  OnDemand: boolean;
  OnDemandDescription?: any;
  MealTypes: MealType[];
  CancellationPolicy: CancellationPolicy;
  CampaignInformations: CampaignInformation[];
  Images: Image[];
  DiscountRate: number;
  DiscountRateDescription?: any;
  BasePrice: string;
  TotalPrice: string;
  TotalPriceCast: string;
  AccommodationDayCountInfo: string;
  HasHygienicalMeasure: boolean;
  PassportRequired: boolean;
  LoyaltyItem?: any;
  PriceDifferenceBackGuarantee: boolean;
  AvailableInstallment: string;
  DiscountInformations: any[];
  Reasons?: any;
}

interface Image {
  CategoryType: string;
  Url: string;
  ThumbnailUrl: string;
  HighResolutionUrl?: any;
}

interface CampaignInformation {
  Key: string;
  Icon: string;
  Description: string;
  Tooltip: string;
  Order: number;
}

interface CancellationPolicy {
  Key?: any;
  Icon?: any;
  Description: string;
  Refundable: boolean;
  CartDescription?: any;
}

interface MealType {
  Key: string;
  Description: string;
  Tooltip?: any;
  Order: number;
}

// enums
export const statusEnumTypes: Record<number, StatusVariants> = {
  0: "warning",
  1: "success",
  2: "denied",
  3: "error",
  4: "warning",
  5: "warning",
  6: "error",
};
