export interface IPlaneReservationData {
  SearchProductKey: string;
  PriceCombinationKeys: string[];
  BookingCode: string;
  SaleCode: string;
  SearchResponse: ISearchResponse;
  DetailResponse: IDetailResponse;
  ProjectCode?: string;
  ReservationNote?: string;
}

export interface IDetailResponse {
  Name: null;
  PricingCombinations: IPricingCombination[];
}

export interface IPricingCombination {
  Key: string;
  TotalPrice: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  FlightSegments: object;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate: null;
  BankCampaingId: null;
  PosKey: null | string;
  CombinationGroups: ICombinationGroup[] | null;
  CombinationGroupKeys: string[] | null;
  Type: string;
}

export interface ICombinationGroup {
  Key: string;
  TotalPrice: string;
  TotalPriceCast: string;
  EquivalentTotalPrice: string;
  BasePrice: string;
  Taxes: string;
  Discount: string;
  OnRequest: boolean;
  Reservable: boolean;
  PricingDate: null;
  BankCampaingId: null;
  PosKey: null;
  GroupId: number;
  FlightSegmentKeys: null;
  FlightSegments: IFlightSegment[];
  TravelTime: string;
  IsOneWayCombinable: boolean;
  Type: string;
  CabinClassTitle: null | string;
  CabinClassDescription: null | string;
  Tags: null;
  Quota: number;
}

export interface IFlightSegment {
  Key: string;
  GroupId: number;
  Origin: string;
  Destination: string;
  DepartureTime: Date;
  ArrivalTime: Date;
  FlightTime: string;
  OperatingAirline: string;
  OperatingAirlineCode: string;
  MarketingAirline: string;
  MarketingAirlineCode: string;
  MarketingAirlineIconUrl: string;
  FlightNumber: string;
  CabinClass: number;
  BookingCode: string;
  Quota: number;
  VoyageCode: null;
}

export interface ISearchResponse {
  SearchId: null;
  HasMorePage: boolean;
  TotalRecord: number;
  FlightSegments: any[];
  CombinationGroups: any[];
  PricingCombinations: IPricingCombination[];
  PassengerList: any[];
  Filter: null;
  IsAbroad: boolean;
}
