import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

interface FlightAddToCartParameters {
  FlightCartProductRequest: FlightCartProductRequest;
}

interface FlightCartProductRequest {
  cardId?: any;
  searchId: string;
  PricingCombinationKeys: string[];
  PreBook: number;
}

export interface IFlightAddToCartResponse {
  cartId: string;
  reservationSummaryCaption: string;
  checkInString: string;
  checkOutString: string;
  checkInDate: string;
  checkOutDate: string;
  totalPriceString: string;
  totalPrice: string;
  kvkkAgreementText: string;
  cancelWarranty?: any;
  currencyMessage?: any;
  isDifferentCurrency: boolean;
}

export const useFlightAddToCartMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: FlightAddToCartParameters) =>
    http
      .post<
        IStrategyRunnerResponse<IFlightAddToCartResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.flightAddToCart))
      .then((res) => getResultFromStrategyResponse(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "flight-add-to-cart",
  });
};
