import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  getServiceResponseFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

interface IFlightCreatePostParameters {
  CorpCreateFlightRequest: CorpCreateFlightRequest;
}

interface CorpCreateFlightRequest {
  SearchId: string;
  CartId: string;
  RequestId?: any;
  TravelReasonId: number;
  BranchId?: number;
  LinkId: string;
  SearchProductKey: string;
  PriceCombinationKeys: string[];
  IsPreBook: boolean;
  KvkkStatus: boolean;
  PassengerInformations: PassengerInformation[];
  ProjectCode?: string;
  ReservationNote?: string;
  RequesterUserIds?: string[];
}

interface PassengerInformation {
  Id: number;
  IsMaster: boolean;
  Address: Address;
  Email: string;
  Prefix: string;
  Suffix: string;
  PhoneNumbers: PhoneNumber[];
  Country: Country;
  LoyaltyCode?: string;
  TcKimlikNo: string;
  SpecialServiceRequests: any[];
  ZipCode: string;
  SecretCustomer?: any;
  PassportTypeId: number;
  MernisQueryStatus: number;
  Key: string;
  Name: string;
  Surname: string;
  Age: number;
  PassengerType: number;
  Birthday: string;
  Gender: number;
  CrmCode: string;
  MilesCode: string;
  HesCode: string;
  PassportNumber: string;
}

interface PhoneNumber {
  CountryCode: number;
  AreaCode: number;
  Number: string;
  Type: number;
}

interface Address {
  AddressName: string;
  Street: string;
  City: string;
  Country: Country;
  PostalCode: string;
}

interface Country {
  Id: number;
  ParentId?: any;
  ParentRegion?: any;
  Label: string;
}

export const useFlightCreatePostMutation = (
  options?: MutationOptions<{ requestId: number }>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: IFlightCreatePostParameters) =>
    http
      .post<
        IStrategyRunnerResponse<{ requestId: number }>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.createPostFlight))
      .then((res) =>
        getResultFromStrategyResponse<{ requestId: number }>(res.data),
      );

  return useMutation({
    mutationFn: service,
    mutationKey: "create-post-flight",
    ...options,
  });
};

export const useFlightCreatePostWithResultMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: IFlightCreatePostParameters) =>
    http
      .post<
        IStrategyRunnerResponse<{ requestId: number }>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.createPostFlight))
      .then((res) =>
        getServiceResponseFromStrategyResponse<{ requestId: number }>(res.data),
      );

  return useMutation({
    mutationFn: service,
    mutationKey: "create-post-flight",
  });
};
