import { useMutation, useQuery } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import type {
  IServiceResponse,
  IStrategyRunnerResponse,
} from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  getServiceResponseFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

interface IFlightDetailVariables {
  FlightDetailRequest: FlightDetailRequest;
}

export interface FlightDetailRequest {
  searchId: string;
  ProductKey: string;
  CombinationGroupKeys?: string[];
}

export interface IFlightDetailResponse {
  name?: any;
  pricingCombinations: PricingCombination[];
}

interface PricingCombination {
  key: string;
  totalPrice: string;
  equivalentTotalPrice: string;
  basePrice: string;
  taxes: string;
  discount: string;
  onRequest: boolean;
  reservable: boolean;
  pricingDate?: any;
  bankCampaingId?: any;
  posKey: string;
  combinationGroups: CombinationGroup[];
  combinationGroupKeys: string[];
  type: string;
}

interface CombinationGroup {
  key: string;
  totalPrice: string;
  totalPriceCast: string;
  equivalentTotalPrice: string;
  basePrice: string;
  taxes: string;
  discount: string;
  onRequest: boolean;
  reservable: boolean;
  pricingDate?: any;
  bankCampaingId?: any;
  posKey?: any;
  groupId: number;
  flightSegments: FlightSegment[];
  flightSegmentKeys: string[];
  travelTime: string;
  isOneWayCombinable: boolean;
  type: string;
  cabinClassTitle?: any;
  cabinClassDescription?: any;
  quota: number;
}

interface FlightSegment {
  key: string;
  groupId: number;
  origin: string;
  destination: string;
  departureTime: string;
  arrivalTime: string;
  flightTime: string;
  operatingAirline: string;
  operatingAirlineIconUrl: string;
  operatingAirlineCode: string;
  marketingAirline: string;
  marketingAirlineIconUrl: string;
  marketingAirlineCode: string;
  flightNumber: string;
  cabinClass: number;
  bookingCode: string;
  quota: number;
  voyageCode?: any;
}

export const useFlightDetailMutation = (
  options?: MutationOptions<IServiceResponse<IFlightDetailResponse>>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: IFlightDetailVariables) =>
    http
      .post<
        IStrategyRunnerResponse<IFlightDetailResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.flightDetail))
      .then((res) => getServiceResponseFromStrategyResponse(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "flight-detail",
    ...options,
  });
};

export const useFlightDetailQuery = (variables: IFlightDetailVariables) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = () =>
    http
      .post<
        IStrategyRunnerResponse<IFlightDetailResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(variables, strategyKeys.flightDetail))
      .then((res) => getResultFromStrategyResponse(res.data));

  return useQuery({
    queryFn: service,
    queryKey: "flight-detail-query",
  });
};
