/* eslint-disable no-underscore-dangle */
/* eslint-disable @typescript-eslint/naming-convention */
import { getResultFromStrategyResponse } from "@/libs/helpers/strategy-service.helper";

import type {
  CombinationGroup,
  FlightFilterResult,
  FlightListStrageryResponse,
  GroupedCombinationGroupByGroupIds,
  IFlightSegment,
  PassengerList,
  PricingCombination,
} from "./flight-search-services.types";

export type GroupedPricingCombinationWithCombinationGroups = {
  pricingCombinations: PricingCombinationWithCombinationGroups[];
  key: string;
};
export type PricingCombinationWithCombinationGroups = {
  combinationGroups: CombinationGroup[];
} & PricingCombination;

export interface IFlightSearchResultSerializer {
  metadata: {
    searchId: string;
    hasMorePage: boolean;
    isAbroad?: boolean;
  };
  totalFlightCount: number;
  flightList: IFlightSegment[];
  combinationGroups: CombinationGroup[];
  passengerList: PassengerList[];
  filterResult: Partial<FlightFilterResult>;
  pricingCombinations: PricingCombinationWithCombinationGroups[];
  pricingCombinationGroups: GroupedPricingCombinationWithCombinationGroups[];
  groupedCombinationGroupByGroupIds?: GroupedCombinationGroupByGroupIds[];
}

export const flightSearchResultSerializer = (
  data: FlightListStrageryResponse,
): IFlightSearchResultSerializer => {
  const response = getResultFromStrategyResponse(data);
  if (response === null)
    return null as unknown as IFlightSearchResultSerializer;

  function getCombinationGroups(combinationKeys: string[]) {
    return response?.combinationGroups.filter((combinationGroupItem) =>
      combinationKeys.includes(combinationGroupItem.key),
    );
  }

  function mapPricingCombination(pricingCombination: PricingCombination) {
    const { combinationGroupKeys, ...pCRest } = pricingCombination;

    if (!response.combinationGroups) {
      return null;
    }
    const _combinationGroupsKeys = combinationGroupKeys.filter((x) =>
      response.combinationGroups.find((y) => y.key === x),
    );

    return {
      ...pCRest,
      combinationGroupKeys: getCombinationGroups(_combinationGroupsKeys).map(
        (x) => x.key,
      ),
      combinationGroups: getCombinationGroups(_combinationGroupsKeys),
    };
  }

  return {
    metadata: {
      searchId: response?.searchId || "",
      hasMorePage: response?.hasMorePage || false,
      isAbroad: response?.isAbroad || false,
    },
    flightList: response?.flightSegments || [],
    totalFlightCount: response?.totalRecord || 0,
    combinationGroups: response?.combinationGroups || [],
    passengerList: response?.passengerList || [],
    pricingCombinationGroups:
      response?.groupedPricingCombinations?.map((x) => {
        return {
          pricingCombinations:
            (x.pricingCombinations.map(
              mapPricingCombination,
            ) as PricingCombinationWithCombinationGroups[]) || [],
          key: x.pricingCombinationKey,
        };
      }) || [],
    pricingCombinations:
      (response?.pricingCombinations?.map(
        mapPricingCombination,
      ) as PricingCombinationWithCombinationGroups[]) || [],
    filterResult: response?.filter || {},
    groupedCombinationGroupByGroupIds:
      response.groupedCombinationGroupByGroupIds,
  };
};
