/* eslint-disable no-console */
import { useQuery } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type { IFlightSearchRequest } from "./flight-search-services.types";
import { flightSearchResultSerializer } from "./flight-search-services-serializer";

interface FlightListSearchQueryProps {
  variables: IFlightSearchRequest;
  pageNumber?: number;
}

export const useFlightListSearchQuery = ({
  variables,
  pageNumber,
}: FlightListSearchQueryProps) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = async (FlightSearchRequest: IFlightSearchRequest) =>
    http
      .post(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            FlightSearchRequest,
          },
          strategyKeys.flightList,
        ),
      )
      .then((res) => flightSearchResultSerializer(res.data));

  const query = useQuery(
    ["flight-search", variables, pageNumber],
    () => service(variables),
    {
      retryDelay: 20000,
    },
  );

  return {
    ...query,
  };
};
