import type {
  IStrategyRunnerResponse,
  StrategyRunnerRequest,
} from "@/@types/types/strategy-service.types";

export type FlightSearchStrategyRequest =
  StrategyRunnerRequest<FlightSearchParameters>;

interface FlightSearchParameters {
  FlightSearchRequest: IFlightSearchRequest;
}

export interface IFlightSearchRequest {
  searchId?: any;
  FlightDisplayType: number;
  FlightTripKind: number;
  searchLegs: FlightSearchLeg[];
  searchPassengers: SearchPassenger[];
  Filter: FlightFilter;
}

export interface FlightFilter {
  PriceMin: number;
  PriceMax: number;
  AirlineCodes?: any;
  Layover?: any;
  GoingFlightDestinations?: any;
  ReturnFlightDestinations?: any;
  GoingDepartureMinTime?: string;
  GoingDepartureMaxTime?: string;
  GoingArrivalMinTime?: string;
  GoingArrivalMaxTime?: string;
  TurnDepartureMinTime?: string;
  TurnDepartureMaxTime?: string;
  TurnArrivalMinTime?: string;
  TurnArrivalMaxTime?: string;
  FlightMaxTime: string;
  FlightMinTime: string;
  PageSize: number;
  IsPaging: boolean;
  ResetPage: boolean;
  IsDirect?: any;
  GroupId: number;
  Order: number;
}

export interface SearchPassenger {
  passengerType: number;
  age: number;
}

export interface FlightSearchLeg {
  originId: number;
  originType: number;
  destinationId: number;
  destinationType: number;
  departureTime: string;
  cabinClass: number | undefined;
}

export type FlightListStrageryResponse =
  IStrategyRunnerResponse<IFlightSearchResult>;

export interface IFlightSearchResult {
  searchId: string;
  isAbroad?: boolean;
  hasMorePage: boolean;
  totalRecord: number;
  flightSegments: IFlightSegment[];
  combinationGroups: CombinationGroup[];
  pricingCombinations: PricingCombination[];
  groupedPricingCombinations?: {
    pricingCombinationKey: string;
    pricingCombinations: PricingCombination[];
  }[];
  passengerList: PassengerList[];
  filter: FlightFilterResult;
  groupedCombinationGroupByGroupIds?: GroupedCombinationGroupByGroupIds[];
}
export interface GroupedCombinationGroupByGroupIds {
  groupId: number;
  groupedCombinationGroups: GroupedCombinationGroup[];
  totalRecord: number;
}
export interface GroupedCombinationGroup {
  combinationGroupKey: string;
  combinationGroups: CombinationGroup[];
}

export interface FlightFilterResult {
  airlineCodes: AirlineCode[];
  layover: AirlineCode[];
  goingFlightDestinations: AirlineCode[];
  returnFlightDestinations: AirlineCode[];
  goingDepartureMinTime: string;
  goingDepartureMaxTime: string;
  goingArrivalMinTime: string;
  goingArrivalMaxTime: string;
  turnDepartureMinTime: string;
  turnDepartureMaxTime: string;
  turnArrivalMinTime: string;
  turnArrivalMaxTime: string;
  flightMaxTime: string;
  flightMinTime: string;
  minPrice: number;
  maxPrice: number;
}

export interface AirlineCode {
  key: string;
  value: string;
  selected: boolean;
  count: number;
}

export interface PassengerList {
  key: string;
  age: number;
  type: number;
}

export interface PricingCombination {
  key: string;
  totalPrice: string;
  equivalentTotalPrice: string;
  basePrice: string;
  taxes: string;
  discount: string;
  onRequest: boolean;
  reservable: boolean;
  pricingDate?: any;
  bankCampaingId?: any;
  posKey?: any;
  combinationGroupKeys: string[];
  type: string;
}

export interface CombinationGroup {
  key: string;
  totalPrice: string;
  totalPriceCast: string;
  equivalentTotalPrice: string;
  basePrice: string;
  taxes: string;
  discount: string;
  onRequest: boolean;
  reservable: boolean;
  pricingDate?: any;
  bankCampaingId?: any;
  posKey?: any;
  groupId: number;
  flightSegmentKeys: string[];
  flightSegments: IFlightSegment[];
  travelTime: string;
  isOneWayCombinable: boolean;
  type: string;
  cabinClassTitle?: string;
  cabinClassDescription?: string;
  quota?: number;
}

export interface IFlightSegment {
  key: string;
  groupId: number;
  origin: string;
  destination: string;
  departureTime: string;
  arrivalTime: string;
  flightTime: string;
  operatingAirline: string;
  operatingAirlineCode: string;
  operatingAirlineIconUrl?: string;
  marketingAirline: string;
  marketingAirlineCode: string;
  marketingAirlineIconUrl?: string;
  flightNumber: string;
  cabinClass: number;
  bookingCode: string;
  quota: number;
  voyageCode?: any;
}
