import { useMutation } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

interface IFlightValidateParameters {
  FlightValidateBookingRequest: FlightValidateBookingRequest;
}

interface FlightValidateBookingRequest {
  CartId: string;
  ReservationNotes: string;
  AddOnsKeyList: any[];
  CancelWarrantySearchId: string;
  SearchId: string;
  KvkkApproval: boolean;
  BookingPassengers: IFlightBookingPassenger[];
  BillingRequest: BillingRequest;
}

interface BillingRequest {
  IsInvoiceInformationDifferent: boolean;
  Type: number;
  InvoiceAccountCode?: any;
  InvoiceFirstName: string;
  InvoiceLastName: string;
  Gender: number;
  InvoiceTitle: string;
  InvoiceTaxOffice: string;
  InvoiceIdentityNumber?: any;
  InvoiceEmail?: any;
  InvoicePhone: string;
  InvoiceAddress: InvoiceAddress;
  InvoiceCountry?: any;
}

interface InvoiceAddress {
  AddressName?: any;
  Street: string;
  City?: any;
  Country?: Country;
  PostalCode?: any;
}

export interface IFlightBookingPassenger {
  Id: number;
  IsMaster: boolean;
  Address: Address;
  Email: string;
  Prefix: string;
  Suffix: string;
  PhoneNumbers: PhoneNumber[];
  Country: Country;
  TcKimlikNo: string;
  SpecialServiceRequests: string;
  ZipCode: string;
  SecretCustomer?: any;
  PassportTypeId: number;
  MernisQueryStatus: number;
  Key: string;
  Name: string;
  Surname: string;
  Age: number;
  PassengerType: number;
  Birthday: string;
  Gender: number;
  CrmCode: string;
  MilesCode: string;
  HesCode: string;
  PassportNumber: string;
}

interface PhoneNumber {
  CountryCode: number;
  AreaCode: number;
  Number: string;
  Type: number;
}

interface Address {
  AddressName: string;
  Street: string;
  City: string;
  Country: Country;
  PostalCode: string;
}

interface Country {
  Id: number;
  ParentId?: any;
  ParentRegion?: any;
  Label: string;
}

export const useFlightValidateMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: IFlightValidateParameters) =>
    http.post(
      "/api/v1/strategy/run",
      setParametersToStrategyRunner(variables, strategyKeys.flightValidate),
    );

  return useMutation({
    mutationFn: service,
    mutationKey: "flight-validate",
  });
};
