import { useMutation, useQuery } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { useLocale } from "@/hooks/useLocale";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type { IHotelAddToCartResponse } from "./hotel-add-to-card-services.types";
import { hotelAddToCardSerializer } from "./hotel-add-to-cart-services.serializer";

interface IHotelAddToCartParameters {
  HotelCartProductRequest: HotelCartProductRequest;
}

interface HotelCartProductRequest {
  SearchId: string;
  ProductKey: string;
}

export const useHotelAddToCartQuery = (
  variables: IHotelAddToCartParameters,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const { getCultureCode } = useLocale();

  const service = () =>
    http
      .post(
        `/api/v1/strategy/run?culture=${getCultureCode()}`,
        setParametersToStrategyRunner(variables, strategyKeys.addToCart),
      )
      .then((res) => hotelAddToCardSerializer(res.data));

  return useQuery({ queryFn: service, queryKey: "hotel-add-to-cart" });
};

export const useHotelAddToCartMutation = (
  options?: MutationOptions<IHotelAddToCartResponse>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const { getCultureCode } = useLocale();

  const service = (variables: IHotelAddToCartParameters) =>
    http
      .post(
        `/api/v1/strategy/run?culture=${getCultureCode()}`,
        setParametersToStrategyRunner(variables, strategyKeys.addToCart),
      )
      .then((res) => hotelAddToCardSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "hotel-add-to-cart-mutation",
    ...options,
  });
};
