import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import type { IServiceResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getServiceResponseFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  IHotelBookingRequestParameters,
  IHotelBookingRequestResponse,
} from "./hotel-booking-request-service.types";

export const useHotelBookingRequestMutation = (
  options?: MutationOptions<IServiceResponse<IHotelBookingRequestResponse>>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: IHotelBookingRequestParameters) =>
    http
      .post(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(variables, strategyKeys.createPost),
      )
      .then((res) =>
        getServiceResponseFromStrategyResponse<IHotelBookingRequestResponse>(
          res.data,
        ),
      );

  return useMutation({
    mutationFn: service,
    mutationKey: "hotel-booking-request",
    ...options,
  });
};
