import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { useLocale } from "@/hooks/useLocale";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import { hotelDetailResultSerializer } from "./hotel-detail-services.serializer";
import type {
  IHotelDetailSerializedResult,
  IHotelSearchDetailRequest,
} from "./hotel-detail-services.types";

export const useHotelDetailListSearchMutation = (
  options?: MutationOptions<IHotelDetailSerializedResult>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const { getCultureCode } = useLocale();

  const service = (variables: IHotelSearchDetailRequest) =>
    http
      .post(
        `/api/v1/strategy/run?culture=${getCultureCode()}`,
        setParametersToStrategyRunner(
          { hotelSearchDetailRequest: variables },
          strategyKeys.hotelDetail,
        ),
      )
      .then((res) => hotelDetailResultSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "hotel-detail",
    ...options,
  });
};
