import type {
  IStrategyRunnerResponse,
  StrategyRunnerRequest,
} from "@/@types/types/strategy-service.types";

export type HotelDetailStrategyRequest =
  StrategyRunnerRequest<HotelDetailParameters>;

interface HotelDetailParameters {
  HotelSearchDetailRequest: IHotelSearchDetailRequest;
}

export interface IHotelSearchDetailRequest {
  searchId: string;
  ProductKey: string;
}

export type IHotelDetailSerializedResult = {
  metadata: Omit<
    IHotelDetailResult,
    | "images"
    | "seasons"
    | "roomGroupResult"
    | "roomCollectionResult"
    | "hotelAddons"
    | "generalInformation"
    | "hotelThemes"
    | "nearDistances"
    | "foodDrinks"
    | "hygienicalMeasures"
  >;
} & Pick<
  IHotelDetailResult,
  | "images"
  | "seasons"
  | "roomGroupResult"
  | "roomCollectionResult"
  | "hotelAddons"
  | "generalInformation"
  | "hotelThemes"
  | "nearDistances"
  | "foodDrinks"
  | "hygienicalMeasures"
>;

export type HotelListStrategyResponse =
  IStrategyRunnerResponse<IHotelDetailResult>;

export interface IHotelDetailResult {
  name: string;
  information: string;
  images: Image[];
  seasons: Season[];
  roomGroupResult: RoomGroupResult[];
  roomCollectionResult: RoomCollectionResult[];
  hotelAddons: HotelAddon[];
  generalInformation: GeneralInformation;
  hotelThemes: HotelTheme[];
  nearDistances: NearDistance[];
  foodDrinks: FoodDrink[];
  hygienicalMeasures: HygienicalMeasures[];
}

export interface HygienicalMeasures {
  description: string;
  details: string[];
  imagePaths: string[];
  name: string;
  priority: number;
  startDate: string;
}

export interface FoodDrink {
  id: number;
  name: string;
  description: string;
  start: string;
  end: string;
  restaurantType: string;
  paidType: string;
}

export interface NearDistance {
  name: string;
  type: string;
  distance: string;
  distanceUnit: string;
}

export interface HotelTheme {
  id: string;
  name: string;
}

export interface GeneralInformation {
  address: string;
  latitude: string;
  longitude: string;
  recommended: boolean;
  size: string;
  barCount: number;
  roomCount: number;
  buildYear: string;
  restaurantCount: number;
  checkIn: string;
  checkOut: string;
  maleRestriction: boolean;
  petRestriction: boolean;
  marriageCertificateRestriction: boolean;
  childRestriction: boolean;
  childRestrictionAge: number;
  priceDifferenceBackGuarantee: boolean;
}

export interface HotelAddon {
  key: string;
  name: string;
  description: string;
  startDate: string;
  endDate: string;
  imagePaths?: string[];
}

export interface RoomCollectionResult {
  roomId: number;
  title: string;
  viewType?: string;
  description: string;
  showcaseImage?: any;
  images?: Image[];
  facilities?: Facility[];
  rooms: Room[];
  attributes?: Attributes[];
  hotelAvailabilityItems: Array<HotelAvailabilityItems>;
}

export interface HotelAvailabilityItems {
  date: Date;
  status: number;
}

export interface Attributes {
  key: string;
  icon: string;
  description: string;
  tooltip?: any;
  order: number;
}
export interface Room {
  roomIndex: number;
  key: string;
  lowestPrice: boolean;
  lowestPriceDescription: string;
  basePrice: string;
  totalPrice: string;
  totalPriceWithDiscount: string;
  discount: string;
  discountRate: number;
  discountRateDescription: string;
  nightlyRateDescription: string;
  onDemand: boolean;
  onDemandDescription: string;
  roomHeadings: string[];
  passengerKeys: string[];
  nightlyRateResults: NightlyRateResult[];
  discountInformations: DiscountInformation[];
  campaignInformations: CampaignInformation[];
  mealType: MealType;
  freeChildStatus?: any;
  cancellationPolicy: CancellationPolicy;
  restrictionList: RestrictionList[];
  addons: Addons[];
}

export interface Addons {
  description: string;
  icon: string;
  key: string;
  order: number;
  tooltip: string;
}
interface RestrictionList {
  key?: any;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
}

interface CancellationPolicy {
  key?: any;
  icon?: any;
  description: string;
  tooltip: string;
  refundable: boolean;
  cartDescription?: any;
}

interface MealType {
  key: string;
  icon?: any;
  description: string;
  tooltip?: any;
  order: number;
}

export interface DiscountInformation {
  price: string;
  key: string;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
}

export interface NightlyRateResult {
  date: string;
  basePrice: string;
  totalPrice: string;
  discount: string;
}

export interface Facility {
  name?: string;
  key: string;
  icon?: any;
  description: string;
  tooltip: string;
  order?: number;
  type?: string;
}
export interface RoomGroupResult {
  roomKeys: string[];
  type: number;
  key: string;
  useCancelWarranty: boolean;
  basePrice: string;
  totalPrice: string;
  discount: string;
  checkInDate: string;
  checkOutDate: string;
  masterHotelId: number;
  campaignInformations: CampaignInformation[];
  loyaltyItem?: any;
}

export interface CampaignInformation {
  key: string;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
}

export interface Season {
  id: number;
  name: string;
  isCurrent: boolean;
  startDate: string;
  endDate: string;
  mealTypes: MealType[];
  facilities: Facility[];
  descriptions?: Description[];
}

export interface Image {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl?: any;
}
interface Description {
  description: string;
  descriptionTypeId: number;
  descriptionTypeText: string;
  __typename: string;
}
