import type { IRetrieveDiscountCoupons } from "../../shared/eva-display-shared-types";
import { useStrategyMutation } from "../../strategy/strategy-runner.service";

interface IHotelRetrieveVariables {
  RetrieveRecordRequest: {
    transactionKey: string;
    cartId: string;
    searchId: string;
  };
}

export interface IHotelRetrieveResponse {
  resultString: string;
  bookingCode: string;
  descriptionList: string[];
  needHelp: string;
  relevantInformations: string;
  relevantInformationTitle: string;
  voucherButtonString: string;
  information: Information;
  hotelInformation: HotelInformation;
  priceSummary: PriceSummary;
  bookingInformation: BookingInformation;
  roomInformations: RoomInformation[];
  additionalProductInformation: AdditionalProductInformation;
  paymentType: string;
  isRecurringPayment: boolean;
  discountCoupons?: IRetrieveDiscountCoupons | null;
  optionDate?: any;
}

interface AdditionalProductInformation {
  caption: string;
  additionalProducts: AdditionalProducts[];
}

interface AdditionalProducts {
  totalPrice: string;
  basePrice: any;
  key: any;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
  isRequired: boolean;
}

interface RoomInformation {
  images: ShowcaseImage[];
  title: string;
  passengerDetail: Information;
  mealType: Information;
  bedType: Information;
  passengerNames: string;
  cancelWarranty?: any;
}

interface BookingInformation {
  caption: string;
  checkInString: string;
  checkInDate: string;
  checkInHour: string;
  checkOutString: string;
  checkOutDate: string;
  checkOutHour: string;
  accommodationCountString: string;
  accommodationCount: string;
}

interface PriceSummary {
  caption: string;
  roomsString: string;
  additionalProductString: string;
  discountString: string;
  totalPriceTitle: string;
  totalPrice: string;
  netPrice: string;
  taxPrice: string;
  totalPriceString: string;
  roomPrices: RoomPrice[];
  loyaltyItem?: LoyaltyItem;
  discounts?: Discount[];
}
export interface Discount {
  totalPrice: string;
  basePrice: null;
  key: null;
  icon: null;
  description: string;
  tooltip: null;
  order: number;
}

interface RoomPrice {
  totalPrice: string;
  basePrice: string;
  key?: any;
  icon?: any;
  description: string;
  tooltip?: any;
  order: number;
}

interface HotelInformation {
  showcaseImage: ShowcaseImage;
  caption: string;
  hotelName: string;
  address: string;
  phoneNumber: string;
  descriptionList: string[];
  latitude: number;
  longitude: number;
  location: string;
}

interface ShowcaseImage {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl?: any;
}

interface Information {
  key?: any;
  icon: string;
  description: string;
  tooltip?: any;
  order: number;
}

export interface LoyaltyItem {
  productKey: string;
  loyalities: Loyality[];
}

interface Loyality {
  key: string;
  value: number;
  productPrice: string;
  loyaltyPrice: string;
}

export const useHotelRetrieveMutation = () =>
  useStrategyMutation<IHotelRetrieveResponse, IHotelRetrieveVariables>({
    strategyKey: "retrieveHotel",
  });
