import type {
  IStrategyRunnerResponse,
  StrategyRunnerRequest,
} from "@/@types/types/strategy-service.types";
import type { IRoom } from "@/hooks/use-room/useRoom.types";

import type {
  RoomCollectionResult,
  RoomGroupResult,
} from "../hotel-detail/hotel-detail-services.types";

export type HotelSearchStrategyRequest =
  StrategyRunnerRequest<HotelSearchParameters>;

interface HotelSearchParameters {
  hotelSearchRequest: IHotelRoomSearchRequest;
}

export interface IHotelRoomSearchRequest {
  searchId?: any;
  requestKey?: any;
  countryCode: string;
  currency: string;
  checkInDate: string | null;
  checkOutDate: string | null;
  pageSize: number;
  pageNumber: number;
  orderBy: string;
  destinationId: number;
  destinationName?: string;
  destinationType: number;
  destinationSubType: number;
  rooms: IRoom[];
  filter: IHotelRoomSearchRequestFilter;
}

export enum FilterPropertyEnum {
  HOTEL_NAME = "hotelName",
  HOTEL_NAMES = "hotelNames",
  FACILITIES = "facilities",
  LOCATIONS = "locations",
  MEAL_TYPES = "mealTypes",
  THEMES = "themes",
  MAX_PRICES = "maxPrice",
  MIN_PRICES = "minPrice",
}
export type FilterPropertyType =
  | FilterPropertyEnum.HOTEL_NAME
  | FilterPropertyEnum.FACILITIES
  | FilterPropertyEnum.LOCATIONS
  | FilterPropertyEnum.MEAL_TYPES
  | FilterPropertyEnum.THEMES
  | FilterPropertyEnum.MIN_PRICES
  | FilterPropertyEnum.MAX_PRICES;
export interface IHotelRoomSearchRequestFilter {
  [FilterPropertyEnum.HOTEL_NAME]: string;
  [FilterPropertyEnum.FACILITIES]: string[];
  [FilterPropertyEnum.LOCATIONS]: string[];
  [FilterPropertyEnum.MEAL_TYPES]: string[];
  [FilterPropertyEnum.THEMES]: string[];
  [FilterPropertyEnum.MIN_PRICES]?: any;
  [FilterPropertyEnum.MAX_PRICES]?: any;
}

export interface IHotelRoomSearchRequestRoom {
  passengers: IHotelRoomSearchRequestRoomPassenger[];
}

export interface IHotelRoomSearchRequestRoomPassenger {
  passengerType: string;
  age?: number;
}

export type HotelRoomListStrategyResponse =
  IStrategyRunnerResponse<IHotelRoomListResult>;

interface IHotelRoomListResult {
  searchId: string;
  hotelName: string;
  checkInDate: string;
  checkOutDate: string;
  checkInHour: string;
  checkOutHour: string;
  destination: string;
  passportRequired: boolean;
  showcaseImage: ShowcaseImage;
  roomGroupResult: RoomGroupResult[];
  roomCollectionResult: RoomCollectionResult[];
  passengerList: PassengerList[];
  documentNumber?: string;
}

export interface PassengerList {
  key: string;
  age: number;
  type: number;
}
interface ShowcaseImage {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl: null;
}
