"use client";

import { useQuery } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { useLocale } from "@/hooks/useLocale";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import { hotelRoomSearchResultSerializer } from "./hotel-room-search-services.serializer";
import type { IHotelRoomSearchRequest } from "./hotel-room-search-services.types";

export const useHotelRoomSearchQuery = (
  hotelSearchRequest: IHotelRoomSearchRequest,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const { getCultureCode } = useLocale();

  const service = () =>
    http
      .post(
        `/api/v1/strategy/run?culture=${getCultureCode()}`,
        setParametersToStrategyRunner(
          {
            hotelSearchRequest,
          },
          strategyKeys.hotelRoomSearch,
        ),
      )
      .then((res) => hotelRoomSearchResultSerializer(res.data));

  return useQuery({
    queryFn: service,
    queryKey: ["widget-search"],
  });
};
