import type {
  IStrategyRunnerResponse,
  StrategyRunnerRequest,
} from "@/@types/types/strategy-service.types";
import type { IRoom } from "@/hooks/use-room/useRoom.types";

export type HotelSearchStrategyRequest =
  StrategyRunnerRequest<HotelSearchParameters>;

interface HotelSearchParameters {
  hotelSearchRequest: IHotelSearchRequest;
}

export interface IHotelSearchRequest {
  searchId?: any;
  requestKey?: any;
  countryCode: string;
  currency: string;
  checkInDate: string;
  checkOutDate: string;
  pageSize: number;
  pageNumber: number;
  orderBy: string;
  destinationId: number;
  destinationName?: string;
  destinationType: string;
  destinationSubType: string;
  rooms: IRoom[];
  filter: IHotelSearchRequestFilter;
  originCode?: string;
  originId?: string;
}

export enum FilterPropertyEnum {
  HOTEL_NAME = "hotelName",
  HOTEL_NAMES = "hotelNames",
  FACILITIES = "facilities",
  LOCATIONS = "locations",
  MEAL_TYPES = "mealTypes",
  THEMES = "themes",
  MAX_PRICES = "maxPrice",
  MIN_PRICES = "minPrice",
}
export type FilterPropertyType =
  | FilterPropertyEnum.HOTEL_NAME
  | FilterPropertyEnum.FACILITIES
  | FilterPropertyEnum.LOCATIONS
  | FilterPropertyEnum.MEAL_TYPES
  | FilterPropertyEnum.THEMES
  | FilterPropertyEnum.MIN_PRICES
  | FilterPropertyEnum.MAX_PRICES;
export interface IHotelSearchRequestFilter {
  [FilterPropertyEnum.HOTEL_NAME]: string;
  [FilterPropertyEnum.FACILITIES]: string[];
  [FilterPropertyEnum.LOCATIONS]: string[];
  [FilterPropertyEnum.MEAL_TYPES]: string[];
  [FilterPropertyEnum.THEMES]: string[];
  [FilterPropertyEnum.MIN_PRICES]?: any;
  [FilterPropertyEnum.MAX_PRICES]?: any;
}

export type HotelListStrategyResponse =
  IStrategyRunnerResponse<IHotelListResult>;

export interface IHotelListResult {
  searchId: string;
  requestKey: string;
  hasMorePage: boolean;
  totalHotelCount: number;
  items: IHotelListItem[];
  passengerList: HotelListPassengerList[];
  filterResult: HotelListFilterResult;
  documentNumber?: string;
}

export interface HotelListFilterResult {
  [FilterPropertyEnum.HOTEL_NAMES]: HotelListLocation[];
  [FilterPropertyEnum.FACILITIES]: HotelListLocation[];
  [FilterPropertyEnum.LOCATIONS]: HotelListLocation[];
  [FilterPropertyEnum.MEAL_TYPES]: HotelListLocation[];
  [FilterPropertyEnum.THEMES]: HotelListLocation[];
  [FilterPropertyEnum.MIN_PRICES]: number;
  [FilterPropertyEnum.MAX_PRICES]: number;
}

export interface HotelListLocation {
  key: string;
  value: string;
  selected: boolean;
  count: number;
}

export interface HotelListPassengerList {
  key: string;
  age: number;
  type: number;
}

export interface IHotelListItem {
  hotelId: number;
  key: string;
  name: string;
  location: string;
  recommended: boolean;
  isAlternative: boolean;
  onDemand: boolean;
  onDemandDescription?: any;
  mealTypes?: HotelListItemMealType[];
  cancellationPolicy?: HotelListItemCancellationPolicy;
  campaignInformations?: HotelListItemCampaignInformation[];
  images?: HotelListItemImage[];
  discountRate: number;
  discountRateDescription?: string;
  basePrice: string;
  totalPrice: string;
  totalPriceWithDiscount: string;
  totalPriceCast: string;
  accommodationDayCountInfo: string;
  hasHygienicalMeasure: boolean;
  passportRequired: boolean;
  loyaltyItem?: {
    productKey: string;
    loyalities: {
      key: string;
      value: number;
    }[];
  };
  priceDifferenceBackGuarantee: boolean;
  availableInstallment: string;
  discountInformations?: HotelListItemDiscountInformation[];
  documentNumber: null | string;
  documentType: number;
}

export interface HotelListItemDiscountInformation {
  price: string;
  key: string;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
}

interface HotelListItemImage {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl?: any;
}

export interface HotelListItemCampaignInformation {
  key: string;
  icon: string;
  description: string;
  tooltip: string;
  order: number;
}

interface HotelListItemCancellationPolicy {
  key?: any;
  icon?: any;
  description: string;
  tooltip?: any;
  refundable: boolean;
  cartDescription?: any;
}

export interface HotelListItemMealType {
  key: string;
  icon: string;
  description: string;
  tooltip?: any;
  order: number;
}
