import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  CarRentalAddToCartRequest,
  IRentACarAddToCartResponse,
} from "./rent-a-car-add-to-cart.types";
import { rentACarAddToCartSerializer } from "./rent-a-car-add-to-cart-service.serializer";

export const useRentACarAddToCart = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (rentACarRequest: CarRentalAddToCartRequest) =>
    http
      .post<IStrategyRunnerResponse<IRentACarAddToCartResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            CarRentalCartProductRequest: rentACarRequest,
          },
          strategyKeys.rentACarAddToCart,
        ),
      )
      .then((res) =>
        rentACarAddToCartSerializer(
          getResultFromStrategyResponse<IRentACarAddToCartResponse>(res.data),
        ),
      );

  return useMutation({
    mutationKey: ["rentACarAddToCart"],
    mutationFn: service,
  });
};
