import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  CarRentalDetailRequest,
  IRentACarDetailResponse,
} from "./rent-a-car-detail.types";
import { rentACarDetailSerializer } from "./rent-a-car-detail-service.serializer";

export const useRentACarDetail = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (rentACarRequest: CarRentalDetailRequest) =>
    http
      .post<IStrategyRunnerResponse<IRentACarDetailResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            CarRentalDetailRequest: rentACarRequest,
          },
          strategyKeys.rentACarDetail,
        ),
      )
      .then((res) =>
        rentACarDetailSerializer(
          getResultFromStrategyResponse<IRentACarDetailResponse>(res.data),
        ),
      );

  return useMutation({
    mutationKey: ["rentACarDetail"],
    mutationFn: service,
  });
};
