import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getServiceResponseFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  CarRentalCreateRequestRequest,
  IRentACarRequestCreateResponse,
} from "./rent-a-car-request-create.types";

export const useRentACarRequestCreate = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (rentACarRequest: CarRentalCreateRequestRequest) =>
    http
      .post<IStrategyRunnerResponse<IRentACarRequestCreateResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            CorpCreateCarRentalRequest: rentACarRequest,
          },
          strategyKeys.rentACarRequestCreate,
        ),
      )
      .then((res) =>
        getServiceResponseFromStrategyResponse<IRentACarRequestCreateResponse>(
          res.data,
        ),
      );

  return useMutation({
    mutationKey: ["rentACarRequestCreate"],
    mutationFn: service,
  });
};
