import { useStrategyMutation } from "../../strategy/strategy-runner.service";

interface IRentACarRetrieveVariables {
  RetrieveRecordRequest: {
    transactionKey: string;
    cartId: string;
    searchId: string;
  };
}

export interface IRentACarRetrieveResponse {
  resultString: string;
  bookingCode: string;
  descriptionList: string[];
  needHelp: null;
  relevantInformations: null;
  voucherButtonString: string;
  information: null;
  priceSummary: PriceSummary;
  saleCode: null;
  carExtraOption?: CarExtraOption[];
  carInsurances?: CarInsurance[];
  carRentalInformation: CarRentalInformation;
  bookingInformation: BookingInformation;
  paymentType: string;
  isRecurringPayment: boolean;
  discountCoupons: null;
}

interface BookingInformation {
  accommodationCount: string;
  accommodationCountString: string;
  caption: string;
  checkInString: string;
  checkOutString: string;
  checkInDate: string;
  checkOutDate: string;
  checkInHour: string;
  checkOutHour: string;
  pickupStation: string;
  returnStation: string;
}

interface CarRentalInformation {
  caption: string;
  carName: string;
  showcaseImage: string;
}

interface CarInsurance {
  code: string;
  calculateInfo: null;
  description: string;
  noOfUnits: number;
  totalPrice: string;
  unitPrice: string;
  selected: boolean;
}

interface CarExtraOption {
  code: string;
  calculateInfo: null;
  name: string;
  totalPrice: string;
  maxDay: number;
  unitPrice: string;
  selected: boolean;
}

interface PriceSummary {
  caption: string;
  additionalProductString: string;
  discountString: string;
  totalPriceTitle: null;
  totalPrice: string;
  netPrice: string;
  taxPrice: string;
  totalPriceString: string;
  loyaltyItem: null;
}

export const useRentACarRetrieveMutation = () =>
  useStrategyMutation<IRentACarRetrieveResponse, IRentACarRetrieveVariables>({
    strategyKey: "retrieveRentACar",
  });
