import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  IRentACarRequest,
  IRentACarSearchResponse,
} from "./rent-a-car-search.types";
import { rentACarSearchSerializer } from "./rent-a-car-search-service.serializer";

export const useRentACarSearch = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (rentACarRequest: IRentACarRequest) =>
    http
      .post<
        IStrategyRunnerResponse<IRentACarSearchResponse>
      >("/api/v1/strategy/run", setParametersToStrategyRunner(rentACarRequest, strategyKeys.rentACarList))
      .then((res) =>
        rentACarSearchSerializer(
          getResultFromStrategyResponse<IRentACarSearchResponse>(res.data),
        ),
      );

  return useMutation({
    mutationKey: ["rentACarSearch"],
    mutationFn: service,
  });
};
