import type { carRentalProviderImageUrl } from "@/components/widget/rent-a-car-card/rent-a-car-card";

export interface PassengerList {
  key: string;
  age: number;
  type: number;
}
export interface IRentACarSearchResponse {
  searchId: string;
  items: RentACarItem[];
  filter: IRentACarSearchResponseFilter;
  totalCount: number;
  hasMorePage: boolean;
  passengerList: PassengerList[];
}

export interface IRentACarSearchResponseFilter {
  priceMin: number;
  priceMax: number;
  isPriceSortedByDesc?: any;
  page: number;
  pageSize?: any;
  automaticTransmissionCount: number;
  manuelTransmissionCount: number;
  carTypeInformations: FilterListItemType[];
  carNameInformations: FilterListItemType[];
  ageLimitInformations: FilterListItemType[];
  passengerCountInformations: FilterListItemType[];
}

export interface FilterListItemType {
  key: string;
  value: string;
  selected: boolean;
  count: number;
}

export interface RentACarItem {
  key: string;
  carDetail: CarDetail;
  carIncluded: CarIncluded[];
  oneWay: string;
  locationFee: string;
  pickupStationKey?: any;
  returnStationKey?: any;
  totalPrice: string;
  equivalentTotalPrice: string;
  basePrice: string;
  taxes: string;
  discount: string;
  fee: Fee;
  commission: Commission;
  bankCampaingId?: any;
  posKey?: any;
  carRentalCompany: CarRentalCompany;
}

export interface Commission {
  code?: any;
  price: string;
  commissionType: number;
  commissionValue: number;
}

export interface Fee {
  code?: any;
  price: string;
}

export interface CarIncluded {
  code: string;
  name: string;
}

export interface CarRentalCompany {
  code: keyof typeof carRentalProviderImageUrl;
  name: string;
}

export interface CarDetail {
  ageLimit: number;
  fuelType: number;
  automaticTransmission: boolean;
  airConditioning: boolean;
  imageUrl: string;
  deposit: string;
  passengerCount: number;
  category: number;
  type: number;
  returnCode: string;
  returnId: string;
  returnDate: string;
  pickupCode: string;
  pickupId: string;
  pickupDate: string;
  name: string;
  doorCount: number;
  driverLicanseLimit: number;
}

export interface IRentACarRequest {
  CarRentalSearchRequest: CarRentalSearchRequest;
}

export interface CarRentalSearchRequest {
  SearchId?: any;
  PickupDateTime: string;
  ReturnDateTime: string;
  PickupStationId?: string;
  ReturnStationId?: string;
  DriverAge: number;
  SearchLeg: SearchLeg;
  Filter?: IRentACarRequestFilter;
}

export interface IRentACarRequestFilter {
  PriceMin?: number;
  PriceMax?: number;
  IsPriceSortedByDesc?: any;
  Page?: number;
  PageSize?: any;
  CarTypes?: number[];
  CarNames?: any[];
  DriverAgeLimits?: any[];
  PassengerCounts?: any[];
  AutomaticTransmission?: boolean | null;
}

export interface SearchLeg {
  PickupStationId: number;
  PickupStationType: number;
  ReturnStationId: number;
  ReturnStationType: number;
}
