import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { setParametersToStrategyRunner } from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type { ITourAddToCartResponse } from "./tour-add-to-card-services.types";
import { tourAddToCardSerializer } from "./tour-add-to-cart-services.serializer";

interface ITourAddToCartParameters {
  TourCartProductRequest: TourCartProductRequest;
}

interface TourCartProductRequest {
  searchId: string;
  productKey: string;
}

export const useTourAddToCartMutation = (
  options?: MutationOptions<ITourAddToCartResponse>,
) => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  const service = (variables: ITourAddToCartParameters) =>
    http
      .post(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(variables, strategyKeys.tourAddToCart),
      )
      .then((res) => tourAddToCardSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "tour-add-to-cart-mutation",
    ...options,
  });
};
