import { useStrategyMutation } from "../../strategy/strategy-runner.service";

interface ITourDetailVariables {
  TourDetailRequest: {
    searchId: string;
    ProductKey: string;
  };
}

export interface ITourDetailResponse {
  tourName: string;
  tourId: number;
  startDate: string;
  endDate: string;
  tourQuota: number;
  hasQuota: boolean;
  description: string;
  basePrice: string;
  totalPrice: string;
  onRequest: boolean;
  tourInformation: TourInformation;
  pricePeriods: PricePeriod[];
  hotelPeriods: HotelPeriod[];
  campaignInformations: CampaignInformation[];
}

export interface TourInformation {
  title: string;
  onRequest: boolean;
  closedGroup: boolean;
  boardType: string;
  currency: string;
  minDay: number;
  minNight: number;
  regionName: string;
  transportTypeName: string;
  transportReturnTypeName: string;
  tourProgram: TourProgram;
  tourDescriptions: TourDescription[];
  images: TourImage[];
  depaturePoints: DepaturePoint[];
}

export interface TourProgram {
  fullText: any;
  isShowFullText: boolean;
  dailyPrograms: DailyProgram[];
}

export interface DailyProgram {
  day: number;
  text?: string;
}

export interface TourDescription {
  title: string;
  text?: string;
  type: number;
}

export interface TourImage {
  categoryType: string;
  url: string;
  thumbnailUrl: string;
  highResolutionUrl: string;
}

export interface DepaturePoint {
  key: string;
  city: string;
  destination: string;
  name: string;
  time: string;
  isNextDay: boolean;
}

export interface PricePeriod {
  name: string;
  startDate: string;
  endDate: string;
  tourQuota: number;
  optionKey: number;
  priceDetail: PriceDetail;
}

export interface PriceDetail {
  singlePp: string;
  doublePp: string;
  extraBed: string;
  firstChild: string;
  secondChild: string;
  infant: string;
  singlePpDiscount: string;
  doublePpDiscount: string;
  extraBedDiscount: string;
  firstChildDiscount: string;
  secondChildDiscount: string;
  infantDiscount: string;
}

export interface HotelPeriod {
  tourCode: string;
  periodCode: string;
  startDate: string;
  endDate: string;
  options: Option[];
}

export interface Option {
  optionCode: string;
  optionName: string;
}

export interface CampaignInformation {
  code: string;
  name: string;
  startDate: string;
  endDate: string;
  priority: number;
  totalDiscount: string;
  discountPercent: any;
  campaignType: number;
  campaignUsage: number;
  used: boolean;
}

export const useTourDetailMutation = () =>
  useStrategyMutation<ITourDetailResponse, ITourDetailVariables>({
    strategyKey: "tourDetail",
  });
