import { useStrategyMutation } from "../../strategy/strategy-runner.service";

interface ITourRetrieveVariables {
  RetrieveRecordRequest: {
    transactionKey: string;
    cartId: string;
    searchId: string;
  };
}

export interface ITourRetrieveResponse {
  resultString: string;
  bookingCode: string;
  descriptionList: string[];
  needHelp: any;
  relevantInformations: any;
  voucherButtonString: string;
  tourInformation: TourInformation;
  priceSummary: PriceSummary;
  bookingInformation: BookingInformation;
  roomInformations: RoomInformation[];
  addons: any;
  additionalProductInformation: any;
}

export interface TourInformation {
  showcaseImage: string;
  caption: string;
  tourName: string;
}

export interface PriceSummary {
  caption: string;
  roomsString: string;
  additionalProductString: string;
  discountString: string;
  totalPrice: string;
  totalPriceString: string;
  discounts: Discount[];
}

export interface Discount {
  totalPrice: string;
  basePrice: string;
  key: any;
  icon: any;
  description: string;
  tooltip: any;
  order: number;
}

export interface BookingInformation {
  caption: string;
  checkInString: string;
  checkInDate: string;
  checkInHour: any;
  checkOutString: string;
  checkOutDate: string;
  checkOutHour: any;
  accommodationCountString: string;
  accommodationCount: string;
}

export interface RoomInformation {
  images: any;
  title: any;
  passengerNames: string;
  cancelWarranty: any;
}

export const useTourRetrieveMutation = () =>
  useStrategyMutation<ITourRetrieveResponse, ITourRetrieveVariables>({
    strategyKey: "retrieveTour",
  });
