/* eslint-disable no-console */
import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  ITourSearchRequest,
  ITourSearchResponse,
} from "./tour-search.types";
import { tourListSerializer } from "./tour-search-service.serializer";

export const useTourSearchMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (tourSearchRequest: ITourSearchRequest) =>
    http
      .post<IStrategyRunnerResponse<ITourSearchResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            tourSearchRequest,
          },
          strategyKeys.tourList,
        ),
      )
      .then((res) =>
        tourListSerializer(getResultFromStrategyResponse(res.data)),
      );

  return useMutation({
    mutationKey: ["tourSearch"],
    mutationFn: service,
  });
};

export const useTourDetailSearchMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (tourSearchRequest: ITourSearchRequest) =>
    http
      .post<IStrategyRunnerResponse<ITourSearchResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            tourSearchRequest,
          },
          strategyKeys.tourList,
        ),
      )
      .then((res) =>
        tourListSerializer(getResultFromStrategyResponse(res.data)),
      );

  return useMutation({
    mutationKey: ["tourDetailSearch"],
    mutationFn: service,
  });
};
