import type { IRoom } from "@/hooks/use-room/useRoom.types";

export interface ITourSearchResponse {
  searchId?: any;
  items: ITourSearchResponseItem[];
  filterResult: SearchFilter;
  hasMore: boolean;
  totalTourCount: number;
  totalCount: number;
  passengerList: PassengerList[];
}
export interface ITourSearchResponseItem {
  key: string;
  title: string;
  defaultThumbnailImageUrl: string;
  option: Option;
  depaturePoints: DepaturePoints[];
  allOptionList: TourOptionItem[];
  packageId: number;
}

export interface ITourSearchRequest {
  tourId: number;
  searchId: any;
  requestKey: any;
  pageSize: number;
  isPaging: boolean;
  isDomestic: boolean;
  resetPage: boolean;
  startDate: string;
  endDate: string;
  orderBy: number;
  categoryTypes: any;
  packageKeys: any;
  regions: any;
  destinations: any;
  keyword: string[] | null;
  cities: any;
  countries: any;
  currency: string;
  rooms: IRoom[];
  searchFilter: SearchFilter;
}

export interface PassengerList {
  key: string;
  age: number;
  type: number;
}

export interface SearchFilterListItem {
  key: string;
  value: string;
  selected: boolean;
  count: number;
}

export interface SearchFilter {
  regionValues: Array<SearchFilterListItem> | null;
  campaignFilterValues: Array<SearchFilterListItem> | null;
  transportTypeValues: Array<SearchFilterListItem> | null;
  minNightValues: Array<SearchFilterListItem> | null;
  categoryValues: Array<SearchFilterListItem> | null;
  roadRouteValues: Array<SearchFilterListItem> | null;
  minPrice: any;
  maxPrice: any;
}

export interface CampaignInformations {
  name: string;
}

export interface DepaturePoints {
  key: string;
  city: string;
  destination: string;
  name: string;
  time: string;
  isNextDay: boolean;
}

export interface Option {
  packageId: number;
  tourId: number;
  key: string;
  title: string;
  tourName: string;
  startDate: string;
  endDate: string;
  optionKey: number;
  onRequest: boolean;
  closedGroup: boolean;
  boardType: string;
  campaignTypeValue: number;
  currency: string;
  minDay: number;
  minNight: number;
  orderScore: number;
  isDailyTour: boolean;
  tourType: any;
  transportType: string;
  transportReturnType: string;
  regionId: number;
  regionName: string;
  tourQuota: number;
  hasQuota: boolean;
  basePrice: string;
  totalPrice: string;
  defaultThumbnailImageUrl: string;
  discountRate: number;
  discountRateDescription: any;
  importantNotes: any;
  campaignInformations: CampaignInformation[];
  services: Service[];
  priceDetail: PriceDetail;
}

export interface CampaignInformation {
  code: string;
  name: string;
  startDate: string;
  endDate: string;
  priority: number;
  totalDiscount: string;
  discountPercent: any;
  campaignType: number;
  campaignUsage: number;
  used: boolean;
}

export interface Service {
  key: string;
  passengerKey: string;
  name: string;
  type: string;
  typeValue: number;
  sourceKey: number;
  totalPrice: string;
  saleDiscount: string;
  isMandatory: boolean;
  isOptional: boolean;
}

export interface PriceDetail {
  singlePp: string;
  doublePp: string;
  extraBed: string;
  firstChild: string;
  secondChild: string;
  infant: string;
  singlePpDiscount: string;
  doublePpDiscount: string;
  extraBedDiscount: string;
  firstChildDiscount: string;
  secondChildDiscount: string;
  infantDiscount: string;
}

export interface TourOptionItem {
  packageId: number;
  tourId: number;
  key: string;
  title: string;
  tourName: string;
  startDate: string;
  endDate: string;
  optionKey: number;
  onRequest: boolean;
  closedGroup: boolean;
  boardType: string;
  campaignTypeValue: number;
  currency: string;
  minDay: number;
  minNight: number;
  orderScore: number;
  isDailyTour: boolean;
  tourType: any;
  transportType: string;
  transportReturnType: string;
  regionId: number;
  regionName: string;
  tourQuota: number;
  hasQuota: boolean;
  basePrice: string;
  totalPrice: string;
  defaultThumbnailImageUrl: string;
  discountRate: number;
  discountRateDescription: any;
  importantNotes: any;
  campaignInformations: CampaignInformation[];
  services: Service[];
  priceDetail: PriceDetail;
}
