import { useMutation } from "react-query";

import type { IStrategyRunnerResponse } from "@/@types/types/strategy-service.types";
import { useHttp } from "@/hooks/useHttp";
import {
  getResultFromStrategyResponse,
  setParametersToStrategyRunner,
} from "@/libs/helpers/strategy-service.helper";
import { useServerDataCtx } from "@/providers/server-data-provider/server-data-provider";

import type {
  ITransferSearchRequest,
  ITransferSearchResponse,
} from "./transfer-search.types";
import { transferListSerializer } from "./transfer-search-service.serializer";

export const useTransferSearchMutation = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");
  const service = (transferSearchRequest: ITransferSearchRequest) =>
    http
      .post<IStrategyRunnerResponse<ITransferSearchResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            transferSearchRequest,
          },
          strategyKeys.transferList,
        ),
      )
      .then((res) =>
        transferListSerializer(getResultFromStrategyResponse(res.data)),
      );

  return useMutation({
    mutationFn: service,
  });
};

export const useTransferListService = () => {
  const { strategyKeys } = useServerDataCtx();
  const http = useHttp("wl-display-api");

  function getTransferListService(
    transferSearchRequest: ITransferSearchRequest,
  ) {
    return http
      .post<IStrategyRunnerResponse<ITransferSearchResponse>>(
        "/api/v1/strategy/run",
        setParametersToStrategyRunner(
          {
            transferSearchRequest,
          },
          strategyKeys.transferList,
        ),
      )
      .then((res) =>
        transferListSerializer(getResultFromStrategyResponse(res.data)),
      );
  }

  return { getTransferListService };
};
