import { useQuery } from "react-query";

import { useHttp } from "@/hooks/useHttp";
import { useLocale } from "@/hooks/useLocale";

interface IGetUsetSettingsResponse {
  errors: any[];
  warnings: any[];
  informations: any[];
  success: boolean;
  Result: Result[];
}

export interface Result {
  SettingId: number;
  SettingName: string;
  PropertyId: number;
  PropertyName: string;
  PropertyDescription: string;
  PropertyType: number;
  PropertyOrder: number;
  PropertyValue: string;
  PropertyValueDescription: null;
  PropertyValueId: number;
  PropertyValueStatus: number;
  CreateDate: string;
  UpdateDate: string;
  SettingType: number;
  DefaultValues: null;
  CulturedSettingName: string;
  CulturedPropertyName: string;
  CulturedPropertyDescription: string;
  CulturedPropertyValue: string;
  CulturedPropertyValueDescription: null;
}

export const useGetUsetSettingsQuery = () => {
  const http = useHttp("eva-panel-api");
  const { getCultureCode } = useLocale();

  const service = () =>
    http
      .get<IGetUsetSettingsResponse>(
        `/api/setting/getusersettings?culture=${getCultureCode()}&v=2`,
      )
      .then((res) => res.data);

  return useQuery({
    queryFn: service,
    queryKey: "get-user-settings",
  });
};
