import { useMutation } from "react-query";

import { useEnv } from "@/hooks/useEnv";
import { useHttp } from "@/hooks/useHttp";

interface IHotelSearchResponseDTO {
  adjustName: string;
  categoryName: string;
  isDomestic: boolean;
  code?: any;
  typeCode: number;
  typeName: string;
  externalData?: any;
  id: number;
  image?: any;
  latitude: number;
  longitude: number;
  productCount: number;
  selected: number;
  value: string;
  destinationId: number;
  destinationType: number;
  destinationBreadCrumb: string;
}

export const useTpSearchMutation = () => {
  const envs = useEnv();
  const http = useHttp("wl-display-api");
  const service = (variables: {
    query: string;
    type:
      | "DomesticHotelPlanner"
      | "FlightPlanner"
      | "HotelPlanner"
      | "DomesticTourPlanner"
      | "AbroadTourPlanner"
      | "TransferPlanner"
      | "CarRentalPlanner";
  }) =>
    http.get<IHotelSearchResponseDTO[]>(
      `${envs.wlDisplayUrl}/api/v1/Shared/Search`,
      {
        params: {
          key: variables.query,
          type: variables.type,
        },
      },
    );

  return useMutation({
    mutationFn: service,
    mutationKey: "hotelSearch",
  });
};
