import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { getEnvs } from "@/libs/environment/env";

import type { DeleteCardPayload } from "./delete-card-services.types";
import { DeleteCardSerializer } from "./delete-card-services-serializer";

export const useDeleteCardMutation = (options?: MutationOptions<any>) => {
  const http = useHttp("masterpass-api");
  const env = getEnvs();

  const service = (variables: DeleteCardPayload) =>
    http
      .post("/deleteCard", {
        timeZone: "+01",
        uiChannelType: "6",
        mobileAccountConfig: "MWA",
        sendSms: env.masterpassSendSms,
        mmrpConfig: "110010",
        identityVerificationFlag: "Y",
        eActionType: "A",
        delinkReason: "",
        actionType: "A",
        defaultAccount: "Y",
        cpinFlag: "Y",
        cardTypeFlag: "05",
        fp: "",
        dateTime: new Date().toISOString(),
        token: variables.token, // masterpassUserData.token,
        msisdn: variables.msisdn, // masterpassUserData.msisdn,;
        accountAliasName: variables.accountAliasName, // kart için girilen özel isim;
        serviceUrl: env.masterpassUrl,
        clientId: env.masterpassClientId,
        version: env.masterpassVersion,
        clientType: env.masterpassClientType,
        sendSmsLanguage: env.masterpassSendSmsLanguage,
        clientIp: "",
      })
      .then((res) => DeleteCardSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "delete-card-mutation",
    ...options,
  });
};
