import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { getEnvs } from "@/libs/environment/env";

import { InitiateManageRecurringPaymentSerializer } from "./initiate-manage-recurring-payment-services.serializer";
import type { InitiateManageRecurringPaymentPayload } from "./initiate-manage-recurring-payment-services.types";

export const useInitiateManageRecurringPaymentMutation = (
  options?: MutationOptions<any>,
) => {
  const http = useHttp("masterpass-api");
  const env = getEnvs();

  const service = (variables: InitiateManageRecurringPaymentPayload) =>
    http
      .post("/initiateManageRecurringPayment", {
        productId: variables.productId, // cartId
        endDate: "",
        amount: variables.amount, // sonra ödenecek tutar
        listAccountName: variables.listAccountName, // card name
        token: variables.token, // store token
        msisdn: variables.msisdn, // mssind
        actionType: "A",
        sendSms: "Y",
        fp: "",
        referenceNo: variables.referenceNo, // store refenceNumber
        dateTime: new Date().toISOString(),
        orderNo: variables.orderNo, // store recurringOrderId
        serviceUrl: env.masterpassUrl,
        clientId: env.masterpassClientId,
        version: env.masterpassVersion,
        clientType: env.masterpassClientType,
        sendSmsLanguage: env.masterpassSendSmsLanguage,
        clientIp: "",
      })
      .then((res) => InitiateManageRecurringPaymentSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "initiate-manage-recurring-payment",
    ...options,
  });
};
