import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { getEnvs } from "@/libs/environment/env";

import type { LinkCardToClientPayload } from "./link-card-to-client-services.types";
import { LinkCardToClientSerializer } from "./link-card-to-client-services-serializer";

export const useLinkCardToClientMutation = (options?: MutationOptions<any>) => {
  const http = useHttp("masterpass-api");
  const env = getEnvs();

  const service = (variables: LinkCardToClientPayload) =>
    http
      .post("/linkCardToClient", {
        sendSms: env.masterpassSendSms,
        referenceNo: variables.referenceNo, // masterpassUserData.referenceNo,
        cardAliasName: "",
        fp: "",
        dateTime: new Date().toISOString(), // anlık zaman
        token: variables.token, // masterpassUserData.token,
        msisdn: variables.msisdn, // masterpassUserData.msisdn,
        serviceUrl: env.masterpassUrl,
        clientId: env.masterpassClientId,
        version: env.masterpassVersion,
        clientType: env.masterpassClientType,
        sendSmsLanguage: env.masterpassSendSmsLanguage,
        clientIp: "",
      })
      .then((res) => LinkCardToClientSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "link-card-to-client-mutation",
    ...options,
  });
};
