import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { getEnvs } from "@/libs/environment/env";

import { listManagementResultSerializer } from "./list-management-services-serializer";
import type { ListManagementPayload } from "./list-management-services-types";

export const useListManagementMutation = (options?: MutationOptions<any>) => {
  const http = useHttp("masterpass-api");
  const env = getEnvs();

  const service = (variables: ListManagementPayload) =>
    http
      .post("/listManagement", {
        listType: "ACCOUNT",
        sendSms: env.masterpassSendSms,
        referenceNo: variables.referenceNo, // masterpassUserData.referenceNo, bu 0000 girilmiş önceki projede
        dateTime: new Date().toISOString(), // anlık zaman
        token: variables.token, // masterpassUserData.token,
        msisdn: variables.msisdn, // masterpassUserData.msisdn,
        serviceUrl: env.masterpassUrl,
        clientId: env.masterpassClientId,
        version: env.masterpassVersion,
        clientType: env.masterpassClientType,
        sendSmsLanguage: env.masterpassSendSmsLanguage,
        clientIp: "",
      })
      .then((res) => listManagementResultSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "list-management-mutation",
    ...options,
  });
};
