import { useMutation } from "react-query";

import type { MutationOptions } from "@/@types/types/query.types";
import { useHttp } from "@/hooks/useHttp";
import { getEnvs } from "@/libs/environment/env";

import type { UpdateUserPayload } from "./update-user-services.types";
import { UpdateUserResultSerializer } from "./update-user-services-serializer";

export const useUpdateUserMutation = (options?: MutationOptions<any>) => {
  const http = useHttp("masterpass-api");
  const env = getEnvs();

  const service = (variables: UpdateUserPayload) =>
    http
      .post("/updateUser", {
        sendSms: env.masterpassSendSms,
        valueType: "USER_ID",
        theNewValue: variables.theNewValue, // masterpassUserData.userId,
        fp: "",
        dateTime: new Date().toISOString(), // anlık zaman
        msisdn: variables.msisdn, // masterpassUserData.msisdn,
        token: variables.token, // masterpassUserData.token,
        referenceNumber: variables.referenceNumber, // masterpassUserData.referenceNo,
        serviceUrl: env.masterpassUrl,
        clientId: env.masterpassClientId,
        version: env.masterpassVersion,
        clientType: env.masterpassClientType,
        sendSmsLanguage: env.masterpassSendSmsLanguage,
        clientIp: "",
      })
      .then((res) => UpdateUserResultSerializer(res.data));

  return useMutation({
    mutationFn: service,
    mutationKey: "update-user-mutation",
    ...options,
  });
};
