import { useQuery } from "react-query";

import { useHttp } from "@/hooks/useHttp";

interface IClientConfigurationResponse {
  errors: any[];
  warnings: any[];
  informations: any[];
  success: boolean;
  result: Result;
}

export interface Result {
  domainType: string;
  domainState: number;
  clientScope: string;
  favIconUrl: string;
  logoUrl: string;
  logoWidth: number;
  logoHeight: number;
  properties: Properties;
  domainProducts: any[];
}

export interface Properties {
  fontFamily: string;
  borderRadius: string;
  color: string;
  fontSize: string;
  fontStyle: string;
  fontWeight: string;
  lineHeight: string;
  textDecorationLine: string;
  linkcolor: string;
  linktype: string;
  mainpage?: string;
}

export const useClientConfigurationQuery = () => {
  const http = useHttp("wl-display-api");

  const service = () =>
    http
      .get<IClientConfigurationResponse>("/api/clientconfiguration/get")
      .then((res) => res.data);

  return useQuery({
    queryFn: service,
    queryKey: "client-configuration",
  });
};
