import { useDispatch, useSelector } from "react-redux";

import { storageManager } from "@/libs/storage-manager";

import type { RootState } from "../store";
import { masterpassActions } from "./masterpass.slice";
import type { IMasterpassStore } from "./masterpass-store.types";

export const useMasterpassStore = () => {
  const masterpassState = useSelector<RootState, IMasterpassStore>(
    (state) => state.masterpass,
  );
  const dispatch = useDispatch();

  function setMasterpassData(masterpassData: IMasterpassStore["data"]) {
    storageManager.set("masterpass", {
      moduleName: masterpassData?.moduleName,
      payload: { ...masterpassData?.payload },
    });
    dispatch(masterpassActions.setMasterpassData(masterpassData));
  }

  function setModuleData(moduleData: IMasterpassStore["data"]) {
    dispatch(masterpassActions.setModuleData(moduleData));
  }

  return {
    masterpassState,
    setMasterpassData,
    setModuleData,
  };
};
