import { useDispatch, useSelector } from "react-redux";

import type { RootState } from "../store";
import { paymentActions } from "./payment.slice";
import type { IPaymentStore } from "./payment-store.types";

export const usePaymentStore = () => {
  const paymentState = useSelector<RootState, IPaymentStore>(
    (state) => state.payment,
  );
  const dispatch = useDispatch();

  function setPaymentData(paymentData: IPaymentStore["data"]) {
    dispatch(paymentActions.setPaymentData(paymentData));
  }

  function setModuleData(moduleData: IPaymentStore["data"]) {
    dispatch(paymentActions.setModuleData(moduleData));
  }

  function resetPaymentStore() {
    dispatch(paymentActions.clearPaymentData());
  }

  return {
    paymentState,
    setPaymentData,
    setModuleData,
    resetPaymentStore,
  };
};
