import { useDispatch, useSelector } from "react-redux";

import type { RootState } from "../store";
import { summaryActions } from "./summary.slice";
import type { ISummaryStore } from "./summary-store.types";

export const useSummaryStore = () => {
  const summaryState = useSelector<RootState, ISummaryStore>(
    (state) => state.summary,
  );
  const dispatch = useDispatch();

  function setSummaryData(summaryData: ISummaryStore["data"]) {
    dispatch(summaryActions.setSummaryData(summaryData));
  }

  function setModuleData(moduleData: ISummaryStore["data"]) {
    dispatch(summaryActions.setModuleData(moduleData));
  }

  function resetSummaryStore() {
    dispatch(summaryActions.clearSummaryData());
  }

  return {
    summaryState,
    setSummaryData,
    setModuleData,
    resetSummaryStore,
  };
};
